@@ -26,33 +26,24 @@ get_cmake_version(){
   CMAKE_REVISION=$(echo "$CMAKE_VERSION" | cut -d. -f3)
 }
 
-add_option(){
-  eval "$1=$2"
-  OPTIONS+=("$1")
-  CMAKE_OPTIONS_ENABLED+=("$1:$3")
-  CMAKE_OPTIONS_DISABLED+=("$1:$4")
-}
-
-add_enabled_option(){
-  eval "$1=$2"
-  OPTIONS+=("$1")
-  CMAKE_OPTIONS_DISABLED+=("$1:$3")
-}
 add_cmake_option(){
   eval "$1=$2"
 }
 
-add_disabled_option(){
-  eval "$1=$2"
-  OPTIONS+=("$1")
-  CMAKE_OPTIONS_ENABLED+=("$1:$3")
+add_option(){
+  BOOTSTRAP_OPTION_NAME="$1"
+  DEFAULT_VALUE="$2"
+  CMAKE_OPTION_NAME="$3"
+  eval "$BOOTSTRAP_OPTION_NAME=$DEFAULT_VALUE"
+  OPTIONS+=("$BOOTSTRAP_OPTION_NAME")
+  CMAKE_OPTIONS+=("$BOOTSTRAP_OPTION_NAME:$CMAKE_OPTION_NAME")
   if [ -n "$4" ]; then
-    CMAKE_MIN_VERSION+=("$1:$4")
+    CMAKE_MIN_VERSION+=("$BOOTSTRAP_OPTION_NAME:$4")
   fi
 
   if [ -n "$5" ]; then
     if [ "$5" = "true" ]; then
-      DEPLOY_LIMITS+=("$1")
+      DEPLOY_LIMITS+=("$BOOTSTRAP_OPTION_NAME")
     fi
   fi
 }
@@ -395,6 +386,8 @@ show_supported_features() {
   echo "AB. Kubernetes Support .........$(print_feature_status KUBERNETES_ENABLED)"
   echo "AC. Google Cloud Support .......$(print_feature_status GCP_ENABLED)"
   echo "AD. ProcFs Support .............$(print_feature_status PROCFS_ENABLED)"
+  echo "AE. Prometheus Support .........$(print_feature_status PROMETHEUS_ENABLED)"
+  echo "AF. Elasticsearch Support ......$(print_feature_status ELASTIC_ENABLED)"
   echo "****************************************"
   echo "            Build Options."
   echo "****************************************"
@@ -417,7 +410,7 @@ show_supported_features() {
 
 read_feature_options(){
   local choice
-  echo -n "Enter choice [A-Z or AA-AD or 1-7] "
+  echo -n "Enter choice [A-Z or AA-AF or 1-7] "
   read -r choice
   choice=$(echo "${choice}" | tr '[:upper:]' '[:lower:]')
   case $choice in
@@ -453,6 +446,8 @@ read_feature_options(){
     ab) ToggleFeature KUBERNETES_ENABLED ;;
     ac) ToggleFeature GCP_ENABLED ;;
     ad) ToggleFeature PROCFS_ENABLED ;;
+    ae) ToggleFeature PROMETHEUS_ENABLED ;;
+    af) ToggleFeature ELASTIC_ENABLED ;;
     1) ToggleFeature TESTS_ENABLED ;;
     2) EnableAllFeatures ;;
     3) ToggleFeature JNI_ENABLED;;
@@ -471,7 +466,7 @@ read_feature_options(){
       fi
       ;;
     q) exit 0;;
-    *) echo -e "${RED}Please enter an option A-Z or AA-AD or 1-7...${NO_COLOR}" && sleep 2
+    *) echo -e "${RED}Please enter an option A-Z or AA-AF or 1-7...${NO_COLOR}" && sleep 2
   esac
 }
 
