@@ -26,6 +26,21 @@ class Cluster(object):
         Deploys a flow to the cluster.
         """
 
+    def stop_flow(self, container_name):
+        """
+        Stops a flow in the cluster.
+        """
+
+    def kill_flow(self, container_name):
+        """
+        Kills (ungracefully stops) a flow in the cluster.
+        """
+
+    def restart_flow(self, container_name):
+        """
+        Stops a flow in the cluster.
+        """
+
     def __enter__(self):
         """
         Allocate ephemeral cluster resources.
