@@ -16,11 +16,12 @@
 
 from minifi.core.FileSystemObserver import FileSystemObserver
 from minifi.core.RemoteProcessGroup import RemoteProcessGroup
-from minifi.core.SSL_cert_utils import gen_cert, rsa_gen_key_callback, make_ca, make_cert, dump_certificate, dump_privatekey
+from minifi.core.SSL_cert_utils import make_ca, make_cert, dump_certificate, dump_privatekey
 from minifi.core.Funnel import Funnel
 
 from minifi.controllers.SSLContextService import SSLContextService
 from minifi.controllers.GCPCredentialsControllerService import GCPCredentialsControllerService
+from minifi.controllers.ElasticsearchCredentialsService import ElasticsearchCredentialsService
 from minifi.controllers.ODBCService import ODBCService
 from minifi.controllers.KubernetesControllerService import KubernetesControllerService
 
@@ -266,10 +267,17 @@ def step_impl(context):
 
 
 @given("a file with the content \"{content}\" is present in \"{path}\"")
+@then("a file with the content \"{content}\" is placed in \"{path}\"")
 def step_impl(context, content, path):
     context.test.add_test_data(path, content)
 
 
+@given("{number_of_files:d} files with the content \"{content}\" are present in \"{path}\"")
+def step_impl(context, number_of_files, content, path):
+    for i in range(0, number_of_files):
+        context.test.add_test_data(path, content)
+
+
 @given("an empty file is present in \"{path}\"")
 def step_impl(context, path):
     context.test.add_test_data(path, "")
@@ -327,21 +335,31 @@ def step_impl(context):
 # TLS
 @given("an ssl context service set up for {producer_name} and {consumer_name}")
 def step_impl(context, producer_name, consumer_name):
-    cert, key = gen_cert()
-    crt_file = '/tmp/resources/test-crt.pem'
-    ssl_context_service = SSLContextService(cert=crt_file, ca_cert=crt_file)
-    context.test.put_test_resource('test-crt.pem', cert.as_pem() + key.as_pem(None, rsa_gen_key_callback))
+    root_ca_cert, root_ca_key = make_ca("root CA")
+    minifi_cert, minifi_key = make_cert("minifi-cpp-flow", root_ca_cert, root_ca_key)
+    secondary_cert, secondary_key = make_cert("secondary", root_ca_cert, root_ca_key)
+    secondary_pem_file = '/tmp/resources/secondary.pem'
+    minifi_crt_file = '/tmp/resources/minifi-cpp-flow.crt'
+    minifi_key_file = '/tmp/resources/minifi-cpp-flow.key'
+    root_ca_crt_file = '/tmp/resources/root_ca.pem'
+    ssl_context_service = SSLContextService(cert=minifi_crt_file, ca_cert=root_ca_crt_file, key=minifi_key_file)
+    context.test.put_test_resource('secondary.pem', dump_certificate(secondary_cert) + dump_privatekey(secondary_key))
+    context.test.put_test_resource('minifi-cpp-flow.crt', dump_certificate(minifi_cert))
+    context.test.put_test_resource('minifi-cpp-flow.key', dump_privatekey(minifi_key))
+    context.test.put_test_resource('root_ca.pem', dump_certificate(root_ca_cert))
+
     producer = context.test.get_node_by_name(producer_name)
     producer.controller_services.append(ssl_context_service)
     producer.set_property("SSL Context Service", ssl_context_service.name)
     consumer = context.test.get_node_by_name(consumer_name)
-    consumer.set_property("SSL Certificate", crt_file)
-    consumer.set_property("SSL Verify Peer", "no")
+    consumer.set_property("SSL Certificate Authority", root_ca_crt_file)
+    consumer.set_property("SSL Certificate", secondary_pem_file)
+    consumer.set_property("SSL Verify Peer", "yes")
 
 
 @given("an ssl context service set up for {producer_name}")
 def step_impl(context, producer_name):
-    ssl_context_service = SSLContextService(cert="/tmp/resources/certs/client_LMN_client.pem", ca_cert="/tmp/resources/certs/ca-cert", key="/tmp/resources/certs/client_LMN_client.key", passphrase="abcdefgh")
+    ssl_context_service = SSLContextService(cert="/tmp/resources/certs/client_cert.pem", ca_cert="/tmp/resources/certs/ca-cert", key="/tmp/resources/certs/client_cert.key", passphrase="abcdefgh")
     producer = context.test.get_node_by_name(producer_name)
     producer.controller_services.append(ssl_context_service)
     producer.set_property("SSL Context Service", ssl_context_service.name)
@@ -377,6 +395,7 @@ def step_impl(context):
 
 # MQTT setup
 @given("an MQTT broker is set up in correspondence with the PublishMQTT")
+@given("an MQTT broker is set up in correspondence with the ConsumeMQTT")
 @given("an MQTT broker is set up in correspondence with the PublishMQTT and ConsumeMQTT")
 def step_impl(context):
     context.test.acquire_container("mqtt-broker", "mqtt-broker")
@@ -410,12 +429,74 @@ def step_impl(context):
     context.test.acquire_container("fake-gcs-server", "fake-gcs-server")
 
 
+# elasticsearch
+@given('an Elasticsearch server is set up and running')
+@given('an Elasticsearch server is set up and a single document is present with "preloaded_id" in "my_index"')
+@given('an Elasticsearch server is set up and a single document is present with "preloaded_id" in "my_index" with "value1" in "field1"')
+def step_impl(context):
+    context.test.start_elasticsearch()
+    context.test.create_doc_elasticsearch("elasticsearch", "my_index", "preloaded_id")
+
+
+# opensearch
+@given('an Opensearch server is set up and running')
+@given('an Opensearch server is set up and a single document is present with "preloaded_id" in "my_index"')
+@given('an Opensearch server is set up and a single document is present with "preloaded_id" in "my_index" with "value1" in "field1"')
+def step_impl(context):
+    context.test.start_opensearch()
+    context.test.add_elastic_user_to_opensearch("opensearch")
+    context.test.create_doc_elasticsearch("opensearch", "my_index", "preloaded_id")
+
+
+@given(u'a SSL context service is set up for PostElasticsearch and Elasticsearch')
+def step_impl(context):
+    minifi_crt_file = '/tmp/resources/elasticsearch/minifi_client.crt'
+    minifi_key_file = '/tmp/resources/elasticsearch/minifi_client.key'
+    root_ca_crt_file = '/tmp/resources/elasticsearch/root_ca.crt'
+    ssl_context_service = SSLContextService(cert=minifi_crt_file, ca_cert=root_ca_crt_file, key=minifi_key_file)
+    post_elasticsearch_json = context.test.get_node_by_name("PostElasticsearch")
+    post_elasticsearch_json.controller_services.append(ssl_context_service)
+    post_elasticsearch_json.set_property("SSL Context Service", ssl_context_service.name)
+
+
+@given(u'a SSL context service is set up for PostElasticsearch and Opensearch')
+def step_impl(context):
+    root_ca_crt_file = '/tmp/resources/opensearch/root-ca.pem'
+    ssl_context_service = SSLContextService(ca_cert=root_ca_crt_file)
+    post_elasticsearch_json = context.test.get_node_by_name("PostElasticsearch")
+    post_elasticsearch_json.controller_services.append(ssl_context_service)
+    post_elasticsearch_json.set_property("SSL Context Service", ssl_context_service.name)
+
+
+@given(u'an ElasticsearchCredentialsService is set up for PostElasticsearch with Basic Authentication')
+def step_impl(context):
+    elasticsearch_credential_service = ElasticsearchCredentialsService()
+    post_elasticsearch_json = context.test.get_node_by_name("PostElasticsearch")
+    post_elasticsearch_json.controller_services.append(elasticsearch_credential_service)
+    post_elasticsearch_json.set_property("Elasticsearch Credentials Provider Service", elasticsearch_credential_service.name)
+
+
+@given(u'an ElasticsearchCredentialsService is set up for PostElasticsearch with ApiKey')
+def step_impl(context):
+    api_key = context.test.elastic_generate_apikey("elasticsearch")
+    elasticsearch_credential_service = ElasticsearchCredentialsService(api_key)
+    post_elasticsearch_json = context.test.get_node_by_name("PostElasticsearch")
+    post_elasticsearch_json.controller_services.append(elasticsearch_credential_service)
+    post_elasticsearch_json.set_property("Elasticsearch Credentials Provider Service", elasticsearch_credential_service.name)
+
+
 # splunk hec
 @given("a Splunk HEC is set up and running")
 def step_impl(context):
     context.test.start_splunk()
 
 
+# TCP client
+@given('a TCP client is set up to send a test TCP message to minifi')
+def step_impl(context):
+    context.test.acquire_container("tcp-client", "tcp-client")
+
+
 @given("SSL is enabled for the Splunk HEC and the SSL context service is set up for PutSplunkHTTP and QuerySplunkIndexingStatus")
 def step_impl(context):
     root_ca_cert, root_ca_key = make_ca("root CA")
@@ -509,6 +590,27 @@ def step_impl(context):
     context.test.start()
 
 
+@then("\"{container_name}\" flow is stopped")
+def step_impl(context, container_name):
+    context.test.stop(container_name)
+
+
+@then("\"{container_name}\" flow is killed")
+def step_impl(context, container_name):
+    context.test.kill(container_name)
+
+
+@then("\"{container_name}\" flow is restarted")
+def step_impl(context, container_name):
+    context.test.restart(container_name)
+
+
+@when("\"{container_name}\" flow is started")
+@then("\"{container_name}\" flow is started")
+def step_impl(context, container_name):
+    context.test.start(container_name)
+
+
 @when("content \"{content}\" is added to file \"{file_name}\" present in directory \"{path}\" {seconds:d} seconds later")
 def step_impl(context, content, file_name, path, seconds):
     time.sleep(seconds)
@@ -537,8 +639,8 @@ def step_impl(context, content, topic_name):
         "bootstrap.servers": "localhost:29093",
         "security.protocol": "ssl",
         "ssl.ca.location": os.path.join(test_dir, "resources/kafka_broker/conf/certs/ca-cert"),
-        "ssl.certificate.location": os.path.join(test_dir, "resources/kafka_broker/conf/certs/client_LMN_client.pem"),
-        "ssl.key.location": os.path.join(test_dir, "resources/kafka_broker/conf/certs/client_LMN_client.key"),
+        "ssl.certificate.location": os.path.join(test_dir, "resources/kafka_broker/conf/certs/client_cert.pem"),
+        "ssl.key.location": os.path.join(test_dir, "resources/kafka_broker/conf/certs/client_cert.key"),
         "ssl.key.password": "abcdefgh",
         "client.id": socket.gethostname()})
     producer.produce(topic_name, content.encode("utf-8"), callback=delivery_report)
@@ -621,8 +723,9 @@ def step_impl(context):
 
 @then("a flowfile with the content \"{content}\" is placed in the monitored directory in less than {duration}")
 @then("a flowfile with the content '{content}' is placed in the monitored directory in less than {duration}")
-def step_impl(context, content, duration):
-    context.test.check_for_single_file_with_content_generated(content, timeparse(duration))
+@then("{number_of_flow_files:d} flowfiles with the content \"{content}\" are placed in the monitored directory in less than {duration}")
+def step_impl(context, content, duration, number_of_flow_files=1):
+    context.test.check_for_multiple_files_generated(number_of_flow_files, timeparse(duration), [content])
 
 
 @then("a flowfile with the JSON content \"{content}\" is placed in the monitored directory in less than {duration}")
@@ -778,7 +881,12 @@ def step_impl(context, log_message, duration):
 # MQTT
 @then("the MQTT broker has a log line matching \"{log_pattern}\"")
 def step_impl(context, log_pattern):
-    context.test.check_container_log_matches_regex('mqtt-broker', log_pattern, 30, count=1)
+    context.test.check_container_log_matches_regex('mqtt-broker', log_pattern, 10, count=1)
+
+
+@then("the MQTT broker has {log_count} log lines matching \"{log_pattern}\"")
+def step_impl(context, log_count, log_pattern):
+    context.test.check_container_log_matches_regex('mqtt-broker', log_pattern, 10, count=int(log_count))
 
 
 @then("the \"{minifi_container_name}\" flow has a log line matching \"{log_pattern}\" in less than {duration}")
@@ -792,6 +900,11 @@ def step_impl(context):
     context.test.start()
 
 
+@when("the MQTT broker is started")
+def step_impl(context):
+    context.test.start('mqtt-broker')
+
+
 # Google Cloud Storage
 @then('an object with the content \"{content}\" is present in the Google Cloud storage')
 def step_imp(context, content):
@@ -813,3 +926,69 @@ def step_imp(context, content):
 def step_imp(context, content, source, source_type, host):
     attr = {"source": source, "sourcetype": source_type, "host": host}
     context.test.check_splunk_event_with_attributes("splunk", content, attr)
+
+
+# Prometheus
+@given("a Prometheus server is set up")
+def step_impl(context):
+    context.test.acquire_container("prometheus", "prometheus")
+
+
+@then("\"{metric_class}\" are published to the Prometheus server in less than {timeout_seconds:d} seconds")
+@then("\"{metric_class}\" is published to the Prometheus server in less than {timeout_seconds:d} seconds")
+def step_impl(context, metric_class, timeout_seconds):
+    context.test.check_metric_class_on_prometheus(metric_class, timeout_seconds)
+
+
+@then("\"{metric_class}\" processor metric is published to the Prometheus server in less than {timeout_seconds:d} seconds for \"{processor_name}\" processor")
+def step_impl(context, metric_class, timeout_seconds, processor_name):
+    context.test.check_processor_metric_on_prometheus(metric_class, timeout_seconds, processor_name)
+
+
+@then("Elasticsearch is empty")
+def step_impl(context):
+    context.test.check_empty_elastic("elasticsearch")
+
+
+@then(u'Elasticsearch has a document with "{doc_id}" in "{index}" that has "{value}" set in "{field}"')
+def step_impl(context, doc_id, index, value, field):
+    context.test.check_elastic_field_value("elasticsearch", index_name=index, doc_id=doc_id, field_name=field, field_value=value)
+
+
+@then("Opensearch is empty")
+def step_impl(context):
+    context.test.check_empty_elastic("opensearch")
+
+
+@then(u'Opensearch has a document with "{doc_id}" in "{index}" that has "{value}" set in "{field}"')
+def step_impl(context, doc_id, index, value, field):
+    context.test.check_elastic_field_value("opensearch", index_name=index, doc_id=doc_id, field_name=field, field_value=value)
+
+
+# MiNiFi C2 Server
+@given("a ssl context service is set up for MiNiFi C2 server")
+def step_impl(context):
+    ssl_context_service = SSLContextService(cert="/tmp/resources/minifi-c2-server-ssl/minifi-cpp-flow.crt", ca_cert="/tmp/resources/minifi-c2-server-ssl/root-ca.pem", key="/tmp/resources/minifi-c2-server-ssl/minifi-cpp-flow.key", passphrase="abcdefgh")
+    ssl_context_service.name = "SSLContextService"
+    container = context.test.acquire_container("minifi-cpp-flow", "minifi-cpp-with-https-c2-config")
+    container.add_controller(ssl_context_service)
+
+
+@given(u'a MiNiFi C2 server is set up')
+def step_impl(context):
+    context.test.acquire_container("minifi-c2-server", "minifi-c2-server")
+
+
+@then("the MiNiFi C2 server logs contain the following message: \"{log_message}\" in less than {duration}")
+def step_impl(context, log_message, duration):
+    context.test.check_container_log_contents("minifi-c2-server", log_message, timeparse(duration))
+
+
+@then("the MiNiFi C2 SSL server logs contain the following message: \"{log_message}\" in less than {duration}")
+def step_impl(context, log_message, duration):
+    context.test.check_container_log_contents("minifi-c2-server-ssl", log_message, timeparse(duration))
+
+
+@given(u'a MiNiFi C2 server is set up with SSL')
+def step_impl(context):
+    context.test.acquire_container("minifi-c2-server", "minifi-c2-server-ssl")
