@@ -20,6 +20,7 @@
 
 #include <string>
 #include <memory>
+#include <utility>
 
 #include "core/controller/ControllerService.h"
 #include "core/logging/LoggerConfiguration.h"
@@ -30,19 +31,34 @@ namespace org::apache::nifi::minifi::azure::controllers {
 
 class AzureStorageCredentialsService : public core::controller::ControllerService {
  public:
+  EXTENSIONAPI static constexpr const char* Description = "Azure Storage Credentials Management Service";
+
   EXTENSIONAPI static const core::Property StorageAccountName;
   EXTENSIONAPI static const core::Property StorageAccountKey;
   EXTENSIONAPI static const core::Property SASToken;
   EXTENSIONAPI static const core::Property CommonStorageAccountEndpointSuffix;
   EXTENSIONAPI static const core::Property ConnectionString;
   EXTENSIONAPI static const core::Property UseManagedIdentityCredentials;
-
-  explicit AzureStorageCredentialsService(const std::string& name, const minifi::utils::Identifier& uuid = {})
-      : ControllerService(name, uuid) {
+  static auto properties() {
+    return std::array{
+      StorageAccountName,
+      StorageAccountKey,
+      SASToken,
+      CommonStorageAccountEndpointSuffix,
+      ConnectionString,
+      UseManagedIdentityCredentials
+    };
   }
 
-  explicit AzureStorageCredentialsService(const std::string& name, const std::shared_ptr<Configure>& /*configuration*/)
-      : ControllerService(name) {
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
+
+  explicit AzureStorageCredentialsService(std::string name, const minifi::utils::Identifier& uuid = {})
+      : ControllerService(std::move(name), uuid) {
+  }
+
+  explicit AzureStorageCredentialsService(std::string name, const std::shared_ptr<Configure>& /*configuration*/)
+      : ControllerService(std::move(name)) {
   }
 
   void initialize() override;
