@@ -21,6 +21,7 @@
 
 #include <memory>
 #include <string>
+#include <utility>
 
 #include "core/Processor.h"
 #include "core/ProcessSession.h"
@@ -33,13 +34,24 @@ namespace org::apache::nifi::minifi::processors {
  */
 class ApplyTemplate : public core::Processor {
  public:
-  explicit ApplyTemplate(const std::string& name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {}
-  static constexpr char const *ProcessorName = "ApplyTemplate";
+  explicit ApplyTemplate(std::string name, const utils::Identifier& uuid = {})
+      : Processor(std::move(name), uuid) {}
 
-  static const core::Property Template;
+  EXTENSIONAPI static constexpr const char* Description = "Applies the mustache template specified by the \"Template\" property and writes the output to the flow file content. "
+    "FlowFile attributes are used as template parameters.";
 
-  static const core::Relationship Success;
+  EXTENSIONAPI static const core::Property Template;
+  static auto properties() { return std::array{Template}; }
+
+  EXTENSIONAPI static const core::Relationship Success;
+  static auto relationships() { return std::array{Success}; }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
   void onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) override;
   void initialize() override;
