@@ -26,86 +26,68 @@
 #include <utility>
 #include <vector>
 
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 #include "utils/gsl.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 const uint64_t ListenHTTP::DEFAULT_BUFFER_SIZE = 20000;
 
-core::Property ListenHTTP::BasePath(
+const core::Property ListenHTTP::BasePath(
     core::PropertyBuilder::createProperty("Base Path")
         ->withDescription("Base path for incoming connections")
         ->isRequired(false)
         ->withDefaultValue<std::string>("contentListener")->build());
 
-core::Property ListenHTTP::Port(
+const core::Property ListenHTTP::Port(
     core::PropertyBuilder::createProperty("Listening Port")
         ->withDescription("The Port to listen on for incoming connections. 0 means port is going to be selected randomly.")
         ->isRequired(true)
         ->withDefaultValue<int>(80, core::StandardValidators::get().LISTEN_PORT_VALIDATOR)->build());
 
-core::Property ListenHTTP::AuthorizedDNPattern("Authorized DN Pattern", "A Regular Expression to apply against the Distinguished Name of incoming"
+const core::Property ListenHTTP::AuthorizedDNPattern("Authorized DN Pattern", "A Regular Expression to apply against the Distinguished Name of incoming"
                                                " connections. If the Pattern does not match the DN, the connection will be refused.",
                                                ".*");
-core::Property ListenHTTP::SSLCertificate("SSL Certificate", "File containing PEM-formatted file including TLS/SSL certificate and key", "");
-core::Property ListenHTTP::SSLCertificateAuthority("SSL Certificate Authority", "File containing trusted PEM-formatted certificates", "");
+const core::Property ListenHTTP::SSLCertificate("SSL Certificate", "File containing PEM-formatted file including TLS/SSL certificate and key", "");
+const core::Property ListenHTTP::SSLCertificateAuthority("SSL Certificate Authority", "File containing trusted PEM-formatted certificates", "");
 
-core::Property ListenHTTP::SSLVerifyPeer(
+const core::Property ListenHTTP::SSLVerifyPeer(
     core::PropertyBuilder::createProperty("SSL Verify Peer")
         ->withDescription("Whether or not to verify the client's certificate (yes/no)")
         ->isRequired(false)
         ->withAllowableValues<std::string>({"yes", "no"})
         ->withDefaultValue("no")->build());
 
-core::Property ListenHTTP::SSLMinimumVersion(
+const core::Property ListenHTTP::SSLMinimumVersion(
     core::PropertyBuilder::createProperty("SSL Minimum Version")
         ->withDescription("Minimum TLS/SSL version allowed (TLS1.2)")
         ->isRequired(false)
         ->withAllowableValues<std::string>({"TLS1.2"})
         ->withDefaultValue("TLS1.2")->build());
 
-core::Property ListenHTTP::HeadersAsAttributesRegex("HTTP Headers to receive as Attributes (Regex)", "Specifies the Regular Expression that determines the names of HTTP Headers that"
+const core::Property ListenHTTP::HeadersAsAttributesRegex("HTTP Headers to receive as Attributes (Regex)", "Specifies the Regular Expression that determines the names of HTTP Headers that"
                                                     " should be passed along as FlowFile attributes",
                                                     "");
 
-core::Property ListenHTTP::BatchSize(
+const core::Property ListenHTTP::BatchSize(
     core::PropertyBuilder::createProperty("Batch Size")
         ->withDescription("Maximum number of buffered requests to be processed in a single batch. If set to zero all buffered requests are processed.")
         ->withDefaultValue<uint64_t>(ListenHTTP::DEFAULT_BUFFER_SIZE)->build());
 
-core::Property ListenHTTP::BufferSize(
+const core::Property ListenHTTP::BufferSize(
     core::PropertyBuilder::createProperty("Buffer Size")
         ->withDescription("Maximum number of HTTP Requests allowed to be buffered before processing them when the processor is triggered. "
                           "If the buffer full, the request is refused. If set to zero the buffer is unlimited.")
         ->withDefaultValue<uint64_t>(ListenHTTP::DEFAULT_BUFFER_SIZE)->build());
 
-core::Relationship ListenHTTP::Success("success", "All files are routed to success");
+const core::Relationship ListenHTTP::Success("success", "All files are routed to success");
 
 void ListenHTTP::initialize() {
   logger_->log_trace("Initializing ListenHTTP");
 
-  // Set the supported properties
-  std::set<core::Property> properties;
-  properties.insert(BasePath);
-  properties.insert(Port);
-  properties.insert(AuthorizedDNPattern);
-  properties.insert(SSLCertificate);
-  properties.insert(SSLCertificateAuthority);
-  properties.insert(SSLVerifyPeer);
-  properties.insert(SSLMinimumVersion);
-  properties.insert(HeadersAsAttributesRegex);
-  properties.insert(BatchSize);
-  properties.insert(BufferSize);
-  setSupportedProperties(properties);
-  // Set the supported relationships
-  std::set<core::Relationship> relationships;
-  relationships.insert(Success);
-  setSupportedRelationships(relationships);
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
 void ListenHTTP::onSchedule(core::ProcessContext *context, core::ProcessSessionFactory* /*sessionFactory*/) {
@@ -127,9 +109,11 @@ void ListenHTTP::onSchedule(core::ProcessContext *context, core::ProcessSessionF
   bool randomPort = listeningPort == "0";
 
   std::string authDNPattern;
-
   if (context->getProperty(AuthorizedDNPattern.getName(), authDNPattern) && !authDNPattern.empty()) {
     logger_->log_debug("ListenHTTP using %s: %s", AuthorizedDNPattern.getName(), authDNPattern);
+  } else {
+    authDNPattern = ".*";
+    logger_->log_debug("Authorized DN Pattern not set or invalid, using default '%s' pattern", authDNPattern);
   }
 
   std::string sslCertFile;
@@ -149,7 +133,7 @@ void ListenHTTP::onSchedule(core::ProcessContext *context, core::ProcessSessionF
     }
 
     if (context->getProperty(SSLVerifyPeer.getName(), sslVerifyPeer)) {
-      if (sslVerifyPeer.empty() || sslVerifyPeer.compare("no") == 0) {
+      if (sslVerifyPeer.empty() || sslVerifyPeer == "no") {
         logger_->log_debug("ListenHTTP will not verify peers");
       } else {
         logger_->log_debug("ListenHTTP will verify peers");
@@ -214,12 +198,13 @@ void ListenHTTP::onSchedule(core::ProcessContext *context, core::ProcessSessionF
     }
   }
 
-  server_.reset(new CivetServer(options, &callbacks_, &logger_));
+  server_ = std::make_unique<CivetServer>(options, &callbacks_, &logger_);
 
   context->getProperty(BatchSize.getName(), batch_size_);
   logger_->log_debug("ListenHTTP using %s: %zu", BatchSize.getName(), batch_size_);
 
-  handler_.reset(new Handler(basePath, context, std::move(authDNPattern), std::move(headersAsAttributesPattern)));
+  handler_ = std::make_unique<Handler>(basePath, context, std::move(authDNPattern),
+    headersAsAttributesPattern.empty() ? std::nullopt : std::make_optional<utils::Regex>(headersAsAttributesPattern));
   server_->addHandler(basePath, handler_.get());
 
   if (randomPort) {
@@ -239,16 +224,21 @@ void ListenHTTP::onSchedule(core::ProcessContext *context, core::ProcessSessionF
 
 ListenHTTP::~ListenHTTP() = default;
 
-void ListenHTTP::onTrigger(core::ProcessContext* /*context*/, core::ProcessSession *session) {
-  logger_->log_debug("OnTrigger ListenHTTP");
-  processIncomingFlowFile(session);
-  processRequestBuffer(session);
+void ListenHTTP::onTrigger(core::ProcessContext*, core::ProcessSession* session) {
+  gsl_Expects(session);
+  logger_->log_trace("OnTrigger ListenHTTP");
+  const bool incoming_processed = processIncomingFlowFile(*session);
+  const bool request_processed = processRequestBuffer(*session);
+  if (!incoming_processed && !request_processed) {
+    yield();
+  }
 }
 
-void ListenHTTP::processIncomingFlowFile(core::ProcessSession *session) {
-  std::shared_ptr<core::FlowFile> flow_file = session->get();
+/// @return Whether there was a flow file processed.
+bool ListenHTTP::processIncomingFlowFile(core::ProcessSession &session) {
+  std::shared_ptr<core::FlowFile> flow_file = session.get();
   if (!flow_file) {
-    return;
+    return false;
   }
 
   std::string type;
@@ -262,14 +252,16 @@ void ListenHTTP::processIncomingFlowFile(core::ProcessSession *session) {
       logger_->log_warn("Using default mime type of application/octet-stream for response body file: %s", response.uri);
       response.mime_type = "application/octet-stream";
     }
-    response.body = to_string(session->readBuffer(flow_file));
-    handler_->setResponseBody(std::move(response));
+    response.body = to_string(session.readBuffer(flow_file));
+    handler_->setResponseBody(response);
   }
 
-  session->remove(flow_file);
+  session.remove(flow_file);
+  return true;
 }
 
-void ListenHTTP::processRequestBuffer(core::ProcessSession *session) {
+/// @return Whether there was a request processed
+bool ListenHTTP::processRequestBuffer(core::ProcessSession& session) {
   std::size_t flow_file_count = 0;
   for (; batch_size_ == 0 || batch_size_ > flow_file_count; ++flow_file_count) {
     FlowFileBufferPair flow_file_buffer_pair;
@@ -278,25 +270,23 @@ void ListenHTTP::processRequestBuffer(core::ProcessSession *session) {
     }
 
     auto flow_file = flow_file_buffer_pair.first;
-    session->add(flow_file);
+    session.add(flow_file);
 
     if (flow_file_buffer_pair.second) {
-      session->write(flow_file, [request_content = flow_file_buffer_pair.second.get()](const std::shared_ptr<io::BaseStream>& stream) -> int64_t {
-        const auto write_ret = stream->write(request_content->getBuffer());
-        return io::isError(write_ret) ? -1 : gsl::narrow<int64_t>(write_ret);
-      });
+      session.writeBuffer(flow_file, flow_file_buffer_pair.second->getBuffer());
     }
 
-    session->transfer(flow_file, Success);
+    session.transfer(flow_file, Success);
   }
 
   logger_->log_debug("ListenHTTP transferred %zu flow files from HTTP request buffer", flow_file_count);
+  return flow_file_count > 0;
 }
 
-ListenHTTP::Handler::Handler(std::string base_uri, core::ProcessContext *context, std::string &&auth_dn_regex, std::string &&header_as_attrs_regex)
+ListenHTTP::Handler::Handler(std::string base_uri, core::ProcessContext *context, std::string &&auth_dn_regex, std::optional<utils::Regex> &&headers_as_attrs_regex)
     : base_uri_(std::move(base_uri)),
       auth_dn_regex_(std::move(auth_dn_regex)),
-      headers_as_attrs_regex_(std::move(header_as_attrs_regex)),
+      headers_as_attrs_regex_(std::move(headers_as_attrs_regex)),
       process_context_(context) {
   context->getProperty(BufferSize.getName(), buffer_size_);
   logger_->log_debug("ListenHTTP using %s: %zu", BufferSize.getName(), buffer_size_);
@@ -321,7 +311,7 @@ void ListenHTTP::Handler::setHeaderAttributes(const mg_request_info *req_info, c
 
     if (strcmp("filename", header->name) == 0) {
       flow_file->setAttribute("filename", header->value);
-    } else if (utils::regexMatch(header->name, headers_as_attrs_regex_)) {
+    } else if (headers_as_attrs_regex_ && utils::regexMatch(header->name, *headers_as_attrs_regex_)) {
       flow_file->setAttribute(header->name, header->value);
     }
   }
@@ -420,6 +410,20 @@ bool ListenHTTP::Handler::handleHead(CivetServer* /*server*/, struct mg_connecti
   return true;
 }
 
+bool ListenHTTP::Handler::handlePut(CivetServer* /*server*/, struct mg_connection* conn) {
+  mg_printf(conn, "HTTP/1.1 405 Method Not Allowed\r\n"
+                  "Content-Type: text/html\r\n"
+                  "Content-Length: 0\r\n\r\n");
+  return true;
+}
+
+bool ListenHTTP::Handler::handleDelete(CivetServer* /*server*/, struct mg_connection* conn) {
+  mg_printf(conn, "HTTP/1.1 405 Method Not Allowed\r\n"
+                  "Content-Type: text/html\r\n"
+                  "Content-Length: 0\r\n\r\n");
+  return true;
+}
+
 void ListenHTTP::Handler::setResponseBody(const ResponseBody& response) {
   std::lock_guard<std::mutex> guard(uri_map_mutex_);
 
@@ -431,7 +435,7 @@ void ListenHTTP::Handler::setResponseBody(const ResponseBody& response) {
     logger_->log_info("Registering response body for URI '%s' of length %lu",
                       response.uri,
                       response.body.size());
-    response_uri_map_[response.uri] = std::move(response);
+    response_uri_map_[response.uri] = response;
   }
 }
 
@@ -450,7 +454,7 @@ void ListenHTTP::Handler::writeBody(mg_connection *conn, const mg_request_info *
       std::lock_guard<std::mutex> guard(uri_map_mutex_);
       std::string req_uri = request_uri_str.substr(base_uri_.size() + 1);
 
-      if (response_uri_map_.count(req_uri)) {
+      if (response_uri_map_.contains(req_uri)) {
         response = response_uri_map_[req_uri];
       }
     }
@@ -522,15 +526,6 @@ void ListenHTTP::notifyStop() {
   handler_.reset();
 }
 
-REGISTER_RESOURCE(ListenHTTP, "Starts an HTTP Server and listens on a given base path to transform incoming requests into FlowFiles. The default URI of the Service will be "
-    "http://{hostname}:{port}/contentListener. Only HEAD, POST, and GET requests are supported. PUT, and DELETE will result in an error and the HTTP response status code 405."
-    " The response body text for all requests, by default, is empty (length of 0). A static response body can be set for a given URI by sending input files to ListenHTTP with "
-    "the http.type attribute set to response_body. The response body FlowFile filename attribute is appended to the Base Path property (separated by a /) when mapped to incoming requests. "
-    "The mime.type attribute of the response body FlowFile is used for the Content-type header in responses. Response body content can be cleared by sending an empty (size 0) "
-    "FlowFile for a given URI mapping.");
+REGISTER_RESOURCE(ListenHTTP, Processor);
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
