@@ -36,44 +36,61 @@
 #include "utils/Export.h"
 #include "utils/RegexUtils.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
-// ListenHTTP Class
 class ListenHTTP : public core::Processor {
  public:
   using FlowFileBufferPair = std::pair<std::shared_ptr<FlowFileRecord>, std::unique_ptr<io::BufferStream>>;
 
-  // Constructor
-  /*!
-   * Create a new processor
-   */
-  explicit ListenHTTP(const std::string& name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid),
+  explicit ListenHTTP(std::string name, const utils::Identifier& uuid = {})
+      : Processor(std::move(name), uuid),
         batch_size_(0) {
     callbacks_.log_message = &logMessage;
     callbacks_.log_access = &logAccess;
   }
-  // Destructor
   ~ListenHTTP() override;
-  // Processor Name
-  EXTENSIONAPI static constexpr char const *ProcessorName = "ListenHTTP";
-  // Supported Properties
-  EXTENSIONAPI static core::Property BasePath;
-  EXTENSIONAPI static core::Property Port;
-  EXTENSIONAPI static core::Property AuthorizedDNPattern;
-  EXTENSIONAPI static core::Property SSLCertificate;
-  EXTENSIONAPI static core::Property SSLCertificateAuthority;
-  EXTENSIONAPI static core::Property SSLVerifyPeer;
-  EXTENSIONAPI static core::Property SSLMinimumVersion;
-  EXTENSIONAPI static core::Property HeadersAsAttributesRegex;
-  EXTENSIONAPI static core::Property BatchSize;
-  EXTENSIONAPI static core::Property BufferSize;
-  // Supported Relationships
-  EXTENSIONAPI static core::Relationship Success;
+
+  EXTENSIONAPI static constexpr const char* Description = "Starts an HTTP Server and listens on a given base path to transform incoming requests into FlowFiles. The default URI of the Service "
+      "will be http://{hostname}:{port}/contentListener. Only HEAD, POST, and GET requests are supported. PUT, and DELETE will result in an error and the HTTP response status code 405. "
+      "The response body text for all requests, by default, is empty (length of 0). A static response body can be set for a given URI by sending input files to ListenHTTP with "
+      "the http.type attribute set to response_body. The response body FlowFile filename attribute is appended to the Base Path property (separated by a /) when mapped to incoming requests. "
+      "The mime.type attribute of the response body FlowFile is used for the Content-type header in responses. Response body content can be cleared by sending an empty (size 0) "
+      "FlowFile for a given URI mapping.";
+
+  EXTENSIONAPI static const core::Property BasePath;
+  EXTENSIONAPI static const core::Property Port;
+  EXTENSIONAPI static const core::Property AuthorizedDNPattern;
+  EXTENSIONAPI static const core::Property SSLCertificate;
+  EXTENSIONAPI static const core::Property SSLCertificateAuthority;
+  EXTENSIONAPI static const core::Property SSLVerifyPeer;
+  EXTENSIONAPI static const core::Property SSLMinimumVersion;
+  EXTENSIONAPI static const core::Property HeadersAsAttributesRegex;
+  EXTENSIONAPI static const core::Property BatchSize;
+  EXTENSIONAPI static const core::Property BufferSize;
+  static auto properties() {
+    return std::array{
+      BasePath,
+      Port,
+      AuthorizedDNPattern,
+      SSLCertificate,
+      SSLCertificateAuthority,
+      SSLVerifyPeer,
+      SSLMinimumVersion,
+      HeadersAsAttributesRegex,
+      BatchSize,
+      BufferSize
+    };
+  }
+
+  EXTENSIONAPI static const core::Relationship Success;
+  static auto relationships() { return std::array{Success}; }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_FORBIDDEN;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
   void onTrigger(core::ProcessContext *context, core::ProcessSession *session) override;
   void initialize() override;
@@ -92,11 +109,13 @@ class ListenHTTP : public core::Processor {
    public:
     Handler(std::string base_uri,
             core::ProcessContext *context,
-            std::string &&authDNPattern,
-            std::string &&headersAsAttributesPattern);
+            std::string &&auth_dn_regex,
+            std::optional<utils::Regex> &&headers_as_attrs_regex);
     bool handlePost(CivetServer *server, struct mg_connection *conn) override;
     bool handleGet(CivetServer *server, struct mg_connection *conn) override;
     bool handleHead(CivetServer *server, struct mg_connection *conn) override;
+    bool handlePut(CivetServer *server, struct mg_connection *conn) override;
+    bool handleDelete(CivetServer *server, struct mg_connection *conn) override;
 
     /**
      * Sets a static response body string to be used for a given URI, with a number of seconds it will be kept in memory.
@@ -107,17 +126,17 @@ class ListenHTTP : public core::Processor {
     bool dequeueRequest(FlowFileBufferPair &flow_file_buffer_pair);
 
    private:
-    void sendHttp500(struct mg_connection *conn);
-    void sendHttp503(struct mg_connection *conn);
+    static void sendHttp500(struct mg_connection *conn);
+    static void sendHttp503(struct mg_connection *conn);
     bool authRequest(mg_connection *conn, const mg_request_info *req_info) const;
     void setHeaderAttributes(const mg_request_info *req_info, const std::shared_ptr<core::FlowFile> &flow_file) const;
     void writeBody(mg_connection *conn, const mg_request_info *req_info, bool include_payload = true);
-    std::unique_ptr<io::BufferStream> createContentBuffer(struct mg_connection *conn, const struct mg_request_info *req_info);
+    static std::unique_ptr<io::BufferStream> createContentBuffer(struct mg_connection *conn, const struct mg_request_info *req_info);
     void enqueueRequest(mg_connection *conn, const mg_request_info *req_info, std::unique_ptr<io::BufferStream>);
 
     std::string base_uri_;
     utils::Regex auth_dn_regex_;
-    utils::Regex headers_as_attrs_regex_;
+    std::optional<utils::Regex> headers_as_attrs_regex_;
     core::ProcessContext *process_context_;
     std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ListenHTTP>::getLogger();
     std::map<std::string, ResponseBody> response_uri_map_;
@@ -168,12 +187,8 @@ class ListenHTTP : public core::Processor {
  private:
   static const uint64_t DEFAULT_BUFFER_SIZE;
 
-  core::annotation::Input getInputRequirement() const override {
-    return core::annotation::Input::INPUT_FORBIDDEN;
-  }
-
-  void processIncomingFlowFile(core::ProcessSession *session);
-  void processRequestBuffer(core::ProcessSession *session);
+  bool processIncomingFlowFile(core::ProcessSession &session);
+  bool processRequestBuffer(core::ProcessSession &session);
 
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<ListenHTTP>::getLogger();
   CivetCallbacks callbacks_;
@@ -183,8 +198,4 @@ class ListenHTTP : public core::Processor {
   uint64_t batch_size_;
 };
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
