@@ -29,7 +29,7 @@
 #include <vector>
 #include <iostream>
 #include <sstream>
-#include "HTTPClient.h"
+#include "BaseHTTPClient.h"
 #include "processors/InvokeHTTP.h"
 #include "TestBase.h"
 #include "Catch.h"
@@ -52,7 +52,6 @@
 #include "processors/LogAttribute.h"
 #include "CoapC2Protocol.h"
 #include "CoapServer.h"
-#include "io/BaseStream.h"
 #include "concurrentqueue.h"
 #include "utils/IntegrationTestUtils.h"
 
@@ -64,7 +63,7 @@ class VerifyCoAPServer : public CoapIntegrationBase {
   }
 
   void testSetup() override {
-    LogTestController::getInstance().setDebug<utils::HTTPClient>();
+    LogTestController::getInstance().setDebug<minifi::extensions::curl::HTTPClient>();
     LogTestController::getInstance().setOff<minifi::processors::InvokeHTTP>();
     LogTestController::getInstance().setDebug<minifi::c2::RESTReceiver>();
     LogTestController::getInstance().setDebug<minifi::c2::C2Agent>();
@@ -99,20 +98,22 @@ class VerifyCoAPServer : public CoapIntegrationBase {
     const auto* const inv = dynamic_cast<minifi::processors::InvokeHTTP*>(proc);
 
     assert(inv != nullptr);
-    std::string url = "";
+    std::string url;
     inv->getProperty(minifi::processors::InvokeHTTP::URL.getName(), url);
 
-    std::string port, scheme, path;
+    std::string port;
+    std::string scheme;
+    std::string path;
 
     parse_http_components(url, port, scheme, path);
     uint16_t newport = std::stoi(port) + 2;
     auto new_port_str = std::to_string(newport);
 
-    server = std::unique_ptr<minifi::coap::CoapServer>(new minifi::coap::CoapServer("127.0.0.1", newport));
+    server = std::make_unique<minifi::coap::CoapServer>("127.0.0.1", newport);
 
 
     server->add_endpoint(minifi::coap::Method::Post, [](minifi::coap::CoapQuery)->minifi::coap::CoapResponse {
-      minifi::coap::CoapResponse response(205, 0x00, 0);
+      minifi::coap::CoapResponse response(205, nullptr, 0);
       return response;
     });
 
@@ -133,7 +134,8 @@ class VerifyCoAPServer : public CoapIntegrationBase {
     {
       // should result in valid operation
       minifi::io::BufferStream stream;
-      uint16_t version = 0, size = 1;
+      uint16_t version = 0;
+      uint16_t size = 1;
       uint8_t operation = 1;
       stream.write(version);
       stream.write(size);
@@ -149,11 +151,11 @@ class VerifyCoAPServer : public CoapIntegrationBase {
 
     server->add_endpoint("heartbeat", minifi::coap::Method::Post, [&](minifi::coap::CoapQuery)-> minifi::coap::CoapResponse {
       if (responses.size_approx() > 0) {
-        minifi::coap::CoapResponse resp(500, 0, 0);;
+        minifi::coap::CoapResponse resp(500, nullptr, 0);;
         responses.try_dequeue(resp);
         return resp;
       }
-      minifi::coap::CoapResponse response(500, 0, 0);
+      minifi::coap::CoapResponse response(500, nullptr, 0);
       return response;
     });
     server->start();
