@@ -63,17 +63,9 @@
 
 #include "Driver.h"
 
-#ifdef EXPRESSION_LANGUAGE_USE_DATE
 #include "date/tz.h"
-#else
-#include <ctime>
-#endif  // EXPRESSION_LANGUAGE_USE_DATE
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace expression {
+namespace org::apache::nifi::minifi::expression {
 
 Expression compile(const std::string &expr_str) {
   std::stringstream expr_str_stream(expr_str);
@@ -84,7 +76,7 @@ Expression compile(const std::string &expr_str) {
 }
 
 Expression make_static(std::string val) {
-  return Expression(Value(val));
+  return Expression(Value(std::move(val)));
 }
 
 Expression make_dynamic(const std::function<Value(const Parameters &params, const std::vector<Expression> &sub_exprs)> &val_fn) {
@@ -103,7 +95,7 @@ Expression make_dynamic_attr(const std::string &attribute_id) {
         return Value(result);
       }
     }
-    return Value();
+    return {};
   });
 }
 
@@ -124,9 +116,11 @@ Value expr_hostname(const std::vector<Value> &args) {
   hostname[1023] = '\0';
   gethostname(hostname, 1023);
 
-  if (args.size() > 0 && args[0].asBoolean()) {
+  if (!args.empty() && args[0].asBoolean()) {
     int status;
-    struct addrinfo hints, *result, *addr_cursor;
+    struct addrinfo hints;
+    struct addrinfo *result;
+    struct addrinfo *addr_cursor;
     memset(&hints, 0, sizeof(hints));
     hints.ai_family = AF_UNSPEC;
     hints.ai_socktype = SOCK_STREAM;
@@ -162,7 +156,9 @@ Value expr_ip(const std::vector<Value>& /*args*/) {
   int status;
   char ip_str[INET6_ADDRSTRLEN];
   struct sockaddr_in *addr;
-  struct addrinfo hints, *result, *addr_cursor;
+  struct addrinfo hints;
+  struct addrinfo *result;
+  struct addrinfo *addr_cursor;
   memset(&hints, 0, sizeof(hints));
   hints.ai_family = AF_INET;
 
@@ -184,7 +180,7 @@ Value expr_ip(const std::vector<Value>& /*args*/) {
   }
 
   freeaddrinfo(result);
-  return Value();
+  return {};
 }
 
 Value expr_uuid(const std::vector<Value>& /*args*/) {
@@ -205,12 +201,12 @@ Value expr_toLower(const std::vector<Value> &args) {
 
 Value expr_substring(const std::vector<Value> &args) {
   if (args.size() < 3) {
-    size_t offset = gsl::narrow<size_t>(args[1].asUnsignedLong());
-    return Value(args[0].asString().substr(offset));
+    auto offset = gsl::narrow<size_t>(args[1].asUnsignedLong());
+    return Value{args[0].asString().substr(offset)};
   } else {
-    size_t offset = gsl::narrow<size_t>(args[1].asUnsignedLong());
-    size_t count = gsl::narrow<size_t>(args[2].asUnsignedLong());
-    return Value(args[0].asString().substr(offset, count));
+    auto offset = gsl::narrow<size_t>(args[1].asUnsignedLong());
+    auto count = gsl::narrow<size_t>(args[2].asUnsignedLong());
+    return Value{args[0].asString().substr(offset, count)};
   }
 }
 
@@ -438,7 +434,7 @@ Value expr_unescapeJson(const std::vector<Value> &args) {
   if (doc.IsArray() && doc.Size() == 1 && doc[0].IsString()) {
     return Value(std::string(doc[0].GetString()));
   } else {
-    return Value();
+    return {};
   }
 }
 
@@ -610,8 +606,6 @@ Value expr_escapeCsv(const std::vector<Value> &args) {
   return Value(result);
 }
 
-#ifdef EXPRESSION_LANGUAGE_USE_DATE
-
 Value expr_format(const std::vector<Value> &args) {
   std::chrono::milliseconds dur(args[0].asUnsignedLong());
   std::chrono::system_clock::time_point dt(dur);
@@ -640,52 +634,6 @@ Value expr_toDate(const std::vector<Value> &args) {
   return Value(int64_t{std::chrono::duration_cast<std::chrono::milliseconds>(zt.get_sys_time().time_since_epoch()).count()});
 }
 
-#else
-
-Value expr_format(const std::vector<Value>& args) {
-  const std::chrono::milliseconds dur(args.at(0).asUnsignedLong());
-  const std::chrono::system_clock::time_point dt(dur);
-  const auto unix_time = std::chrono::system_clock::to_time_t(dt);
-  const auto zoned_time = [&args, unix_time] {
-    std::tm buf{};
-    const auto requested_timezone = args.size() > 2 ? args[2].asString() : std::string{};
-    if (requested_timezone == "UTC" || requested_timezone == "GMT") {
-#ifdef WIN32
-      const auto err = gmtime_s(&buf, &unix_time);
-      if (!err) { return buf; }
-      throw std::system_error{err, std::generic_category()};
-#else
-      tzset();
-      const std::tm* const result = gmtime_r(&unix_time, &buf);
-      if (result) { return *result; }
-      throw std::system_error{errno, std::generic_category()};
-#endif /* WIN32 */
-    } else if (!requested_timezone.empty()) {
-      throw std::domain_error{"format() with Non-UTC custom timezone is only supported when compiled with the date.h library"};
-    } else {
-#ifdef WIN32
-      const auto err = localtime_s(&buf, &unix_time);
-      if (!err) { return buf; }
-      throw std::system_error{err, std::generic_category()};
-#else
-      tzset();
-      const std::tm* const result = localtime_r(&unix_time, &buf);
-      if (result) { return *result; }
-      throw std::system_error{errno, std::generic_category()};
-#endif /* WIN32 */
-    }
-  }();
-  char result_buf[512] = {0};
-  std::strftime(result_buf, 512, args.at(1).asString().c_str(), &zoned_time);
-  return Value(std::string(result_buf));
-}
-
-Value expr_toDate(const std::vector<Value>&) {
-  throw std::domain_error{"toDate() is only supported when compiled with the date.h library"};
-}
-
-#endif  // EXPRESSION_LANGUAGE_USE_DATE
-
 Value expr_now(const std::vector<Value>& /*args*/) {
   return Value(int64_t{std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::system_clock::now().time_since_epoch()).count()});
 }
@@ -774,8 +722,6 @@ Value expr_base64Decode(const std::vector<Value> &args) {
   return Value(utils::StringUtils::from_base64(args[0].asString(), utils::as_string));
 }
 
-#ifdef EXPRESSION_LANGUAGE_USE_REGEX
-
 Value expr_replace(const std::vector<Value> &args) {
   std::string result = args[0].asString();
   const std::string &find = args[1].asString();
@@ -835,8 +781,6 @@ Value expr_find(const std::vector<Value> &args) {
   return Value(utils::regexSearch(subject, expr));
 }
 
-#endif  // EXPRESSION_LANGUAGE_USE_REGEX
-
 Value expr_trim(const std::vector<Value> &args) {
   return Value{utils::StringUtils::trim(args[0].asString())};
 }
@@ -864,7 +808,7 @@ Value expr_binary_op(const std::vector<Value> &args, long double (*ldop)(long do
       return Value(ldop(args[0].asLongDouble(), args[1].asLongDouble()));
     }
   } catch (const std::exception &) {
-    return Value();
+    return {};
   }
 }
 
@@ -966,7 +910,7 @@ Expression make_dynamic_function_incomplete(const std::string &function_name, co
   } else {
     return make_dynamic([=](const Parameters &params, const std::vector<Expression>& /*sub_exprs*/) -> Value {
       std::vector<Value> evaluated_args;
-
+      evaluated_args.reserve(args.size());
       for (const auto &arg : args) {
         evaluated_args.emplace_back(arg(params));
       }
@@ -1071,7 +1015,7 @@ Value expr_ifElse(const std::vector<Value> &args) {
 }
 
 Expression make_allAttributes(const std::string &function_name, const std::vector<Expression> &args) {
-  if (args.size() < 1) {
+  if (args.empty()) {
     std::stringstream message_ss;
     message_ss << "Expression language function " << function_name << " called with " << args.size() << " argument(s), but " << 1 << " are required";
     throw std::runtime_error(message_ss.str());
@@ -1091,7 +1035,7 @@ Expression make_allAttributes(const std::string &function_name, const std::vecto
 
   result.make_multi([=](const Parameters& /*params*/) -> std::vector<Expression> {
     std::vector<Expression> out_exprs;
-
+    out_exprs.reserve(args.size());
     for (const auto &arg : args) {
       out_exprs.emplace_back(make_dynamic([=](const Parameters &params,
                   const std::vector<Expression>& /*sub_exprs*/) -> Value {
@@ -1104,7 +1048,7 @@ Expression make_allAttributes(const std::string &function_name, const std::vecto
                 if (cur_flow_file && cur_flow_file->getAttribute(attr_id, attr_val)) {
                   return Value(attr_val);
                 } else {
-                  return Value();
+                  return {};
                 }
               }));
     }
@@ -1116,7 +1060,7 @@ Expression make_allAttributes(const std::string &function_name, const std::vecto
 }
 
 Expression make_anyAttribute(const std::string &function_name, const std::vector<Expression> &args) {
-  if (args.size() < 1) {
+  if (args.empty()) {
     std::stringstream message_ss;
     message_ss << "Expression language function " << function_name << " called with " << args.size() << " argument(s), but " << 1 << " are required";
     throw std::runtime_error(message_ss.str());
@@ -1136,7 +1080,7 @@ Expression make_anyAttribute(const std::string &function_name, const std::vector
 
   result.make_multi([=](const Parameters& /*params*/) -> std::vector<Expression> {
     std::vector<Expression> out_exprs;
-
+    out_exprs.reserve(args.size());
     for (const auto &arg : args) {
       out_exprs.emplace_back(make_dynamic([=](const Parameters &params,
                   const std::vector<Expression>& /*sub_exprs*/) -> Value {
@@ -1149,7 +1093,7 @@ Expression make_anyAttribute(const std::string &function_name, const std::vector
                 if (cur_flow_file && cur_flow_file->getAttribute(attr_id, attr_val)) {
                   return Value(attr_val);
                 } else {
-                  return Value();
+                  return {};
                 }
               }));
     }
@@ -1160,10 +1104,8 @@ Expression make_anyAttribute(const std::string &function_name, const std::vector
   return result;
 }
 
-#ifdef EXPRESSION_LANGUAGE_USE_REGEX
-
 Expression make_allMatchingAttributes(const std::string &function_name, const std::vector<Expression> &args) {
-  if (args.size() < 1) {
+  if (args.empty()) {
     std::stringstream message_ss;
     message_ss << "Expression language function " << function_name << " called with " << args.size() << " argument(s), but " << 1 << " are required";
     throw std::runtime_error(message_ss.str());
@@ -1202,7 +1144,7 @@ Expression make_allMatchingAttributes(const std::string &function_name, const st
                     if (cur_flow_file && cur_flow_file->getAttribute(attr.first, attr_val)) {
                       return Value(attr_val);
                     } else {
-                      return Value();
+                      return {};
                     }
                   }));
         }
@@ -1216,7 +1158,7 @@ Expression make_allMatchingAttributes(const std::string &function_name, const st
 }
 
 Expression make_anyMatchingAttribute(const std::string &function_name, const std::vector<Expression> &args) {
-  if (args.size() < 1) {
+  if (args.empty()) {
     std::stringstream message_ss;
     message_ss << "Expression language function " << function_name << " called with " << args.size() << " argument(s), but " << 1 << " are required";
     throw std::runtime_error(message_ss.str());
@@ -1255,7 +1197,7 @@ Expression make_anyMatchingAttribute(const std::string &function_name, const std
                     if (cur_flow_file && cur_flow_file->getAttribute(attr.first, attr_val)) {
                       return Value(attr_val);
                     } else {
-                      return Value();
+                      return {};
                     }
                   }));
         }
@@ -1268,8 +1210,6 @@ Expression make_anyMatchingAttribute(const std::string &function_name, const std
   return result;
 }
 
-#endif  // EXPRESSION_LANGUAGE_USE_REGEX
-
 Expression make_allDelineatedValues(const std::string &function_name, const std::vector<Expression> &args) {
   if (args.size() != 2) {
     std::stringstream message_ss;
@@ -1372,7 +1312,7 @@ Expression make_join(const std::string &function_name, const std::vector<Express
     throw std::runtime_error(message_ss.str());
   }
 
-  auto delim_expr = args[1];
+  const auto& delim_expr = args[1];
 
   return args[0].make_aggregate([delim_expr](const Parameters &params,
       const std::vector<Expression> &sub_exprs) -> Value {
@@ -1457,7 +1397,6 @@ Expression make_dynamic_function(const std::string &function_name, const std::ve
     return make_dynamic_function_incomplete<expr_base64Encode>(function_name, args, 0);
   } else if (function_name == "base64Decode") {
     return make_dynamic_function_incomplete<expr_base64Decode>(function_name, args, 0);
-#ifdef EXPRESSION_LANGUAGE_USE_REGEX
   } else if (function_name == "replace") {
     return make_dynamic_function_incomplete<expr_replace>(function_name, args, 2);
   } else if (function_name == "replaceFirst") {
@@ -1476,7 +1415,6 @@ Expression make_dynamic_function(const std::string &function_name, const std::ve
     return make_allMatchingAttributes(function_name, args);
   } else if (function_name == "anyMatchingAttribute") {
     return make_anyMatchingAttribute(function_name, args);
-#endif  // EXPRESSION_LANGUAGE_USE_REGEX
   } else if (function_name == "trim") {
     return make_dynamic_function_incomplete<expr_trim>(function_name, args, 0);
   } else if (function_name == "append") {
@@ -1567,11 +1505,7 @@ Expression make_function_composition(const Expression &arg, const std::vector<st
 }
 
 bool Expression::is_dynamic() const {
-  if (val_fn_) {
-    return true;
-  } else {
-    return false;
-  }
+  return static_cast<bool>(val_fn_);
 }
 
 Expression Expression::operator+(const Expression &other_expr) const {
@@ -1607,8 +1541,7 @@ Expression Expression::operator+(const Expression &other_expr) const {
     other_val_fn,
     other_sub_expr_generator](const Parameters &params,
         const std::vector<Expression>& /*sub_exprs*/) -> Value {
-      Value result(val);
-      return Value(result.asString().append(other_val_fn(params, other_sub_expr_generator(params)).asString()));
+      return Value(val.asString().append(other_val_fn(params, other_sub_expr_generator(params)).asString()));
     });
   } else if (!is_dynamic() && !other_expr.is_dynamic()) {
     std::string result(val_.asString());
@@ -1627,13 +1560,14 @@ Value Expression::operator()(const Parameters &params) const {
   }
 }
 
-Expression Expression::compose_multi(const std::function<Value(const std::vector<Value> &)> fn, const std::vector<Expression> &args) const {
+Expression Expression::compose_multi(const std::function<Value(const std::vector<Value> &)>& fn, const std::vector<Expression> &args) const {
   auto result = make_dynamic(val_fn_);
   auto compose_expr_generator = sub_expr_generator_;
 
   result.sub_expr_generator_ = [=](const Parameters &params) -> std::vector<Expression> {
     auto sub_exprs = compose_expr_generator(params);
-    std::vector<Expression> out_exprs {};
+    std::vector<Expression> out_exprs;
+    out_exprs.reserve(sub_exprs.size());
     for (const auto &sub_expr : sub_exprs) {
       out_exprs.emplace_back(make_dynamic([=](const Parameters &params,
                   const std::vector<Expression>& /*sub_exprs*/) {
@@ -1656,7 +1590,7 @@ Expression Expression::compose_multi(const std::function<Value(const std::vector
   return result;
 }
 
-Expression Expression::make_aggregate(std::function<Value(const Parameters &params, const std::vector<Expression> &sub_exprs)> val_fn) const {
+Expression Expression::make_aggregate(const std::function<Value(const Parameters &params, const std::vector<Expression> &sub_exprs)>& val_fn) const {
   auto sub_expr_generator = sub_expr_generator_;
   return make_dynamic([sub_expr_generator,
   val_fn](const Parameters &params,
@@ -1665,8 +1599,10 @@ Expression Expression::make_aggregate(std::function<Value(const Parameters &para
   });
 }
 
-} /* namespace expression */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+#ifdef WIN32
+void dateSetInstall(const std::string& install) {
+  date::set_install(install);
+}
+#endif
+
+}  // namespace org::apache::nifi::minifi::expression
