@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -24,12 +23,9 @@
 #include "c2/protocols/RESTProtocol.h"
 #include "controllers/SSLContextService.h"
 #include "../client/HTTPClient.h"
+#include "utils/Enum.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace c2 {
+namespace org::apache::nifi::minifi::c2 {
 
 /**
  * Purpose and Justification: Encapsulates the restful protocol that is built upon C2Protocol.
@@ -40,8 +36,15 @@ namespace c2 {
  *
  */
 class RESTSender : public RESTProtocol, public C2Protocol {
+  SMART_ENUM(RequestEncoding,
+    (None, "none"),
+    (Gzip, "gzip")
+  )
+
  public:
-  explicit RESTSender(const std::string &name, const utils::Identifier &uuid = utils::Identifier());
+  explicit RESTSender(std::string name, const utils::Identifier &uuid = utils::Identifier());
+
+  EXTENSIONAPI static constexpr const char* Description = "Encapsulates the restful protocol that is built upon C2Protocol.";
 
   C2Payload consumePayload(const std::string &url, const C2Payload &payload, Direction direction, bool async) override;
 
@@ -52,7 +55,7 @@ class RESTSender : public RESTProtocol, public C2Protocol {
   void initialize(core::controller::ControllerServiceProvider* controller, const std::shared_ptr<Configure> &configure) override;
 
  protected:
-  C2Payload sendPayload(const std::string url, const Direction direction, const C2Payload &payload, std::optional<std::string> data);
+  C2Payload sendPayload(const std::string& url, const Direction direction, const C2Payload &payload, std::optional<std::string> data);
 
   /**
    * Initializes the SSLContextService onto the HTTP client if one is needed
@@ -60,19 +63,16 @@ class RESTSender : public RESTProtocol, public C2Protocol {
    * @param type type of HTTP request
    * @param url HTTP url
    */
-  void setSecurityContext(utils::HTTPClient &client, const std::string &type, const std::string &url);
+  void setSecurityContext(extensions::curl::HTTPClient &client, const std::string &type, const std::string &url);
 
   std::shared_ptr<minifi::controllers::SSLContextService> ssl_context_service_;
 
   std::string rest_uri_;
   std::string ack_uri_;
+  RequestEncoding req_encoding_;
 
  private:
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<RESTSender>::getLogger();
 };
 
-}  // namespace c2
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::c2
