@@ -24,7 +24,7 @@
 #include "utils/IntegrationTestUtils.h"
 #include "utils/crypto/EncryptionProvider.h"
 
-using std::literals::chrono_literals::operator""s;
+using namespace std::literals::chrono_literals;
 
 int main(int argc, char **argv) {
   const cmd_args args = parse_cmdline_args(argc, argv, "update");
