@@ -43,7 +43,7 @@ class VerifyC2Server : public HTTPIntegrationBase {
   }
 
   void testSetup() override {
-    LogTestController::getInstance().setDebug<utils::HTTPClient>();
+    LogTestController::getInstance().setDebug<minifi::extensions::curl::HTTPClient>();
     LogTestController::getInstance().setDebug<processors::InvokeHTTP>();
     LogTestController::getInstance().setDebug<c2::RESTReceiver>();
     LogTestController::getInstance().setDebug<c2::C2Agent>();
@@ -72,7 +72,9 @@ class VerifyC2Server : public HTTPIntegrationBase {
     std::string url;
     inv->getProperty(processors::InvokeHTTP::URL.getName(), url);
 
-    std::string port, scheme, path;
+    std::string port;
+    std::string scheme;
+    std::string path;
     parse_http_components(url, port, scheme, path);
     configuration->set(Configuration::nifi_c2_enable, "true");
     configuration->set(Configuration::nifi_c2_agent_class, "test");
