@@ -123,7 +123,7 @@ int main(int argc, char **argv) {
   harness.setKeyDir(args.key_dir);
   PauseResumeHandler responder{flow_resumed_successfully, harness.getConfiguration()};
 
-  std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
+  std::shared_ptr<core::Repository> test_repo = std::make_shared<TestThreadedRepository>();
   std::shared_ptr<core::Repository> test_flow_repo = std::make_shared<TestFlowRepository>();
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   configuration->set(minifi::Configure::nifi_default_directory, args.key_dir);
@@ -150,7 +150,9 @@ int main(int argc, char **argv) {
   assert(inv != nullptr);
   std::string url;
   inv->getProperty(minifi::processors::InvokeHTTP::URL.getName(), url);
-  std::string port, scheme, path;
+  std::string port;
+  std::string scheme;
+  std::string path;
   std::unique_ptr<TestServer> server;
   parse_http_components(url, port, scheme, path);
   server = std::make_unique<TestServer>(port, path, &responder);
