@@ -69,7 +69,9 @@ class VerifyC2Server : public HTTPIntegrationBase {
     std::string url;
     inv->getProperty(minifi::processors::InvokeHTTP::URL.getName(), url);
 
-    std::string port, scheme, path;
+    std::string port;
+    std::string scheme;
+    std::string path;
     parse_http_components(url, port, scheme, path);
     configuration->set(org::apache::nifi::minifi::Configuration::nifi_c2_enable, "true");
     configuration->set(org::apache::nifi::minifi::Configuration::nifi_c2_agent_class, "test");
