@@ -40,8 +40,8 @@
 #include "integration/IntegrationBase.h"
 #include "utils/IntegrationTestUtils.h"
 
-REGISTER_RESOURCE(MockControllerService, "");
-REGISTER_RESOURCE(MockProcessor, "");
+REGISTER_RESOURCE(MockControllerService, ControllerService);
+REGISTER_RESOURCE(MockProcessor, Processor);
 
 void waitToVerifyProcessor() {
   std::this_thread::sleep_for(std::chrono::seconds(2));
@@ -53,14 +53,12 @@ int main(int argc, char **argv) {
 
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
 
-  std::shared_ptr<core::Repository> test_repo = std::make_shared<TestRepository>();
+  std::shared_ptr<core::Repository> test_repo = std::make_shared<TestThreadedRepository>();
   std::shared_ptr<core::Repository> test_flow_repo = std::make_shared<TestFlowRepository>();
 
   configuration->set(minifi::Configure::nifi_flow_configuration_file, args.test_file);
-  std::string client_cert = "cn.crt.pem";
   std::string priv_key_file = "cn.ckey.pem";
   std::string passphrase = "cn.pass";
-  std::string ca_cert = "nifi-cert.pem";
   configuration->set(minifi::Configure::nifi_security_client_certificate, args.test_file);
   configuration->set(minifi::Configure::nifi_security_client_private_key, priv_key_file);
   configuration->set(minifi::Configure::nifi_security_client_pass_phrase, passphrase);
@@ -71,7 +69,6 @@ int main(int argc, char **argv) {
   content_repo->initialize(configuration);
   std::unique_ptr<core::FlowConfiguration> yaml_ptr = std::make_unique<core::YamlConfiguration>(
       test_repo, test_repo, content_repo, stream_factory, configuration, args.test_file);
-  std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
 
   const auto controller = std::make_shared<minifi::FlowController>(test_repo, test_flow_repo, configuration, std::move(yaml_ptr),
       content_repo,
