@@ -32,22 +32,16 @@
 #include "core/controller/ControllerService.h"
 #include "core/logging/LoggerConfiguration.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace jni {
-namespace controllers {
+namespace org::apache::nifi::minifi::jni::controllers {
 
 /**
  * Purpose and Justification: Java Controller Service is intended to be used either within the flow or
  * based on a static load in JVM Creator. The static load simply loads via minifi properties.
- *
  */
 class JavaControllerService : public core::controller::ControllerService, public std::enable_shared_from_this<JavaControllerService>, public JavaServicer {
  public:
-  explicit JavaControllerService(const std::string &name, const utils::Identifier &uuid = {})
-      : ControllerService(name, uuid) {
+  explicit JavaControllerService(std::string name, const utils::Identifier &uuid = {})
+      : ControllerService(std::move(name), uuid) {
   }
 
   explicit JavaControllerService(const std::string &name, const std::shared_ptr<Configure> &configuration)
@@ -56,9 +50,21 @@ class JavaControllerService : public core::controller::ControllerService, public
     initialize();
   }
 
-  static core::Property NarDirectory;
-  static core::Property NarDeploymentDirectory;
-  static core::Property NarDocumentDirectory;
+  EXTENSIONAPI static constexpr const char* Description = "Allows specification of nars to be used within referenced processors.";
+
+  EXTENSIONAPI static const core::Property NarDirectory;
+  EXTENSIONAPI static const core::Property NarDeploymentDirectory;
+  EXTENSIONAPI static const core::Property NarDocumentDirectory;
+  static auto properties() {
+    return std::array{
+      NarDirectory,
+      NarDeploymentDirectory,
+      NarDocumentDirectory
+    };
+  }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
 
   void initialize() override;
 
@@ -92,12 +98,11 @@ class JavaControllerService : public core::controller::ControllerService, public
   JNIEnv *attach() override {
     return loader->attach();
   }
+
   void detach() override {
       loader->detach();
     }
 
-
-
   jobject getClassLoader() override {
     return loader->getClassLoader();
   }
@@ -153,9 +158,4 @@ class JavaControllerService : public core::controller::ControllerService, public
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<JavaControllerService>::getLogger();
 };
 
-} /* namespace controllers */
-} /* namespace jni */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::jni::controllers
