@@ -42,39 +42,47 @@
 #include "WriteArchiveStream.h"
 #include "ReadArchiveStream.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
-// CompressContent Class
 class CompressContent : public core::Processor {
  public:
-  // Constructor
-  /*!
-   * Create a new processor
-   */
-  explicit CompressContent(const std::string& name, const utils::Identifier& uuid = {})
-    : core::Processor(name, uuid)
+  explicit CompressContent(std::string name, const utils::Identifier& uuid = {})
+    : core::Processor(std::move(name), uuid)
     , updateFileName_(false)
     , encapsulateInTar_(false) {
   }
-  // Destructor
   ~CompressContent() override = default;
-  // Processor Name
-  EXTENSIONAPI static constexpr char const* ProcessorName = "CompressContent";
-  // Supported Properties
-  EXTENSIONAPI static core::Property CompressMode;
-  EXTENSIONAPI static core::Property CompressLevel;
-  EXTENSIONAPI static core::Property CompressFormat;
-  EXTENSIONAPI static core::Property UpdateFileName;
-  EXTENSIONAPI static core::Property EncapsulateInTar;
-  EXTENSIONAPI static core::Property BatchSize;
 
-  // Supported Relationships
-  EXTENSIONAPI static core::Relationship Failure;
-  EXTENSIONAPI static core::Relationship Success;
+  EXTENSIONAPI static constexpr const char* Description = "Compresses or decompresses the contents of FlowFiles using a user-specified compression algorithm "
+      "and updates the mime.type attribute as appropriate";
+
+  EXTENSIONAPI static const core::Property CompressMode;
+  EXTENSIONAPI static const core::Property CompressLevel;
+  EXTENSIONAPI static const core::Property CompressFormat;
+  EXTENSIONAPI static const core::Property UpdateFileName;
+  EXTENSIONAPI static const core::Property EncapsulateInTar;
+  EXTENSIONAPI static const core::Property BatchSize;
+  static auto properties() {
+    return std::array{
+      CompressMode,
+      CompressLevel,
+      CompressFormat,
+      UpdateFileName,
+      EncapsulateInTar,
+      BatchSize
+    };
+  }
+
+  EXTENSIONAPI static const core::Relationship Success;
+  EXTENSIONAPI static const core::Relationship Failure;
+  static auto relationships() { return std::array{Success, Failure}; }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_REQUIRED;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
   static const std::string TAR_EXT;
 
@@ -104,14 +112,14 @@ class CompressContent : public core::Processor {
     std::shared_ptr<core::ProcessSession> session_;
     bool success_{false};
 
-    int64_t operator()(const std::shared_ptr<io::BaseStream>& output_stream) {
+    int64_t operator()(const std::shared_ptr<io::OutputStream>& output_stream) {
       std::shared_ptr<io::ZlibBaseStream> filterStream;
       if (compress_mode_ == CompressionMode::Compress) {
         filterStream = std::make_shared<io::ZlibCompressStream>(gsl::make_not_null(output_stream.get()), io::ZlibCompressionFormat::GZIP, compress_level_);
       } else {
         filterStream = std::make_shared<io::ZlibDecompressStream>(gsl::make_not_null(output_stream.get()), io::ZlibCompressionFormat::GZIP);
       }
-      session_->read(flow_, [this, &filterStream](const std::shared_ptr<io::BaseStream>& input_stream) -> int64_t {
+      session_->read(flow_, [this, &filterStream](const std::shared_ptr<io::InputStream>& input_stream) -> int64_t {
         std::vector<std::byte> buffer(16 * 1024U);
         size_t read_size = 0;
         while (read_size < flow_->getSize()) {
@@ -159,10 +167,6 @@ class CompressContent : public core::Processor {
 
   void processFlowFile(const std::shared_ptr<core::FlowFile>& flowFile, const std::shared_ptr<core::ProcessSession>& session);
 
-  core::annotation::Input getInputRequirement() const override {
-    return core::annotation::Input::INPUT_REQUIRED;
-  }
-
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<CompressContent>::getLogger();
   int compressLevel_{};
   CompressionMode compressMode_;
@@ -174,8 +178,4 @@ class CompressContent : public core::Processor {
   static const std::map<io::CompressionFormat, std::string> fileExtension_;
 };
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
