@@ -22,11 +22,10 @@
 #include <archive.h>
 #include <archive_entry.h>
 
-#include <string.h>
+#include <cstring>
 
 #include <array>
 #include <string>
-#include <set>
 
 #include <memory>
 
@@ -36,26 +35,16 @@
 #include "Exception.h"
 #include "utils/gsl.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 std::shared_ptr<utils::IdGenerator> FocusArchiveEntry::id_generator_ = utils::IdGenerator::getIdGenerator();
 
-core::Property FocusArchiveEntry::Path("Path", "The path within the archive to focus (\"/\" to focus the total archive)", "");
-core::Relationship FocusArchiveEntry::Success("success", "success operational on the flow record");
+const core::Property FocusArchiveEntry::Path("Path", "The path within the archive to focus (\"/\" to focus the total archive)", "");
+const core::Relationship FocusArchiveEntry::Success("success", "success operational on the flow record");
 
 void FocusArchiveEntry::initialize() {
-  //! Set the supported properties
-  std::set<core::Property> properties;
-  properties.insert(Path);
-  setSupportedProperties(properties);
-  //! Set the supported relationships
-  std::set<core::Relationship> relationships;
-  relationships.insert(Success);
-  setSupportedRelationships(relationships);
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
 void FocusArchiveEntry::onTrigger(core::ProcessContext *context, core::ProcessSession *session) {
@@ -96,7 +85,7 @@ void FocusArchiveEntry::onTrigger(core::ProcessContext *context, core::ProcessSe
   }
 
   // Restore target archive entry
-  if (targetEntryStashKey != "") {
+  if (!targetEntryStashKey.empty()) {
     session->restore(targetEntryStashKey, flowFile);
   } else {
     logger_->log_warn("FocusArchiveEntry failed to locate target entry: %s",
@@ -137,11 +126,11 @@ void FocusArchiveEntry::onTrigger(core::ProcessContext *context, core::ProcessSe
   session->transfer(flowFile, Success);
 }
 
-typedef struct {
-  std::shared_ptr<io::BaseStream> stream;
+struct FocusArchiveEntryReadData {
+  std::shared_ptr<io::InputStream> stream;
   core::Processor *processor;
   std::array<std::byte, 8196> buf;
-} FocusArchiveEntryReadData;
+};
 
 // Read callback which reads from the flowfile stream
 la_ssize_t FocusArchiveEntry::ReadCallback::read_cb(struct archive * a, void *d, const void **buf) {
@@ -163,7 +152,7 @@ la_ssize_t FocusArchiveEntry::ReadCallback::read_cb(struct archive * a, void *d,
   return gsl::narrow<la_ssize_t>(read);
 }
 
-int64_t FocusArchiveEntry::ReadCallback::operator()(const std::shared_ptr<io::BaseStream>& stream) const {
+int64_t FocusArchiveEntry::ReadCallback::operator()(const std::shared_ptr<io::InputStream>& stream) const {
   auto inputArchive = archive_read_new();
   struct archive_entry *entry;
   int64_t nlen = 0;
@@ -176,15 +165,13 @@ int64_t FocusArchiveEntry::ReadCallback::operator()(const std::shared_ptr<io::Ba
   archive_read_support_filter_all(inputArchive);
 
   // Read each item in the archive
-  int res;
-
-  if ((res = archive_read_open(inputArchive, &data, ok_cb, read_cb, ok_cb))) {
+  if (archive_read_open(inputArchive, &data, ok_cb, read_cb, ok_cb)) {
     logger_->log_error("FocusArchiveEntry can't open due to archive error: %s", archive_error_string(inputArchive));
     return nlen;
   }
 
   while (proc_->isRunning()) {
-    res = archive_read_next_header(inputArchive, &entry);
+    auto res = archive_read_next_header(inputArchive, &entry);
 
     if (res == ARCHIVE_EOF) {
       break;
@@ -254,12 +241,6 @@ FocusArchiveEntry::ReadCallback::ReadCallback(core::Processor *processor, utils:
   _archiveMetadata = archiveMetadata;
 }
 
-REGISTER_RESOURCE(FocusArchiveEntry, "Allows manipulation of entries within an archive (e.g. TAR) by focusing on one entry within the archive at a time. "
-    "When an archive entry is focused, that entry is treated as the content of the FlowFile and may be manipulated independently of the rest of the archive."
-    " To restore the FlowFile to its original state, use UnfocusArchiveEntry.");
+REGISTER_RESOURCE(FocusArchiveEntry, Processor);
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
