@@ -19,12 +19,11 @@
  */
 #include "UnfocusArchiveEntry.h"
 
-#include <string.h>
+#include <cstring>
 #include <iostream>
 #include <fstream>
 #include <memory>
 #include <string>
-#include <set>
 #include <system_error>
 
 #include "archive.h"
@@ -35,22 +34,13 @@
 #include "core/Resource.h"
 #include "utils/gsl.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
-core::Relationship UnfocusArchiveEntry::Success("success", "success operational on the flow record");
+const core::Relationship UnfocusArchiveEntry::Success("success", "success operational on the flow record");
 
 void UnfocusArchiveEntry::initialize() {
-  //! Set the supported properties
-  std::set<core::Property> properties;
-  setSupportedProperties(properties);
-  //! Set the supported relationships
-  std::set<core::Relationship> relationships;
-  relationships.insert(Success);
-  setSupportedRelationships(relationships);
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
 void UnfocusArchiveEntry::onTrigger(core::ProcessContext *context, core::ProcessSession *session) {
@@ -149,9 +139,9 @@ UnfocusArchiveEntry::WriteCallback::WriteCallback(ArchiveMetadata *archiveMetada
   _archiveMetadata = archiveMetadata;
 }
 
-typedef struct {
-  std::shared_ptr<io::BaseStream> stream;
-} UnfocusArchiveEntryWriteData;
+struct UnfocusArchiveEntryWriteData {
+  std::shared_ptr<io::OutputStream> stream;
+};
 
 la_ssize_t UnfocusArchiveEntry::WriteCallback::write_cb(struct archive *, void *d, const void *buffer, size_t length) {
   auto* const data = static_cast<UnfocusArchiveEntryWriteData *>(d);
@@ -159,7 +149,7 @@ la_ssize_t UnfocusArchiveEntry::WriteCallback::write_cb(struct archive *, void *
   return io::isError(write_ret) ? -1 : gsl::narrow<la_ssize_t>(write_ret);
 }
 
-int64_t UnfocusArchiveEntry::WriteCallback::operator()(const std::shared_ptr<io::BaseStream>& stream) const {
+int64_t UnfocusArchiveEntry::WriteCallback::operator()(const std::shared_ptr<io::OutputStream>& stream) const {
   auto outputArchive = archive_write_new();
   int64_t nlen = 0;
 
@@ -209,7 +199,7 @@ int64_t UnfocusArchiveEntry::WriteCallback::operator()(const std::shared_ptr<io:
 
       while (ifs.good()) {
         ifs.read(buf, sizeof(buf));
-        size_t len = gsl::narrow<size_t>(ifs.gcount());
+        auto len = gsl::narrow<size_t>(ifs.gcount());
         int64_t written = archive_write_data(outputArchive, buf, len);
         if (written < 0) {
           logger_->log_error("UnfocusArchiveEntry failed to write data to "
@@ -235,10 +225,6 @@ int64_t UnfocusArchiveEntry::WriteCallback::operator()(const std::shared_ptr<io:
   return nlen;
 }
 
-REGISTER_RESOURCE(UnfocusArchiveEntry, "Restores a FlowFile which has had an archive entry focused via FocusArchiveEntry to its original state.");
+REGISTER_RESOURCE(UnfocusArchiveEntry, Processor);
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
