@@ -37,20 +37,35 @@ namespace org::apache::nifi::minifi::extensions::procfs {
 
 class ProcFsMonitor : public core::Processor {
  public:
-  explicit ProcFsMonitor(const std::string& name, utils::Identifier uuid = utils::Identifier())
-      : Processor(name, uuid) {
+  explicit ProcFsMonitor(std::string name, utils::Identifier uuid = utils::Identifier())
+      : Processor(std::move(name), uuid) {
   }
   ~ProcFsMonitor() override = default;
 
-  static constexpr char const *ProcessorName = "ProcFsMonitor";
+  EXTENSIONAPI static constexpr const char* Description = "This processor can create FlowFiles with various performance data through the proc pseudo-filesystem. (Linux only)";
 
   EXTENSIONAPI static const core::Property OutputFormatProperty;
   EXTENSIONAPI static const core::Property OutputCompactnessProperty;
   EXTENSIONAPI static const core::Property DecimalPlaces;
   EXTENSIONAPI static const core::Property ResultRelativenessProperty;
+  static auto properties() {
+    return std::array{
+      OutputFormatProperty,
+      OutputCompactnessProperty,
+      DecimalPlaces,
+      ResultRelativenessProperty
+    };
+  }
 
   EXTENSIONAPI static const core::Relationship Success;
+  static auto relationships() { return std::array{Success}; }
 
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_FORBIDDEN;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = true;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
  public:
   void onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& sessionFactory) override;
@@ -75,14 +90,6 @@ class ProcFsMonitor : public core::Processor {
   )
 
  private:
-  bool isSingleThreaded() const override {
-    return true;
-  }
-
-  core::annotation::Input getInputRequirement() const override {
-    return core::annotation::Input::INPUT_FORBIDDEN;
-  }
-
   rapidjson::Value& prepareJSONBody(rapidjson::Document& root);
 
   void setupDecimalPlacesFromProperties(const core::ProcessContext& context);
