@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -17,30 +16,26 @@
  */
 #pragma once
 
-#include <string>
 #include <memory>
+#include <string>
+#include <utility>
 
 #include "core/Core.h"
 #include "core/Connectable.h"
 #include "core/ContentRepository.h"
-#include "properties/Configure.h"
+#include "core/BufferedContentSession.h"
 #include "core/logging/LoggerConfiguration.h"
+#include "core/Property.h"
 #include "database/RocksDatabase.h"
-#include "core/ContentSession.h"
-
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-namespace repository {
+#include "properties/Configure.h"
 
+namespace org::apache::nifi::minifi::core::repository {
 
 /**
  * DatabaseContentRepository is a content repository that stores data onto the local file system.
  */
 class DatabaseContentRepository : public core::ContentRepository, public core::Connectable {
-  class Session : public ContentSession {
+  class Session : public BufferedContentSession {
    public:
     explicit Session(std::shared_ptr<ContentRepository> repository);
 
@@ -50,8 +45,8 @@ class DatabaseContentRepository : public core::ContentRepository, public core::C
  public:
   static constexpr const char* ENCRYPTION_KEY_NAME = "nifi.database.content.repository.encryption.key";
 
-  explicit DatabaseContentRepository(const std::string& name = getClassName<DatabaseContentRepository>(), const utils::Identifier& uuid = {})
-      : core::Connectable(name, uuid),
+  explicit DatabaseContentRepository(std::string name = getClassName<DatabaseContentRepository>(), const utils::Identifier& uuid = {})
+      : core::Connectable(std::move(name), uuid),
         is_valid_(false),
         db_(nullptr),
         logger_(logging::LoggerFactory<DatabaseContentRepository>::getLogger()) {
@@ -60,11 +55,15 @@ class DatabaseContentRepository : public core::ContentRepository, public core::C
     stop();
   }
 
+  static auto properties() { return std::array<core::Property, 0>{}; }
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+
   std::shared_ptr<ContentSession> createSession() override;
 
   bool initialize(const std::shared_ptr<minifi::Configure> &configuration) override;
 
-  void stop() override;
+  void stop();
 
   std::shared_ptr<io::BaseStream> write(const minifi::ResourceClaim &claim, bool append = false) override;
 
@@ -104,9 +103,4 @@ class DatabaseContentRepository : public core::ContentRepository, public core::C
   std::shared_ptr<logging::Logger> logger_;
 };
 
-} /* namespace repository */
-} /* namespace core */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::core::repository
