@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -27,30 +26,29 @@
 #include "rocksdb/options.h"
 #include "rocksdb/slice.h"
 #include "rocksdb/utilities/checkpoint.h"
-#include "core/Repository.h"
 #include "core/Core.h"
-#include "Connection.h"
 #include "core/logging/LoggerConfiguration.h"
+#include "core/ThreadedRepository.h"
+#include "Connection.h"
 #include "concurrentqueue.h"
 #include "database/RocksDatabase.h"
 #include "encryption/RocksDbEncryptionProvider.h"
 #include "utils/crypto/EncryptionProvider.h"
+#include "SwapManager.h"
+#include "FlowFileLoader.h"
+#include "range/v3/algorithm/all_of.hpp"
+#include "utils/Literals.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-namespace repository {
+namespace org::apache::nifi::minifi::core::repository {
 
 #ifdef WIN32
-#define FLOWFILE_REPOSITORY_DIRECTORY ".\\flowfile_repository"
-#define FLOWFILE_CHECKPOINT_DIRECTORY ".\\flowfile_checkpoint"
+constexpr auto FLOWFILE_REPOSITORY_DIRECTORY = ".\\flowfile_repository";
+constexpr auto FLOWFILE_CHECKPOINT_DIRECTORY = ".\\flowfile_checkpoint";
 #else
-#define FLOWFILE_REPOSITORY_DIRECTORY "./flowfile_repository"
-#define FLOWFILE_CHECKPOINT_DIRECTORY "./flowfile_checkpoint"
+constexpr auto FLOWFILE_REPOSITORY_DIRECTORY = "./flowfile_repository";
+constexpr auto FLOWFILE_CHECKPOINT_DIRECTORY = "./flowfile_checkpoint";
 #endif
-#define MAX_FLOWFILE_REPOSITORY_STORAGE_SIZE (10*1024*1024)  // 10M
+constexpr auto MAX_FLOWFILE_REPOSITORY_STORAGE_SIZE = 10_MiB;
 constexpr auto MAX_FLOWFILE_REPOSITORY_ENTRY_LIFE_TIME = std::chrono::minutes(10);
 constexpr auto FLOWFILE_REPOSITORY_PURGE_PERIOD = std::chrono::seconds(2);
 constexpr auto FLOWFILE_REPOSITORY_RETRY_INTERVAL_INCREMENTS = std::chrono::milliseconds(500);
@@ -59,23 +57,22 @@ constexpr auto FLOWFILE_REPOSITORY_RETRY_INTERVAL_INCREMENTS = std::chrono::mill
  * Flow File repository
  * Design: Extends Repository and implements the run function, using rocksdb as the primary substrate.
  */
-class FlowFileRepository : public core::Repository {
+class FlowFileRepository : public ThreadedRepository, public SwapManager {
  public:
   static constexpr const char* ENCRYPTION_KEY_NAME = "nifi.flowfile.repository.encryption.key";
-  // Constructor
 
-  FlowFileRepository(const std::string& name, const utils::Identifier& /*uuid*/)
-      : FlowFileRepository(name) {
+  FlowFileRepository(std::string name, const utils::Identifier& /*uuid*/)
+      : FlowFileRepository(std::move(name)) {
   }
 
-  FlowFileRepository(const std::string repo_name = "",
-                     const std::string& checkpoint_dir = FLOWFILE_CHECKPOINT_DIRECTORY,
+  explicit FlowFileRepository(std::string repo_name = "",
+                     std::string checkpoint_dir = FLOWFILE_CHECKPOINT_DIRECTORY,
                      std::string directory = FLOWFILE_REPOSITORY_DIRECTORY,
                      std::chrono::milliseconds maxPartitionMillis = MAX_FLOWFILE_REPOSITORY_ENTRY_LIFE_TIME,
                      int64_t maxPartitionBytes = MAX_FLOWFILE_REPOSITORY_STORAGE_SIZE,
                      std::chrono::milliseconds purgePeriod = FLOWFILE_REPOSITORY_PURGE_PERIOD)
       : core::SerializableComponent(repo_name),
-        Repository(repo_name.length() > 0 ? repo_name : core::getClassName<FlowFileRepository>(), std::move(directory), maxPartitionMillis, maxPartitionBytes, purgePeriod),
+        ThreadedRepository(repo_name.length() > 0 ? std::move(repo_name) : core::getClassName<FlowFileRepository>(), std::move(directory), maxPartitionMillis, maxPartitionBytes, purgePeriod),
         checkpoint_dir_(std::move(checkpoint_dir)),
         content_repo_(nullptr),
         checkpoint_(nullptr),
@@ -87,7 +84,11 @@ class FlowFileRepository : public core::Repository {
     stop();
   }
 
-  bool isNoop() override {
+  static auto properties() { return std::array<core::Property, 0>{}; }
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+
+  bool isNoop() const override {
     return false;
   }
 
@@ -95,7 +96,6 @@ class FlowFileRepository : public core::Repository {
 
   virtual void printStats();
 
-  // initialize
   bool initialize(const std::shared_ptr<Configure> &configure) override {
     config_ = configure;
     std::string value;
@@ -125,10 +125,11 @@ class FlowFileRepository : public core::Repository {
     // To avoid DB write issues during heavy load it's recommended to have high number of buffer.
     // Rocksdb's stall feature can also trigger in case the number of buffers is >= 3.
     // The more buffers we have the more memory rocksdb can utilize without significant memory consumption under low load.
-    auto cf_options = [] (minifi::internal::Writable<rocksdb::ColumnFamilyOptions>& cf_opts) {
-      cf_opts.set(&rocksdb::ColumnFamilyOptions::write_buffer_size, 8ULL << 20U);
-      cf_opts.set<int>(&rocksdb::ColumnFamilyOptions::max_write_buffer_number, 20);
-      cf_opts.set<int>(&rocksdb::ColumnFamilyOptions::min_write_buffer_number_to_merge, 1);
+    auto cf_options = [] (rocksdb::ColumnFamilyOptions& cf_opts) {
+      cf_opts.OptimizeForPointLookup(4);
+      cf_opts.write_buffer_size = 8ULL << 20U;
+      cf_opts.max_write_buffer_number = 20;
+      cf_opts.min_write_buffer_number_to_merge = 1;
     };
     db_ = minifi::internal::RocksDatabase::create(db_options, cf_options, directory_);
     if (db_->open()) {
@@ -140,9 +141,7 @@ class FlowFileRepository : public core::Repository {
     }
   }
 
-  void run() override;
-
-  bool Put(std::string key, const uint8_t *buf, size_t bufLen) override {
+  bool Put(const std::string& key, const uint8_t *buf, size_t bufLen) override {
     // persistent to the DB
     auto opendb = db_->open();
     if (!opendb) {
@@ -171,16 +170,15 @@ class FlowFileRepository : public core::Repository {
     return ExecuteWithRetry(operation);
   }
 
-
   /**
-   *
    * Deletes the key
    * @return status of the delete operation
    */
-  bool Delete(std::string key) override {
+  bool Delete(const std::string& key) override {
     keys_to_delete.enqueue(key);
     return true;
   }
+
   /**
    * Sets the value from the provided key
    * @return status of the get operation.
@@ -195,49 +193,58 @@ class FlowFileRepository : public core::Repository {
 
   void loadComponent(const std::shared_ptr<core::ContentRepository> &content_repo) override;
 
-  void start() override {
-    if (this->purge_period_ <= std::chrono::milliseconds(0)) {
-      return;
+  bool start() override {
+    const bool ret = ThreadedRepository::start();
+    if (swap_loader_) {
+      swap_loader_->start();
     }
-    if (running_) {
-      return;
+    return ret;
+  }
+
+  bool stop() override {
+    if (swap_loader_) {
+      swap_loader_->stop();
     }
-    running_ = true;
-    thread_ = std::thread(&FlowFileRepository::run, this);
-    logger_->log_debug("%s Repository Monitor Thread Start", getName());
+    return ThreadedRepository::stop();
+  }
+
+  void store([[maybe_unused]] std::vector<std::shared_ptr<core::FlowFile>> flow_files) override {
+    gsl_Expects(ranges::all_of(flow_files, &FlowFile::isStored));
+    // pass, flowfiles are already persisted in the repository
+  }
+
+  std::future<std::vector<std::shared_ptr<core::FlowFile>>> load(std::vector<SwappedFlowFile> flow_files) override {
+    return swap_loader_->load(std::move(flow_files));
   }
 
  private:
-  bool ExecuteWithRetry(std::function<rocksdb::Status()> operation);
+  void run() override;
+
+  bool ExecuteWithRetry(const std::function<rocksdb::Status()>& operation);
 
-  /**
-   * Initialize the repository
-   */
   void initialize_repository();
 
   /**
    * Returns true if a checkpoint is needed at startup
    * @return true if a checkpoint is needed.
    */
-  bool need_checkpoint(minifi::internal::OpenRocksDb& opendb);
+  static bool need_checkpoint(minifi::internal::OpenRocksDb& opendb);
 
-  /**
-   * Prunes stored flow files.
-   */
   void prune_stored_flowfiles();
 
+  std::thread& getThread() override {
+    return thread_;
+  }
+
   std::string checkpoint_dir_;
   moodycamel::ConcurrentQueue<std::string> keys_to_delete;
   std::shared_ptr<core::ContentRepository> content_repo_;
   std::unique_ptr<minifi::internal::RocksDatabase> db_;
   std::unique_ptr<rocksdb::Checkpoint> checkpoint_;
+  std::unique_ptr<FlowFileLoader> swap_loader_;
   std::shared_ptr<logging::Logger> logger_;
   std::shared_ptr<minifi::Configure> config_;
+  std::thread thread_;
 };
 
-} /* namespace repository */
-} /* namespace core */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::core::repository
