@@ -20,7 +20,6 @@
  */
 
 #include <memory>
-#include <set>
 #include <utility>
 
 #ifdef PYTHON_SUPPORT
@@ -28,51 +27,39 @@
 #endif  // PYTHON_SUPPORT
 
 #include "ExecuteScript.h"
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 #include "utils/ProcessorConfigUtils.h"
 #include "utils/StringUtils.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
-core::Property ExecuteScript::ScriptEngine(
+const core::Property ExecuteScript::ScriptEngine(
   core::PropertyBuilder::createProperty("Script Engine")
     ->withDescription(R"(The engine to execute scripts (python, lua))")
     ->isRequired(true)
     ->withAllowableValues(ScriptEngineOption::values())
     ->withDefaultValue(toString(ScriptEngineOption::PYTHON))
     ->build());
-core::Property ExecuteScript::ScriptFile("Script File",
+const core::Property ExecuteScript::ScriptFile("Script File",
     R"(Path to script file to execute. Only one of Script File or Script Body may be used)", "");
-core::Property ExecuteScript::ScriptBody("Script Body",
+const core::Property ExecuteScript::ScriptBody("Script Body",
     R"(Body of script to execute. Only one of Script File or Script Body may be used)", "");
-core::Property ExecuteScript::ModuleDirectory("Module Directory",
+const core::Property ExecuteScript::ModuleDirectory("Module Directory",
     R"(Comma-separated list of paths to files and/or directories which contain modules required by the script)", "");
 
-core::Relationship ExecuteScript::Success("success", "Script successes");
-core::Relationship ExecuteScript::Failure("failure", "Script failures");
+const core::Relationship ExecuteScript::Success("success", "Script successes");
+const core::Relationship ExecuteScript::Failure("failure", "Script failures");
 
-ScriptEngineFactory::ScriptEngineFactory(core::Relationship& success, core::Relationship& failure, std::shared_ptr<core::logging::Logger> logger)
+ScriptEngineFactory::ScriptEngineFactory(const core::Relationship& success, const core::Relationship& failure, std::shared_ptr<core::logging::Logger> logger)
   : success_(success),
     failure_(failure),
-    logger_(logger) {
+    logger_(std::move(logger)) {
 }
 
 void ExecuteScript::initialize() {
-  std::set<core::Property> properties;
-  properties.insert(ScriptEngine);
-  properties.insert(ScriptFile);
-  properties.insert(ScriptBody);
-  properties.insert(ModuleDirectory);
-  setSupportedProperties(std::move(properties));
-
-  std::set<core::Relationship> relationships;
-  relationships.insert(Success);
-  relationships.insert(Failure);
-  setSupportedRelationships(std::move(relationships));
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 
 #ifdef PYTHON_SUPPORT
   python::PythonScriptEngine::initialize();
@@ -81,7 +68,7 @@ void ExecuteScript::initialize() {
 
 void ExecuteScript::onSchedule(core::ProcessContext *context, core::ProcessSessionFactory* /*sessionFactory*/) {
 #ifdef LUA_SUPPORT
-  script_engine_q_ = std::make_unique<ScriptEngineQueue<lua::LuaScriptEngine>>(getMaxConcurrentTasks(), engine_factory_, logger_);
+  lua_script_engine_queue_ = utils::ResourceQueue<lua::LuaScriptEngine>::create(getMaxConcurrentTasks(), logger_);
 #endif  // LUA_SUPPORT
 #ifdef PYTHON_SUPPORT
   python_script_engine_ = engine_factory_.createEngine<python::PythonScriptEngine>();
@@ -108,17 +95,28 @@ void ExecuteScript::onSchedule(core::ProcessContext *context, core::ProcessSessi
 
 void ExecuteScript::onTrigger(const std::shared_ptr<core::ProcessContext> &context,
                               const std::shared_ptr<core::ProcessSession> &session) {
-  std::shared_ptr<script::ScriptEngine> engine;
+  script::ScriptEngine* engine = nullptr;
+
+#ifdef LUA_SUPPORT
+  std::optional<utils::ResourceQueue<lua::LuaScriptEngine>::ResourceWrapper> lua_script_engine;
+#endif
 
   if (script_engine_ == ScriptEngineOption::PYTHON) {
 #ifdef PYTHON_SUPPORT
-    engine = python_script_engine_;
+    gsl_Expects(python_script_engine_);
+    engine = python_script_engine_.get();
 #else
     throw std::runtime_error("Python support is disabled in this build.");
 #endif  // PYTHON_SUPPORT
   } else if (script_engine_ == ScriptEngineOption::LUA) {
 #ifdef LUA_SUPPORT
-    engine = script_engine_q_->getScriptEngine();
+    gsl_Expects(lua_script_engine_queue_);
+    auto create_engine = [&]() -> std::unique_ptr<lua::LuaScriptEngine> {
+      return engine_factory_.createEngine<lua::LuaScriptEngine>();
+    };
+
+    lua_script_engine.emplace(lua_script_engine_queue_->getResource(create_engine));
+    engine = lua_script_engine->get();
 #else
     throw std::runtime_error("Lua support is disabled in this build.");
 #endif  // LUA_SUPPORT
@@ -140,30 +138,9 @@ void ExecuteScript::onTrigger(const std::shared_ptr<core::ProcessContext> &conte
     throw std::runtime_error("Neither Script Body nor Script File is available to execute");
   }
 
-  if (script_engine_ == ScriptEngineOption::PYTHON) {
-#ifdef PYTHON_SUPPORT
-    triggerEngineProcessor<python::PythonScriptEngine>(engine, context, session);
-#else
-    throw std::runtime_error("Python support is disabled in this build.");
-#endif  // PYTHON_SUPPORT
-  } else if (script_engine_ == ScriptEngineOption::LUA) {
-#ifdef LUA_SUPPORT
-    triggerEngineProcessor<lua::LuaScriptEngine>(engine, context, session);
-    script_engine_q_->returnScriptEngine(std::static_pointer_cast<lua::LuaScriptEngine>(engine));
-#else
-    throw std::runtime_error("Lua support is disabled in this build.");
-#endif  // LUA_SUPPORT
-  }
+  engine->onTrigger(context, session);
 }
 
-REGISTER_RESOURCE(ExecuteScript, "Executes a script given the flow file and a process session. The script is responsible for handling the incoming flow file (transfer to SUCCESS or remove, e.g.) "
-    "as well as any flow files created by the script. If the handling is incomplete or incorrect, the session will be rolled back.Scripts must define an onTrigger function which accepts NiFi Context"
-    " and Property objects. For efficiency, scripts are executed once when the processor is run, then the onTrigger method is called for each incoming flowfile. This enables scripts to keep state "
-    "if they wish, although there will be a script context per concurrent task of the processor. In order to, e.g., compute an arithmetic sum based on incoming flow file information, set the "
-    "concurrent tasks to 1.");
+REGISTER_RESOURCE(ExecuteScript, Processor);
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
