@@ -23,15 +23,11 @@
 
 #include "LuaScriptEngine.h"
 #include "LuaProcessSession.h"
+#include "utils/StringUtils.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace lua {
+namespace org::apache::nifi::minifi::lua {
 
-LuaScriptEngine::LuaScriptEngine()
-    : lua_() {
+LuaScriptEngine::LuaScriptEngine() {
   lua_.open_libraries(sol::lib::base,
                       sol::lib::os,
                       sol::lib::coroutine,
@@ -58,18 +54,20 @@ LuaScriptEngine::LuaScriptEngine()
       "removeAttribute", &script::ScriptFlowFile::removeAttribute,
       "updateAttribute", &script::ScriptFlowFile::updateAttribute,
       "setAttribute", &script::ScriptFlowFile::setAttribute);
-  lua_.new_usertype<lua::LuaBaseStream>(
-      "BaseStream",
-      "read", &lua::LuaBaseStream::read,
-      "write", &lua::LuaBaseStream::write);
+  lua_.new_usertype<lua::LuaInputStream>(
+      "InputStream",
+      "read", &lua::LuaInputStream::read);
+  lua_.new_usertype<lua::LuaOutputStream>(
+      "OutputStream",
+      "write", &lua::LuaOutputStream::write);
 }
 
 void LuaScriptEngine::executeScriptWithAppendedModulePaths(std::string& script) {
   for (const auto& module_path : module_paths_) {
     if (std::filesystem::is_regular_file(std::filesystem::status(module_path))) {
-      script = "package.path = package.path .. \";" + module_path + "\"\n" + script;
+      script = utils::StringUtils::join_pack("package.path = package.path .. [[;", module_path, "]]\n", script);
     } else {
-      script = "package.path = package.path .. \";" + module_path + "/?.lua\"\n" + script;
+      script = utils::StringUtils::join_pack("package.path = package.path .. [[;", module_path, "/?.lua]]\n", script);
     }
   }
   lua_.script(script, sol::script_throw_on_error);
@@ -102,8 +100,4 @@ void LuaScriptEngine::evalFile(const std::string &file_name) {
   }
 }
 
-} /* namespace lua */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::lua
