@@ -31,11 +31,7 @@
 
 #include "LuaProcessSession.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace lua {
+namespace org::apache::nifi::minifi::lua {
 
 class LuaScriptEngine : public script::ScriptEngine {
  public:
@@ -84,7 +80,7 @@ class LuaScriptEngine : public script::ScriptEngine {
   };
 
   void onTrigger(const std::shared_ptr<core::ProcessContext> &context,
-      const std::shared_ptr<core::ProcessSession> &session) {
+      const std::shared_ptr<core::ProcessSession> &session) override {
     auto script_context = convert(context);
     auto lua_session = convert(session);
     TriggerSession trigger_session(script_context, lua_session);
@@ -115,8 +111,4 @@ class LuaScriptEngine : public script::ScriptEngine {
   sol::state lua_;
 };
 
-} /* namespace lua */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::lua
