@@ -27,14 +27,10 @@
 
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace python {
-namespace processors {
+namespace org::apache::nifi::minifi::python::processors {
 
 const core::Property ExecutePythonProcessor::ScriptFile(core::PropertyBuilder::createProperty("Script File")
     ->withDescription("Path to script file to execute. Only one of Script File or Script Body may be used")
@@ -59,16 +55,9 @@ const core::Relationship ExecutePythonProcessor::Failure("failure", "Script fail
 
 void ExecutePythonProcessor::initialize() {
   if (getProperties().empty()) {
-    setSupportedProperties({
-      ScriptFile,
-      ScriptBody,
-      ModuleDirectory
-    });
+    setSupportedProperties(properties());
     setAcceptAllProperties();
-    setSupportedRelationships({
-      Success,
-      Failure
-    });
+    setSupportedRelationships(relationships());
   }
 
   if (processor_initialized_) {
@@ -128,7 +117,7 @@ void ExecutePythonProcessor::onTrigger(const std::shared_ptr<core::ProcessContex
 void ExecutePythonProcessor::appendPathForImportModules() {
   std::string module_directory;
   getProperty(ModuleDirectory.getName(), module_directory);
-  if (module_directory.size()) {
+  if (!module_directory.empty()) {
     python_script_engine_->setModulePaths(utils::StringUtils::splitAndTrimRemovingEmpty(module_directory, ","));
   }
 }
@@ -151,8 +140,8 @@ void ExecutePythonProcessor::loadScript() {
     throw std::runtime_error("Neither Script Body nor Script File is available to execute");
   }
 
-  if (script_file.size()) {
-    if (script_body.size()) {
+  if (!script_file.empty()) {
+    if (!script_body.empty()) {
       throw std::runtime_error("Only one of Script File or Script Body may be used");
     }
     script_file_path_ = script_file;
@@ -161,7 +150,6 @@ void ExecutePythonProcessor::loadScript() {
     return;
   }
   script_to_exec_ = script_body;
-  return;
 }
 
 void ExecutePythonProcessor::reloadScriptIfUsingScriptFileProperty() {
@@ -188,16 +176,6 @@ std::unique_ptr<PythonScriptEngine> ExecutePythonProcessor::createScriptEngine()
   return engine;
 }
 
-REGISTER_RESOURCE(
-    ExecutePythonProcessor, "Executes a script given the flow file and a process session. The script is responsible for handling the incoming flow file (transfer to SUCCESS or remove, e.g.) "
-    "as well as any flow files created by the script. If the handling is incomplete or incorrect, the session will be rolled back.Scripts must define an onTrigger function which accepts NiFi Context"
-    " and Property objects. For efficiency, scripts are executed once when the processor is run, then the onTrigger method is called for each incoming flowfile. This enables scripts to keep state "
-    "if they wish, although there will be a script context per concurrent task of the processor. In order to, e.g., compute an arithmetic sum based on incoming flow file information, set the "
-    "concurrent tasks to 1.");
+REGISTER_RESOURCE(ExecutePythonProcessor, Processor);
 
-} /* namespace processors */
-} /* namespace python */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::python::processors
