@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -20,10 +19,8 @@
 
 #include <memory>
 #include <algorithm>
-#include <cctype>
 #include <cstdint>
 #include <cstring>
-#include <iostream>
 #include <iterator>
 #include <limits>
 #include <map>
@@ -35,174 +32,58 @@
 #include <tuple>
 #include <deque>
 
-#include "utils/ByteArrayCallback.h"
 #include "utils/TimeUtil.h"
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
 #include "core/FlowFile.h"
-#include "core/logging/Logger.h"
 #include "core/ProcessContext.h"
 #include "core/Relationship.h"
 #include "core/Resource.h"
 #include "io/BufferStream.h"
 #include "io/StreamFactory.h"
-#include "ResourceClaim.h"
-
-#include "rapidjson/document.h"
 #include "rapidjson/ostreamwrapper.h"
-#include "rapidjson/istreamwrapper.h"
-#include "rapidjson/writer.h"
 
 using namespace std::literals::chrono_literals;
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
-
-core::Property ListSFTP::ListingStrategy(core::PropertyBuilder::createProperty("Listing Strategy")
-    ->withDescription("Specify how to determine new/updated entities. See each strategy descriptions for detail.")
-    ->isRequired(true)
-    ->withAllowableValues<std::string>({LISTING_STRATEGY_TRACKING_TIMESTAMPS, LISTING_STRATEGY_TRACKING_ENTITIES})
-    ->withDefaultValue(LISTING_STRATEGY_TRACKING_TIMESTAMPS)->build());
-
-core::Property ListSFTP::RemotePath(core::PropertyBuilder::createProperty("Remote Path")
-    ->withDescription("The fully qualified filename on the remote system")
-    ->isRequired(false)->supportsExpressionLanguage(true)->build());
-
-core::Property ListSFTP::SearchRecursively(core::PropertyBuilder::createProperty("Search Recursively")
-    ->withDescription("If true, will pull files from arbitrarily nested subdirectories; "
-                      "otherwise, will not traverse subdirectories")
-    ->isRequired(true)->withDefaultValue<bool>(false)->build());
-
-core::Property ListSFTP::FollowSymlink(core::PropertyBuilder::createProperty("Follow symlink")
-    ->withDescription("If true, will pull even symbolic files and also nested symbolic subdirectories; "
-                      "otherwise, will not read symbolic files and will not traverse symbolic link subdirectories")
-    ->isRequired(true)->withDefaultValue<bool>(false)->build());
-
-core::Property ListSFTP::FileFilterRegex(core::PropertyBuilder::createProperty("File Filter Regex")
-    ->withDescription("Provides a Java Regular Expression for filtering Filenames; "
-                      "if a filter is supplied, only files whose names match that Regular Expression will be fetched")
-    ->isRequired(false)->build());
-
-core::Property ListSFTP::PathFilterRegex(core::PropertyBuilder::createProperty("Path Filter Regex")
-    ->withDescription("When Search Recursively is true, then only subdirectories whose path matches the given Regular Expression will be scanned")
-    ->isRequired(false)->build());
-
-core::Property ListSFTP::IgnoreDottedFiles(core::PropertyBuilder::createProperty("Ignore Dotted Files")
-    ->withDescription("If true, files whose names begin with a dot (\".\") will be ignored")
-    ->isRequired(true)->withDefaultValue<bool>(true)->build());
-
-core::Property ListSFTP::TargetSystemTimestampPrecision(core::PropertyBuilder::createProperty("Target System Timestamp Precision")
-    ->withDescription("Specify timestamp precision at the target system. "
-                      "Since this processor uses timestamp of entities to decide which should be listed, "
-                      "it is crucial to use the right timestamp precision.")
-    ->isRequired(true)
-    ->withAllowableValues<std::string>({TARGET_SYSTEM_TIMESTAMP_PRECISION_AUTO_DETECT,
-                                            TARGET_SYSTEM_TIMESTAMP_PRECISION_MILLISECONDS,
-                                            TARGET_SYSTEM_TIMESTAMP_PRECISION_SECONDS,
-                                            TARGET_SYSTEM_TIMESTAMP_PRECISION_MINUTES})
-    ->withDefaultValue(TARGET_SYSTEM_TIMESTAMP_PRECISION_AUTO_DETECT)->build());
-
-core::Property ListSFTP::EntityTrackingTimeWindow(core::PropertyBuilder::createProperty("Entity Tracking Time Window")
-    ->withDescription("Specify how long this processor should track already-listed entities. "
-                      "'Tracking Entities' strategy can pick any entity whose timestamp is inside the specified time window. "
-                      "For example, if set to '30 minutes', any entity having timestamp in recent 30 minutes will be the listing target when this processor runs. "
-                      "A listed entity is considered 'new/updated' and a FlowFile is emitted if one of following condition meets: "
-                      "1. does not exist in the already-listed entities, "
-                      "2. has newer timestamp than the cached entity, "
-                      "3. has different size than the cached entity. "
-                      "If a cached entity's timestamp becomes older than specified time window, that entity will be removed from the cached already-listed entities. "
-                      "Used by 'Tracking Entities' strategy.")
-    ->isRequired(false)->build());
-
-core::Property ListSFTP::EntityTrackingInitialListingTarget(core::PropertyBuilder::createProperty("Entity Tracking Initial Listing Target")
-    ->withDescription("Specify how initial listing should be handled. Used by 'Tracking Entities' strategy.")
-    ->withAllowableValues<std::string>({ENTITY_TRACKING_INITIAL_LISTING_TARGET_TRACKING_TIME_WINDOW,
-                                            ENTITY_TRACKING_INITIAL_LISTING_TARGET_ALL_AVAILABLE})
-    ->isRequired(false)->withDefaultValue(ENTITY_TRACKING_INITIAL_LISTING_TARGET_ALL_AVAILABLE)->build());
-
-core::Property ListSFTP::MinimumFileAge(core::PropertyBuilder::createProperty("Minimum File Age")
-    ->withDescription("The minimum age that a file must be in order to be pulled; "
-                      "any file younger than this amount of time (according to last modification date) will be ignored")
-    ->isRequired(true)->withDefaultValue<core::TimePeriodValue>("0 sec")->build());
-
-core::Property ListSFTP::MaximumFileAge(core::PropertyBuilder::createProperty("Maximum File Age")
-    ->withDescription("The maximum age that a file must be in order to be pulled; "
-                      "any file older than this amount of time (according to last modification date) will be ignored")
-    ->isRequired(false)->build());
-
-core::Property ListSFTP::MinimumFileSize(core::PropertyBuilder::createProperty("Minimum File Size")
-    ->withDescription("The minimum size that a file must be in order to be pulled")
-    ->isRequired(true)->withDefaultValue<core::DataSizeValue>("0 B")->build());
-
-core::Property ListSFTP::MaximumFileSize(core::PropertyBuilder::createProperty("Maximum File Size")
-    ->withDescription("The maximum size that a file must be in order to be pulled")
-    ->isRequired(false)->build());
-
-core::Relationship ListSFTP::Success("success", "All FlowFiles that are received are routed to success");
+namespace org::apache::nifi::minifi::processors {
 
 const std::map<std::string, uint64_t> ListSFTP::LISTING_LAG_MAP = {
   {ListSFTP::TARGET_SYSTEM_TIMESTAMP_PRECISION_SECONDS, 1000},
   {ListSFTP::TARGET_SYSTEM_TIMESTAMP_PRECISION_MINUTES, 60000},
 };
 
-constexpr char const* ListSFTP::LISTING_STRATEGY_TRACKING_TIMESTAMPS;
-constexpr char const* ListSFTP::LISTING_STRATEGY_TRACKING_ENTITIES;
+namespace {
+uint64_t toUnixTime(const std::optional<std::chrono::system_clock::time_point> time_point) {
+  if (!time_point)
+    return 0;
+  return std::chrono::duration_cast<std::chrono::milliseconds>(time_point->time_since_epoch()).count();
+}
 
-constexpr char const* ListSFTP::TARGET_SYSTEM_TIMESTAMP_PRECISION_AUTO_DETECT;
-constexpr char const* ListSFTP::TARGET_SYSTEM_TIMESTAMP_PRECISION_MILLISECONDS;
-constexpr char const* ListSFTP::TARGET_SYSTEM_TIMESTAMP_PRECISION_SECONDS;
-constexpr char const* ListSFTP::TARGET_SYSTEM_TIMESTAMP_PRECISION_MINUTES;
+std::optional<std::chrono::system_clock::time_point> fromUnixTime(const uint64_t timestamp) {
+  if (timestamp == 0)
+    return std::nullopt;
+  return std::chrono::system_clock::time_point{std::chrono::milliseconds{timestamp}};
+}
 
-constexpr char const* ListSFTP::ENTITY_TRACKING_INITIAL_LISTING_TARGET_TRACKING_TIME_WINDOW;
-constexpr char const* ListSFTP::ENTITY_TRACKING_INITIAL_LISTING_TARGET_ALL_AVAILABLE;
-
-constexpr char const* ListSFTP::ProcessorName;
+}  // namespace
 
 void ListSFTP::initialize() {
   logger_->log_trace("Initializing FetchSFTP");
 
-  // Set the supported properties
-  std::set<core::Property> properties;
-  addSupportedCommonProperties(properties);
-  properties.insert(ListingStrategy);
-  properties.insert(RemotePath);
-  properties.insert(SearchRecursively);
-  properties.insert(FollowSymlink);
-  properties.insert(FileFilterRegex);
-  properties.insert(PathFilterRegex);
-  properties.insert(IgnoreDottedFiles);
-  properties.insert(TargetSystemTimestampPrecision);
-  properties.insert(EntityTrackingTimeWindow);
-  properties.insert(EntityTrackingInitialListingTarget);
-  properties.insert(MinimumFileAge);
-  properties.insert(MaximumFileAge);
-  properties.insert(MinimumFileSize);
-  properties.insert(MaximumFileSize);
-  setSupportedProperties(properties);
-
-  // Set the supported relationships
-  std::set<core::Relationship> relationships;
-  relationships.insert(Success);
-  setSupportedRelationships(relationships);
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
-ListSFTP::ListSFTP(const std::string& name, const utils::Identifier& uuid /*= utils::Identifier()*/)
-    : SFTPProcessorBase(name, uuid)
+ListSFTP::ListSFTP(std::string name, const utils::Identifier& uuid /*= utils::Identifier()*/)
+    : SFTPProcessorBase(std::move(name), uuid)
     , search_recursively_(false)
     , follow_symlink_(false)
-    , file_filter_regex_set_(false)
-    , path_filter_regex_set_(false)
     , ignore_dotted_files_(false)
     , minimum_file_age_(0U)
     , maximum_file_age_(0U)
     , minimum_file_size_(0U)
     , maximum_file_size_(0U)
     , already_loaded_from_cache_(false)
-    , last_listed_latest_entry_timestamp_(0U)
-    , last_processed_latest_entry_timestamp_(0U)
     , initial_listing_complete_(false) {
   logger_ = core::logging::LoggerFactory<ListSFTP>::getLogger();
 }
@@ -233,27 +114,19 @@ void ListSFTP::onSchedule(const std::shared_ptr<core::ProcessContext> &context,
   } else {
     follow_symlink_ = utils::StringUtils::toBool(value).value_or(false);
   }
-  if (context->getProperty(FileFilterRegex.getName(), file_filter_regex_)) {
+  if (context->getProperty(FileFilterRegex.getName(), file_filter_regex_) && !file_filter_regex_.empty()) {
     try {
       compiled_file_filter_regex_ = utils::Regex(file_filter_regex_);
-      file_filter_regex_set_ = true;
     } catch (const Exception &e) {
       logger_->log_error("Failed to compile File Filter Regex \"%s\"", file_filter_regex_.c_str());
-      file_filter_regex_set_ = false;
     }
-  } else {
-    file_filter_regex_set_ = false;
   }
-  if (context->getProperty(PathFilterRegex.getName(), path_filter_regex_)) {
+  if (context->getProperty(PathFilterRegex.getName(), path_filter_regex_) && !path_filter_regex_.empty()) {
     try {
       compiled_path_filter_regex_ = utils::Regex(path_filter_regex_);
-      path_filter_regex_set_ = true;
     } catch (const Exception &e) {
       logger_->log_error("Failed to compile Path Filter Regex \"%s\"", path_filter_regex_.c_str());
-      path_filter_regex_set_ = false;
     }
-  } else {
-    path_filter_regex_set_ = false;
   }
   if (!context->getProperty(IgnoreDottedFiles.getName(), value)) {
     logger_->log_error("Ignore Dotted Files attribute is missing or invalid");
@@ -293,8 +166,8 @@ void ListSFTP::invalidateCache() {
   already_loaded_from_cache_ = false;
 
   last_run_time_ = std::chrono::steady_clock::time_point();
-  last_listed_latest_entry_timestamp_ = 0U;
-  last_processed_latest_entry_timestamp_ = 0U;
+  last_listed_latest_entry_timestamp_.reset();
+  last_processed_latest_entry_timestamp_.reset();
   latest_identifiers_processed_.clear();
 
   initial_listing_complete_ = false;
@@ -395,11 +268,11 @@ bool ListSFTP::filterFile(const std::string& parent_path, const std::string& fil
   }
 
   /* File Filter Regex */
-  if (file_filter_regex_set_) {
+  if (compiled_file_filter_regex_) {
     bool match = false;
-    match = utils::regexSearch(filename, compiled_file_filter_regex_);
+    match = utils::regexMatch(filename, *compiled_file_filter_regex_);
     if (!match) {
-      logger_->log_debug("Ignoring \"%s/%s\" because it did not match the File Filter Regex \"%s\"",
+      logger_->log_debug(R"(Ignoring "%s/%s" because it did not match the File Filter Regex "%s")",
                          parent_path.c_str(),
                          filename.c_str(),
                          file_filter_regex_);
@@ -416,12 +289,12 @@ bool ListSFTP::filterDirectory(const std::string& parent_path, const std::string
   }
 
   /* Path Filter Regex */
-  if (path_filter_regex_set_) {
+  if (compiled_path_filter_regex_) {
     std::string dir_path = utils::file::FileUtils::concat_path(parent_path, filename, true /*force_posix*/);
     bool match = false;
-    match = utils::regexSearch(dir_path, compiled_path_filter_regex_);
+    match = utils::regexMatch(dir_path, *compiled_path_filter_regex_);
     if (!match) {
-      logger_->log_debug("Not recursing into \"%s\" because it did not match the Path Filter Regex \"%s\"",
+      logger_->log_debug(R"(Not recursing into "%s" because it did not match the Path Filter Regex "%s")",
                          dir_path.c_str(),
                          path_filter_regex_);
       return false;
@@ -442,11 +315,7 @@ bool ListSFTP::createAndTransferFlowFileFromChild(
     logger_->log_error("Modification date %lu of \"%s/%s\" larger than int64_t max", child.attrs.mtime, child.parent_path.c_str(), child.filename.c_str());
     return true;
   }
-  std::string mtime_str;
-  if (!utils::timeutils::getDateTimeStr(gsl::narrow<int64_t>(child.attrs.mtime), mtime_str)) {
-    logger_->log_error("Failed to convert modification date %lu of \"%s/%s\" to string", child.attrs.mtime, child.parent_path.c_str(), child.filename.c_str());
-    return true;
-  }
+  auto mtime_str = utils::timeutils::getDateTimeStr(date::sys_seconds{std::chrono::seconds(child.attrs.mtime)});
 
   /* Create FlowFile */
   auto flow_file = session->create();
@@ -499,8 +368,8 @@ bool ListSFTP::persistTrackingTimestampsCache(const std::shared_ptr<core::Proces
   state["hostname"] = hostname;
   state["username"] = username;
   state["remote_path"] = remote_path;
-  state["listing.timestamp"] = std::to_string(last_listed_latest_entry_timestamp_);
-  state["processed.timestamp"] = std::to_string(last_processed_latest_entry_timestamp_);
+  state["listing.timestamp"] = std::to_string(toUnixTime(last_listed_latest_entry_timestamp_));
+  state["processed.timestamp"] = std::to_string(toUnixTime(last_processed_latest_entry_timestamp_));
   size_t i = 0;
   for (const auto& identifier : latest_identifiers_processed_) {
     state["id." + std::to_string(i)] = identifier;
@@ -583,8 +452,8 @@ bool ListSFTP::updateFromTrackingTimestampsCache(const std::shared_ptr<core::Pro
     return false;
   }
 
-  last_listed_latest_entry_timestamp_ = state_listing_timestamp;
-  last_processed_latest_entry_timestamp_ = state_processed_timestamp;
+  last_listed_latest_entry_timestamp_ = fromUnixTime(state_listing_timestamp);
+  last_processed_latest_entry_timestamp_ = fromUnixTime(state_processed_timestamp);
   latest_identifiers_processed_ = std::move(state_ids);
 
   return true;
@@ -598,7 +467,7 @@ void ListSFTP::listByTrackingTimestamps(
     const std::string& username,
     const std::string& remote_path,
     std::vector<Child>&& files) {
-  uint64_t min_timestamp_to_list = last_listed_latest_entry_timestamp_;
+  auto min_timestamp_to_list = last_listed_latest_entry_timestamp_;
 
   /* Load state from cache file if needed */
   if (!already_loaded_from_cache_) {
@@ -611,16 +480,16 @@ void ListSFTP::listByTrackingTimestamps(
   }
 
   std::chrono::steady_clock::time_point current_run_time = std::chrono::steady_clock::now();
-  time_t now = time(nullptr);
+  auto now = std::chrono::system_clock::now();
 
   /* Order children by timestamp and try to detect timestamp precision if needed  */
-  std::map<uint64_t /*timestamp*/, std::list<Child>> ordered_files;
+  std::map<std::chrono::system_clock::time_point, std::list<Child>> ordered_files;
   bool target_system_has_seconds = false;
   for (auto&& file : files) {
-    uint64_t timestamp = file.attrs.mtime * 1000;
-    target_system_has_seconds |= timestamp % 60000 != 0;
+    std::chrono::system_clock::time_point timestamp{std::chrono::seconds(file.attrs.mtime)};
+    target_system_has_seconds |= std::chrono::round<std::chrono::minutes>(timestamp) != timestamp;
 
-    bool new_file = min_timestamp_to_list == 0U || (timestamp >= min_timestamp_to_list && timestamp >= last_processed_latest_entry_timestamp_);
+    bool new_file = !min_timestamp_to_list.has_value() || (timestamp >= min_timestamp_to_list && timestamp >= last_processed_latest_entry_timestamp_);
     if (new_file) {
       auto& files_for_timestamp = ordered_files[timestamp];
       files_for_timestamp.emplace_back(std::move(file));
@@ -629,9 +498,9 @@ void ListSFTP::listByTrackingTimestamps(
     }
   }
 
-  uint64_t latest_listed_entry_timestamp_this_cycle = 0U;
+  std::optional<std::chrono::system_clock::time_point> latest_listed_entry_timestamp_this_cycle;
   size_t flow_files_created = 0U;
-  if (ordered_files.size() > 0) {
+  if (!ordered_files.empty()) {
     latest_listed_entry_timestamp_this_cycle = ordered_files.crbegin()->first;
 
     std::string remote_system_timestamp_precision;
@@ -652,20 +521,20 @@ void ListSFTP::listByTrackingTimestamps(
        */
       remote_system_timestamp_precision = TARGET_SYSTEM_TIMESTAMP_PRECISION_SECONDS;
     }
-    uint64_t listing_lag = LISTING_LAG_MAP.at(remote_system_timestamp_precision);
-    logger_->log_debug("The listing lag is %lu ms", listing_lag);
+    std::chrono::milliseconds listing_lag{LISTING_LAG_MAP.at(remote_system_timestamp_precision)};
+    logger_->log_debug("The listing lag is %lu ms", listing_lag.count());
 
     /* If the latest listing time is equal to the last listing time, there are no entries with a newer timestamp than previously seen */
-    if (latest_listed_entry_timestamp_this_cycle == last_listed_latest_entry_timestamp_) {
-      const auto& latest_files = ordered_files.at(latest_listed_entry_timestamp_this_cycle);
-      uint64_t elapsed_time = std::chrono::duration_cast<std::chrono::milliseconds>(current_run_time - last_run_time_).count();
+    if (latest_listed_entry_timestamp_this_cycle == last_listed_latest_entry_timestamp_ && latest_listed_entry_timestamp_this_cycle) {
+      const auto& latest_files = ordered_files.at(*latest_listed_entry_timestamp_this_cycle);
+      auto elapsed_time = std::chrono::duration_cast<std::chrono::milliseconds>(current_run_time - last_run_time_);
       /* If a precision-specific listing lag has not yet elapsed since out last execution, we wait. */
       if (elapsed_time < listing_lag) {
         logger_->log_debug("The latest listed entry timestamp is the same as the last listed entry timestamp (%lu) "
                            "and the listing lag has not yet elapsed (%lu ms < % lu ms). Yielding.",
-                           latest_listed_entry_timestamp_this_cycle,
-                           elapsed_time,
-                           listing_lag);
+                           toUnixTime(latest_listed_entry_timestamp_this_cycle),
+                           elapsed_time.count(),
+                           listing_lag.count());
         context->yield();
         return;
       }
@@ -678,24 +547,24 @@ void ListSFTP::listByTrackingTimestamps(
             return latest_identifiers_processed_.count(child.getPath()) == 1U;
           })) {
         logger_->log_debug("The latest listed entry timestamp is the same as the last listed entry timestamp (%lu) "
-                           "and all files for that timestamp has been processed. Yielding.", latest_listed_entry_timestamp_this_cycle);
+                           "and all files for that timestamp has been processed. Yielding.", toUnixTime(latest_listed_entry_timestamp_this_cycle));
         context->yield();
         return;
       }
     } else {
       /* Determine the minimum reliable timestamp based on precision */
-      uint64_t minimum_reliable_timestamp = now * 1000 - listing_lag;
+      auto minimum_reliable_timestamp = now - listing_lag;
       if (remote_system_timestamp_precision == TARGET_SYSTEM_TIMESTAMP_PRECISION_SECONDS) {
-        minimum_reliable_timestamp -= minimum_reliable_timestamp % 1000;
+        std::chrono::floor<std::chrono::seconds>(minimum_reliable_timestamp);
       } else {
-        minimum_reliable_timestamp -= minimum_reliable_timestamp % 60000;
+        std::chrono::floor<std::chrono::minutes>(minimum_reliable_timestamp);
       }
       /* If the latest timestamp is not old enough, we wait another cycle */
-      if (minimum_reliable_timestamp < latest_listed_entry_timestamp_this_cycle) {
+      if (latest_listed_entry_timestamp_this_cycle && minimum_reliable_timestamp < latest_listed_entry_timestamp_this_cycle) {
         logger_->log_debug("Skipping files with latest timestamp because their modification date is not smaller than the minimum reliable timestamp: %lu ms >= %lu ms",
-            latest_listed_entry_timestamp_this_cycle,
-            minimum_reliable_timestamp);
-        ordered_files.erase(latest_listed_entry_timestamp_this_cycle);
+                           toUnixTime(latest_listed_entry_timestamp_this_cycle),
+                           toUnixTime(minimum_reliable_timestamp));
+        ordered_files.erase(*latest_listed_entry_timestamp_this_cycle);
       }
     }
 
@@ -703,7 +572,7 @@ void ListSFTP::listByTrackingTimestamps(
       if (files_for_timestamp.first == last_processed_latest_entry_timestamp_) {
         /* Filter out previously processed entities. */
         for (auto it = files_for_timestamp.second.begin(); it != files_for_timestamp.second.end();) {
-          if (latest_identifiers_processed_.count(it->getPath()) != 0U) {
+          if (latest_identifiers_processed_.contains(it->getPath())) {
             it = files_for_timestamp.second.erase(it);
           } else {
             ++it;
@@ -724,7 +593,7 @@ void ListSFTP::listByTrackingTimestamps(
   }
 
   /* If we have a listing timestamp, it is worth persisting the state */
-  if (latest_listed_entry_timestamp_this_cycle != 0U) {
+  if (latest_listed_entry_timestamp_this_cycle) {
     bool processed_new_files = flow_files_created > 0U;
     if (processed_new_files) {
       auto last_files_it = ordered_files.crbegin();
@@ -1066,13 +935,4 @@ void ListSFTP::onTrigger(const std::shared_ptr<core::ProcessContext> &context, c
   put_connection_back_to_cache();
 }
 
-REGISTER_RESOURCE(ListSFTP, "Performs a listing of the files residing on an SFTP server. "
-                            "For each file that is found on the remote server, a new FlowFile will be created with "
-                            "the filename attribute set to the name of the file on the remote server. "
-                            "This can then be used in conjunction with FetchSFTP in order to fetch those files.");
-
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
