@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -27,7 +26,6 @@
 #include <iterator>
 #include <limits>
 #include <map>
-#include <set>
 #include <string>
 #include <utility>
 #include <vector>
@@ -44,135 +42,17 @@
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
-
-core::Property PutSFTP::RemotePath(core::PropertyBuilder::createProperty("Remote Path")
-    ->withDescription("The path on the remote system from which to pull or push files")
-    ->isRequired(false)->supportsExpressionLanguage(true)->build());
-
-core::Property PutSFTP::CreateDirectory(core::PropertyBuilder::createProperty("Create Directory")
-    ->withDescription("Specifies whether or not the remote directory should be created if it does not exist.")
-    ->isRequired(true)->withDefaultValue<bool>(false)->build());
-
-core::Property PutSFTP::DisableDirectoryListing(core::PropertyBuilder::createProperty("Disable Directory Listing")
-    ->withDescription("If set to 'true', directory listing is not performed prior to create missing directories. "
-                      "By default, this processor executes a directory listing command to see target directory existence before creating missing directories. "
-                      "However, there are situations that you might need to disable the directory listing such as the following. "
-                      "Directory listing might fail with some permission setups (e.g. chmod 100) on a directory. "
-                      "Also, if any other SFTP client created the directory after this processor performed a listing and before a directory creation request by this processor is finished, "
-                      "then an error is returned because the directory already exists.")
-    ->isRequired(false)->withDefaultValue<bool>(false)->build());
-
-core::Property PutSFTP::BatchSize(core::PropertyBuilder::createProperty("Batch Size")
-    ->withDescription("The maximum number of FlowFiles to send in a single connection")
-    ->isRequired(true)->withDefaultValue<uint64_t>(500)->build());
-
-core::Property PutSFTP::ConflictResolution(core::PropertyBuilder::createProperty("Conflict Resolution")
-    ->withDescription("Determines how to handle the problem of filename collisions")
-    ->isRequired(true)
-    ->withAllowableValues<std::string>({CONFLICT_RESOLUTION_REPLACE,
-                                        CONFLICT_RESOLUTION_IGNORE,
-                                        CONFLICT_RESOLUTION_RENAME,
-                                        CONFLICT_RESOLUTION_REJECT,
-                                        CONFLICT_RESOLUTION_FAIL,
-                                        CONFLICT_RESOLUTION_NONE})
-    ->withDefaultValue(CONFLICT_RESOLUTION_NONE)->build());
-
-core::Property PutSFTP::RejectZeroByte(core::PropertyBuilder::createProperty("Reject Zero-Byte Files")
-    ->withDescription("Determines whether or not Zero-byte files should be rejected without attempting to transfer")
-    ->isRequired(false)->withDefaultValue<bool>(true)->build());
-
-core::Property PutSFTP::DotRename(core::PropertyBuilder::createProperty("Dot Rename")
-    ->withDescription("If true, then the filename of the sent file is prepended with a \".\" and then renamed back to the original once the file is completely sent. "
-                      "Otherwise, there is no rename. This property is ignored if the Temporary Filename property is set.")
-    ->isRequired(false)->withDefaultValue<bool>(true)->build());
-
-core::Property PutSFTP::TempFilename(core::PropertyBuilder::createProperty("Temporary Filename")
-    ->withDescription("If set, the filename of the sent file will be equal to the value specified during the transfer and after successful completion will be renamed to the original filename. "
-                      "If this value is set, the Dot Rename property is ignored.")
-    ->isRequired(false)->supportsExpressionLanguage(true)->build());
-
-core::Property PutSFTP::LastModifiedTime(core::PropertyBuilder::createProperty("Last Modified Time")
-    ->withDescription("The lastModifiedTime to assign to the file after transferring it. "
-                      "If not set, the lastModifiedTime will not be changed. "
-                      "Format must be yyyy-MM-dd'T'HH:mm:ssZ. "
-                      "You may also use expression language such as ${file.lastModifiedTime}. "
-                      "If the value is invalid, the processor will not be invalid but will fail to change lastModifiedTime of the file.")
-    ->isRequired(false)->supportsExpressionLanguage(true)->build());
-
-core::Property PutSFTP::Permissions(core::PropertyBuilder::createProperty("Permissions")
-    ->withDescription("The permissions to assign to the file after transferring it. "
-                      "Format must be either UNIX rwxrwxrwx with a - in place of denied permissions (e.g. rw-r--r--) or an octal number (e.g. 644). "
-                      "If not set, the permissions will not be changed. "
-                      "You may also use expression language such as ${file.permissions}. "
-                      "If the value is invalid, the processor will not be invalid but will fail to change permissions of the file.")
-    ->isRequired(false)->supportsExpressionLanguage(true)->build());
-
-core::Property PutSFTP::RemoteOwner(core::PropertyBuilder::createProperty("Remote Owner")
-    ->withDescription("Integer value representing the User ID to set on the file after transferring it. "
-                      "If not set, the owner will not be set. You may also use expression language such as ${file.owner}. "
-                      "If the value is invalid, the processor will not be invalid but will fail to change the owner of the file.")
-    ->isRequired(false)->supportsExpressionLanguage(true)->build());
-
-core::Property PutSFTP::RemoteGroup(core::PropertyBuilder::createProperty("Remote Group")
-    ->withDescription("Integer value representing the Group ID to set on the file after transferring it. "
-                     "If not set, the group will not be set. You may also use expression language such as ${file.group}. "
-                     "If the value is invalid, the processor will not be invalid but will fail to change the group of the file.")
-    ->isRequired(false)->supportsExpressionLanguage(true)->build());
-
-core::Property PutSFTP::UseCompression(core::PropertyBuilder::createProperty("Use Compression")
-    ->withDescription("Indicates whether or not ZLIB compression should be used when transferring files")
-    ->isRequired(true)->withDefaultValue<bool>(false)->build());
-
-
-core::Relationship PutSFTP::Success("success", "FlowFiles that are successfully sent will be routed to success");
-core::Relationship PutSFTP::Reject("reject", "FlowFiles that were rejected by the destination system");
-core::Relationship PutSFTP::Failure("failure", "FlowFiles that failed to send to the remote system; failure is usually looped back to this processor");
-
-constexpr char const* PutSFTP::CONFLICT_RESOLUTION_REPLACE;
-constexpr char const* PutSFTP::CONFLICT_RESOLUTION_IGNORE;
-constexpr char const* PutSFTP::CONFLICT_RESOLUTION_RENAME;
-constexpr char const* PutSFTP::CONFLICT_RESOLUTION_REJECT;
-constexpr char const* PutSFTP::CONFLICT_RESOLUTION_FAIL;
-constexpr char const* PutSFTP::CONFLICT_RESOLUTION_NONE;
-
-constexpr char const* PutSFTP::ProcessorName;
+namespace org::apache::nifi::minifi::processors {
 
 void PutSFTP::initialize() {
   logger_->log_trace("Initializing PutSFTP");
 
-  // Set the supported properties
-  std::set<core::Property> properties;
-  addSupportedCommonProperties(properties);
-  properties.insert(RemotePath);
-  properties.insert(CreateDirectory);
-  properties.insert(DisableDirectoryListing);
-  properties.insert(BatchSize);
-  properties.insert(ConflictResolution);
-  properties.insert(RejectZeroByte);
-  properties.insert(DotRename);
-  properties.insert(TempFilename);
-  properties.insert(LastModifiedTime);
-  properties.insert(Permissions);
-  properties.insert(RemoteOwner);
-  properties.insert(RemoteGroup);
-  properties.insert(UseCompression);
-  setSupportedProperties(properties);
-
-  // Set the supported relationships
-  std::set<core::Relationship> relationships;
-  relationships.insert(Success);
-  relationships.insert(Reject);
-  relationships.insert(Failure);
-  setSupportedRelationships(relationships);
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
-PutSFTP::PutSFTP(const std::string& name, const utils::Identifier& uuid /*= utils::Identifier()*/)
-  : SFTPProcessorBase(name, uuid),
+PutSFTP::PutSFTP(std::string name, const utils::Identifier& uuid /*= utils::Identifier()*/)
+  : SFTPProcessorBase(std::move(name), uuid),
     create_directory_(false),
     batch_size_(0),
     reject_zero_byte_(false),
@@ -230,8 +110,7 @@ bool PutSFTP::processOne(const std::shared_ptr<core::ProcessContext> &context, c
   std::string remote_path;
   bool disable_directory_listing = false;
   std::string temp_file_name;
-  bool last_modified_time_set = false;
-  int64_t last_modified_time = 0U;
+  std::optional<std::chrono::system_clock::time_point> last_modified_;
   bool permissions_set = false;
   uint32_t permissions = 0U;
   bool remote_owner_set = false;
@@ -251,17 +130,14 @@ bool PutSFTP::processOne(const std::shared_ptr<core::ProcessContext> &context, c
   if (remote_path.empty()) {
     remote_path = ".";
   }
-  if (context->getDynamicProperty(DisableDirectoryListing.getName(), value)) {
-    disable_directory_listing = utils::StringUtils::toBool(value).value_or(false);
-  } else if (context->getProperty(DisableDirectoryListing.getName(), value)) {
+  if (context->getDynamicProperty(DisableDirectoryListing.getName(), value) ||
+      context->getProperty(DisableDirectoryListing.getName(), value)) {
     disable_directory_listing = utils::StringUtils::toBool(value).value_or(false);
   }
   context->getProperty(TempFilename, temp_file_name, flow_file);
-  if (context->getProperty(LastModifiedTime, value, flow_file)) {
-    if (core::Property::StringToDateTime(value, last_modified_time)) {
-      last_modified_time_set = true;
-    }
-  }
+  if (context->getProperty(LastModifiedTime, value, flow_file))
+    last_modified_ = utils::timeutils::parseDateTimeStr(value);
+
   if (context->getProperty(Permissions, value, flow_file)) {
     if (core::Property::StringToPermissions(value, permissions)) {
       permissions_set = true;
@@ -387,9 +263,6 @@ bool PutSFTP::processOne(const std::shared_ptr<core::ProcessContext> &context, c
         context->yield();
         return false;
       case SFTPProcessorBase::CreateDirectoryHierarchyError::CREATE_DIRECTORY_HIERARCHY_ERROR_NOT_A_DIRECTORY:
-        session->transfer(flow_file, Failure);
-        put_connection_back_to_cache();
-        return true;
       case SFTPProcessorBase::CreateDirectoryHierarchyError::CREATE_DIRECTORY_HIERARCHY_ERROR_NOT_FOUND:
       case SFTPProcessorBase::CreateDirectoryHierarchyError::CREATE_DIRECTORY_HIERARCHY_ERROR_PERMISSION_DENIED:
         session->transfer(flow_file, Failure);
@@ -417,7 +290,7 @@ bool PutSFTP::processOne(const std::shared_ptr<core::ProcessContext> &context, c
   logger_->log_debug("The target path is %s, final target path is %s", target_path.c_str(), final_target_path.c_str());
 
   try {
-    session->read(flow_file, [&client, &target_path, this](const std::shared_ptr<io::BaseStream>& stream) {
+    session->read(flow_file, [&client, &target_path, this](const std::shared_ptr<io::InputStream>& stream) {
       if (!client->putFile(target_path,
           *stream,
           conflict_resolution_ == CONFLICT_RESOLUTION_REPLACE /*overwrite*/,
@@ -445,21 +318,21 @@ bool PutSFTP::processOne(const std::shared_ptr<core::ProcessContext> &context, c
   }
 
   /* Set file attributes if needed */
-  if (last_modified_time_set ||
+  if (last_modified_ ||
       permissions_set ||
       remote_owner_set ||
       remote_group_set) {
     utils::SFTPClient::SFTPAttributes attrs;
     attrs.flags = 0U;
-    if (last_modified_time_set) {
+    if (last_modified_) {
       /*
        * NiFi doesn't set atime, only mtime, but because they can only be set together,
        * if we don't want to modify atime, we first have to get it.
        * Therefore setting them both saves an extra protocol round.
        */
       attrs.flags |= utils::SFTPClient::SFTP_ATTRIBUTE_MTIME | utils::SFTPClient::SFTP_ATTRIBUTE_ATIME;
-      attrs.mtime = last_modified_time;
-      attrs.atime = last_modified_time;
+      attrs.mtime = std::chrono::duration_cast<std::chrono::seconds>(last_modified_->time_since_epoch()).count();
+      attrs.atime = std::chrono::duration_cast<std::chrono::seconds>(last_modified_->time_since_epoch()).count();
     }
     if (permissions_set) {
       attrs.flags |= utils::SFTPClient::SFTP_ATTRIBUTE_PERMISSIONS;
@@ -493,10 +366,4 @@ void PutSFTP::onTrigger(const std::shared_ptr<core::ProcessContext> &context, co
   }
 }
 
-REGISTER_RESOURCE(PutSFTP, "Sends FlowFiles to an SFTP Server");
-
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
