@@ -76,7 +76,7 @@ class ListSFTPTestsFixture {
     REQUIRE_FALSE(src_dir.empty());
 
     // Start SFTP server
-    sftp_server = std::unique_ptr<SFTPTestServer>(new SFTPTestServer(src_dir));
+    sftp_server = std::make_unique<SFTPTestServer>(src_dir);
     REQUIRE(true == sftp_server->start());
 
     // Build MiNiFi processing graph
@@ -94,7 +94,7 @@ class ListSFTPTestsFixture {
     list_sftp.reset();
     plan.reset();
 
-    plan = testController.createPlan(configuration, state_dir.c_str());
+    plan = testController.createPlan(configuration, state_dir);
     if (list_sftp_uuid == nullptr) {
       list_sftp = plan->addProcessor(
           "ListSFTP",
@@ -142,7 +142,7 @@ class ListSFTPTestsFixture {
     auto full_path = ss.str();
     std::deque<std::string> parent_dirs;
     std::string parent_dir = full_path;
-    while ((parent_dir = utils::file::FileUtils::get_parent_path(parent_dir)) != "") {
+    while (!(parent_dir = utils::file::FileUtils::get_parent_path(parent_dir)).empty()) {
       parent_dirs.push_front(parent_dir);
     }
     for (const auto& dir : parent_dirs) {
@@ -234,9 +234,9 @@ TEST_CASE_METHOD(ListSFTPTestsFixture, "ListSFTP list one file writes attributes
   testController.runSession(plan, true);
 
   auto file = src_dir + "/vfs/nifi_test/tstFile.ext";
-  std::string mtime_str;
-  REQUIRE(true == utils::timeutils::getDateTimeStr(utils::file::to_time_t(utils::file::last_write_time(file).value()), mtime_str));
-  uint64_t uid, gid;
+  auto mtime_str = utils::timeutils::getDateTimeStr(std::chrono::time_point_cast<std::chrono::seconds>(utils::file::to_sys(utils::file::last_write_time(file).value())));
+  uint64_t uid = 0;
+  uint64_t gid = 0;
   REQUIRE(true == utils::file::FileUtils::get_uid_gid(file, uid, gid));
   uint32_t permissions;
   REQUIRE(true == utils::file::FileUtils::get_permissions(file, permissions));
