@@ -79,7 +79,7 @@ class ListThenFetchSFTPTestsFixture {
     REQUIRE(plan);
 
     // Start SFTP server
-    sftp_server = std::unique_ptr<SFTPTestServer>(new SFTPTestServer(src_dir));
+    sftp_server = std::make_unique<SFTPTestServer>(src_dir);
     REQUIRE(true == sftp_server->start());
 
     // Build MiNiFi processing graph
