@@ -41,6 +41,7 @@
 #include "TestBase.h"
 #include "Catch.h"
 #include "Exception.h"
+#include "date/date.h"
 #include "utils/StringUtils.h"
 #include "utils/file/FileUtils.h"
 #include "core/Core.h"
@@ -82,7 +83,7 @@ class PutSFTPTestsFixture {
     REQUIRE(plan);
 
     // Start SFTP server
-    sftp_server = std::unique_ptr<SFTPTestServer>(new SFTPTestServer(dst_dir));
+    sftp_server = std::make_unique<SFTPTestServer>(dst_dir);
     REQUIRE(true == sftp_server->start());
 
     // Build MiNiFi processing graph
@@ -126,7 +127,7 @@ class PutSFTPTestsFixture {
   }
 
   // Create source file
-  void createFile(const std::string &dir, const std::string& relative_path, const std::string& content) {
+  static void createFile(const std::string &dir, const std::string& relative_path, const std::string& content) {
     std::fstream file;
     std::stringstream ss;
     ss << dir << "/" << relative_path;
@@ -506,7 +507,7 @@ TEST_CASE_METHOD(PutSFTPTestsFixture, "PutSFTP set mtime", "[PutSFTP]") {
 
   testFile("nifi_test/tstFile1.ext", "content 1");
   using namespace std::chrono;  // NOLINT(build/namespaces)
-  time_point<system_clock> modification_time = sys_days(January / 24 / 2065) + 5h + 20min;
+  system_clock::time_point modification_time = date::sys_days(date::January / 24 / 2065) + 5h + 20min;
   testModificationTime("nifi_test/tstFile1.ext", file_clock::from_sys(modification_time));
 }
 
