@@ -33,14 +33,14 @@ std::string get_sftp_test_dir();
 
 class SFTPTestServer {
  public:
-  SFTPTestServer(const std::string& working_directory,
+  SFTPTestServer(std::string working_directory,
       const std::string& host_key_file = "resources/host.pem",
       const std::string& jar_path = "tools/sftp-test-server/target/SFTPTestServer-1.0.0.jar");
   ~SFTPTestServer();
 
   bool start();
   bool stop();
-  uint16_t getPort();
+  uint16_t getPort() const;
 
  private:
   std::shared_ptr<org::apache::nifi::minifi::core::logging::Logger> logger_ = org::apache::nifi::minifi::core::logging::LoggerFactory<SFTPTestServer>::getLogger();
