@@ -27,17 +27,7 @@
 
 #include <soci/error.h>
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
-
-const core::Property SQLProcessor::DBControllerService(
-    core::PropertyBuilder::createProperty("DB Controller Service")
-    ->isRequired(true)
-    ->withDescription("Database Controller Service.")
-    ->supportsExpressionLanguage(true)->build());
+namespace org::apache::nifi::minifi::processors {
 
 void SQLProcessor::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
   std::string controllerService;
@@ -86,8 +76,4 @@ std::vector<std::string> SQLProcessor::collectArguments(const std::shared_ptr<co
   return arguments;
 }
 
-}  // namespace processors
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::processors
