@@ -21,10 +21,11 @@
 #define EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_APPENDHOSTINFO_H_
 
 #include <memory>
-#include <string>
 #include <optional>
 #include <regex>
 #include <shared_mutex>
+#include <string>
+#include <utility>
 
 #include "core/Property.h"
 #include "FlowFileRecord.h"
@@ -34,32 +35,44 @@
 #include "core/logging/LoggerConfiguration.h"
 #include "utils/Export.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 class AppendHostInfo : public core::Processor {
  public:
   static constexpr const char* REFRESH_POLICY_ON_TRIGGER = "On every trigger";
   static constexpr const char* REFRESH_POLICY_ON_SCHEDULE = "On schedule";
 
-  explicit AppendHostInfo(const std::string& name, const utils::Identifier& uuid = {})
-      : core::Processor(name, uuid),
+  explicit AppendHostInfo(std::string name, const utils::Identifier& uuid = {})
+      : core::Processor(std::move(name), uuid),
         refresh_on_trigger_(false) {
   }
   ~AppendHostInfo() override = default;
-  static constexpr char const* ProcessorName = "AppendHostInfo";
 
-  EXTENSIONAPI static core::Property InterfaceNameFilter;
-  EXTENSIONAPI static core::Property HostAttribute;
-  EXTENSIONAPI static core::Property IPAttribute;
-  EXTENSIONAPI static core::Property RefreshPolicy;
+  EXTENSIONAPI static constexpr const char* Description = "Appends host information such as IP address and hostname as an attribute to incoming flowfiles.";
 
-  EXTENSIONAPI static core::Relationship Success;
+  EXTENSIONAPI static const core::Property InterfaceNameFilter;
+  EXTENSIONAPI static const core::Property HostAttribute;
+  EXTENSIONAPI static const core::Property IPAttribute;
+  EXTENSIONAPI static const core::Property RefreshPolicy;
+  static auto properties() {
+    return std::array{
+      InterfaceNameFilter,
+      HostAttribute,
+      IPAttribute,
+      RefreshPolicy
+    };
+  }
+
+  EXTENSIONAPI static const core::Relationship Success;
+  static auto relationships() { return std::array{Success}; }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
- public:
   void onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>& sessionFactory) override;
   void onTrigger(core::ProcessContext* context, core::ProcessSession* session) override;
   void initialize() override;
@@ -79,10 +92,6 @@ class AppendHostInfo : public core::Processor {
   std::optional<std::string> ipaddresses_;
 };
 
-}  // namespace processors
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::processors
 
 #endif  // EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_APPENDHOSTINFO_H_
