@@ -15,8 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_GETTCP_H_
-#define EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_GETTCP_H_
+#pragma once
 
 #include <map>
 #include <memory>
@@ -38,11 +37,7 @@
 #include "utils/gsl.h"
 #include "utils/Export.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 class SocketAfterExecute : public utils::AfterExecute<int> {
  public:
@@ -96,71 +91,22 @@ class DataHandler {
   }
   static const char *SOURCE_ENDPOINT_ATTRIBUTE;
 
-  int16_t handle(std::string source, uint8_t *message, size_t size, bool partial);
+  int16_t handle(const std::string& source, uint8_t *message, size_t size, bool partial);
 
  private:
   std::shared_ptr<core::ProcessSessionFactory> sessionFactory_;
 };
 
-class GetTCPMetrics : public state::response::ResponseNode {
+class GetTCP : public core::Processor {
  public:
-  GetTCPMetrics()
-      : state::response::ResponseNode("GetTCPMetrics") {
-  }
-
-  GetTCPMetrics(const std::string& name, const utils::Identifier& uuid)
-      : state::response::ResponseNode(name, uuid) {
-  }
-  ~GetTCPMetrics() override = default;
-  std::string getName() const override {
-    return core::Connectable::getName();
-  }
-
-  std::vector<state::response::SerializedResponseNode> serialize() override {
-    std::vector<state::response::SerializedResponseNode> resp;
-
-    state::response::SerializedResponseNode iter;
-    iter.name = "OnTriggerInvocations";
-    iter.value = (uint32_t)iterations_.load();
-
-    resp.push_back(iter);
-
-    state::response::SerializedResponseNode accepted_files;
-    accepted_files.name = "AcceptedFiles";
-    accepted_files.value = (uint32_t)accepted_files_.load();
-
-    resp.push_back(accepted_files);
-
-    state::response::SerializedResponseNode input_bytes;
-    input_bytes.name = "InputBytes";
-    input_bytes.value = (uint32_t)input_bytes_.load();
-
-    resp.push_back(input_bytes);
-
-    return resp;
-  }
-
- protected:
-  friend class GetTCP;
-
-  std::atomic<size_t> iterations_{0};
-  std::atomic<size_t> accepted_files_{0};
-  std::atomic<size_t> input_bytes_{0};
-};
-
-// GetTCP Class
-class GetTCP : public core::Processor, public state::response::MetricsNodeSource {
- public:
-  explicit GetTCP(const std::string& name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid),
-        running_(false),
-        stay_connected_(true),
-        concurrent_handlers_(2),
-        endOfMessageByte(static_cast<std::byte>(13)),
-        receive_buffer_size_(16 * 1024 * 1024),
-        connection_attempt_limit_(3),
-        ssl_service_(nullptr) {
-    metrics_ = std::make_shared<GetTCPMetrics>();
+  explicit GetTCP(std::string name, const utils::Identifier& uuid = {})
+    : Processor(std::move(name), uuid),
+      running_(false),
+      stay_connected_(true),
+      concurrent_handlers_(2),
+      endOfMessageByte(static_cast<std::byte>(13)),
+      receive_buffer_size_(16 * 1024 * 1024),
+      connection_attempt_limit_(3) {
   }
 
   ~GetTCP() override {
@@ -168,96 +114,71 @@ class GetTCP : public core::Processor, public state::response::MetricsNodeSource
     client_thread_pool_.shutdown();
   }
 
-// Processor Name
-  EXTENSIONAPI static constexpr char const* ProcessorName = "GetTCP";
+  EXTENSIONAPI static constexpr const char* Description = "Establishes a TCP Server that defines and retrieves one or more byte messages from clients";
 
-  // Supported Properties
-  EXTENSIONAPI static core::Property EndpointList;
-  EXTENSIONAPI static core::Property ConcurrentHandlers;
-  EXTENSIONAPI static core::Property ReconnectInterval;
-  EXTENSIONAPI static core::Property StayConnected;
-  EXTENSIONAPI static core::Property ReceiveBufferSize;
-  EXTENSIONAPI static core::Property SSLContextService;
-  EXTENSIONAPI static core::Property ConnectionAttemptLimit;
-  EXTENSIONAPI static core::Property EndOfMessageByte;
+  EXTENSIONAPI static const core::Property EndpointList;
+  EXTENSIONAPI static const core::Property ConcurrentHandlers;
+  EXTENSIONAPI static const core::Property ReconnectInterval;
+  EXTENSIONAPI static const core::Property StayConnected;
+  EXTENSIONAPI static const core::Property ReceiveBufferSize;
+  EXTENSIONAPI static const core::Property SSLContextService;
+  EXTENSIONAPI static const core::Property ConnectionAttemptLimit;
+  EXTENSIONAPI static const core::Property EndOfMessageByte;
+  static auto properties() {
+    return std::array{
+      EndpointList,
+      ConcurrentHandlers,
+      ReconnectInterval,
+      StayConnected,
+      ReceiveBufferSize,
+      SSLContextService,
+      ConnectionAttemptLimit,
+      EndOfMessageByte
+    };
+  }
 
-  // Supported Relationships
-  EXTENSIONAPI static core::Relationship Success;
-  EXTENSIONAPI static core::Relationship Partial;
+  EXTENSIONAPI static const core::Relationship Success;
+  EXTENSIONAPI static const core::Relationship Partial;
+  static auto relationships() { return std::array{Success, Partial}; }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
- public:
-  /**
-   * Function that's executed when the processor is scheduled.
-   * @param context process context.
-   * @param sessionFactory process session factory that is used when creating
-   * ProcessSession objects.
-   */
   void onSchedule(const std::shared_ptr<core::ProcessContext> &processContext, const std::shared_ptr<core::ProcessSessionFactory> &sessionFactory) override;
-
   void onSchedule(core::ProcessContext* /*processContext*/, core::ProcessSessionFactory* /*sessionFactory*/) override {
     throw std::logic_error{"GetTCP::onSchedule(ProcessContext*, ProcessSessionFactory*) is unimplemented"};
   }
-  /**
-   * Execution trigger for the GetTCP Processor
-   * @param context processor context
-   * @param session processor session reference.
-   */
   void onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) override;
-
   void onTrigger(core::ProcessContext* /*context*/, core::ProcessSession* /*session*/) override {
     throw std::logic_error{"GetTCP::onTrigger(ProcessContext*, ProcessSession*) is unimplemented"};
   }
-
-  // Initialize, over write by NiFi GetTCP
   void initialize() override;
 
-  int16_t getMetricNodes(std::vector<std::shared_ptr<state::response::ResponseNode>> &metric_vector) override;
-
  protected:
   void notifyStop() override;
 
  private:
   std::function<int()> f_ex;
-
   std::atomic<bool> running_;
-
   std::unique_ptr<DataHandler> handler_;
-
   std::vector<std::string> endpoints;
-
   std::map<std::string, std::future<int>*> live_clients_;
-
   moodycamel::ConcurrentQueue<std::unique_ptr<io::Socket>> socket_ring_buffer_;
-
   bool stay_connected_;
-
   uint16_t concurrent_handlers_;
-
   std::byte endOfMessageByte;
-
   std::chrono::milliseconds reconnect_interval_{5000};
-
   uint64_t receive_buffer_size_;
-
   uint16_t connection_attempt_limit_;
-
-  std::shared_ptr<GetTCPMetrics> metrics_;
-
   // Mutex for ensuring clients are running
-
   std::mutex mutex_;
-
   std::shared_ptr<minifi::controllers::SSLContextService> ssl_service_;
-
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<GetTCP>::getLogger();
-
   utils::ThreadPool<int> client_thread_pool_;
 };
 
-}  // namespace processors
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
-#endif  // EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_GETTCP_H_
+}  // namespace org::apache::nifi::minifi::processors
