@@ -17,8 +17,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_HASHCONTENT_H_
-#define EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_HASHCONTENT_H_
+#pragma once
 
 #ifdef OPENSSL_SUPPORT
 
@@ -37,7 +36,6 @@
 #include "FlowFileRecord.h"
 #include "core/Processor.h"
 #include "core/ProcessSession.h"
-#include "io/BaseStream.h"
 #include "utils/StringUtils.h"
 #include "utils/Export.h"
 
@@ -47,7 +45,7 @@ using HashReturnType = std::pair<std::string, int64_t>;
 namespace { // NOLINT
 #define HASH_BUFFER_SIZE 16384
 
-  HashReturnType MD5Hash(const std::shared_ptr<org::apache::nifi::minifi::io::BaseStream>& stream) {
+  HashReturnType MD5Hash(const std::shared_ptr<org::apache::nifi::minifi::io::InputStream>& stream) {
     HashReturnType ret_val;
     ret_val.second = 0;
     std::array<std::byte, HASH_BUFFER_SIZE> buffer{};
@@ -71,7 +69,7 @@ namespace { // NOLINT
     return ret_val;
   }
 
-  HashReturnType SHA1Hash(const std::shared_ptr<org::apache::nifi::minifi::io::BaseStream>& stream) {
+  HashReturnType SHA1Hash(const std::shared_ptr<org::apache::nifi::minifi::io::InputStream>& stream) {
     HashReturnType ret_val;
     ret_val.second = 0;
     std::array<std::byte, HASH_BUFFER_SIZE> buffer{};
@@ -95,7 +93,7 @@ namespace { // NOLINT
     return ret_val;
   }
 
-  HashReturnType SHA256Hash(const std::shared_ptr<org::apache::nifi::minifi::io::BaseStream>& stream) {
+  HashReturnType SHA256Hash(const std::shared_ptr<org::apache::nifi::minifi::io::InputStream>& stream) {
     HashReturnType ret_val;
     ret_val.second = 0;
     std::array<std::byte, HASH_BUFFER_SIZE> buffer{};
@@ -123,42 +121,45 @@ namespace { // NOLINT
 
 namespace org::apache::nifi::minifi::processors {
 
-static const std::map<std::string, const std::function<HashReturnType(const std::shared_ptr<io::BaseStream>&)>> HashAlgos =
+static const std::map<std::string, const std::function<HashReturnType(const std::shared_ptr<io::InputStream>&)>> HashAlgos =
   { {"MD5",  MD5Hash}, {"SHA1", SHA1Hash}, {"SHA256", SHA256Hash} };
 
-//! HashContent Class
 class HashContent : public core::Processor {
  public:
-  //! Constructor
-  /*!
-  * Create a new processor
-  */
-  explicit HashContent(const std::string& name,  const utils::Identifier& uuid = {})
-      : Processor(name, uuid) {
+  explicit HashContent(std::string name,  const utils::Identifier& uuid = {})
+      : Processor(std::move(name), uuid) {
   }
-  //! Processor Name
-  EXTENSIONAPI static constexpr char const* ProcessorName = "HashContent";
-  //! Supported Properties
-  EXTENSIONAPI static core::Property HashAttribute;
-  EXTENSIONAPI static core::Property HashAlgorithm;
-  EXTENSIONAPI static core::Property FailOnEmpty;
-  //! Supported Relationships
-  EXTENSIONAPI static core::Relationship Success;
-  EXTENSIONAPI static core::Relationship Failure;
+
+  EXTENSIONAPI static constexpr const char* Description = "HashContent calculates the checksum of the content of the flowfile and adds it as an attribute. "
+      "Configuration options exist to select hashing algorithm and set the name of the attribute.";
+
+  EXTENSIONAPI static const core::Property HashAttribute;
+  EXTENSIONAPI static const core::Property HashAlgorithm;
+  EXTENSIONAPI static const core::Property FailOnEmpty;
+  static auto properties() {
+    return std::array{
+      HashAttribute,
+      HashAlgorithm,
+      FailOnEmpty
+    };
+  }
+
+  EXTENSIONAPI static const core::Relationship Success;
+  EXTENSIONAPI static const core::Relationship Failure;
+  static auto relationships() { return std::array{Success, Failure}; }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_REQUIRED;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
   void onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) override;
-
-  //! OnTrigger method, implemented by NiFi HashContent
   void onTrigger(core::ProcessContext *context, core::ProcessSession *session) override;
-  //! Initialize, over write by NiFi HashContent
   void initialize() override;
 
  private:
-  core::annotation::Input getInputRequirement() const override {
-    return core::annotation::Input::INPUT_REQUIRED;
-  }
-
-  //! Logger
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<HashContent>::getLogger();
   std::string algoName_;
   std::string attrKey_;
@@ -168,5 +169,3 @@ class HashContent : public core::Processor {
 }  // namespace org::apache::nifi::minifi::processors
 
 #endif  // OPENSSL_SUPPORT
-
-#endif  // EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_HASHCONTENT_H_
