@@ -17,8 +17,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_PUTFILE_H_
-#define EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_PUTFILE_H_
+#pragma once
 
 #include <memory>
 #include <string>
@@ -32,11 +31,7 @@
 #include "utils/Id.h"
 #include "utils/Export.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 class PutFile : public core::Processor {
  public:
@@ -44,38 +39,47 @@ class PutFile : public core::Processor {
   static constexpr char const *CONFLICT_RESOLUTION_STRATEGY_IGNORE = "ignore";
   static constexpr char const *CONFLICT_RESOLUTION_STRATEGY_FAIL = "fail";
 
-  static constexpr char const *ProcessorName = "PutFile";
-
-  /*!
-   * Create a new processor
-   */
-  PutFile(const std::string& name,  const utils::Identifier& uuid = {}) // NOLINT
-      : core::Processor(name, uuid) {
+  explicit PutFile(std::string name,  const utils::Identifier& uuid = {})
+      : core::Processor(std::move(name), uuid) {
   }
 
   ~PutFile() override = default;
 
-  // Supported Properties
-  EXTENSIONAPI static core::Property Directory;
-  EXTENSIONAPI static core::Property ConflictResolution;
-  EXTENSIONAPI static core::Property CreateDirs;
-  EXTENSIONAPI static core::Property MaxDestFiles;
+  EXTENSIONAPI static constexpr const char* Description = "Writes the contents of a FlowFile to the local file system";
+
 #ifndef WIN32
-  EXTENSIONAPI static core::Property Permissions;
-  EXTENSIONAPI static core::Property DirectoryPermissions;
+  EXTENSIONAPI static const core::Property Permissions;
+  EXTENSIONAPI static const core::Property DirectoryPermissions;
 #endif
-  // Supported Relationships
-  EXTENSIONAPI static core::Relationship Success;
-  EXTENSIONAPI static core::Relationship Failure;
+  EXTENSIONAPI static const core::Property Directory;
+  EXTENSIONAPI static const core::Property ConflictResolution;
+  EXTENSIONAPI static const core::Property CreateDirs;
+  EXTENSIONAPI static const core::Property MaxDestFiles;
+  static auto properties() {
+    return std::array{
+#ifndef WIN32
+      Permissions,
+      DirectoryPermissions,
+#endif
+      Directory,
+      ConflictResolution,
+      CreateDirs,
+      MaxDestFiles
+    };
+  }
+
+  EXTENSIONAPI static const core::Relationship Success;
+  EXTENSIONAPI static const core::Relationship Failure;
+  static auto relationships() { return std::array{Success, Failure}; }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_REQUIRED;
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
-  /**
-   * Function that's executed when the processor is scheduled.
-   * @param context process context.
-   * @param sessionFactory process session factory that is used when creating
-   * ProcessSession objects.
-   */
   void onSchedule(core::ProcessContext *context, core::ProcessSessionFactory *sessionFactory) override;
-
   void onTrigger(core::ProcessContext *context, core::ProcessSession *session) override;
   void initialize() override;
 
@@ -83,7 +87,7 @@ class PutFile : public core::Processor {
    public:
     ReadCallback(std::string tmp_file, std::string dest_file);
     ~ReadCallback();
-    int64_t operator()(const std::shared_ptr<io::BaseStream>& stream);
+    int64_t operator()(const std::shared_ptr<io::InputStream>& stream);
     bool commit();
 
    private:
@@ -99,19 +103,15 @@ class PutFile : public core::Processor {
    * @param filename from which to generate temporary write file path
    * @return
    */
-  std::string tmpWritePath(const std::string &filename, const std::string &directory) const;
+  static std::string tmpWritePath(const std::string &filename, const std::string &directory);
 
  private:
-  core::annotation::Input getInputRequirement() const override {
-    return core::annotation::Input::INPUT_REQUIRED;
-  }
-
   std::string conflict_resolution_;
   bool try_mkdirs_ = true;
   int64_t max_dest_files_ = -1;
 
   bool putFile(core::ProcessSession *session,
-               std::shared_ptr<core::FlowFile> flowFile,
+               const std::shared_ptr<core::FlowFile>& flowFile,
                const std::string &tmpFile,
                const std::string &destFile,
                const std::string &destDir);
@@ -135,10 +135,4 @@ class PutFile : public core::Processor {
 #endif
 };
 
-}  // namespace processors
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
-#endif  // EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_PUTFILE_H_
+}  // namespace org::apache::nifi::minifi::processors
