@@ -20,6 +20,7 @@
 #include <algorithm>
 #include <vector>
 
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 #include "core/TypedValues.h"
 #include "core/logging/LoggerConfiguration.h"
@@ -74,23 +75,14 @@ const core::Relationship ReplaceText::Success("success", "FlowFiles that have be
                                                          "This includes both FlowFiles that had text replaced and those that did not.");
 const core::Relationship ReplaceText::Failure("failure", "FlowFiles that could not be updated are routed to this relationship.");
 
-ReplaceText::ReplaceText(const std::string& name, const utils::Identifier& uuid)
-  : core::Processor(name, uuid),
+ReplaceText::ReplaceText(std::string name, const utils::Identifier& uuid)
+  : core::Processor(std::move(name), uuid),
     logger_(core::logging::LoggerFactory<ReplaceText>::getLogger()) {
 }
 
 void ReplaceText::initialize() {
-  setSupportedProperties({
-      EvaluationMode,
-      LineByLineEvaluationMode,
-      ReplacementStrategy,
-      SearchValue,
-      ReplacementValue
-  });
-  setSupportedRelationships({
-      Success,
-      Failure
-  });
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
 void ReplaceText::onSchedule(const std::shared_ptr<core::ProcessContext>& context, const std::shared_ptr<core::ProcessSessionFactory>&) {
@@ -302,6 +294,6 @@ std::string ReplaceText::getAttributeValue(const std::shared_ptr<core::FlowFile>
   }
 }
 
-REGISTER_RESOURCE(ReplaceText, "Updates the content of a FlowFile by replacing parts of it using various replacement strategies.");
+REGISTER_RESOURCE(ReplaceText, Processor);
 
 }  // namespace org::apache::nifi::minifi::processors
