@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -18,6 +17,7 @@
 
 #include "RetryFlowFile.h"
 
+#include "core/PropertyBuilder.h"
 #include "core/PropertyValidation.h"
 #include "core/Resource.h"
 
@@ -27,7 +27,7 @@ namespace nifi {
 namespace minifi {
 namespace processors {
 
-core::Property RetryFlowFile::RetryAttribute(core::PropertyBuilder::createProperty("Retry Attribute")
+const core::Property RetryFlowFile::RetryAttribute(core::PropertyBuilder::createProperty("Retry Attribute")
     ->withDescription(
         "The name of the attribute that contains the current retry count for the FlowFile."
         "WARNING: If the name matches an attribute already on the FlowFile that does not contain a numerical value, "
@@ -37,26 +37,26 @@ core::Property RetryFlowFile::RetryAttribute(core::PropertyBuilder::createProper
     ->isRequired(true)
     ->build());
 
-core::Property RetryFlowFile::MaximumRetries(core::PropertyBuilder::createProperty("Maximum Retries")
+const core::Property RetryFlowFile::MaximumRetries(core::PropertyBuilder::createProperty("Maximum Retries")
     ->withDescription("The maximum number of times a FlowFile can be retried before being passed to the 'retries_exceeded' relationship.")
     ->withDefaultValue<uint64_t>(3)
     ->supportsExpressionLanguage(true)
     ->isRequired(true)
     ->build());
 
-core::Property RetryFlowFile::PenalizeRetries(core::PropertyBuilder::createProperty("Penalize Retries")
+const core::Property RetryFlowFile::PenalizeRetries(core::PropertyBuilder::createProperty("Penalize Retries")
   ->withDescription("If set to 'true', this Processor will penalize input FlowFiles before passing them to the 'retry' relationship. This does not apply to the 'retries_exceeded' relationship.")
   ->withDefaultValue<bool>(true)
   ->isRequired(true)
   ->build());
 
-core::Property RetryFlowFile::FailOnNonNumericalOverwrite(core::PropertyBuilder::createProperty("Fail on Non-numerical Overwrite")
+const core::Property RetryFlowFile::FailOnNonNumericalOverwrite(core::PropertyBuilder::createProperty("Fail on Non-numerical Overwrite")
     ->withDescription("If the FlowFile already has the attribute defined in 'Retry Attribute' that is *not* a number, fail the FlowFile instead of resetting that value to '1'")
     ->withDefaultValue<bool>(false)
     ->isRequired(true)
     ->build());
 
-core::Property RetryFlowFile::ReuseMode(core::PropertyBuilder::createProperty("Reuse Mode")
+const core::Property RetryFlowFile::ReuseMode(core::PropertyBuilder::createProperty("Reuse Mode")
     ->withDescription(
         "Defines how the Processor behaves if the retry FlowFile has a different retry UUID than "
         "the instance that received the FlowFile. This generally means that the attribute was "
@@ -66,28 +66,18 @@ core::Property RetryFlowFile::ReuseMode(core::PropertyBuilder::createProperty("R
     ->isRequired(true)
     ->build());
 
-core::Relationship RetryFlowFile::Retry("retry",
+const core::Relationship RetryFlowFile::Retry("retry",
   "Input FlowFile has not exceeded the configured maximum retry count, pass this relationship back to the input Processor to create a limited feedback loop.");
-core::Relationship RetryFlowFile::RetriesExceeded("retries_exceeded",
+const core::Relationship RetryFlowFile::RetriesExceeded("retries_exceeded",
   "Input FlowFile has exceeded the configured maximum retry count, do not pass this relationship back to the input Processor to terminate the limited feedback loop.");
-core::Relationship RetryFlowFile::Failure("failure",
+const core::Relationship RetryFlowFile::Failure("failure",
     "The processor is configured such that a non-numerical value on 'Retry Attribute' results in a failure instead of resetting "
     "that value to '1'. This will immediately terminate the limited feedback loop. Might also include when 'Maximum Retries' contains "
     " attribute expression language that does not resolve to an Integer.");
 
 void RetryFlowFile::initialize() {
-  setSupportedProperties({
-    RetryAttribute,
-    MaximumRetries,
-    PenalizeRetries,
-    FailOnNonNumericalOverwrite,
-    ReuseMode,
-  });
-  setSupportedRelationships({
-    Retry,
-    RetriesExceeded,
-    Failure,
-  });
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
 void RetryFlowFile::onSchedule(core::ProcessContext* context, core::ProcessSessionFactory* /* sessionFactory */) {
@@ -182,14 +172,7 @@ void RetryFlowFile::setRetriesExceededAttributesOnFlowFile(core::ProcessContext*
   }
 }
 
-REGISTER_RESOURCE(RetryFlowFile,
-    "FlowFiles passed to this Processor have a 'Retry Attribute' value checked against a configured 'Maximum Retries' value. "
-    "If the current attribute value is below the configured maximum, the FlowFile is passed to a retry relationship. "
-    "The FlowFile may or may not be penalized in that condition. If the FlowFile's attribute value exceeds the configured maximum, "
-    "the FlowFile will be passed to a 'retries_exceeded' relationship. "
-    "WARNING: If the incoming FlowFile has a non-numeric value in the configured 'Retry Attribute' attribute, it will be reset to '1'. "
-    "You may choose to fail the FlowFile instead of performing the reset. Additional dynamic properties can be defined for any attributes "
-    "you wish to add to the FlowFiles transferred to 'retries_exceeded'. These attributes support attribute expression language.");
+REGISTER_RESOURCE(RetryFlowFile, Processor);
 
 } /* namespace processors */
 } /* namespace minifi */
