@@ -46,15 +46,11 @@
 #include "TailFile.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 #include "utils/RegexUtils.h"
 
-
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 const core::Property TailFile::FileName(
     core::PropertyBuilder::createProperty("File to Tail")
@@ -139,6 +135,13 @@ const core::Property TailFile::AttributeProviderService(
         ->asType<minifi::controllers::AttributeProviderService>()
         ->build());
 
+const core::Property TailFile::BatchSize(
+    core::PropertyBuilder::createProperty("Batch Size")
+        ->withDescription("Maximum number of flowfiles emitted in a single trigger. If set to 0 all new content will be processed.")
+        ->isRequired(true)
+        ->withDefaultValue<uint32_t>(0)
+        ->build());
+
 const core::Relationship TailFile::Success("success", "All files are routed to success");
 
 const char *TailFile::CURRENT_STR = "CURRENT.";
@@ -222,8 +225,8 @@ class FileReaderCallback {
     openFile(file_name, offset, input_stream_, logger_);
   }
 
-  int64_t operator()(const std::shared_ptr<io::BaseStream>& output_stream) {
-    io::CRCStream<io::BaseStream> crc_stream{gsl::make_not_null(output_stream.get()), checksum_};
+  int64_t operator()(const std::shared_ptr<io::OutputStream>& output_stream) {
+    io::CRCStream<io::OutputStream> crc_stream{gsl::make_not_null(output_stream.get()), checksum_};
 
     uint64_t num_bytes_written = 0;
     bool found_delimiter = false;
@@ -295,10 +298,10 @@ class WholeFileReaderCallback {
     return checksum_;
   }
 
-  int64_t operator()(const std::shared_ptr<io::BaseStream>& output_stream) {
+  int64_t operator()(const std::shared_ptr<io::OutputStream>& output_stream) {
     std::array<char, BUFFER_SIZE> buffer;
 
-    io::CRCStream<io::BaseStream> crc_stream{gsl::make_not_null(output_stream.get()), checksum_};
+    io::CRCStream<io::OutputStream> crc_stream{gsl::make_not_null(output_stream.get()), checksum_};
 
     uint64_t num_bytes_written = 0;
 
@@ -327,18 +330,8 @@ class WholeFileReaderCallback {
 }  // namespace
 
 void TailFile::initialize() {
-  setSupportedProperties({
-    FileName,
-    StateFile,
-    Delimiter,
-    TailMode,
-    BaseDirectory,
-    RecursiveLookup,
-    LookupFrequency,
-    RollingFilenamePattern,
-    InitialStartPosition,
-    AttributeProviderService});
-  setSupportedRelationships({Success});
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
 void TailFile::onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory>& /*sessionFactory*/) {
@@ -393,7 +386,8 @@ void TailFile::onSchedule(const std::shared_ptr<core::ProcessContext> &context,
   } else {
     tail_mode_ = Mode::SINGLE;
 
-    std::string path, file_name;
+    std::string path;
+    std::string file_name;
     if (utils::file::getFileNameAndPath(file_to_tail_, path, file_name)) {
       // NOTE: position and checksum will be updated in recoverState() if there is a persisted state for this file
       tail_states_.emplace(file_to_tail_, TailState{path, file_name});
@@ -408,6 +402,11 @@ void TailFile::onSchedule(const std::shared_ptr<core::ProcessContext> &context,
   context->getProperty(RollingFilenamePattern.getName(), rolling_filename_pattern_glob);
   rolling_filename_pattern_ = utils::file::globToRegex(rolling_filename_pattern_glob);
   initial_start_position_ = InitialStartPositions{utils::parsePropertyWithAllowableValuesOrThrow(*context, InitialStartPosition.getName(), InitialStartPositions::values())};
+
+  uint32_t batch_size = 0;
+  if (context->getProperty(BatchSize.getName(), batch_size) && batch_size != 0) {
+    batch_size_ = batch_size;
+  }
 }
 
 void TailFile::parseAttributeProviderServiceProperty(core::ProcessContext& context) {
@@ -463,7 +462,8 @@ void TailFile::parseStateFileLine(char *buf, std::map<std::string, TailState> &s
   value = utils::StringUtils::trimRight(value);
 
   if (key == "FILENAME") {
-    std::string fileLocation, fileName;
+    std::string fileLocation;
+    std::string fileName;
     if (utils::file::getFileNameAndPath(value, fileLocation, fileName)) {
       logger_->log_debug("State migration received path %s, file %s", fileLocation, fileName);
       state.emplace(fileName, TailState{fileLocation, fileName});
@@ -482,7 +482,8 @@ void TailFile::parseStateFileLine(char *buf, std::map<std::string, TailState> &s
   }
   if (key.find(CURRENT_STR) == 0) {
     const auto file = key.substr(strlen(CURRENT_STR));
-    std::string fileLocation, fileName;
+    std::string fileLocation;
+    std::string fileName;
     if (utils::file::getFileNameAndPath(value, fileLocation, fileName)) {
       state[file].path_ = fileLocation;
       state[file].file_name_ = fileName;
@@ -541,7 +542,8 @@ bool TailFile::getStateFromStateManager(std::map<std::string, TailState> &new_ta
             readOptionalInt64(state_map, "file." + std::to_string(i) + ".last_read_time")
         }};
 
-        std::string fileLocation, fileName;
+        std::string fileLocation;
+        std::string fileName;
         if (utils::file::getFileNameAndPath(current, fileLocation, fileName)) {
           logger_->log_debug("Received path %s, file %s", fileLocation, fileName);
           new_tail_states.emplace(current, TailState{fileLocation, fileName, position, last_read_time, checksum});
@@ -671,7 +673,7 @@ std::vector<TailState> TailFile::findRotatedFilesAfterLastReadTime(const TailSta
   return sortAndSkipMainFilePrefix(state, matched_files_with_mtime);
 }
 
-std::vector<TailState> TailFile::sortAndSkipMainFilePrefix(const TailState &state, std::vector<TailStateWithMtime>& matched_files_with_mtime) const {
+std::vector<TailState> TailFile::sortAndSkipMainFilePrefix(const TailState &state, std::vector<TailStateWithMtime>& matched_files_with_mtime) {
   const auto first_by_mtime_then_by_name = [](const auto& left, const auto& right) {
     return std::tie(left.mtime_, left.tail_state_.file_name_) <
            std::tie(right.mtime_, right.tail_state_.file_name_);
@@ -776,7 +778,7 @@ void TailFile::processSingleFile(const std::shared_ptr<core::ProcessSession> &se
                                  TailState &state) {
   std::string fileName = state.file_name_;
 
-  if (utils::file::file_size(full_file_name) == 0u) {
+  if (utils::file::file_size(full_file_name) == 0U) {
     logger_->log_warn("Unable to read file %s as it does not exist or has size zero", full_file_name);
     return;
   }
@@ -794,7 +796,7 @@ void TailFile::processSingleFile(const std::shared_ptr<core::ProcessSession> &se
     FileReaderCallback file_reader{full_file_name, state.position_, delim, state.checksum_};
     TailState state_copy{state};
 
-    while (file_reader.hasMoreToRead()) {
+    while (file_reader.hasMoreToRead() && (!batch_size_ || *batch_size_ > num_flow_files)) {
       auto flow_file = session->create();
       session->write(flow_file, std::ref(file_reader));
 
@@ -849,7 +851,7 @@ void TailFile::updateFlowFileAttributes(const std::string &full_file_name, const
   }
 }
 
-void TailFile::updateStateAttributes(TailState &state, uint64_t size, uint64_t checksum) const {
+void TailFile::updateStateAttributes(TailState &state, uint64_t size, uint64_t checksum) {
   state.position_ += size;
   state.last_read_time_ = std::chrono::file_clock::now();
   state.checksum_ = checksum;
@@ -868,7 +870,7 @@ void TailFile::checkForRemovedFiles() {
     const std::string &full_file_name = kv.first;
     const TailState &state = kv.second;
     utils::Regex pattern_regex(file_to_tail_);
-    if (utils::file::file_size(state.fileNameWithPath()) == 0u ||
+    if (utils::file::file_size(state.fileNameWithPath()) == 0U ||
         !utils::regexMatch(state.file_name_, pattern_regex)) {
       file_names_to_remove.push_back(full_file_name);
     }
@@ -907,7 +909,7 @@ void TailFile::checkForNewFiles(core::ProcessContext& context) {
   }
 }
 
-std::string TailFile::baseDirectoryFromAttributes(const controllers::AttributeProviderService::AttributeMap& attribute_map, core::ProcessContext& context) const {
+std::string TailFile::baseDirectoryFromAttributes(const controllers::AttributeProviderService::AttributeMap& attribute_map, core::ProcessContext& context) {
   auto flow_file = std::make_shared<FlowFileRecord>();
   for (const auto& [key, value] : attribute_map) {
     flow_file->setAttribute(key, value);
@@ -919,15 +921,6 @@ std::chrono::milliseconds TailFile::getLookupFrequency() const {
   return lookup_frequency_;
 }
 
-REGISTER_RESOURCE(TailFile, "\"Tails\" a file, or a list of files, ingesting data from the file as it is written to the file. The file is expected to be textual."
-                  " Data is ingested only when a new line is encountered (carriage return or new-line character or combination). If the file to tail is periodically \"rolled over\","
-                  " as is generally the case with log files, an optional Rolling Filename Pattern can be used to retrieve data from files that have rolled over, even if the rollover"
-                  " occurred while NiFi was not running (provided that the data still exists upon restart of NiFi). It is generally advisable to set the Run Schedule to a few seconds,"
-                  " rather than running with the default value of 0 secs, as this Processor will consume a lot of resources if scheduled very aggressively. At this time, this Processor"
-                  " does not support ingesting files that have been compressed when 'rolled over'.");
+REGISTER_RESOURCE(TailFile, Processor);
 
-}  // namespace processors
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::processors
