@@ -17,8 +17,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_TAILFILE_H_
-#define EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_TAILFILE_H_
+#pragma once
 
 #include <map>
 #include <memory>
@@ -27,6 +26,7 @@
 #include <unordered_map>
 #include <vector>
 #include <set>
+#include <optional>
 
 #include "controllers/AttributeProviderService.h"
 #include "FlowFileRecord.h"
@@ -37,11 +37,7 @@
 #include "utils/Enum.h"
 #include "utils/Export.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 struct TailState {
   TailState(std::string path, std::string file_name, uint64_t position,
@@ -83,16 +79,19 @@ SMART_ENUM(InitialStartPositions,
 
 class TailFile : public core::Processor {
  public:
-  explicit TailFile(const std::string& name, const utils::Identifier& uuid = {})
-      : core::Processor(name, uuid) {
+  explicit TailFile(std::string name, const utils::Identifier& uuid = {})
+      : core::Processor(std::move(name), uuid) {
   }
 
   ~TailFile() override = default;
 
-  // Processor Name
-  EXTENSIONAPI static constexpr char const* ProcessorName = "TailFile";
+  EXTENSIONAPI static constexpr const char* Description = "\"Tails\" a file, or a list of files, ingesting data from the file as it is written to the file. The file is expected to be textual."
+      " Data is ingested only when a new line is encountered (carriage return or new-line character or combination). If the file to tail is periodically \"rolled over\","
+      " as is generally the case with log files, an optional Rolling Filename Pattern can be used to retrieve data from files that have rolled over, even if the rollover"
+      " occurred while NiFi was not running (provided that the data still exists upon restart of NiFi). It is generally advisable to set the Run Schedule to a few seconds,"
+      " rather than running with the default value of 0 secs, as this Processor will consume a lot of resources if scheduled very aggressively. At this time, this Processor"
+      " does not support ingesting files that have been compressed when 'rolled over'.";
 
-  // Supported Properties
   EXTENSIONAPI static const core::Property FileName;
   EXTENSIONAPI static const core::Property StateFile;
   EXTENSIONAPI static const core::Property Delimiter;
@@ -103,10 +102,40 @@ class TailFile : public core::Processor {
   EXTENSIONAPI static const core::Property RollingFilenamePattern;
   EXTENSIONAPI static const core::Property InitialStartPosition;
   EXTENSIONAPI static const core::Property AttributeProviderService;
+  EXTENSIONAPI static const core::Property BatchSize;
+
+  static auto properties() {
+    return std::array{
+      FileName,
+      StateFile,
+      Delimiter,
+      TailMode,
+      BaseDirectory,
+      RecursiveLookup,
+      LookupFrequency,
+      RollingFilenamePattern,
+      InitialStartPosition,
+      AttributeProviderService,
+      BatchSize
+    };
+  }
 
-  // Supported Relationships
   EXTENSIONAPI static const core::Relationship Success;
 
+  static auto relationships() {
+    return std::array{Success};
+  }
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicProperties = false;
+
+  EXTENSIONAPI static constexpr bool SupportsDynamicRelationships = false;
+
+  EXTENSIONAPI static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_FORBIDDEN;
+
+  EXTENSIONAPI static constexpr bool IsSingleThreaded = true;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
+
   /**
    * Function that's executed when the processor is scheduled.
    * @param context process context, provides eg. configuration.
@@ -138,14 +167,6 @@ class TailFile : public core::Processor {
     TimePoint mtime_;
   };
 
-  core::annotation::Input getInputRequirement() const override {
-    return core::annotation::Input::INPUT_FORBIDDEN;
-  }
-
-  bool isSingleThreaded() const override {
-    return true;
-  }
-
   void parseAttributeProviderServiceProperty(core::ProcessContext& context);
   void parseStateFileLine(char *buf, std::map<std::string, TailState> &state) const;
   void processAllRotatedFiles(const std::shared_ptr<core::ProcessSession> &session, TailState &state);
@@ -154,24 +175,24 @@ class TailFile : public core::Processor {
   std::string parseRollingFilePattern(const TailState &state) const;
   std::vector<TailState> findAllRotatedFiles(const TailState &state) const;
   std::vector<TailState> findRotatedFilesAfterLastReadTime(const TailState &state) const;
-  std::vector<TailState> sortAndSkipMainFilePrefix(const TailState &state, std::vector<TailStateWithMtime>& matched_files_with_mtime) const;
+  static std::vector<TailState> sortAndSkipMainFilePrefix(const TailState &state, std::vector<TailStateWithMtime>& matched_files_with_mtime);
   void processFile(const std::shared_ptr<core::ProcessSession> &session,
                    const std::string &full_file_name,
                    TailState &state);
   void processSingleFile(const std::shared_ptr<core::ProcessSession> &session,
                          const std::string &full_file_name,
                          TailState &state);
-  bool getStateFromStateManager(std::map<std::string, TailState> &state) const;
+  bool getStateFromStateManager(std::map<std::string, TailState> &new_tail_states) const;
   bool getStateFromLegacyStateFile(const std::shared_ptr<core::ProcessContext>& context,
                                    std::map<std::string, TailState> &new_tail_states) const;
   void doMultifileLookup(core::ProcessContext& context);
   void checkForRemovedFiles();
   void checkForNewFiles(core::ProcessContext& context);
-  std::string baseDirectoryFromAttributes(const controllers::AttributeProviderService::AttributeMap& attribute_map, core::ProcessContext& context) const;
+  static std::string baseDirectoryFromAttributes(const controllers::AttributeProviderService::AttributeMap& attribute_map, core::ProcessContext& context);
   void updateFlowFileAttributes(const std::string &full_file_name, const TailState &state, const std::string &fileName,
                                 const std::string &baseName, const std::string &extension,
                                 std::shared_ptr<core::FlowFile> &flow_file) const;
-  void updateStateAttributes(TailState &state, uint64_t size, uint64_t checksum) const;
+  static void updateStateAttributes(TailState &state, uint64_t size, uint64_t checksum);
   bool isOldFileInitiallyRead(TailState &state) const;
 
   static const char *CURRENT_STR;
@@ -192,13 +213,8 @@ class TailFile : public core::Processor {
   bool first_trigger_{true};
   controllers::AttributeProviderService* attribute_provider_service_ = nullptr;
   std::unordered_map<std::string, controllers::AttributeProviderService::AttributeMap> extra_attributes_;
+  std::optional<uint32_t> batch_size_;
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<TailFile>::getLogger();
 };
 
-}  // namespace processors
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
-#endif  // EXTENSIONS_STANDARD_PROCESSORS_PROCESSORS_TAILFILE_H_
+}  // namespace org::apache::nifi::minifi::processors
