@@ -32,12 +32,13 @@
 #include "state/ProcessorController.h"
 #include "integration/IntegrationBase.h"
 #include "utils/IntegrationTestUtils.h"
+#include "utils/TestUtils.h"
 
-using std::literals::chrono_literals::operator""s;
+using namespace std::literals::chrono_literals;
 
 class TailFileTestHarness : public IntegrationBase {
  public:
-  TailFileTestHarness() : IntegrationBase(1s) {
+  TailFileTestHarness() : IntegrationBase(2s) {
     dir = testController.createTempDirectory();
 
     statefile = dir + utils::file::get_separator();
@@ -53,6 +54,9 @@ class TailFileTestHarness : public IntegrationBase {
     LogTestController::getInstance().setInfo<minifi::processors::LogAttribute>();
     LogTestController::getInstance().setTrace<minifi::processors::TailFile>();
     LogTestController::getInstance().setTrace<minifi::FlowController>();
+#ifdef WIN32
+    utils::dateSetInstall(TZ_DATA_DIR);
+#endif
   }
 
   void cleanup() override {
@@ -74,8 +78,8 @@ class TailFileTestHarness : public IntegrationBase {
     fc.executeOnComponent("tf", [this] (minifi::state::StateController& component) {
       auto proc = dynamic_cast<minifi::state::ProcessorController*>(&component);
       if (nullptr != proc) {
-        proc->getProcessor()->setProperty(minifi::processors::TailFile::FileName, ss.str());
-        proc->getProcessor()->setProperty(minifi::processors::TailFile::StateFile, statefile);
+        proc->getProcessor().setProperty(minifi::processors::TailFile::FileName, ss.str());
+        proc->getProcessor().setProperty(minifi::processors::TailFile::StateFile, statefile);
       }
     });
   }
