@@ -17,7 +17,6 @@
  */
 #include <list>
 #include <fstream>
-#include <map>
 #include <memory>
 #include <utility>
 #include <string>
@@ -144,7 +143,6 @@ TEST_CASE("Test usage of ExtractText in regex mode", "[extracttextRegexTest]") {
 
   std::shared_ptr<core::Processor> maprocessor = plan->addProcessor("ExtractText", "testExtractText", core::Relationship("success", "description"), true);
   plan->setProperty(maprocessor, org::apache::nifi::minifi::processors::ExtractText::RegexMode.getName(), "true");
-  plan->setProperty(maprocessor, org::apache::nifi::minifi::processors::ExtractText::IgnoreCaptureGroupZero.getName(), "true");
   plan->setProperty(maprocessor, org::apache::nifi::minifi::processors::ExtractText::EnableRepeatingCaptureGroup.getName(), "true");
   plan->setProperty(maprocessor, "RegexAttr", "Speed limit ([0-9]+)", true);
   plan->setProperty(maprocessor, "InvalidRegex", "[Invalid)A(F)", true);
@@ -162,17 +160,34 @@ TEST_CASE("Test usage of ExtractText in regex mode", "[extracttextRegexTest]") {
     test_file.close();
   }
 
-  plan->runNextProcessor();  // GetFile
-  plan->runNextProcessor();  // ExtractText
-  plan->runNextProcessor();  // LogAttribute
+  std::list<std::string> expected_logs;
 
-  std::list<std::string> suffixes = { "", ".0", ".1" };
+  SECTION("Do not include capture group 0") {
+    plan->setProperty(maprocessor, org::apache::nifi::minifi::processors::ExtractText::IncludeCaptureGroupZero.getName(), "false");
 
-  for (const auto& suffix : suffixes) {
-    ss.str("");
-    ss << "key:" << "RegexAttr" << suffix << " value:" << ((suffix == ".1") ? "80" : "130");
-    std::string log_check = ss.str();
-    REQUIRE(LogTestController::getInstance().contains(log_check));
+    testController.runSession(plan);
+
+    expected_logs = {
+      "key:RegexAttr value:130",
+      "key:RegexAttr.0 value:130",
+      "key:RegexAttr.1 value:80"
+    };
+  }
+
+  SECTION("Include capture group 0") {
+    testController.runSession(plan);
+
+    expected_logs = {
+      "key:RegexAttr value:Speed limit 130",
+      "key:RegexAttr.0 value:Speed limit 130",
+      "key:RegexAttr.1 value:130",
+      "key:RegexAttr.2 value:Speed limit 80",
+      "key:RegexAttr.3 value:80"
+    };
+  }
+
+  for (const auto& log : expected_logs) {
+    REQUIRE(LogTestController::getInstance().contains(log));
   }
 
   std::string error_str = "error encountered when trying to construct regular expression from property (key: InvalidRegex)";
@@ -199,6 +214,7 @@ TEST_CASE("Test usage of ExtractText in regex mode with large regex matches", "[
 
   auto extract_text_processor = plan->addProcessor("ExtractText", "ExtractText", core::Relationship("success", "description"), true);
   plan->setProperty(extract_text_processor, org::apache::nifi::minifi::processors::ExtractText::RegexMode.getName(), "true");
+  plan->setProperty(extract_text_processor, org::apache::nifi::minifi::processors::ExtractText::IncludeCaptureGroupZero.getName(), "false");
   plan->setProperty(extract_text_processor, "RegexAttr", "Speed limit (.*)", true);
 
   auto log_attribute_processor = plan->addProcessor("LogAttribute", "outputLogAttribute", core::Relationship("success", "description"), true);
