@@ -19,15 +19,18 @@
 #include "Catch.h"
 #include "ListenSyslog.h"
 #include "SingleProcessorTestController.h"
-#include "asio.hpp"
+#include "Utils.h"
+#include "controllers/SSLContextService.h"
+#include "range/v3/algorithm/contains.hpp"
 
 using ListenSyslog = org::apache::nifi::minifi::processors::ListenSyslog;
 
 using namespace std::literals::chrono_literals;
 
-namespace org::apache::nifi::minifi::processors::testing {
+namespace org::apache::nifi::minifi::test {
 
 constexpr uint64_t SYSLOG_PORT = 10255;
+constexpr auto local_addresses = {"127.0.0.1", "::ffff:127.0.0.1", "::1"};
 
 struct ValidRFC5424Message {
   constexpr ValidRFC5424Message(std::string_view message,
@@ -196,36 +199,10 @@ constexpr std::string_view rfc5424_logger_example_1 = R"(<13>1 2022-03-17T10:10:
 
 constexpr std::string_view invalid_syslog = "not syslog";
 
-void sendUDPPacket(const std::string_view content, uint64_t port) {
-  asio::io_context io_context;
-  asio::ip::udp::socket socket(io_context);
-  asio::ip::udp::endpoint remote_endpoint(asio::ip::address::from_string("127.0.0.1"), port);
-  socket.open(asio::ip::udp::v4());
-  std::error_code err;
-  socket.send_to(asio::buffer(content, content.size()), remote_endpoint, 0, err);
-  REQUIRE(!err);
-  socket.close();
-}
-
-void sendMessagesViaTCP(const std::vector<std::string_view>& contents, uint64_t port) {
-  asio::io_context io_context;
-  asio::ip::tcp::socket socket(io_context);
-  asio::ip::tcp::endpoint remote_endpoint(asio::ip::address::from_string("127.0.0.1"), port);
-  socket.connect(remote_endpoint);
-  std::error_code err;
-  for (auto& content : contents) {
-    std::string tcp_message(content);
-    tcp_message += '\n';
-    socket.send(asio::buffer(tcp_message, tcp_message.size()), 0, err);
-  }
-  REQUIRE(!err);
-  socket.close();
-}
-
 void check_for_only_basic_attributes(core::FlowFile& flow_file, uint16_t port, std::string_view protocol) {
   CHECK(std::to_string(port) == flow_file.getAttribute("syslog.port"));
   CHECK(protocol == flow_file.getAttribute("syslog.protocol"));
-  CHECK("127.0.0.1" == flow_file.getAttribute("syslog.sender"));
+  CHECK(ranges::contains(local_addresses, flow_file.getAttribute("syslog.sender")));
 
   CHECK(std::nullopt == flow_file.getAttribute("syslog.valid"));
   CHECK(std::nullopt == flow_file.getAttribute("syslog.priority"));
@@ -242,7 +219,7 @@ void check_for_only_basic_attributes(core::FlowFile& flow_file, uint16_t port, s
 void check_parsed_attributes(const core::FlowFile& flow_file, const ValidRFC5424Message& original_message, uint16_t port, std::string_view protocol) {
   CHECK(std::to_string(port) == flow_file.getAttribute("syslog.port"));
   CHECK(protocol == flow_file.getAttribute("syslog.protocol"));
-  CHECK("127.0.0.1" == flow_file.getAttribute("syslog.sender"));
+  CHECK(ranges::contains(local_addresses, flow_file.getAttribute("syslog.sender")));
 
   CHECK("true" == flow_file.getAttribute("syslog.valid"));
   CHECK(original_message.priority_ == flow_file.getAttribute("syslog.priority"));
@@ -261,7 +238,7 @@ void check_parsed_attributes(const core::FlowFile& flow_file, const ValidRFC5424
 void check_parsed_attributes(const core::FlowFile& flow_file, const ValidRFC3164Message& original_message, uint16_t port, std::string_view protocol) {
   CHECK(std::to_string(port) == flow_file.getAttribute("syslog.port"));
   CHECK(protocol == flow_file.getAttribute("syslog.protocol"));
-  CHECK("127.0.0.1" == flow_file.getAttribute("syslog.sender"));
+  CHECK(ranges::contains(local_addresses, flow_file.getAttribute("syslog.sender")));
 
   CHECK("true" == flow_file.getAttribute("syslog.valid"));
   CHECK(original_message.priority_ == flow_file.getAttribute("syslog.priority"));
@@ -272,47 +249,10 @@ void check_parsed_attributes(const core::FlowFile& flow_file, const ValidRFC3164
   CHECK(original_message.msg_ == flow_file.getAttribute("syslog.msg"));
 }
 
-bool triggerUntil(test::SingleProcessorTestController& controller,
-                  const std::unordered_map<core::Relationship, size_t>& expected_quantities,
-                  std::unordered_map<core::Relationship, std::vector<std::shared_ptr<core::FlowFile>>>& result,
-                  const std::chrono::milliseconds max_duration,
-                  const std::chrono::milliseconds wait_time = 50ms) {
-  auto start_time = std::chrono::steady_clock::now();
-  while (std::chrono::steady_clock::now() < start_time + max_duration) {
-    for (auto& [relationship, flow_files] : controller.trigger()) {
-      result[relationship].insert(result[relationship].end(), flow_files.begin(), flow_files.end());
-    }
-    bool expected_quantities_met = true;
-    for (const auto& [relationship, expected_quantity] : expected_quantities) {
-      if (result[relationship].size() < expected_quantity) {
-        expected_quantities_met = false;
-        break;
-      }
-    }
-    if (expected_quantities_met)
-      return true;
-    std::this_thread::sleep_for(wait_time);
-  }
-  return false;
-}
-
-bool countLogOccurrencesUntil(const std::string& pattern,
-                              const int occurrences,
-                              const std::chrono::milliseconds max_duration,
-                              const std::chrono::milliseconds wait_time = 50ms) {
-  auto start_time = std::chrono::steady_clock::now();
-  while (std::chrono::steady_clock::now() < start_time + max_duration) {
-    if (LogTestController::getInstance().countOccurrences(pattern) == occurrences)
-      return true;
-    std::this_thread::sleep_for(wait_time);
-  }
-  return false;
-}
-
-TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
+TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog][NetworkListenerProcessor]") {
   const auto listen_syslog = std::make_shared<ListenSyslog>("ListenSyslog");
 
-  test::SingleProcessorTestController controller{listen_syslog};
+  SingleProcessorTestController controller{listen_syslog};
   LogTestController::getInstance().setTrace<ListenSyslog>();
   REQUIRE(listen_syslog->setProperty(ListenSyslog::Port, std::to_string(SYSLOG_PORT)));
   REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "2"));
@@ -320,22 +260,40 @@ TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
   std::string protocol;
 
   SECTION("UDP") {
+    asio::ip::udp::endpoint endpoint;
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), SYSLOG_PORT);
+    }
+    SECTION("sending through IPv6", "[IPv6]") {
+      if (utils::isIPv6Disabled())
+        return;
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v6::loopback(), SYSLOG_PORT);
+    }
     protocol = "UDP";
     REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "UDP"));
     controller.plan->scheduleProcessor(listen_syslog);
-    sendUDPPacket(rfc5424_logger_example_1, SYSLOG_PORT);
-    sendUDPPacket(invalid_syslog, SYSLOG_PORT);
+    utils::sendUdpDatagram(rfc5424_logger_example_1, endpoint);
+    utils::sendUdpDatagram(invalid_syslog, endpoint);
   }
 
   SECTION("TCP") {
+    asio::ip::tcp::endpoint endpoint;
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), SYSLOG_PORT);
+    }
+    SECTION("sending through IPv6", "[IPv6]") {
+      if (utils::isIPv6Disabled())
+        return;
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), SYSLOG_PORT);
+    }
     protocol = "TCP";
     REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
     controller.plan->scheduleProcessor(listen_syslog);
-    sendMessagesViaTCP({rfc5424_logger_example_1}, SYSLOG_PORT);
-    sendMessagesViaTCP({invalid_syslog}, SYSLOG_PORT);
+    REQUIRE(utils::sendMessagesViaTCP({rfc5424_logger_example_1}, endpoint));
+    REQUIRE(utils::sendMessagesViaTCP({invalid_syslog}, endpoint));
   }
   std::unordered_map<core::Relationship, std::vector<std::shared_ptr<core::FlowFile>>> result;
-  REQUIRE(triggerUntil(controller, {{ListenSyslog::Success, 2}}, result, 300ms, 50ms));
+  REQUIRE(controller.triggerUntil({{ListenSyslog::Success, 2}}, result, 300ms, 50ms));
   CHECK(controller.plan->getContent(result.at(ListenSyslog::Success)[0]) == rfc5424_logger_example_1);
   CHECK(controller.plan->getContent(result.at(ListenSyslog::Success)[1]) == invalid_syslog);
 
@@ -343,10 +301,10 @@ TEST_CASE("ListenSyslog without parsing test", "[ListenSyslog]") {
   check_for_only_basic_attributes(*result.at(ListenSyslog::Success)[1], SYSLOG_PORT, protocol);
 }
 
-TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog]") {
+TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog][NetworkListenerProcessor]") {
   const auto listen_syslog = std::make_shared<ListenSyslog>("ListenSyslog");
 
-  test::SingleProcessorTestController controller{listen_syslog};
+  SingleProcessorTestController controller{listen_syslog};
   LogTestController::getInstance().setTrace<ListenSyslog>();
   REQUIRE(listen_syslog->setProperty(ListenSyslog::Port, std::to_string(SYSLOG_PORT)));
   REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "100"));
@@ -354,46 +312,63 @@ TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog]") {
 
   std::string protocol;
   SECTION("UDP") {
+    asio::ip::udp::endpoint endpoint;
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), SYSLOG_PORT);
+    }
+    SECTION("sending through IPv6", "[IPv6]") {
+      if (utils::isIPv6Disabled())
+        return;
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v6::loopback(), SYSLOG_PORT);
+    }
     protocol = "UDP";
     REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "UDP"));
     controller.plan->scheduleProcessor(listen_syslog);
     std::this_thread::sleep_for(100ms);
-    sendUDPPacket(rfc5424_doc_example_1.unparsed_, SYSLOG_PORT);
-    sendUDPPacket(rfc5424_doc_example_2.unparsed_, SYSLOG_PORT);
-    sendUDPPacket(rfc5424_doc_example_3.unparsed_, SYSLOG_PORT);
-    sendUDPPacket(rfc5424_doc_example_4.unparsed_, SYSLOG_PORT);
+    utils::sendUdpDatagram(rfc5424_doc_example_1.unparsed_, endpoint);
+    utils::sendUdpDatagram(rfc5424_doc_example_2.unparsed_, endpoint);
+    utils::sendUdpDatagram(rfc5424_doc_example_3.unparsed_, endpoint);
+    utils::sendUdpDatagram(rfc5424_doc_example_4.unparsed_, endpoint);
 
-    sendUDPPacket(rfc3164_doc_example_1.unparsed_, SYSLOG_PORT);
-    sendUDPPacket(rfc3164_doc_example_2.unparsed_, SYSLOG_PORT);
-    sendUDPPacket(rfc3164_doc_example_3.unparsed_, SYSLOG_PORT);
-    sendUDPPacket(rfc3164_doc_example_4.unparsed_, SYSLOG_PORT);
+    utils::sendUdpDatagram(rfc3164_doc_example_1.unparsed_, endpoint);
+    utils::sendUdpDatagram(rfc3164_doc_example_2.unparsed_, endpoint);
+    utils::sendUdpDatagram(rfc3164_doc_example_3.unparsed_, endpoint);
+    utils::sendUdpDatagram(rfc3164_doc_example_4.unparsed_, endpoint);
 
-    sendUDPPacket(rfc5424_logger_example_1, SYSLOG_PORT);
-    sendUDPPacket(invalid_syslog, SYSLOG_PORT);
+    utils::sendUdpDatagram(rfc5424_logger_example_1, endpoint);
+    utils::sendUdpDatagram(invalid_syslog, endpoint);
   }
 
   SECTION("TCP") {
+    asio::ip::tcp::endpoint endpoint;
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), SYSLOG_PORT);
+    }
+    SECTION("sending through IPv6", "[IPv6]") {
+      if (utils::isIPv6Disabled())
+        return;
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), SYSLOG_PORT);
+    }
     protocol = "TCP";
     REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
     controller.plan->scheduleProcessor(listen_syslog);
     std::this_thread::sleep_for(100ms);
-    sendMessagesViaTCP({rfc5424_doc_example_1.unparsed_,
-                        rfc5424_doc_example_2.unparsed_,
-                        rfc5424_doc_example_3.unparsed_,
-                        rfc5424_doc_example_4.unparsed_}, SYSLOG_PORT);
+    REQUIRE(utils::sendMessagesViaTCP({rfc5424_doc_example_1.unparsed_,
+                                       rfc5424_doc_example_2.unparsed_,
+                                       rfc5424_doc_example_3.unparsed_,
+                                       rfc5424_doc_example_4.unparsed_}, endpoint));
 
-    sendMessagesViaTCP({rfc3164_doc_example_1.unparsed_,
-                        rfc3164_doc_example_2.unparsed_,
-                        rfc3164_doc_example_3.unparsed_,
-                        rfc3164_doc_example_4.unparsed_}, SYSLOG_PORT);
+    REQUIRE(utils::sendMessagesViaTCP({rfc3164_doc_example_1.unparsed_,
+                                       rfc3164_doc_example_2.unparsed_,
+                                       rfc3164_doc_example_3.unparsed_,
+                                       rfc3164_doc_example_4.unparsed_}, endpoint));
 
-
-    sendMessagesViaTCP({rfc5424_logger_example_1}, SYSLOG_PORT);
-    sendMessagesViaTCP({invalid_syslog}, SYSLOG_PORT);
+    REQUIRE(utils::sendMessagesViaTCP({rfc5424_logger_example_1}, endpoint));
+    REQUIRE(utils::sendMessagesViaTCP({invalid_syslog}, endpoint));
   }
 
   std::unordered_map<core::Relationship, std::vector<std::shared_ptr<core::FlowFile>>> result;
-  REQUIRE(triggerUntil(controller, {{ListenSyslog::Success, 9}, {ListenSyslog::Invalid, 1}}, result, 300ms, 50ms));
+  REQUIRE(controller.triggerUntil({{ListenSyslog::Success, 9}, {ListenSyslog::Invalid, 1}}, result, 300ms, 50ms));
   REQUIRE(result.at(ListenSyslog::Success).size() == 9);
   REQUIRE(result.at(ListenSyslog::Invalid).size() == 1);
 
@@ -428,9 +403,9 @@ TEST_CASE("ListenSyslog with parsing test", "[ListenSyslog]") {
 }
 
 
-TEST_CASE("ListenSyslog can be rescheduled", "[ListenSyslog]") {
+TEST_CASE("ListenSyslog can be rescheduled", "[ListenSyslog][NetworkListenerProcessor]") {
   const auto listen_syslog = std::make_shared<ListenSyslog>("ListenSyslog");
-  test::SingleProcessorTestController controller{listen_syslog};
+  SingleProcessorTestController controller{listen_syslog};
   LogTestController::getInstance().setTrace<ListenSyslog>();
   REQUIRE(listen_syslog->setProperty(ListenSyslog::Port, std::to_string(SYSLOG_PORT)));
   REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "100"));
@@ -450,10 +425,10 @@ TEST_CASE("ListenSyslog can be rescheduled", "[ListenSyslog]") {
   }
 }
 
-TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog]") {
+TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog][NetworkListenerProcessor]") {
   const auto listen_syslog = std::make_shared<ListenSyslog>("ListenSyslog");
 
-  test::SingleProcessorTestController controller{listen_syslog};
+  SingleProcessorTestController controller{listen_syslog};
   REQUIRE(listen_syslog->setProperty(ListenSyslog::Port, std::to_string(SYSLOG_PORT)));
   REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "10"));
   REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages, "false"));
@@ -462,21 +437,40 @@ TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog]") {
   LogTestController::getInstance().setWarn<ListenSyslog>();
 
   SECTION("UDP") {
+    asio::ip::udp::endpoint endpoint;
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v4::loopback(), SYSLOG_PORT);
+    }
+    SECTION("sending through IPv6", "[IPv6]") {
+      if (utils::isIPv6Disabled())
+        return;
+      endpoint = asio::ip::udp::endpoint(asio::ip::address_v6::loopback(), SYSLOG_PORT);
+    }
     REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "UDP"));
     controller.plan->scheduleProcessor(listen_syslog);
     for (auto i = 0; i < 100; ++i) {
-      sendUDPPacket(rfc5424_doc_example_1.unparsed_, SYSLOG_PORT);
+      utils::sendUdpDatagram(rfc5424_doc_example_1.unparsed_, endpoint);
     }
+    CHECK(utils::countLogOccurrencesUntil("Queue is full. UDP message ignored.", 50, 300ms, 50ms));
   }
 
   SECTION("TCP") {
+    asio::ip::tcp::endpoint endpoint;
+    SECTION("sending through IPv4", "[IPv4]") {
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), SYSLOG_PORT);
+    }
+    SECTION("sending through IPv6", "[IPv6]") {
+      if (utils::isIPv6Disabled())
+        return;
+      endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), SYSLOG_PORT);
+    }
     REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
     controller.plan->scheduleProcessor(listen_syslog);
     for (auto i = 0; i < 100; ++i) {
-      sendMessagesViaTCP({rfc5424_doc_example_1.unparsed_}, SYSLOG_PORT);
+      REQUIRE(utils::sendMessagesViaTCP({rfc5424_doc_example_1.unparsed_}, endpoint));
     }
+    CHECK(utils::countLogOccurrencesUntil("Queue is full. TCP message ignored.", 50, 300ms, 50ms));
   }
-  CHECK(countLogOccurrencesUntil("Queue is full. Syslog message ignored.", 50, 300ms, 50ms));
   CHECK(controller.trigger().at(ListenSyslog::Success).size() == 10);
   CHECK(controller.trigger().at(ListenSyslog::Success).size() == 10);
   CHECK(controller.trigger().at(ListenSyslog::Success).size() == 10);
@@ -485,4 +479,45 @@ TEST_CASE("ListenSyslog max queue and max batch size test", "[ListenSyslog]") {
   CHECK(controller.trigger().at(ListenSyslog::Success).empty());
 }
 
-}  // namespace org::apache::nifi::minifi::processors::testing
+TEST_CASE("Test ListenSyslog via TCP with SSL connection", "[ListenSyslog][NetworkListenerProcessor]") {
+  asio::ip::tcp::endpoint endpoint;
+  SECTION("sending through IPv4", "[IPv4]") {
+    endpoint = asio::ip::tcp::endpoint(asio::ip::address_v4::loopback(), SYSLOG_PORT);
+  }
+  SECTION("sending through IPv6", "[IPv6]") {
+    if (utils::isIPv6Disabled())
+      return;
+    endpoint = asio::ip::tcp::endpoint(asio::ip::address_v6::loopback(), SYSLOG_PORT);
+  }
+  const auto listen_syslog = std::make_shared<ListenSyslog>("ListenSyslog");
+
+  SingleProcessorTestController controller{listen_syslog};
+  auto ssl_context_service = controller.plan->addController("SSLContextService", "SSLContextService");
+  const auto executable_dir = minifi::utils::file::FileUtils::get_executable_dir();
+  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::CACertificate.getName(),
+      minifi::utils::file::concat_path(executable_dir, "resources/ca_A.crt")));
+  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::ClientCertificate.getName(),
+      minifi::utils::file::concat_path(executable_dir, "resources/localhost_by_A.pem")));
+  REQUIRE(controller.plan->setProperty(ssl_context_service, controllers::SSLContextService::PrivateKey.getName(),
+      minifi::utils::file::concat_path(executable_dir, "resources/localhost_by_A.pem")));
+  LogTestController::getInstance().setTrace<ListenSyslog>();
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::Port, std::to_string(SYSLOG_PORT)));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::MaxBatchSize, "2"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ParseMessages, "false"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::ProtocolProperty, "TCP"));
+  REQUIRE(listen_syslog->setProperty(ListenSyslog::SSLContextService, "SSLContextService"));
+  ssl_context_service->enable();
+  controller.plan->scheduleProcessor(listen_syslog);
+  REQUIRE(utils::sendMessagesViaSSL({rfc5424_logger_example_1}, endpoint, minifi::utils::file::concat_path(executable_dir, "resources/ca_A.crt")));
+  REQUIRE(utils::sendMessagesViaSSL({invalid_syslog}, endpoint, minifi::utils::file::concat_path(executable_dir, "/resources/ca_A.crt")));
+
+  std::unordered_map<core::Relationship, std::vector<std::shared_ptr<core::FlowFile>>> result;
+  REQUIRE(controller.triggerUntil({{ListenSyslog::Success, 2}}, result, 300ms, 50ms));
+  CHECK(controller.plan->getContent(result.at(ListenSyslog::Success)[0]) == rfc5424_logger_example_1);
+  CHECK(controller.plan->getContent(result.at(ListenSyslog::Success)[1]) == invalid_syslog);
+
+  check_for_only_basic_attributes(*result.at(ListenSyslog::Success)[0], SYSLOG_PORT, "TCP");
+  check_for_only_basic_attributes(*result.at(ListenSyslog::Success)[1], SYSLOG_PORT, "TCP");
+}
+
+}  // namespace org::apache::nifi::minifi::test
