@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#define EXTENSION_LIST "*minifi-*,!*http-curl*,!*coap*,!*splunk*"
+#define EXTENSION_LIST "*minifi-*,!*http-curl*,!*coap*,!*splunk*,!*elastic*"
 
 #include <cstdio>
 #include <utility>
@@ -70,7 +70,6 @@ TEST_CASE("Test GetFileMultiple", "[getfileCreate3]") {
   std::shared_ptr<TestRepository> repo = std::static_pointer_cast<TestRepository>(test_repo);
 
   auto dir = testController.createTempDirectory();
-
   utils::Identifier processoruuid = processor->getUUID();
   REQUIRE(processoruuid);
 
@@ -226,13 +225,13 @@ TEST_CASE("Test GetFile Ignore", "[getfileCreate3]") {
 
   records = reporter->getEvents();
 
-  for (auto provEventRecord : records) {
+  for (const auto& provEventRecord : records) {
     REQUIRE(provEventRecord->getComponentType() == processor->getName());
   }
   session->commit();
   std::shared_ptr<core::FlowFile> ffr = session->get();
 
-  REQUIRE(repo->getRepoMap().size() == 0);
+  REQUIRE(repo->getRepoMap().empty());
   prev++;
 }
 
@@ -305,7 +304,7 @@ TEST_CASE("LogAttributeTest", "[getfileCreate3]") {
   auto records = plan->getProvenanceRecords();
   std::shared_ptr<core::FlowFile> record = plan->getCurrentFlowFile();
   REQUIRE(record == nullptr);
-  REQUIRE(records.size() == 0);
+  REQUIRE(records.empty());
 
   std::fstream file;
   std::stringstream ss;
@@ -371,7 +370,7 @@ void testMultiplesLogAttribute(int fileCount, int flowsToLog, std::string verify
   auto records = plan->getProvenanceRecords();
   std::shared_ptr<core::FlowFile> record = plan->getCurrentFlowFile();
   REQUIRE(record == nullptr);
-  REQUIRE(records.size() == 0);
+  REQUIRE(records.empty());
 
   std::vector<std::string> files;
 
@@ -433,7 +432,7 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
   auto records = plan->getProvenanceRecords();
   std::shared_ptr<core::FlowFile> record = plan->getCurrentFlowFile();
   REQUIRE(record == nullptr);
-  REQUIRE(records.size() == 0);
+  REQUIRE(records.empty());
 
   std::fstream file;
   std::stringstream ss;
@@ -446,7 +445,7 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
 
   records = plan->getProvenanceRecords();
   record = plan->getCurrentFlowFile();
-  for (auto provEventRecord : records) {
+  for (const auto& provEventRecord : records) {
     REQUIRE(provEventRecord->getComponentType() == processor->getName());
   }
   std::shared_ptr<core::FlowFile> ffr = plan->getCurrentFlowFile();
@@ -460,7 +459,7 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
     newRecord.DeSerialize(gsl::make_span(entry.second).as_span<const std::byte>());
 
     bool found = false;
-    for (auto provRec : records) {
+    for (const auto& provRec : records) {
       if (provRec->getEventId() == newRecord.getEventId()) {
         REQUIRE(provRec->getEventId() == newRecord.getEventId());
         REQUIRE(provRec->getComponentId() == newRecord.getComponentId());
@@ -498,37 +497,33 @@ TEST_CASE("Test Find file", "[getfileCreate3]") {
 
 class TestProcessorNoContent : public minifi::core::Processor {
  public:
-  explicit TestProcessorNoContent(const std::string& name, const utils::Identifier& uuid = {})
-      : Processor(name, uuid),
-        Success("success", "All files are routed to success") {
-  }
-  // Destructor
-  virtual ~TestProcessorNoContent() {
+  explicit TestProcessorNoContent(std::string name, const utils::Identifier& uuid = {})
+      : Processor(std::move(name), uuid) {
   }
 
-  core::Relationship Success;
+  static constexpr const char* Description = "test resource";
+  static auto properties() { return std::array<core::Property, 0>{}; }
+  static const core::Relationship Success;
+  static auto relationships() { return std::array{Success}; }
+  static constexpr bool SupportsDynamicProperties = false;
+  static constexpr bool SupportsDynamicRelationships = false;
+  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  static constexpr bool IsSingleThreaded = false;
 
-  /**
-   * Function that's executed when the processor is scheduled.
-   * @param context process context.
-   * @param sessionFactory process session factory that is used when creating
-   * ProcessSession objects.
-   */
-  void onSchedule(core::ProcessContext* /*context*/, core::ProcessSessionFactory* /*sessionFactory*/) {
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
+
+  void onSchedule(core::ProcessContext* /*context*/, core::ProcessSessionFactory* /*sessionFactory*/) override {
   }
-  /**
-   * Execution trigger for the GetFile Processor
-   * @param context processor context
-   * @param session processor session reference.
-   */
-  virtual void onTrigger(core::ProcessContext* /*context*/, core::ProcessSession *session) {
+  void onTrigger(core::ProcessContext* /*context*/, core::ProcessSession *session) override {
     auto ff = session->create();
     ff->addAttribute("Attribute", "AttributeValue");
     session->transfer(ff, Success);
   }
 };
 
-REGISTER_RESOURCE(TestProcessorNoContent, "test resource");
+const core::Relationship TestProcessorNoContent::Success("success", "All files are routed to success");
+
+REGISTER_RESOURCE(TestProcessorNoContent, Processor);
 
 TEST_CASE("TestEmptyContent", "[emptyContent]") {
   TestController testController;
@@ -827,3 +822,11 @@ TEST_CASE("isSingleThreaded - two threads for a single threaded processor", "[is
   REQUIRE(LogTestController::getInstance().contains("[warning] Processor myProc can not be run in parallel, its "
                                                     "\"max concurrent tasks\" value is too high. It was set to 1 from 2."));
 }
+
+TEST_CASE("Test getProcessorType", "[getProcessorType]") {
+  TestController testController;
+
+  std::shared_ptr<TestPlan> plan = testController.createPlan();
+  auto processor = plan->addProcessor("GenerateFlowFile", "myProc");
+  REQUIRE(processor->getProcessorType() == "GenerateFlowFile");
+}
