@@ -43,6 +43,8 @@
 #include "TailFile.h"
 #include "LogAttribute.h"
 #include "utils/TestUtils.h"
+#include "utils/StringUtils.h"
+#include "SingleProcessorTestController.h"
 
 using namespace std::literals::chrono_literals;
 
@@ -239,7 +241,8 @@ TEST_CASE("TailFile picks up the state correctly if it is rewritten between runs
   testController.runSession(plan, true);
   REQUIRE(LogTestController::getInstance().contains("key:filename value:minifi-tmpfile.0-13.txt"));
 
-  std::string filePath, fileName;
+  std::string filePath;
+  std::string fileName;
   REQUIRE(utils::file::getFileNameAndPath(temp_file.str(), filePath, fileName));
 
   // should stay the same
@@ -319,7 +322,8 @@ TEST_CASE("TailFile converts the old-style state file to the new-style state", "
     std::unordered_map<std::string, std::string> state;
     REQUIRE(plan->getProcessContextForProcessor(tailfile)->getStateManager()->get(state));
 
-    std::string filePath, fileName;
+    std::string filePath;
+    std::string fileName;
     REQUIRE(utils::file::getFileNameAndPath(temp_file, filePath, fileName));
     std::unordered_map<std::string, std::string> expected_state{{"file.0.name", fileName},
                                                                 {"file.0.position", "35"},
@@ -363,7 +367,10 @@ TEST_CASE("TailFile converts the old-style state file to the new-style state", "
     std::unordered_map<std::string, std::string> state;
     REQUIRE(plan->getProcessContextForProcessor(tailfile)->getStateManager()->get(state));
 
-    std::string filePath1, filePath2, fileName1, fileName2;
+    std::string filePath1;
+    std::string filePath2;
+    std::string fileName1;
+    std::string fileName2;
     REQUIRE(utils::file::getFileNameAndPath(temp_file_1, filePath1, fileName1));
     REQUIRE(utils::file::getFileNameAndPath(temp_file_2, filePath2, fileName2));
     std::unordered_map<std::string, std::string> expected_state{{"file.0.name", fileName1},
@@ -1110,7 +1117,7 @@ TEST_CASE("TailFile finds and finishes the renamed file and continues with the n
   // use persistent state storage that defaults to rocksDB, not volatile
   const auto configuration = std::make_shared<minifi::Configure>();
   {
-    auto test_plan = testController.createPlan(configuration, state_dir.c_str());
+    auto test_plan = testController.createPlan(configuration, state_dir);
     auto tail_file = test_plan->addProcessor("TailFile", tail_file_uuid, "Tail", {success_relationship});
     test_plan->setProperty(tail_file, minifi::processors::TailFile::FileName.getName(), test_file);
     auto log_attr = test_plan->addProcessor("LogAttribute", "Log", success_relationship, true);
@@ -1131,7 +1138,7 @@ TEST_CASE("TailFile finds and finishes the renamed file and continues with the n
   createTempFile(log_dir, "test.log", "line eight is the last line\n");
 
   {
-    auto test_plan = testController.createPlan(configuration, state_dir.c_str());
+    auto test_plan = testController.createPlan(configuration, state_dir);
     auto tail_file = test_plan->addProcessor("TailFile", tail_file_uuid, "Tail", {success_relationship});
     test_plan->setProperty(tail_file, minifi::processors::TailFile::FileName.getName(), test_file);
     auto log_attr = test_plan->addProcessor("LogAttribute", "Log", success_relationship, true);
@@ -1344,7 +1351,7 @@ TEST_CASE("TailFile handles the Delimiter setting correctly", "[delimiter]") {
     auto temp_directory = testController.createTempDirectory();
 
     std::string delimiter = test_case.second;
-    std::string full_file_name = createTempFile(temp_directory, "test.log", "one" + delimiter + "two" + delimiter);
+    std::string full_file_name = createTempFile(temp_directory, "test.log", utils::StringUtils::join_pack("one", delimiter, "two", delimiter));
 
     auto plan = testController.createPlan();
 
@@ -1772,7 +1779,14 @@ TEST_CASE("TailFile onSchedule throws if an invalid Attribute Provider Service i
 namespace {
 
 class TestAttributeProviderService : public minifi::controllers::AttributeProviderService {
+ public:
   using AttributeProviderService::AttributeProviderService;
+
+  static constexpr const char* Description = "An attribute provider service which provides a constant set of records.";
+  static auto properties() { return std::array<core::Property, 0>{}; }
+  static constexpr bool SupportsDynamicProperties = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
+
   void initialize() override {};
   void onEnable() override {};
   std::optional<std::vector<AttributeMap>> getAttributes() override {
@@ -1781,7 +1795,7 @@ class TestAttributeProviderService : public minifi::controllers::AttributeProvid
   }
   std::string_view name() const override { return "test"; }
 };
-REGISTER_RESOURCE(TestAttributeProviderService, "An attribute provider service which provides a constant set of records.");
+REGISTER_RESOURCE(TestAttributeProviderService, ControllerService);
 
 }  // namespace
 
@@ -1834,3 +1848,32 @@ TEST_CASE("TailFile can use an AttributeProviderService", "[AttributeProviderSer
 
   LogTestController::getInstance().reset();
 }
+
+TEST_CASE("TailFile honors batch size for maximum lines processed", "[batchSize]") {
+  LogTestController::getInstance().setTrace<minifi::processors::TailFile>();
+
+  auto tailfile = std::make_shared<minifi::processors::TailFile>("TailFile");
+  minifi::test::SingleProcessorTestController test_controller(tailfile);
+
+  auto dir = test_controller.createTempDirectory();
+  std::stringstream temp_file;
+  temp_file << dir << utils::file::get_separator() << TMP_FILE;
+
+  std::ofstream tmpfile;
+  tmpfile.open(temp_file.str(), std::ios::out | std::ios::binary);
+  for (auto i = 0; i < 20; ++i) {
+    tmpfile << NEW_TAIL_DATA;
+  }
+  tmpfile.close();
+
+  std::stringstream state_file;
+  state_file << dir << utils::file::get_separator() << STATE_FILE;
+
+  tailfile->setProperty(minifi::processors::TailFile::FileName.getName(), temp_file.str());
+  tailfile->setProperty(minifi::processors::TailFile::Delimiter.getName(), "\n");
+  tailfile->setProperty(minifi::processors::TailFile::BatchSize.getName(), "10");
+
+  const auto result = test_controller.trigger();
+  const auto& file_contents = result.at(minifi::processors::TailFile::Success);
+  REQUIRE(file_contents.size() == 10);
+}
