@@ -34,8 +34,8 @@ using namespace std::literals::chrono_literals;
 TEST_CASE("Test YAML Config Processing", "[YamlConfiguration]") {
   TestController test_controller;
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
@@ -225,8 +225,8 @@ Provenance Reporting:
 TEST_CASE("Test YAML v3 Invalid Type", "[YamlConfiguration3]") {
   TestController test_controller;
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
@@ -351,8 +351,8 @@ NiFi Properties Overrides: {}
 TEST_CASE("Test YAML v3 Config Processing", "[YamlConfiguration3]") {
   TestController test_controller;
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
@@ -505,8 +505,8 @@ TEST_CASE("Test Dynamic Unsupported", "[YamlConfigurationDynamicUnsupported]") {
   logTestController.setDebug<TestPlan>();
   logTestController.setTrace<core::YamlConfiguration>();
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
@@ -516,8 +516,8 @@ TEST_CASE("Test Dynamic Unsupported", "[YamlConfigurationDynamicUnsupported]") {
 Flow Controller:
   name: Simple
 Processors:
-- name: PutFile
-  class: PutFile
+- name: GenerateFlowFile
+  class: GenerateFlowFile
   Properties:
      Dynamic Property: Bad
       )";
@@ -525,10 +525,10 @@ Processors:
   std::unique_ptr<core::ProcessGroup> rootFlowConfig = yamlConfig.getYamlRoot(configYamlStream);
 
   REQUIRE(rootFlowConfig);
-  REQUIRE(rootFlowConfig->findProcessorByName("PutFile"));
-  const utils::Identifier uuid = rootFlowConfig->findProcessorByName("PutFile")->getUUID();
+  REQUIRE(rootFlowConfig->findProcessorByName("GenerateFlowFile"));
+  const utils::Identifier uuid = rootFlowConfig->findProcessorByName("GenerateFlowFile")->getUUID();
   REQUIRE(uuid);
-  REQUIRE(!rootFlowConfig->findProcessorByName("PutFile")->getUUIDStr().empty());
+  REQUIRE(!rootFlowConfig->findProcessorByName("GenerateFlowFile")->getUUIDStr().empty());
 
   REQUIRE(LogTestController::getInstance().contains("[warning] Unable to set the dynamic property "
                                                     "Dynamic Property with value Bad"));
@@ -541,8 +541,8 @@ TEST_CASE("Test Required Property", "[YamlConfigurationRequiredProperty]") {
   logTestController.setDebug<TestPlan>();
   logTestController.setDebug<core::YamlConfiguration>();
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
@@ -586,8 +586,8 @@ TEST_CASE("Test Required Property 2", "[YamlConfigurationRequiredProperty2]") {
   logTestController.setDebug<core::YamlConfiguration>();
   logTestController.setDebug<core::Processor>();
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
@@ -615,11 +615,15 @@ Processors:
 
 class DummyComponent : public core::ConfigurableComponent {
  public:
-  virtual bool supportsDynamicProperties() {
+  bool supportsDynamicProperties() const override {
     return false;
   }
 
-  virtual bool canEdit() {
+  bool supportsDynamicRelationships() const override {
+    return false;
+  }
+
+  bool canEdit() override {
     return true;
   }
 };
@@ -631,17 +635,17 @@ TEST_CASE("Test Dependent Property", "[YamlConfigurationDependentProperty]") {
   logTestController.setDebug<TestPlan>();
   logTestController.setDebug<core::YamlConfiguration>();
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
   core::YamlConfiguration yamlConfig(testProvRepo, testFlowFileRepo, content_repo, streamFactory, configuration);
   const auto component = std::make_shared<DummyComponent>();
-  std::set<core::Property> props;
-  props.emplace(core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }));
-  props.emplace(core::Property("Prop B", "Prop B desc", "val B", true, "", { "Prop A" }, { }));
-  component->setSupportedProperties(std::move(props));
+  component->setSupportedProperties(std::array{
+    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
+    core::Property("Prop B", "Prop B desc", "val B", true, "", { "Prop A" }, { })
+  });
   yamlConfig.validateComponentProperties(*component, "component A", "section A");
   REQUIRE(true);  // Expected to get here w/o any exceptions
 }
@@ -653,17 +657,17 @@ TEST_CASE("Test Dependent Property 2", "[YamlConfigurationDependentProperty2]")
   logTestController.setDebug<TestPlan>();
   logTestController.setDebug<core::YamlConfiguration>();
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
   core::YamlConfiguration yamlConfig(testProvRepo, testFlowFileRepo, content_repo, streamFactory, configuration);
   const auto component = std::make_shared<DummyComponent>();
-  std::set<core::Property> props;
-  props.emplace(core::Property("Prop A", "Prop A desc", "", false, "", { }, { }));
-  props.emplace(core::Property("Prop B", "Prop B desc", "val B", true, "", { "Prop A" }, { }));
-  component->setSupportedProperties(std::move(props));
+  component->setSupportedProperties(std::array{
+    core::Property("Prop A", "Prop A desc", "", false, "", { }, { }),
+    core::Property("Prop B", "Prop B desc", "val B", true, "", { "Prop A" }, { })
+  });
   bool config_failed = false;
   try {
     yamlConfig.validateComponentProperties(*component, "component A", "section A");
@@ -683,17 +687,17 @@ TEST_CASE("Test Exclusive Property", "[YamlConfigurationExclusiveProperty]") {
   LogTestController &logTestController = LogTestController::getInstance();
   logTestController.setDebug<TestPlan>();
   logTestController.setDebug<core::YamlConfiguration>();
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
   core::YamlConfiguration yamlConfig(testProvRepo, testFlowFileRepo, content_repo, streamFactory, configuration);
   const auto component = std::make_shared<DummyComponent>();
-  std::set<core::Property> props;
-  props.emplace(core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }));
-  props.emplace(core::Property("Prop B", "Prop B desc", "val B", true, "", { }, { { "Prop A", "^abcd.*$" } }));
-  component->setSupportedProperties(std::move(props));
+  component->setSupportedProperties(std::array{
+    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
+    core::Property("Prop B", "Prop B desc", "val B", true, "", { }, { { "Prop A", "^abcd.*$" } })
+  });
   yamlConfig.validateComponentProperties(*component, "component A", "section A");
   REQUIRE(true);  // Expected to get here w/o any exceptions
 }
@@ -703,17 +707,17 @@ TEST_CASE("Test Regex Property", "[YamlConfigurationRegexProperty]") {
   LogTestController &logTestController = LogTestController::getInstance();
   logTestController.setDebug<TestPlan>();
   logTestController.setDebug<core::YamlConfiguration>();
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
   core::YamlConfiguration yamlConfig(testProvRepo, testFlowFileRepo, content_repo, streamFactory, configuration);
   const auto component = std::make_shared<DummyComponent>();
-  std::set<core::Property> props;
-  props.emplace(core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }));
-  props.emplace(core::Property("Prop B", "Prop B desc", "val B", true, "^val.*$", { }, { }));
-  component->setSupportedProperties(std::move(props));
+  component->setSupportedProperties(std::array{
+    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
+    core::Property("Prop B", "Prop B desc", "val B", true, "^val.*$", { }, { })
+  });
   yamlConfig.validateComponentProperties(*component, "component A", "section A");
   REQUIRE(true);  // Expected to get here w/o any exceptions
 }
@@ -724,17 +728,17 @@ TEST_CASE("Test Exclusive Property 2", "[YamlConfigurationExclusiveProperty2]")
   LogTestController &logTestController = LogTestController::getInstance();
   logTestController.setDebug<TestPlan>();
   logTestController.setDebug<core::YamlConfiguration>();
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
   core::YamlConfiguration yamlConfig(testProvRepo, testFlowFileRepo, content_repo, streamFactory, configuration);
   const auto component = std::make_shared<DummyComponent>();
-  std::set<core::Property> props;
-  props.emplace(core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }));
-  props.emplace(core::Property("Prop B", "Prop B desc", "val B", true, "", { }, { { "Prop A", "^val.*$" } }));
-  component->setSupportedProperties(std::move(props));
+  component->setSupportedProperties(std::array{
+    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
+    core::Property("Prop B", "Prop B desc", "val B", true, "", { }, { { "Prop A", "^val.*$" } })
+  });
   bool config_failed = false;
   try {
     yamlConfig.validateComponentProperties(*component, "component A", "section A");
@@ -752,17 +756,17 @@ TEST_CASE("Test Regex Property 2", "[YamlConfigurationRegexProperty2]") {
   LogTestController &logTestController = LogTestController::getInstance();
   logTestController.setDebug<TestPlan>();
   logTestController.setDebug<core::YamlConfiguration>();
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
   core::YamlConfiguration yamlConfig(testProvRepo, testFlowFileRepo, content_repo, streamFactory, configuration);
   const auto component = std::make_shared<DummyComponent>();
-  std::set<core::Property> props;
-  props.emplace(core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }));
-  props.emplace(core::Property("Prop B", "Prop B desc", "val B", true, "^notval.*$", { }, { }));
-  component->setSupportedProperties(std::move(props));
+  component->setSupportedProperties(std::array{
+    core::Property("Prop A", "Prop A desc", "val A", true, "", { }, { }),
+    core::Property("Prop B", "Prop B desc", "val B", true, "^notval.*$", { }, { })
+  });
   bool config_failed = false;
   try {
     yamlConfig.validateComponentProperties(*component, "component A", "section A");
@@ -780,8 +784,8 @@ TEST_CASE("Test Regex Property 2", "[YamlConfigurationRegexProperty2]") {
 TEST_CASE("Test YAML Config With Funnel", "[YamlConfiguration]") {
   TestController test_controller;
 
-  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> testProvRepo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> testFlowFileRepo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> streamFactory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
@@ -871,8 +875,8 @@ Remote Process Groups: []
 
 TEST_CASE("Test UUID duplication checks", "[YamlConfiguration]") {
   TestController test_controller;
-  std::shared_ptr<core::Repository> test_prov_repo = core::createRepository("provenancerepository", true);
-  std::shared_ptr<core::Repository> test_flow_file_repo = core::createRepository("flowfilerepository", true);
+  std::shared_ptr<core::Repository> test_prov_repo = core::createRepository("provenancerepository");
+  std::shared_ptr<core::Repository> test_flow_file_repo = core::createRepository("flowfilerepository");
   std::shared_ptr<minifi::Configure> configuration = std::make_shared<minifi::Configure>();
   std::shared_ptr<minifi::io::StreamFactory> stream_factory = minifi::io::StreamFactory::getInstance(configuration);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::VolatileContentRepository>();
