@@ -26,13 +26,13 @@
 #include "utils/OptionalUtils.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 
-namespace org { namespace apache { namespace nifi { namespace minifi { namespace extensions { namespace systemd {
+namespace org::apache::nifi::minifi::extensions::systemd {
 
 namespace chr = std::chrono;
 
-constexpr const char* ConsumeJournald::CURSOR_KEY;
 const core::Relationship ConsumeJournald::Success("success", "Successfully consumed journal messages.");
 
 const core::Property ConsumeJournald::BatchSize = core::PropertyBuilder::createProperty("Batch Size")
@@ -73,13 +73,13 @@ const core::Property ConsumeJournald::TimestampFormat = core::PropertyBuilder::c
     ->isRequired(true)
     ->build();
 
-ConsumeJournald::ConsumeJournald(const std::string &name, const utils::Identifier &id, std::unique_ptr<libwrapper::LibWrapper>&& libwrapper)
-    :core::Processor{name, id}, libwrapper_{std::move(libwrapper)}
+ConsumeJournald::ConsumeJournald(std::string name, const utils::Identifier &id, std::unique_ptr<libwrapper::LibWrapper>&& libwrapper)
+    :core::Processor{std::move(name), id}, libwrapper_{std::move(libwrapper)}
 {}
 
 void ConsumeJournald::initialize() {
-  setSupportedProperties({BatchSize, PayloadFormat, IncludeTimestamp, JournalType, ProcessOldMessages, TimestampFormat});
-  setSupportedRelationships({Success});
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 
   worker_ = std::make_unique<utils::FifoExecutor>();
 }
@@ -267,12 +267,6 @@ std::string ConsumeJournald::getCursor() const {
   return std::string{cursor.get()};
 }
 
-REGISTER_RESOURCE(ConsumeJournald, "Consume systemd-journald journal messages. Creates one flow file per message."
-    "Fields are mapped to attributes. Realtime timestamp is mapped to the 'timestamp' attribute.");
+REGISTER_RESOURCE(ConsumeJournald, Processor);
 
-}  // namespace systemd
-}  // namespace extensions
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::extensions::systemd
