@@ -1,7 +1,4 @@
 /**
- * @file CollectorInitiatedSubscription.cpp
- CollectorInitiatedSubscription class implementation
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -19,6 +16,7 @@
  */
 
 #include "CollectorInitiatedSubscription.h"
+
 #include <vector>
 #include <queue>
 #include <map>
@@ -33,33 +31,133 @@
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 #include "core/ProcessSessionFactory.h"
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
-
 #include "utils/gsl.h"
+#include "utils/OptionalUtils.h"
 
 #pragma comment(lib, "wevtapi.lib")
 #pragma comment(lib, "Wecapi.lib")
 
 using namespace std::literals::chrono_literals;
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 #define LOG_SUBSCRIPTION_ERROR(error) logError(__LINE__, error)
 #define LOG_SUBSCRIPTION_WINDOWS_ERROR(info) logWindowsError(__LINE__, info)
 
-static std::string to_string(const wchar_t* pChar) {
+namespace {
+std::string to_string(const wchar_t *pChar) {
   return std::wstring_convert<std::codecvt_utf8<wchar_t>>().to_bytes(pChar);
 }
 
-const std::string ProcessorName("CollectorInitiatedSubscription");
+std::wstring to_wstring(const std::string& utf8_string) {
+  return std::wstring_convert<std::codecvt_utf8<wchar_t>>().from_bytes(utf8_string);
+}
+}  // namespace
 
-//! Supported Relationships
-static core::Relationship s_success("success", "Relationship for successfully consumed events.");
+const core::Property CollectorInitiatedSubscription::SubscriptionName =
+    core::PropertyBuilder::createProperty("Subscription Name")->
+        isRequired(true)->
+        withDescription("The name of the subscription. The value provided for this parameter should be unique within the computer's scope.")->
+        supportsExpressionLanguage(true)->
+        build();
 
+const core::Property CollectorInitiatedSubscription::SubscriptionDescription =
+    core::PropertyBuilder::createProperty("Subscription Description")->
+        isRequired(true)->
+        withDescription("A description of the subscription.")->
+        supportsExpressionLanguage(true)->
+        build();
+
+const core::Property CollectorInitiatedSubscription::SourceAddress =
+    core::PropertyBuilder::createProperty("Source Address")->
+        isRequired(true)->
+        withDescription("The IP address or fully qualified domain name (FQDN) of the local or remote computer (event source) from which the events are collected.")->
+        supportsExpressionLanguage(true)->
+        build();
+
+const core::Property CollectorInitiatedSubscription::SourceUserName =
+    core::PropertyBuilder::createProperty("Source User Name")->
+        isRequired(true)->
+        withDescription("The user name, which is used by the remote computer (event source) to authenticate the user.")->
+        supportsExpressionLanguage(true)->
+        build();
+
+const core::Property CollectorInitiatedSubscription::SourcePassword =
+    core::PropertyBuilder::createProperty("Source Password")->
+        isRequired(true)->
+        withDescription("The password, which is used by the remote computer (event source) to authenticate the user.")->
+        supportsExpressionLanguage(true)->
+        build();
+
+const core::Property CollectorInitiatedSubscription::SourceChannels =
+    core::PropertyBuilder::createProperty("Source Channels")->
+        isRequired(true)->
+        withDescription("The Windows Event Log Channels (on domain computer(s)) from which events are transferred.")->
+        supportsExpressionLanguage(true)->
+        build();
+
+const core::Property CollectorInitiatedSubscription::MaxDeliveryItems =
+    core::PropertyBuilder::createProperty("Max Delivery Items")->
+        isRequired(true)->
+        withDefaultValue<core::DataSizeValue>("1000")->
+        withDescription("Determines the maximum number of items that will forwarded from an event source for each request.")->
+        build();
+
+const core::Property CollectorInitiatedSubscription::DeliveryMaxLatencyTime =
+    core::PropertyBuilder::createProperty("Delivery MaxLatency Time")->
+        isRequired(true)->
+        withDefaultValue<core::TimePeriodValue>("10 min")->
+        withDescription("How long, in milliseconds, the event source should wait before sending events.")->
+        build();
+
+const core::Property CollectorInitiatedSubscription::HeartbeatInterval =
+    core::PropertyBuilder::createProperty("Heartbeat Interval")->
+        isRequired(true)->
+        withDefaultValue<core::TimePeriodValue>("10 min")->
+        withDescription(
+        "Time interval, in milliseconds, which is observed between the sent heartbeat messages."
+        " The event collector uses this property to determine the interval between queries to the event source.")->
+        build();
+
+const core::Property CollectorInitiatedSubscription::Channel =
+    core::PropertyBuilder::createProperty("Channel")->
+        isRequired(true)->
+        withDefaultValue("ForwardedEvents")->
+        withDescription("The Windows Event Log Channel (on local machine) to which events are transferred.")->
+        supportsExpressionLanguage(true)->
+        build();
+
+const core::Property CollectorInitiatedSubscription::Query =
+    core::PropertyBuilder::createProperty("Query")->
+        isRequired(true)->
+        withDefaultValue("*")->
+        withDescription("XPath Query to filter events. (See https://msdn.microsoft.com/en-us/library/windows/desktop/dd996910(v=vs.85).aspx for examples.)")->
+        supportsExpressionLanguage(true)->
+        build();
+
+const core::Property CollectorInitiatedSubscription::MaxBufferSize =
+    core::PropertyBuilder::createProperty("Max Buffer Size")->
+        isRequired(true)->
+        withDefaultValue<core::DataSizeValue>("1 MB")->
+        withDescription(
+        "The individual Event Log XMLs are rendered to a buffer."
+        " This specifies the maximum size in bytes that the buffer will be allowed to grow to. (Limiting the maximum size of an individual Event XML.)")->
+        build();
+
+const core::Property CollectorInitiatedSubscription::InactiveDurationToReconnect =
+    core::PropertyBuilder::createProperty("Inactive Duration To Reconnect")->
+        isRequired(true)->
+        withDefaultValue<core::TimePeriodValue>("10 min")->
+        withDescription(
+        "If no new event logs are processed for the specified time period,"
+        " this processor will try reconnecting to recover from a state where any further messages cannot be consumed."
+        " Such situation can happen if Windows Event Log service is restarted, or ERROR_EVT_QUERY_RESULT_STALE (15011) is returned."
+        " Setting no duration, e.g. '0 ms' disables auto-reconnection.")->
+        build();
+
+const core::Relationship CollectorInitiatedSubscription::Success("success", "Relationship for successfully consumed events.");
 
 CollectorInitiatedSubscription::CollectorInitiatedSubscription(const std::string& name, const utils::Identifier& uuid)
   : core::Processor(name, uuid), logger_(core::logging::LoggerFactory<CollectorInitiatedSubscription>::getLogger()) {
@@ -70,133 +168,16 @@ CollectorInitiatedSubscription::CollectorInitiatedSubscription(const std::string
   } else {
     LOG_SUBSCRIPTION_WINDOWS_ERROR("GetComputerName");
   }
-
-  supportedProperties_ = {
-    subscriptionName_ = {
-      core::PropertyBuilder::createProperty("Subscription Name")->
-      isRequired(true)->
-      withDescription("The name of the subscription. The value provided for this parameter should be unique within the computer's scope.")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    subscriptionDescription_ = {
-      core::PropertyBuilder::createProperty("Subscription Description")->
-      isRequired(true)->
-      withDescription("A description of the subscription.")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    sourceAddress_ = {
-      core::PropertyBuilder::createProperty("Source Address")->
-      isRequired(true)->
-      withDescription("The IP address or fully qualified domain name (FQDN) of the local or remote computer (event source) from which the events are collected.")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    sourceUserName_ = {
-      core::PropertyBuilder::createProperty("Source User Name")->
-      isRequired(true)->
-      withDescription("The user name, which is used by the remote computer (event source) to authenticate the user.")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    sourcePassword_ = {
-      core::PropertyBuilder::createProperty("Source Password")->
-      isRequired(true)->
-      withDescription("The password, which is used by the remote computer (event source) to authenticate the user.")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    sourceChannels_ = {
-      core::PropertyBuilder::createProperty("Source Channels")->
-      isRequired(true)->
-      withDescription("The Windows Event Log Channels (on domain computer(s)) from which events are transferred.")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    maxDeliveryItems_ = {
-      core::PropertyBuilder::createProperty("Max Delivery Items")->
-      isRequired(true)->
-      withDefaultValue<core::DataSizeValue>("1000")->
-      withDescription("Determines the maximum number of items that will forwarded from an event source for each request.")->
-      build()
-    },
-
-    deliveryMaxLatencyTime_ = {
-      core::PropertyBuilder::createProperty("Delivery MaxLatency Time")->
-      isRequired(true)->
-      withDefaultValue<core::TimePeriodValue>("10 min")->
-      withDescription("How long, in milliseconds, the event source should wait before sending events.")->
-      build()
-    },
-
-    heartbeatInterval_ = {
-      core::PropertyBuilder::createProperty("Heartbeat Interval")->
-      isRequired(true)->
-      withDefaultValue<core::TimePeriodValue>("10 min")->
-      withDescription(
-        "Time interval, in milliseconds, which is observed between the sent heartbeat messages."
-        " The event collector uses this property to determine the interval between queries to the event source.")->
-      build()
-    },
-
-    channel_ = {
-      core::PropertyBuilder::createProperty("Channel")->
-      isRequired(true)->
-      withDefaultValue("ForwardedEvents")->
-      withDescription("The Windows Event Log Channel (on local machine) to which events are transferred.")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    query_ = {
-      core::PropertyBuilder::createProperty("Query")->
-      isRequired(true)->
-      withDefaultValue("*")->
-      withDescription("XPath Query to filter events. (See https://msdn.microsoft.com/en-us/library/windows/desktop/dd996910(v=vs.85).aspx for examples.)")->
-      supportsExpressionLanguage(true)->
-      build()
-    },
-
-    maxBufferSize_ = {
-      core::PropertyBuilder::createProperty("Max Buffer Size")->
-      isRequired(true)->
-      withDefaultValue<core::DataSizeValue>("1 MB")->
-      withDescription(
-        "The individual Event Log XMLs are rendered to a buffer."
-        " This specifies the maximum size in bytes that the buffer will be allowed to grow to. (Limiting the maximum size of an individual Event XML.)")->
-      build()
-    },
-
-    inactiveDurationToReconnect_ = {
-      core::PropertyBuilder::createProperty("Inactive Duration To Reconnect")->
-      isRequired(true)->
-      withDefaultValue<core::TimePeriodValue>("10 min")->
-      withDescription(
-        "If no new event logs are processed for the specified time period,"
-        " this processor will try reconnecting to recover from a state where any further messages cannot be consumed."
-        " Such situation can happen if Windows Event Log service is restarted, or ERROR_EVT_QUERY_RESULT_STALE (15011) is returned."
-        " Setting no duration, e.g. '0 ms' disables auto-reconnection.")->
-      build()
-    }
-  };
 }
 
 void CollectorInitiatedSubscription::initialize() {
-  //! Set the supported properties
-  setSupportedProperties(supportedProperties_.getProperties());
-
-  //! Set the supported relationships
-  setSupportedRelationships({s_success});
+  setSupportedProperties(properties());
+  setSupportedRelationships(relationships());
 }
 
 void CollectorInitiatedSubscription::onSchedule(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSessionFactory> &sessionFactory) {
+  gsl_Expects(context);
+
   if (subscriptionHandle_) {
     logger_->log_error("Processor already subscribed to Event Log, expected cleanup to unsubscribe.");
   } else {
@@ -209,9 +190,14 @@ void CollectorInitiatedSubscription::onSchedule(const std::shared_ptr<core::Proc
 
     subscribe(context);
   }
+
+  subscription_name_ = to_wstring(context->getProperty(SubscriptionName).value());
+  max_buffer_size_ = context->getProperty<core::DataSizeValue>(MaxBufferSize).value();
 }
 
 void CollectorInitiatedSubscription::onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) {
+  gsl_Expects(context);
+
   if (!subscriptionHandle_) {
     if (!subscribe(context)) {
       context->yield();
@@ -219,7 +205,6 @@ void CollectorInitiatedSubscription::onTrigger(const std::shared_ptr<core::Proce
     }
   }
 
-  // Check subscription runtime status.
   checkSubscriptionRuntimeStatus();
 
   const auto flowFileCount = processQueue(session);
@@ -228,9 +213,11 @@ void CollectorInitiatedSubscription::onTrigger(const std::shared_ptr<core::Proce
 
   if (flowFileCount > 0) {
     lastActivityTimestamp_ = now;
-  } else if (inactiveDurationToReconnect_.value() > 0) {
-    if ((now - lastActivityTimestamp_) > inactiveDurationToReconnect_.value()) {
-      logger_->log_info("Exceeds configured 'inactive duration to reconnect' %lld ms. Unsubscribe to reconnect..", inactiveDurationToReconnect_.value());
+  } else if (auto inactive_duration_to_reconnect_ms = context->getProperty<core::TimePeriodValue>(InactiveDurationToReconnect)
+             | utils::map([](const auto& time_period_value) { return time_period_value.getMilliseconds().count(); });
+             inactive_duration_to_reconnect_ms && *inactive_duration_to_reconnect_ms > 0) {
+    if ((now - lastActivityTimestamp_) > *inactive_duration_to_reconnect_ms) {
+      logger_->log_info("Exceeds configured 'inactive duration to reconnect' %lld ms. Unsubscribe to reconnect..", *inactive_duration_to_reconnect_ms);
       unsubscribe();
     }
   }
@@ -241,7 +228,7 @@ void CollectorInitiatedSubscription::logInvalidSubscriptionPropertyType(int line
 }
 
 bool CollectorInitiatedSubscription::checkSubscriptionRuntimeStatus() {
-  EC_HANDLE hSubscription = EcOpenSubscription(subscriptionName_.value().c_str(), EC_READ_ACCESS, EC_OPEN_EXISTING);
+  EC_HANDLE hSubscription = EcOpenSubscription(subscription_name_.c_str(), EC_READ_ACCESS, EC_OPEN_EXISTING);
   if (!hSubscription) {
     LOG_SUBSCRIPTION_WINDOWS_ERROR("EcOpenSubscription");
     return false;
@@ -302,7 +289,7 @@ bool CollectorInitiatedSubscription::checkSubscriptionRuntimeStatus() {
     buffer.resize(sizeof(EC_VARIANT));
     DWORD dwBufferSize{};
     if (!EcGetSubscriptionRunTimeStatus(
-          subscriptionName_.value().c_str(),
+        subscription_name_.c_str(),
           statusInfoID,
           eventSource.c_str(),
           flags,
@@ -311,7 +298,7 @@ bool CollectorInitiatedSubscription::checkSubscriptionRuntimeStatus() {
           &dwBufferSize)) {
       if (ERROR_INSUFFICIENT_BUFFER == GetLastError()) {
         buffer.resize(dwBufferSize);
-        if (!EcGetSubscriptionRunTimeStatus(subscriptionName_.value().c_str(),
+        if (!EcGetSubscriptionRunTimeStatus(subscription_name_.c_str(),
               statusInfoID,
               eventSource.c_str(),
               flags,
@@ -391,7 +378,7 @@ bool CollectorInitiatedSubscription::checkSubscriptionRuntimeStatus() {
     const auto lastError = vProperty->UInt32Val;
 
     if (lastError == 0 && (runtimeStatus == EcRuntimeStatusActiveStatusActive || runtimeStatus == EcRuntimeStatusActiveStatusTrying)) {
-      logger_->log_info("Subscription '%ws': status '%ws', no error.", subscriptionName_.value().c_str(), strRuntimeStatus.c_str());
+      logger_->log_info("Subscription '%ws': status '%ws', no error.", subscription_name_.c_str(), strRuntimeStatus.c_str());
       return true;
     }
 
@@ -441,20 +428,20 @@ bool CollectorInitiatedSubscription::getSubscriptionProperty(EC_HANDLE hSubscrip
 }
 
 bool CollectorInitiatedSubscription::createSubscription(const std::shared_ptr<core::ProcessContext>& context) {
-  supportedProperties_.init(context);
+  gsl_Expects(context);
 
   // If subcription already exists, delete it.
-  EC_HANDLE hSubscription = EcOpenSubscription(subscriptionName_.value().c_str(), EC_READ_ACCESS, EC_OPEN_EXISTING);
+  EC_HANDLE hSubscription = EcOpenSubscription(subscription_name_.c_str(), EC_READ_ACCESS, EC_OPEN_EXISTING);
   if (hSubscription) {
     EcClose(hSubscription);
-    if (!EcDeleteSubscription(subscriptionName_.value().c_str(), 0)) {
+    if (!EcDeleteSubscription(subscription_name_.c_str(), 0)) {
       LOG_SUBSCRIPTION_WINDOWS_ERROR("EcDeleteSubscription");
       return false;
     }
   }
 
   // Create subscription.
-  hSubscription = EcOpenSubscription(subscriptionName_.value().c_str(), EC_READ_ACCESS | EC_WRITE_ACCESS, EC_CREATE_NEW);
+  hSubscription = EcOpenSubscription(subscription_name_.c_str(), EC_READ_ACCESS | EC_WRITE_ACCESS, EC_CREATE_NEW);
   if (!hSubscription) {
     LOG_SUBSCRIPTION_WINDOWS_ERROR("EcOpenSubscription");
     return false;
@@ -487,21 +474,30 @@ bool CollectorInitiatedSubscription::createSubscription(const std::shared_ptr<co
     EC_VARIANT prop_;
   };
 
+  const auto subscription_description = to_wstring(context->getProperty(SubscriptionDescription).value());
+  const auto source_channels = to_wstring(context->getProperty(SourceChannels).value());
+  const auto channel = to_wstring(context->getProperty(Channel).value());
+  const auto max_delivery_items = context->getProperty<core::DataSizeValue>(MaxDeliveryItems).value().getValue();
+  const auto delivery_max_latency_time = context->getProperty<core::TimePeriodValue>(DeliveryMaxLatencyTime).value().getMilliseconds().count();
+  const auto heartbeat_interval = context->getProperty<core::TimePeriodValue>(HeartbeatInterval).value().getMilliseconds().count();
+  const auto source_user_name = to_wstring(context->getProperty(SourceUserName).value());
+  const auto source_password = to_wstring(context->getProperty(SourcePassword).value());
+
   std::vector<SubscriptionProperty> listProperty = {
-    {EcSubscriptionDescription, subscriptionDescription_.value()},
+    {EcSubscriptionDescription, subscription_description},
     {EcSubscriptionURI, std::wstring(L"http://schemas.microsoft.com/wbem/wsman/1/windows/EventLog")},
-    {EcSubscriptionQuery, L"<QueryList><Query Path=\"" + sourceChannels_.value() + L"\"><Select>*</Select></Query></QueryList>"},
-    {EcSubscriptionLogFile, channel_.value()},
+    {EcSubscriptionQuery, L"<QueryList><Query Path=\"" + source_channels + L"\"><Select>*</Select></Query></QueryList>"},
+    {EcSubscriptionLogFile, channel},
     {EcSubscriptionConfigurationMode, static_cast<uint32_t>(EcConfigurationModeCustom)},
     {EcSubscriptionDeliveryMode, static_cast<uint32_t>(EcDeliveryModePull)},
-    {EcSubscriptionDeliveryMaxItems, static_cast<uint32_t>(maxDeliveryItems_.value())},
-    {EcSubscriptionDeliveryMaxLatencyTime, static_cast<uint32_t>(deliveryMaxLatencyTime_.value())},
-    {EcSubscriptionHeartbeatInterval, static_cast<uint32_t>(heartbeatInterval_.value())},
+    {EcSubscriptionDeliveryMaxItems, static_cast<uint32_t>(max_delivery_items)},
+    {EcSubscriptionDeliveryMaxLatencyTime, static_cast<uint32_t>(delivery_max_latency_time)},
+    {EcSubscriptionHeartbeatInterval, static_cast<uint32_t>(heartbeat_interval)},
     {EcSubscriptionContentFormat, static_cast<uint32_t>(EcContentFormatRenderedText)},
     {EcSubscriptionCredentialsType, static_cast<uint32_t>(EcSubscriptionCredDefault)},
     {EcSubscriptionEnabled, true},
-    {EcSubscriptionCommonUserName, sourceUserName_.value()},
-    {EcSubscriptionCommonPassword, sourcePassword_.value()}
+    {EcSubscriptionCommonUserName, source_user_name},
+    {EcSubscriptionCommonPassword, source_password}
   };
   for (auto& prop : listProperty) {
     if (!EcSetSubscriptionProperty(hSubscription, prop.propId_, 0, &prop.prop_)) {
@@ -542,7 +538,8 @@ bool CollectorInitiatedSubscription::createSubscription(const std::shared_ptr<co
     return false;
   }
 
-  for (auto& prop : std::vector<SubscriptionProperty>{{EcSubscriptionEventSourceAddress, sourceAddress_.value()}, {EcSubscriptionEventSourceEnabled, true}}) {
+  const auto source_address = to_wstring(context->getProperty(SourceAddress).value());
+  for (auto& prop : std::vector<SubscriptionProperty>{{EcSubscriptionEventSourceAddress, source_address}, {EcSubscriptionEventSourceEnabled, true}}) {
     if (!EcSetObjectArrayProperty(hArray, prop.propId_, dwEventSourceCount, 0, &prop.prop_)) {
       LOG_SUBSCRIPTION_WINDOWS_ERROR("EcSetObjectArrayProperty id: " + std::to_string(prop.propId_));
       return false;
@@ -558,55 +555,64 @@ bool CollectorInitiatedSubscription::createSubscription(const std::shared_ptr<co
 }
 
 bool CollectorInitiatedSubscription::subscribe(const std::shared_ptr<core::ProcessContext> &context) {
-  logger_->log_debug("CollectorInitiatedSubscription: maxBufferSize_ %lld", maxBufferSize_.value());
+  gsl_Expects(context);
 
-  provenanceUri_ = "winlog://" + computerName_ + "/" + to_string(channel_.value().c_str()) + "?" + to_string(query_.value().c_str());
+  logger_->log_debug("CollectorInitiatedSubscription: MaxBufferSize %lld", max_buffer_size_.getValue());
+
+  const auto channel = context->getProperty(Channel).value();
+  const auto query = context->getProperty(Query).value();
+  provenanceUri_ = "winlog://" + computerName_ + "/" + channel + "?" + query;
+
+  const auto channel_ws = to_wstring(context->getProperty(Channel).value());
+  const auto query_ws = to_wstring(context->getProperty(Query).value());
+
+  const EVT_SUBSCRIBE_CALLBACK callback = [](EVT_SUBSCRIBE_NOTIFY_ACTION action, PVOID pContext, EVT_HANDLE hEvent) {
+    auto pCollectorInitiatedSubscription = static_cast<CollectorInitiatedSubscription*>(pContext);
+
+    auto& logger = pCollectorInitiatedSubscription->logger_;
+
+    if (action == EvtSubscribeActionError) {
+      if (ERROR_EVT_QUERY_RESULT_STALE == reinterpret_cast<intptr_t>(hEvent)) {
+        logger->log_error("Received missing event notification. Consider triggering processor more frequently or increasing queue size.");
+      } else {
+        logger->log_error("Received the following Win32 error: %x", hEvent);
+      }
+    } else if (action == EvtSubscribeActionDeliver) {
+      DWORD size = 0;
+      DWORD used = 0;
+      DWORD propertyCount = 0;
+
+      if (!EvtRender(NULL, hEvent, EvtRenderEventXml, size, 0, &used, &propertyCount)) {
+        if (ERROR_INSUFFICIENT_BUFFER == GetLastError()) {
+          if (used > pCollectorInitiatedSubscription->max_buffer_size_.getValue()) {
+            logger->log_error("Dropping event %p because it couldn't be rendered within %llu bytes.", hEvent, pCollectorInitiatedSubscription->max_buffer_size_.getValue());
+            return 0UL;
+          }
+
+          size = used;
+          std::vector<wchar_t> buf(size/2);
+          if (EvtRender(NULL, hEvent, EvtRenderEventXml, size, &buf[0], &used, &propertyCount)) {
+            auto xml = to_string(&buf[0]);
+
+            pCollectorInitiatedSubscription->renderedXMLs_.enqueue(std::move(xml));
+          } else {
+            logger->log_error("EvtRender returned the following error code: %d.", GetLastError());
+          }
+        }
+      }
+    }
+
+    return 0UL;
+  };
 
   subscriptionHandle_ = EvtSubscribe(
       NULL,
       NULL,
-      channel_.value().c_str(),
-      query_.value().c_str(),
+      channel_ws.c_str(),
+      query_ws.c_str(),
       NULL,
       this,
-      [](EVT_SUBSCRIBE_NOTIFY_ACTION action, PVOID pContext, EVT_HANDLE hEvent) {
-        auto pCollectorInitiatedSubscription = static_cast<CollectorInitiatedSubscription*>(pContext);
-
-        auto& logger = pCollectorInitiatedSubscription->logger_;
-
-        if (action == EvtSubscribeActionError) {
-          if (ERROR_EVT_QUERY_RESULT_STALE == reinterpret_cast<intptr_t>(hEvent)) {
-            logger->log_error("Received missing event notification. Consider triggering processor more frequently or increasing queue size.");
-          } else {
-            logger->log_error("Received the following Win32 error: %x", hEvent);
-          }
-        } else if (action == EvtSubscribeActionDeliver) {
-          DWORD size = 0;
-          DWORD used = 0;
-          DWORD propertyCount = 0;
-
-          if (!EvtRender(NULL, hEvent, EvtRenderEventXml, size, 0, &used, &propertyCount)) {
-            if (ERROR_INSUFFICIENT_BUFFER == GetLastError()) {
-              if (used > pCollectorInitiatedSubscription->maxBufferSize_.value()) {
-                logger->log_error("Dropping event %p because it couldn't be rendered within %llu bytes.", hEvent, pCollectorInitiatedSubscription->maxBufferSize_.value());
-                return 0UL;
-              }
-
-              size = used;
-              std::vector<wchar_t> buf(size/2);
-              if (EvtRender(NULL, hEvent, EvtRenderEventXml, size, &buf[0], &used, &propertyCount)) {
-                auto xml = to_string(&buf[0]);
-
-                pCollectorInitiatedSubscription->renderedXMLs_.enqueue(std::move(xml));
-              } else {
-                logger->log_error("EvtRender returned the following error code: %d.", GetLastError());
-              }
-            }
-          }
-        }
-
-        return 0UL;
-      },
+      callback,
       EvtSubscribeToFutureEvents | EvtSubscribeStrict);
 
   if (!subscriptionHandle_) {
@@ -636,7 +642,7 @@ int CollectorInitiatedSubscription::processQueue(const std::shared_ptr<core::Pro
     session->writeBuffer(flowFile, xml);
     session->putAttribute(flowFile, core::SpecialFlowAttribute::MIME_TYPE, "application/xml");
     session->getProvenanceReporter()->receive(flowFile, provenanceUri_, getUUIDStr(), "Consume windows event logs", 0ms);
-    session->transfer(flowFile, s_success);
+    session->transfer(flowFile, Success);
 
     flowFileCount++;
   }
@@ -645,7 +651,7 @@ int CollectorInitiatedSubscription::processQueue(const std::shared_ptr<core::Pro
 }
 
 void CollectorInitiatedSubscription::notifyStop() {
-  if (!EcDeleteSubscription(subscriptionName_.value().c_str(), 0)) {
+  if (!EcDeleteSubscription(subscription_name_.c_str(), 0)) {
     LOG_SUBSCRIPTION_WINDOWS_ERROR("EcDeleteSubscription");
   }
 
@@ -689,10 +695,6 @@ void CollectorInitiatedSubscription::logWindowsError(int line, const std::string
   LocalFree(lpMsg);
 }
 
-REGISTER_RESOURCE(CollectorInitiatedSubscription, "Windows Event Log Subscribe Callback to receive FlowFiles from Events on Windows.");
+REGISTER_RESOURCE(CollectorInitiatedSubscription, Processor);
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
