@@ -17,8 +17,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_FLOWCONTROLLER_H_
-#define LIBMINIFI_INCLUDE_FLOWCONTROLLER_H_
+#pragma once
 
 #include <algorithm>
 #include <atomic>
@@ -57,6 +56,8 @@
 #include "TimerDrivenSchedulingAgent.h"
 #include "utils/Id.h"
 #include "utils/file/FileSystem.h"
+#include "core/state/nodes/ResponseNodeLoader.h"
+#include "core/state/MetricsPublisher.h"
 
 namespace org::apache::nifi::minifi {
 
@@ -109,12 +110,12 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
   int16_t resume() override;
   // Unload the current flow YAML, clean the root process group and all its children
   int16_t stop() override;
-  int16_t applyUpdate(const std::string &source, const std::string &configuration, bool persist) override;
+  int16_t applyUpdate(const std::string &source, const std::string &configuration, bool persist, const std::optional<std::string>& flow_id) override;
   int16_t drainRepositories() override {
     return -1;
   }
 
-  void executeOnComponent(const std::string &name, std::function<void(state::StateController&)> func) override;
+  void executeOnComponent(const std::string& id_or_name, std::function<void(state::StateController&)> func) override;
   void executeOnAllComponents(std::function<void(state::StateController&)> func) override;
 
   int16_t clearConnection(const std::string &connection) override;
@@ -144,7 +145,7 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
   // first it will validate the payload with the current root node config for flowController
   // like FlowController id/name is the same and new version is greater than the current version
   // after that, it will apply the configuration
-  bool applyConfiguration(const std::string &source, const std::string &configurePayload);
+  bool applyConfiguration(const std::string &source, const std::string &configurePayload, const std::optional<std::string>& flow_id = std::nullopt);
 
   // get name
   std::string getName() const override {
@@ -181,7 +182,7 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
    * Retrieves the agent manifest to be sent as a response to C2 DESCRIBE manifest
    * @return the agent manifest response node
    */
-  std::shared_ptr<state::response::ResponseNode> getAgentManifest() override;
+  state::response::NodeReporter::ReportedNode getAgentManifest() override;
 
   uint64_t getUptime() override;
 
@@ -197,6 +198,8 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
    */
   std::unique_ptr<core::ProcessGroup> loadInitialFlow();
 
+  void loadMetricsPublisher();
+
  protected:
   // function to load the flow file repo.
   void loadFlowRepo();
@@ -235,15 +238,15 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
  private:
   std::vector<state::StateController*> getAllComponents();
 
-  state::StateController* getComponent(const std::string &name);
+  state::StateController* getComponent(const std::string& id_or_name);
 
-  state::StateController* getProcessorController(const std::string& name,
-                                                 const std::function<std::unique_ptr<state::ProcessorController>(core::Processor&)>& controllerFactory);
+  state::StateController* getProcessorController(const std::string& id_or_name,
+      const std::function<gsl::not_null<std::unique_ptr<state::ProcessorController>>(core::Processor&)>& controllerFactory);
 
   std::vector<state::StateController*> getAllProcessorControllers(
-          const std::function<std::unique_ptr<state::ProcessorController>(core::Processor&)>& controllerFactory);
+          const std::function<gsl::not_null<std::unique_ptr<state::ProcessorController>>(core::Processor&)>& controllerFactory);
 
-  std::unique_ptr<state::ProcessorController> createController(core::Processor& processor);
+  gsl::not_null<std::unique_ptr<state::ProcessorController>> createController(core::Processor& processor);
 
   std::chrono::milliseconds shutdown_check_interval_{1000};
   std::shared_ptr<core::logging::Logger> logger_ = core::logging::LoggerFactory<FlowController>::getLogger();
@@ -252,8 +255,7 @@ class FlowController : public core::controller::ForwardingControllerServiceProvi
   // Thread pool for schedulers
   utils::ThreadPool<utils::TaskRescheduleInfo> thread_pool_;
   std::map<utils::Identifier, std::unique_ptr<state::ProcessorController>> processor_to_controller_;
+  std::unique_ptr<state::MetricsPublisher> metrics_publisher_;
 };
 
 }  // namespace org::apache::nifi::minifi
-
-#endif  // LIBMINIFI_INCLUDE_FLOWCONTROLLER_H_
