@@ -68,7 +68,7 @@ class C2Agent : public state::UpdateController {
   C2Agent(core::controller::ControllerServiceProvider *controller,
           state::Pausable *pause_handler,
           state::StateMonitor* updateSink,
-          std::shared_ptr<Configure> configure,
+          std::shared_ptr<Configure> configuration,
           std::shared_ptr<utils::file::FileSystem> filesystem,
           std::function<void()> request_restart);
 
@@ -86,11 +86,6 @@ class C2Agent : public state::UpdateController {
    */
   void performHeartBeat();
 
-  std::chrono::milliseconds getHeartBeatDelay() {
-    std::lock_guard<std::mutex> lock(heartbeat_mutex);
-    return heart_beat_period_;
-  }
-
   std::optional<std::string> fetchFlow(const std::string& uri) const;
 
  protected:
@@ -108,7 +103,7 @@ class C2Agent : public state::UpdateController {
    * @param name name of this metric
    * @param metrics metrics to include.
    */
-  void serializeMetrics(C2Payload &parent_payload, const std::string &name, const std::vector<state::response::SerializedResponseNode> &metrics, bool is_container = false, bool is_collapsible = true);
+  void serializeMetrics(C2Payload &metric_payload, const std::string &name, const std::vector<state::response::SerializedResponseNode> &metrics, bool is_container = false, bool is_collapsible = true);
 
   /**
    * Extract the payload
@@ -173,10 +168,11 @@ class C2Agent : public state::UpdateController {
 
   bool handleConfigurationUpdate(const C2ContentResponse &resp);
   void handlePropertyUpdate(const C2ContentResponse &resp);
+  void handleAssetUpdate(const C2ContentResponse &resp);
 
   std::optional<std::string> resolveFlowUrl(const std::string& url) const;
-
   std::optional<std::string> resolveUrl(const std::string& url) const;
+  static std::optional<std::string> getFlowIdFromConfigUpdate(const C2ContentResponse &resp);
 
  protected:
   std::timed_mutex metrics_mutex_;
