@@ -20,26 +20,24 @@
 
 #include <memory>
 #include <string>
+#include <utility>
 
 #include "C2Protocol.h"
 #include "C2Payload.h"
 #include "core/controller/ControllerServiceProvider.h"
 #include "properties/Configure.h"
 #include "core/Connectable.h"
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace c2 {
+
+namespace org::apache::nifi::minifi::c2 {
 
 /**
- * Defines a heart beat reporting interface. Note that this differs from
+ * Defines a heartbeat reporting interface. Note that this differs from
  * C2Protocol as heartbeats can be any interface which provides only one way communication.
  */
 class HeartbeatReporter : public core::Connectable {
  public:
-  HeartbeatReporter(const std::string& name, const utils::Identifier& uuid)
-      : core::Connectable(name, uuid),
+  HeartbeatReporter(std::string name, const utils::Identifier& uuid)
+      : core::Connectable(std::move(name), uuid),
         controller_(nullptr),
         update_sink_(nullptr),
         configuration_(nullptr) {
@@ -51,9 +49,11 @@ class HeartbeatReporter : public core::Connectable {
     update_sink_ = updateSink;
     configuration_ = configure;
   }
-  virtual ~HeartbeatReporter() = default;
+
+  ~HeartbeatReporter() override = default;
+
   /**
-   * Send a C2 payloadd to the provided URI. The direction indicates to the protocol whether or not this a transmit or receive operation.
+   * Send a C2 payload to the provided URI. The direction indicates to the protocol whether or not this a transmit or receive operation.
    * Depending on the protocol this may mean different things.
    *
    * @param url url.
@@ -67,39 +67,27 @@ class HeartbeatReporter : public core::Connectable {
   /**
    * Determines if we are connected and operating
    */
-  virtual bool isRunning() {
+  bool isRunning() override {
     return true;
   }
 
-  /**
-   * Block until work is available on any input connection, or the given duration elapses
-   * @param timeoutMs timeout in milliseconds
-   */
-  void waitForWork(uint64_t timeoutMs);
-
-  virtual void yield() {
+  void yield() override {
   }
 
   /**
    * Determines if work is available by this connectable
    * @return boolean if work is available.
    */
-  virtual bool isWorkAvailable() {
+  bool isWorkAvailable() override {
     return true;
   }
 
  protected:
   core::controller::ControllerServiceProvider* controller_;
-
   state::StateMonitor* update_sink_;
-
   std::shared_ptr<Configure> configuration_;
 };
 
-}  // namespace c2
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::c2
 
 #endif  // LIBMINIFI_INCLUDE_C2_HEARTBEATREPORTER_H_
