@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -15,8 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_CONTROLLERS_SSLCONTEXTSERVICE_H_
-#define LIBMINIFI_INCLUDE_CONTROLLERS_SSLCONTEXTSERVICE_H_
+#pragma once
 
 #ifndef WIN32_LEAN_AND_MEAN
 #define WIN32_LEAN_AND_MEAN 1
@@ -33,21 +31,21 @@
 #include <openssl/bio.h>
 #include <openssl/pkcs12.h>
 #endif
+
 #include <iostream>
 #include <memory>
 #include <string>
+#include <utility>
+
 #include "utils/StringUtils.h"
 #include "utils/tls/ExtendedKeyUsage.h"
 #include "io/validation.h"
 #include "../core/controller/ControllerService.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "utils/Export.h"
+#include "utils/tls/CertificateUtils.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace controllers {
+namespace org::apache::nifi::minifi::controllers {
 
 class SSLContext {
  public:
@@ -81,15 +79,15 @@ class SSLContext {
  */
 class SSLContextService : public core::controller::ControllerService {
  public:
-  explicit SSLContextService(const std::string &name, const utils::Identifier &uuid = {})
-      : ControllerService(name, uuid),
+  explicit SSLContextService(std::string name, const utils::Identifier &uuid = {})
+      : ControllerService(std::move(name), uuid),
         initialized_(false),
         valid_(false),
         logger_(core::logging::LoggerFactory<SSLContextService>::getLogger()) {
   }
 
-  explicit SSLContextService(const std::string &name, const std::shared_ptr<Configure> &configuration)
-      : ControllerService(name),
+  explicit SSLContextService(std::string name, const std::shared_ptr<Configure> &configuration)
+      : ControllerService(std::move(name)),
         initialized_(false),
         valid_(false),
         logger_(core::logging::LoggerFactory<SSLContextService>::getLogger()) {
@@ -141,7 +139,7 @@ class SSLContextService : public core::controller::ControllerService {
 #endif  // WIN32
   }
 
-  virtual void initialize();
+  void initialize() override;
 
   std::unique_ptr<SSLContext> createSSLContext();
 
@@ -155,14 +153,14 @@ class SSLContextService : public core::controller::ControllerService {
 
   const std::string &getCACertificate();
 
-  void yield() {
+  void yield() override {
   }
 
-  bool isRunning() {
+  bool isRunning() override {
     return getState() == core::controller::ControllerServiceState::ENABLED;
   }
 
-  bool isWorkAvailable() {
+  bool isWorkAvailable() override {
     return false;
   }
 
@@ -170,13 +168,10 @@ class SSLContextService : public core::controller::ControllerService {
   bool configure_ssl_context(SSL_CTX *ctx);
 #endif
 
-  virtual void onEnable();
+  void onEnable() override;
+
+  MINIFIAPI static constexpr const char* Description = "Controller service that provides SSL/TLS capabilities to consuming interfaces";
 
-  MINIFIAPI static const core::Property ClientCertificate;
-  MINIFIAPI static const core::Property PrivateKey;
-  MINIFIAPI static const core::Property Passphrase;
-  MINIFIAPI static const core::Property CACertificate;
-  MINIFIAPI static const core::Property UseSystemCertStore;
 #ifdef WIN32
   MINIFIAPI static const core::Property CertStoreLocation;
   MINIFIAPI static const core::Property ServerCertStore;
@@ -184,6 +179,30 @@ class SSLContextService : public core::controller::ControllerService {
   MINIFIAPI static const core::Property ClientCertCN;
   MINIFIAPI static const core::Property ClientCertKeyUsage;
 #endif  // WIN32
+  MINIFIAPI static const core::Property ClientCertificate;
+  MINIFIAPI static const core::Property PrivateKey;
+  MINIFIAPI static const core::Property Passphrase;
+  MINIFIAPI static const core::Property CACertificate;
+  MINIFIAPI static const core::Property UseSystemCertStore;
+  static auto properties() {
+    return std::array{
+#ifdef WIN32
+      CertStoreLocation,
+      ServerCertStore,
+      ClientCertStore,
+      ClientCertCN,
+      ClientCertKeyUsage,
+#endif  // WIN32
+      ClientCertificate,
+      PrivateKey,
+      Passphrase,
+      CACertificate,
+      UseSystemCertStore
+    };
+  }
+
+  MINIFIAPI static constexpr bool SupportsDynamicProperties = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
 
  protected:
   virtual void initializeProperties();
@@ -228,18 +247,21 @@ class SSLContextService : public core::controller::ControllerService {
   bool addClientCertificateFromSystemStoreToSSLContext(SSL_CTX* ctx) const;
   bool addServerCertificatesFromSystemStoreToSSLContext(SSL_CTX* ctx) const;
 #ifdef WIN32
-  bool useClientCertificate(SSL_CTX* ctx, PCCERT_CONTEXT certificate) const;
-  void addServerCertificateToSSLStore(X509_STORE* ssl_store, PCCERT_CONTEXT certificate) const;
+  using ClientCertCallback = std::function<bool(utils::tls::X509_unique_ptr cert, utils::tls::EVP_PKEY_unique_ptr priv_key)>;
+  using ServerCertCallback = std::function<bool(utils::tls::X509_unique_ptr cert)>;
+
+  bool findClientCertificate(ClientCertCallback cb) const;
+  bool findServerCertificate(ServerCertCallback cb) const;
+
+  bool useClientCertificate(PCCERT_CONTEXT certificate, ClientCertCallback cb) const;
+  bool useServerCertificate(PCCERT_CONTEXT certificate, ServerCertCallback cb) const;
 #endif  // WIN32
 #endif  // OPENSSL_SUPPORT
 
+  void verifyCertificateExpiration();
+
   std::shared_ptr<core::logging::Logger> logger_;
 };
 typedef int (SSLContextService::*ptr)(char *, int, int, void *);
 
-}  // namespace controllers
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-#endif  // LIBMINIFI_INCLUDE_CONTROLLERS_SSLCONTEXTSERVICE_H_
+}  // namespace org::apache::nifi::minifi::controllers
