@@ -15,8 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_CORE_PROCESSGROUP_H_
-#define LIBMINIFI_INCLUDE_CORE_PROCESSGROUP_H_
+#pragma once
 
 #include <memory>
 #include <string>
@@ -28,26 +27,25 @@
 #include <algorithm>
 #include <set>
 #include <utility>
+#include <tuple>
 
 #include "Processor.h"
-#include "Funnel.h"
 #include "Exception.h"
 #include "TimerDrivenSchedulingAgent.h"
 #include "EventDrivenSchedulingAgent.h"
 #include "CronDrivenSchedulingAgent.h"
+#include "Port.h"
 #include "core/logging/Logger.h"
 #include "controller/ControllerServiceNode.h"
 #include "controller/ControllerServiceMap.h"
 #include "utils/Id.h"
-#include "utils/HTTPClient.h"
+#include "utils/BaseHTTPClient.h"
 #include "utils/CallBackTimer.h"
+#include "range/v3/algorithm/find_if.hpp"
 
 struct ProcessGroupTestAccessor;
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
+namespace org::apache::nifi::minifi {
 
 namespace state {
 class StateController;
@@ -56,7 +54,6 @@ class ProcessorController;
 
 namespace core {
 
-// Process Group Type
 enum ProcessGroupType {
   ROOT_PROCESS_GROUP = 0,
   SIMPLE_PROCESS_GROUP,
@@ -65,7 +62,6 @@ enum ProcessGroupType {
 
 #define ONSCHEDULE_RETRY_INTERVAL 30000  // millisecs
 
-// ProcessGroup Class
 class ProcessGroup : public CoreComponent {
   friend struct ::ProcessGroupTestAccessor;
  public:
@@ -73,15 +69,11 @@ class ProcessGroup : public CoreComponent {
     ExcludeChildren,
     IncludeChildren
   };
-  // Constructor
-  /*!
-   * Create a new process group
-   */
 
-  ProcessGroup(ProcessGroupType type, const std::string& name, const utils::Identifier& uuid, int version, ProcessGroup *parent);
-  ProcessGroup(ProcessGroupType type, const std::string& name);
-  ProcessGroup(ProcessGroupType type, const std::string& name, const utils::Identifier& uuid);
-  ProcessGroup(ProcessGroupType type, const std::string& name, const utils::Identifier& uuid, int version);
+  ProcessGroup(ProcessGroupType type, std::string name, const utils::Identifier& uuid, int version, ProcessGroup *parent);
+  ProcessGroup(ProcessGroupType type, std::string name);
+  ProcessGroup(ProcessGroupType type, std::string name, const utils::Identifier& uuid);
+  ProcessGroup(ProcessGroupType type, std::string name, const utils::Identifier& uuid, int version);
   // Destructor
   ~ProcessGroup() override;
   // Set URL
@@ -174,18 +166,22 @@ class ProcessGroup : public CoreComponent {
     std::lock_guard<std::recursive_mutex> lock(mutex_);
     return parent_process_group_;
   }
-  // Add processor
-  void addProcessor(std::unique_ptr<Processor> processor);
-  // Add child processor group
+  [[maybe_unused]] std::tuple<Processor*, bool> addProcessor(std::unique_ptr<Processor> processor);
+  void addPort(std::unique_ptr<Port> port);
   void addProcessGroup(std::unique_ptr<ProcessGroup> child);
-  // ! Add connections
   void addConnection(std::unique_ptr<Connection> connection);
-  // Generic find
+  const std::set<Port*>& getPorts() const {
+    return ports_;
+  }
+
+  Port* findPortById(const utils::Identifier& uuid) const;
+  Port* findChildPortById(const utils::Identifier& uuid) const;
+
   template <typename Fun>
   Processor* findProcessor(Fun condition, Traverse traverse) const {
     std::lock_guard<std::recursive_mutex> lock(mutex_);
-    const auto found = std::find_if(processors_.cbegin(), processors_.cend(), condition);
-    if (found != processors_.cend()) {
+    const auto found = ranges::find_if(processors_, condition);
+    if (found != ranges::end(processors_)) {
       return found->get();
     }
     for (const auto& processGroup : child_process_groups_) {
@@ -241,9 +237,10 @@ class ProcessGroup : public CoreComponent {
   int config_version_;
   // Process Group Type
   const ProcessGroupType type_;
-  // Processors (ProcessNode) inside this process group which include Input/Output Port, Remote Process Group input/Output port
+  // Processors (ProcessNode) inside this process group which include Remote Process Group input/Output port
   std::set<std::unique_ptr<Processor>> processors_;
   std::set<Processor*> failed_processors_;
+  std::set<Port*> ports_;
   std::set<std::unique_ptr<ProcessGroup>> child_process_groups_;
   // Connections between the processor inside the group;
   std::set<std::unique_ptr<Connection>> connections_;
@@ -269,6 +266,8 @@ class ProcessGroup : public CoreComponent {
   core::controller::ControllerServiceMap controller_service_map_;
 
  private:
+  static Port* findPortById(const std::set<Port*>& ports, const utils::Identifier& uuid);
+
   // Mutex for protection
   mutable std::recursive_mutex mutex_;
   // Logger
@@ -281,8 +280,4 @@ class ProcessGroup : public CoreComponent {
   std::unique_ptr<utils::CallBackTimer> onScheduleTimer_;
 };
 }  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-#endif  // LIBMINIFI_INCLUDE_CORE_PROCESSGROUP_H_
+}  // namespace org::apache::nifi::minifi
