@@ -15,8 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_CORE_PROCESSSESSION_H_
-#define LIBMINIFI_INCLUDE_CORE_PROCESSSESSION_H_
+#pragma once
 
 #include <memory>
 #include <string>
@@ -28,22 +27,21 @@
 #include <atomic>
 #include <algorithm>
 #include <set>
+#include <unordered_map>
+#include <unordered_set>
 
 #include "ProcessContext.h"
 #include "FlowFileRecord.h"
 #include "Exception.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 #include "core/Deprecated.h"
 #include "FlowFile.h"
 #include "WeakReference.h"
 #include "provenance/Provenance.h"
 #include "utils/gsl.h"
+#include "ProcessorMetrics.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
+namespace org::apache::nifi::minifi::core {
 namespace detail {
 struct ReadBufferResult {
   int64_t status;
@@ -81,19 +79,21 @@ class ProcessSession : public ReferenceContainer {
   // Create a new UUID FlowFile with no content resource claim and inherit all attributes from parent
   std::shared_ptr<core::FlowFile> create(const std::shared_ptr<core::FlowFile> &parent = {});
   // Add a FlowFile to the session
-  virtual void add(const std::shared_ptr<core::FlowFile> &flow);
+  virtual void add(const std::shared_ptr<core::FlowFile> &record);
   // Clone a new UUID FlowFile from parent both for content resource claim and attributes
   std::shared_ptr<core::FlowFile> clone(const std::shared_ptr<core::FlowFile> &parent);
   // Clone a new UUID FlowFile from parent for attributes and sub set of parent content resource claim
   std::shared_ptr<core::FlowFile> clone(const std::shared_ptr<core::FlowFile> &parent, int64_t offset, int64_t size);
   // Transfer the FlowFile to the relationship
-  virtual void transfer(const std::shared_ptr<core::FlowFile> &flow, Relationship relationship);
+  virtual void transfer(const std::shared_ptr<core::FlowFile>& flow, const Relationship& relationship);
   // Put Attribute
-  void putAttribute(const std::shared_ptr<core::FlowFile> &flow, std::string key, std::string value);
+  void putAttribute(const std::shared_ptr<core::FlowFile>& flow, const std::string& key, const std::string& value);
   // Remove Attribute
-  void removeAttribute(const std::shared_ptr<core::FlowFile> &flow, std::string key);
+  void removeAttribute(const std::shared_ptr<core::FlowFile>& flow, const std::string& key);
   // Remove Flow File
   void remove(const std::shared_ptr<core::FlowFile> &flow);
+  // Access the contents of the flow file as an input stream; returns null if the flow file has no content claim
+  std::shared_ptr<io::InputStream> getFlowFileContentStream(const std::shared_ptr<core::FlowFile>& flow_file);
   // Execute the given read callback against the content
   int64_t read(const std::shared_ptr<core::FlowFile> &flow, const io::InputStreamCallback& callback);
   // Read content into buffer
@@ -147,6 +147,10 @@ class ProcessSession : public ReferenceContainer {
 
   bool existsFlowFileInRelationship(const Relationship &relationship);
 
+  void setMetrics(const std::shared_ptr<ProcessorMetrics>& metrics) {
+    metrics_ = metrics;
+  }
+
 // Prevent default copy constructor and assignment operation
 // Only support pass by reference or pointer
   ProcessSession(const ProcessSession &parent) = delete;
@@ -158,16 +162,25 @@ class ProcessSession : public ReferenceContainer {
     std::shared_ptr<FlowFile> snapshot;
   };
 
+  using Relationships = std::unordered_set<Relationship>;
+
+  Relationships relationships_;
+
+  struct NewFlowFileInfo {
+    std::shared_ptr<core::FlowFile> flow_file;
+    const Relationship* rel{nullptr};
+  };
+
   // FlowFiles being modified by current process session
-  std::map<utils::Identifier, FlowFileUpdate> _updatedFlowFiles;
+  std::map<utils::Identifier, FlowFileUpdate> updated_flowfiles_;
+  // updated FlowFiles being transferred to the relationship
+  std::map<utils::Identifier, const Relationship*> updated_relationships_;
   // FlowFiles being added by current process session
-  std::map<utils::Identifier, std::shared_ptr<core::FlowFile>> _addedFlowFiles;
+  std::map<utils::Identifier, NewFlowFileInfo> added_flowfiles_;
   // FlowFiles being deleted by current process session
-  std::vector<std::shared_ptr<core::FlowFile>> _deletedFlowFiles;
-  // FlowFiles being transfered to the relationship
-  std::map<utils::Identifier, Relationship> _transferRelationship;
+  std::vector<std::shared_ptr<core::FlowFile>> deleted_flowfiles_;
   // FlowFiles being cloned for multiple connections per relationship
-  std::vector<std::shared_ptr<core::FlowFile>> _clonedFlowFiles;
+  std::vector<std::shared_ptr<core::FlowFile>> cloned_flowfiles_;
 
  private:
   enum class RouteResult {
@@ -177,7 +190,12 @@ class ProcessSession : public ReferenceContainer {
     Error_NoRelationship
   };
 
-  RouteResult routeFlowFile(const std::shared_ptr<FlowFile>& record);
+  struct TransferMetrics {
+    size_t transfer_count = 0;
+    uint64_t transfer_size = 0;
+  };
+
+  RouteResult routeFlowFile(const std::shared_ptr<FlowFile>& record, const std::function<void(const FlowFile&, const Relationship&)>& transfer_callback);
 
   void persistFlowFilesBeforeTransfer(
       std::map<Connectable*, std::vector<std::shared_ptr<core::FlowFile>>>& transactionMap,
@@ -200,11 +218,8 @@ class ProcessSession : public ReferenceContainer {
   CoreComponentStateManager* stateManager_;
 
   static std::shared_ptr<utils::IdGenerator> id_generator_;
+
+  std::shared_ptr<ProcessorMetrics> metrics_;
 };
 
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-#endif  // LIBMINIFI_INCLUDE_CORE_PROCESSSESSION_H_
+}  // namespace org::apache::nifi::minifi::core
