@@ -20,19 +20,18 @@
 
 #include <memory>
 #include <string>
+#include <utility>
 #include <vector>
-#include <set>
+
 #include "properties/Configure.h"
 #include "core/Core.h"
 #include "core/ConfigurableComponent.h"
 #include "core/Connectable.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-namespace controller {
+#define ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES \
+  bool supportsDynamicProperties() const override { return SupportsDynamicProperties; }
+
+namespace org::apache::nifi::minifi::core::controller {
 
 enum ControllerServiceState {
   /**
@@ -61,43 +60,33 @@ enum ControllerServiceState {
  */
 class ControllerService : public ConfigurableComponent, public Connectable {
  public:
-  /**
-   * Controller Service constructor.
-   */
   ControllerService()
       : Connectable(core::getClassName<ControllerService>()),
         configuration_(std::make_shared<Configure>()) {
     current_state_ = DISABLED;
   }
 
-  /**
-   * Controller Service constructor.
-   */
-  explicit ControllerService(const std::string &name, const utils::Identifier &uuid)
-      : Connectable(name, uuid),
+  explicit ControllerService(std::string name, const utils::Identifier &uuid)
+      : Connectable(std::move(name), uuid),
         configuration_(std::make_shared<Configure>()) {
     current_state_ = DISABLED;
   }
 
-  /**
-     * Controller Service constructor.
-     */
-    explicit ControllerService(const std::string &name)
-        : Connectable(name),
-          configuration_(std::make_shared<Configure>()) {
-      current_state_ = DISABLED;
-    }
+  explicit ControllerService(std::string name)
+      : Connectable(std::move(name)),
+        configuration_(std::make_shared<Configure>()) {
+    current_state_ = DISABLED;
+  }
 
-  virtual void initialize() {
-    // set base supported properties
-    Property property("Linked Services", "Referenced Controller Services");
-    std::set<Property> supportedProperties;
-    supportedProperties.insert(property);
-    setSupportedProperties(supportedProperties);
+  void initialize() override {
     current_state_ = ENABLED;
   }
 
-  virtual ~ControllerService() {
+  bool supportsDynamicRelationships() const final {
+    return false;
+  }
+
+  ~ControllerService() override {
     notifyStop();
   }
 
@@ -131,10 +120,6 @@ class ControllerService : public ConfigurableComponent, public Connectable {
     }
   }
 
-  virtual bool supportsDynamicProperties() {
-    return false;
-  }
-
   void setLinkedControllerServices(const std::vector<std::shared_ptr<controller::ControllerService>> &services) {
     linked_services_ = services;
   }
@@ -143,16 +128,11 @@ class ControllerService : public ConfigurableComponent, public Connectable {
   std::vector<std::shared_ptr<controller::ControllerService> > linked_services_;
   std::shared_ptr<Configure> configuration_;
   std::atomic<ControllerServiceState> current_state_;
-  virtual bool canEdit() {
+  bool canEdit() override {
     return true;
   }
 };
 
-}  // namespace controller
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::core::controller
 
 #endif  // LIBMINIFI_INCLUDE_CORE_CONTROLLER_CONTROLLERSERVICE_H_
