@@ -15,59 +15,50 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_CORE_REPOSITORY_FILESYSTEMREPOSITORY_H_
-#define LIBMINIFI_INCLUDE_CORE_REPOSITORY_FILESYSTEMREPOSITORY_H_
+
+#pragma once
 
 #include <memory>
 #include <string>
+#include <utility>
 
 #include "core/Core.h"
 #include "../ContentRepository.h"
 #include "properties/Configure.h"
-#include "core/logging/LoggerConfiguration.h"
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-namespace repository {
+#include "core/logging/LoggerFactory.h"
+
+namespace org::apache::nifi::minifi::core::repository {
 
 /**
  * FileSystemRepository is a content repository that stores data onto the local file system.
  */
 class FileSystemRepository : public core::ContentRepository, public core::CoreComponent {
  public:
-  FileSystemRepository(std::string name = getClassName<FileSystemRepository>()) // NOLINT
-      : core::CoreComponent(name),
+  explicit FileSystemRepository(std::string name = getClassName<FileSystemRepository>())
+      : core::CoreComponent(std::move(name)),
         logger_(logging::LoggerFactory<FileSystemRepository>::getLogger()) {
   }
-  virtual ~FileSystemRepository() = default;
 
-  virtual bool initialize(const std::shared_ptr<minifi::Configure> &configuration);
+  ~FileSystemRepository() override = default;
 
-  virtual void stop();
+  bool initialize(const std::shared_ptr<minifi::Configure>& configuration) override;
 
-  bool exists(const minifi::ResourceClaim &streamId);
+  bool exists(const minifi::ResourceClaim& streamId) override;
 
-  virtual std::shared_ptr<io::BaseStream> write(const minifi::ResourceClaim &claim, bool append = false);
+  std::shared_ptr<io::BaseStream> write(const minifi::ResourceClaim& claim, bool append = false) override;
 
-  virtual std::shared_ptr<io::BaseStream> read(const minifi::ResourceClaim &claim);
+  std::shared_ptr<io::BaseStream> read(const minifi::ResourceClaim& claim) override;
 
-  virtual bool close(const minifi::ResourceClaim &claim) {
+  bool close(const minifi::ResourceClaim& claim) override {
     return remove(claim);
   }
 
-  virtual bool remove(const minifi::ResourceClaim &claim);
+  bool remove(const minifi::ResourceClaim& claim) override;
+
+  std::shared_ptr<ContentSession> createSession() override;
 
  private:
   std::shared_ptr<logging::Logger> logger_;
 };
 
-}  // namespace repository
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
-#endif  // LIBMINIFI_INCLUDE_CORE_REPOSITORY_FILESYSTEMREPOSITORY_H_
+}  // namespace org::apache::nifi::minifi::core::repository
