@@ -23,8 +23,11 @@
 
 #include "VolatileRepository.h"
 #include "FlowFileRecord.h"
+#include "core/ThreadedRepository.h"
 #include "utils/gsl.h"
 
+struct VolatileFlowFileRepositoryTestAccessor;
+
 namespace org {
 namespace apache {
 namespace nifi {
@@ -36,12 +39,12 @@ namespace repository {
  * Volatile flow file repository. keeps a running counter of the current location, freeing
  * those which we no longer hold.
  */
-class VolatileFlowFileRepository : public VolatileRepository<std::string>, public utils::EnableSharedFromThis<VolatileFlowFileRepository> {
-  using utils::EnableSharedFromThis<VolatileFlowFileRepository>::sharedFromThis;
+class VolatileFlowFileRepository : public VolatileRepository<std::string, core::ThreadedRepository> {
+  friend struct ::VolatileFlowFileRepositoryTestAccessor;
 
  public:
-  explicit VolatileFlowFileRepository(std::string repo_name = "",
-                                      std::string /*dir*/ = REPOSITORY_DIRECTORY,
+  explicit VolatileFlowFileRepository(const std::string& repo_name = "",
+                                      const std::string& /*dir*/ = REPOSITORY_DIRECTORY,
                                       std::chrono::milliseconds maxPartitionMillis = MAX_REPOSITORY_ENTRY_LIFE_TIME,
                                       int64_t maxPartitionBytes = MAX_REPOSITORY_STORAGE_SIZE,
                                       std::chrono::milliseconds purgePeriod = REPOSITORY_PURGE_PERIOD)
@@ -51,15 +54,23 @@ class VolatileFlowFileRepository : public VolatileRepository<std::string>, publi
     content_repo_ = nullptr;
   }
 
+  ~VolatileFlowFileRepository() override {
+    stop();
+  }
+
+ private:
   void run() override {
-    repo_full_ = false;
-    while (running_) {
+    while (isRunning()) {
       std::this_thread::sleep_for(purge_period_);
       flush();
     }
     flush();
   }
 
+  std::thread& getThread() override {
+    return thread_;
+  }
+
   void flush() override {
     if (purge_required_ && nullptr != content_repo_) {
       std::lock_guard<std::mutex> lock(purge_mutex_);
@@ -80,7 +91,6 @@ class VolatileFlowFileRepository : public VolatileRepository<std::string>, publi
     content_repo_ = content_repo;
   }
 
- protected:
   void emplace(RepoValue<std::string> &old_value) override {
     std::string buffer;
     old_value.emplace(buffer);
@@ -89,6 +99,7 @@ class VolatileFlowFileRepository : public VolatileRepository<std::string>, publi
   }
 
   std::shared_ptr<core::ContentRepository> content_repo_;
+  std::thread thread_;
 };
 }  // namespace repository
 }  // namespace core
