@@ -25,6 +25,7 @@
 #include <map>
 #include "utils/ThreadPool.h"
 #include "utils/BackTrace.h"
+#include "io/InputStream.h"
 
 namespace org {
 namespace apache {
@@ -114,11 +115,11 @@ class Pausable {
 
 class StateController : public Pausable {
  public:
-  virtual ~StateController() = default;
+  ~StateController() override = default;
 
-  virtual std::string getComponentName() const = 0;
+  [[nodiscard]] virtual std::string getComponentName() const = 0;
 
-  virtual utils::Identifier getComponentUUID() const = 0;
+  [[nodiscard]] virtual utils::Identifier getComponentUUID() const = 0;
   /**
    * Start the client
    */
@@ -141,8 +142,8 @@ class StateMonitor : public StateController {
  public:
   ~StateMonitor() override = default;
 
-  // Execute callback func on the named component. Thread safe, locking mutex_, preventing concurrent flow update
-  virtual void executeOnComponent(const std::string &name, std::function<void(state::StateController&)> func) = 0;
+  // Execute callback func on the component. Thread safe, locking mutex_, preventing concurrent flow update
+  virtual void executeOnComponent(const std::string &id_or_name, std::function<void(state::StateController&)> func) = 0;
 
   // Execute callback func on the all components. Thread safe, locking mutex_, preventing concurrent flow update
   virtual void executeOnAllComponents(std::function<void(state::StateController&)> func) = 0;
@@ -163,7 +164,7 @@ class StateMonitor : public StateController {
    * < 0 is an error code
    * 0 is success
    */
-  virtual int16_t applyUpdate(const std::string & source, const std::string &configuration, bool persist = false) = 0;
+  virtual int16_t applyUpdate(const std::string & source, const std::string &configuration, bool persist = false, const std::optional<std::string>& flow_id = std::nullopt) = 0;
 
   /**
    * Apply an update that the agent must decode. This is useful for certain operations
