@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -15,8 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_CORE_STATE_NODES_AGENTINFORMATION_H_
-#define LIBMINIFI_INCLUDE_CORE_STATE_NODES_AGENTINFORMATION_H_
+#pragma once
 
 #include <memory>
 #include <string>
@@ -70,19 +68,19 @@ namespace org::apache::nifi::minifi::state::response {
 
 class ComponentManifest : public DeviceInformation {
  public:
-  ComponentManifest(const std::string& name, const utils::Identifier& uuid)
-      : DeviceInformation(name, uuid) {
+  ComponentManifest(std::string name, const utils::Identifier& uuid)
+      : DeviceInformation(std::move(name), uuid) {
   }
 
-  ComponentManifest(const std::string &name) // NOLINT
-      : DeviceInformation(name) {
+  explicit ComponentManifest(std::string name)
+      : DeviceInformation(std::move(name)) {
   }
 
-  std::string getName() const {
+  std::string getName() const override {
     return CoreComponent::getName();
   }
 
-  virtual std::vector<SerializedResponseNode> serialize() {
+  std::vector<SerializedResponseNode> serialize() override {
     std::vector<SerializedResponseNode> serialized;
     SerializedResponseNode resp;
     resp.name = "componentManifest";
@@ -102,54 +100,54 @@ class ComponentManifest : public DeviceInformation {
       std::vector<SerializedResponseNode> serialized;
       for (const auto& group : descriptions) {
         SerializedResponseNode desc;
-        desc.name = group.class_name_;
+        desc.name = group.full_name_;
         SerializedResponseNode className;
         className.name = "type";
-        className.value = group.class_name_;
+        className.value = group.full_name_;
 
         if (!group.class_properties_.empty()) {
           SerializedResponseNode props;
           props.name = "propertyDescriptors";
           for (auto && prop : group.class_properties_) {
             SerializedResponseNode child;
-            child.name = prop.first;
+            child.name = prop.getName();
 
             SerializedResponseNode descriptorName;
             descriptorName.name = "name";
-            descriptorName.value = prop.first;
+            descriptorName.value = prop.getName();
 
             SerializedResponseNode descriptorDescription;
             descriptorDescription.name = "description";
-            descriptorDescription.value = prop.second.getDescription();
+            descriptorDescription.value = prop.getDescription();
 
             SerializedResponseNode validatorName;
             validatorName.name = "validator";
-            if (prop.second.getValidator()) {
-              validatorName.value = prop.second.getValidator()->getName();
+            if (prop.getValidator()) {
+              validatorName.value = prop.getValidator()->getName();
             } else {
               validatorName.value = "VALID";
             }
 
             SerializedResponseNode supportsExpressionLanguageScope;
             supportsExpressionLanguageScope.name = "expressionLanguageScope";
-            supportsExpressionLanguageScope.value = prop.second.supportsExpressionLanguage() ? "FLOWFILE_ATTRIBUTES" : "NONE";
+            supportsExpressionLanguageScope.value = prop.supportsExpressionLanguage() ? "FLOWFILE_ATTRIBUTES" : "NONE";
 
             SerializedResponseNode descriptorRequired;
             descriptorRequired.name = "required";
-            descriptorRequired.value = prop.second.getRequired();
+            descriptorRequired.value = prop.getRequired();
 
             SerializedResponseNode descriptorValidRegex;
             descriptorValidRegex.name = "validRegex";
-            descriptorValidRegex.value = prop.second.getValidRegex();
+            descriptorValidRegex.value = prop.getValidRegex();
 
             SerializedResponseNode descriptorDefaultValue;
             descriptorDefaultValue.name = "defaultValue";
-            descriptorDefaultValue.value = prop.second.getValue();
+            descriptorDefaultValue.value = prop.getValue();
 
             SerializedResponseNode descriptorDependentProperties;
             descriptorDependentProperties.name = "dependentProperties";
 
-            for (const auto &propName : prop.second.getDependentProperties()) {
+            for (const auto &propName : prop.getDependentProperties()) {
               SerializedResponseNode descriptorDependentProperty;
               descriptorDependentProperty.name = propName;
               descriptorDependentProperties.children.push_back(descriptorDependentProperty);
@@ -158,14 +156,14 @@ class ComponentManifest : public DeviceInformation {
             SerializedResponseNode descriptorExclusiveOfProperties;
             descriptorExclusiveOfProperties.name = "exclusiveOfProperties";
 
-            for (const auto &exclusiveProp : prop.second.getExclusiveOfProperties()) {
+            for (const auto &exclusiveProp : prop.getExclusiveOfProperties()) {
               SerializedResponseNode descriptorExclusiveOfProperty;
               descriptorExclusiveOfProperty.name = exclusiveProp.first;
               descriptorExclusiveOfProperty.value = exclusiveProp.second;
               descriptorExclusiveOfProperties.children.push_back(descriptorExclusiveOfProperty);
             }
 
-            const auto &allowed_types = prop.second.getAllowedTypes();
+            const auto &allowed_types = prop.getAllowedTypes();
             if (!allowed_types.empty()) {
               SerializedResponseNode allowed_type;
               allowed_type.name = "typeProvidedByValue";
@@ -193,10 +191,10 @@ class ComponentManifest : public DeviceInformation {
 
             child.children.push_back(descriptorName);
 
-            if (prop.first != prop.second.getDisplayName()) {
+            if (prop.getName() != prop.getDisplayName()) {
               SerializedResponseNode displayName;
               displayName.name = "displayName";
-              displayName.value = prop.second.getDisplayName();
+              displayName.value = prop.getDisplayName();
               child.children.push_back(displayName);
             }
             child.children.push_back(descriptorDescription);
@@ -208,11 +206,11 @@ class ComponentManifest : public DeviceInformation {
             child.children.push_back(descriptorDependentProperties);
             child.children.push_back(descriptorExclusiveOfProperties);
 
-            if (!prop.second.getAllowedValues().empty()) {
+            if (!prop.getAllowedValues().empty()) {
               SerializedResponseNode allowedValues;
               allowedValues.name = "allowableValues";
               allowedValues.array = true;
-              for (const auto &av : prop.second.getAllowedValues()) {
+              for (const auto &av : prop.getAllowedValues()) {
                 SerializedResponseNode allowableValue;
                 allowableValue.name = "allowableValues";
 
@@ -280,25 +278,19 @@ class ComponentManifest : public DeviceInformation {
           desc.children.push_back(relationships);
         }
 
-        auto lastOfIdx = group.class_name_.find_last_of('.');
-        std::string processorName = group.class_name_;
+        auto lastOfIdx = group.full_name_.find_last_of('.');
+        std::string processorName = group.full_name_;
         if (lastOfIdx != std::string::npos) {
           lastOfIdx++;  // if a value is found, increment to move beyond the .
-          size_t nameLength = group.class_name_.length() - lastOfIdx;
-          processorName = group.class_name_.substr(lastOfIdx, nameLength);
-        }
-        std::string description;
-
-        bool foundDescription = AgentDocs::getDescription(processorName, description);
-
-        if (!foundDescription) {
-          foundDescription = AgentDocs::getDescription(group.class_name_, description);
+          size_t nameLength = group.full_name_.length() - lastOfIdx;
+          processorName = group.full_name_.substr(lastOfIdx, nameLength);
         }
 
-        if (foundDescription) {
+
+        {
           SerializedResponseNode proc_desc;
           proc_desc.name = "typeDescription";
-          proc_desc.value = description;
+          proc_desc.value = group.description_;
           desc.children.push_back(proc_desc);
         }
 
@@ -318,15 +310,15 @@ class ComponentManifest : public DeviceInformation {
 
 class ExternalManifest : public ComponentManifest {
  public:
-  ExternalManifest(const std::string& name, const utils::Identifier& uuid)
-      : ComponentManifest(name, uuid) {
+  ExternalManifest(std::string name, const utils::Identifier& uuid)
+      : ComponentManifest(std::move(name), uuid) {
   }
 
-  ExternalManifest(const std::string &name) // NOLINT
-      : ComponentManifest(name) {
+  explicit ExternalManifest(std::string name)
+      : ComponentManifest(std::move(name)) {
   }
 
-  virtual std::vector<SerializedResponseNode> serialize() {
+  std::vector<SerializedResponseNode> serialize() override {
     std::vector<SerializedResponseNode> serialized;
     SerializedResponseNode resp;
     resp.name = "componentManifest";
@@ -340,21 +332,21 @@ class ExternalManifest : public ComponentManifest {
 
 class Bundles : public DeviceInformation {
  public:
-  Bundles(const std::string& name, const utils::Identifier& uuid)
-      : DeviceInformation(name, uuid) {
+  Bundles(std::string name, const utils::Identifier& uuid)
+      : DeviceInformation(std::move(name), uuid) {
     setArray(true);
   }
 
-  Bundles(const std::string &name) // NOLINT
-      : DeviceInformation(name) {
+  explicit Bundles(std::string name)
+      : DeviceInformation(std::move(name)) {
     setArray(true);
   }
 
-  std::string getName() const {
+  std::string getName() const override {
     return "bundles";
   }
 
-  std::vector<SerializedResponseNode> serialize() {
+  std::vector<SerializedResponseNode> serialize() override {
     std::vector<SerializedResponseNode> serialized;
     for (auto group : AgentBuild::getExtensions()) {
       SerializedResponseNode bundle;
@@ -418,23 +410,31 @@ class Bundles : public DeviceInformation {
  */
 class AgentStatus : public StateMonitorNode {
  public:
-  AgentStatus(const std::string& name, const utils::Identifier& uuid)
-      : StateMonitorNode(name, uuid) {
+  AgentStatus(std::string name, const utils::Identifier& uuid)
+      : StateMonitorNode(std::move(name), uuid) {
   }
 
-  AgentStatus(const std::string &name) // NOLINT
-      : StateMonitorNode(name) {
+  explicit AgentStatus(std::string name)
+      : StateMonitorNode(std::move(name)) {
   }
 
-  std::string getName() const {
-    return "status";
+  MINIFIAPI static constexpr const char* Description = "Metric node that defines current agent status including repository, component and resource usage information.";
+
+  std::string getName() const override {
+    return "AgentStatus";
   }
 
   void setRepositories(const std::map<std::string, std::shared_ptr<core::Repository>> &repositories) {
     repositories_ = repositories;
   }
 
-  std::vector<SerializedResponseNode> serialize() {
+  void addRepository(const std::shared_ptr<core::Repository> &repo) {
+    if (nullptr != repo) {
+      repositories_.insert(std::make_pair(repo->getName(), repo));
+    }
+  }
+
+  std::vector<SerializedResponseNode> serialize() override {
     std::vector<SerializedResponseNode> serialized;
     auto serializedRepositories = serializeRepositories();
     if (!serializedRepositories.empty()) {
@@ -452,6 +452,36 @@ class AgentStatus : public StateMonitorNode {
     return serialized;
   }
 
+  std::vector<PublishedMetric> calculateMetrics() override {
+    std::vector<PublishedMetric> metrics;
+    for (const auto& [_, repo] : repositories_) {
+      metrics.push_back({"is_running", (repo->isRunning() ? 1.0 : 0.0), {{"metric_class", getName()}, {"repository_name", repo->getName()}}});
+      metrics.push_back({"is_full", (repo->isFull() ? 1.0 : 0.0), {{"metric_class", getName()}, {"repository_name", repo->getName()}}});
+      metrics.push_back({"repository_size", static_cast<double>(repo->getRepoSize()), {{"metric_class", getName()}, {"repository_name", repo->getName()}}});
+    }
+    if (nullptr != monitor_) {
+      auto uptime = monitor_->getUptime();
+      metrics.push_back({"uptime_milliseconds", static_cast<double>(uptime), {{"metric_class", getName()}}});
+    }
+
+    if (nullptr != monitor_) {
+      monitor_->executeOnAllComponents([this, &metrics](StateController& component){
+        metrics.push_back({"is_running", (component.isRunning() ? 1.0 : 0.0),
+          {{"component_uuid", component.getComponentUUID().to_string()}, {"component_name", component.getComponentName()}, {"metric_class", getName()}}});
+      });
+    }
+
+    metrics.push_back({"agent_memory_usage_bytes", static_cast<double>(utils::OsUtils::getCurrentProcessPhysicalMemoryUsage()), {{"metric_class", getName()}}});
+
+    double cpu_usage = -1.0;
+    {
+      std::lock_guard<std::mutex> guard(cpu_load_tracker_mutex_);
+      cpu_usage = cpu_load_tracker_.getCpuUsageAndRestartCollection();
+    }
+    metrics.push_back({"agent_cpu_utilization", cpu_usage, {{"metric_class", getName()}}});
+    return metrics;
+  }
+
  protected:
   SerializedResponseNode serializeRepositories() const {
     SerializedResponseNode repositories;
@@ -599,12 +629,12 @@ class AgentMonitor {
  */
 class AgentManifest : public DeviceInformation {
  public:
-  AgentManifest(const std::string& name, const utils::Identifier& uuid)
-    : DeviceInformation(name, uuid) {
+  AgentManifest(std::string name, const utils::Identifier& uuid)
+    : DeviceInformation(std::move(name), uuid) {
   }
 
-  explicit AgentManifest(const std::string& name)
-    : DeviceInformation(name) {
+  explicit AgentManifest(std::string name)
+    : DeviceInformation(std::move(name)) {
   }
 
   std::string getName() const override {
@@ -664,13 +694,13 @@ class AgentManifest : public DeviceInformation {
 
 class AgentNode : public DeviceInformation, public AgentMonitor, public AgentIdentifier {
  public:
-  AgentNode(const std::string& name, const utils::Identifier& uuid)
-      : DeviceInformation(name, uuid) {
+  AgentNode(std::string name, const utils::Identifier& uuid)
+      : DeviceInformation(std::move(name), uuid) {
     setArray(false);
   }
 
-  explicit AgentNode(const std::string& name)
-      : DeviceInformation(name) {
+  explicit AgentNode(std::string name)
+      : DeviceInformation(std::move(name)) {
     setArray(false);
   }
 
@@ -749,18 +779,20 @@ class AgentNode : public DeviceInformation, public AgentMonitor, public AgentIde
  */
 class AgentInformation : public AgentNode {
  public:
-  AgentInformation(const std::string& name, const utils::Identifier& uuid)
-      : AgentNode(name, uuid),
+  AgentInformation(std::string name, const utils::Identifier& uuid)
+      : AgentNode(std::move(name), uuid),
         include_agent_status_(true) {
     setArray(false);
   }
 
-  explicit AgentInformation(const std::string &name)
-      : AgentNode(name),
+  explicit AgentInformation(std::string name)
+      : AgentNode(std::move(name)),
         include_agent_status_(true) {
     setArray(false);
   }
 
+  MINIFIAPI static constexpr const char* Description = "Metric node that defines all agent information, to include the manifest, and bundle information as part of a healthy hearbeat.";
+
   std::string getName() const override {
     return "agentInfo";
   }
@@ -788,5 +820,3 @@ class AgentInformation : public AgentNode {
 };
 
 }  // namespace org::apache::nifi::minifi::state::response
-
-#endif  // LIBMINIFI_INCLUDE_CORE_STATE_NODES_AGENTINFORMATION_H_
