@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -15,8 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_CORE_STATE_NODES_FLOWINFORMATION_H_
-#define LIBMINIFI_INCLUDE_CORE_STATE_NODES_FLOWINFORMATION_H_
+#pragma once
 
 #include <functional>
 #include <memory>
@@ -41,13 +39,9 @@
 #include "../nodes/StateMonitor.h"
 #include "Connection.h"
 #include "io/ClientSocket.h"
+#include "../ConnectionStore.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace state {
-namespace response {
+namespace org::apache::nifi::minifi::state::response {
 
 class FlowVersion : public DeviceInformation {
  public:
@@ -61,16 +55,16 @@ class FlowVersion : public DeviceInformation {
     setFlowVersion(registry_url, bucket_id, flow_id.empty() ? getUUIDStr() : flow_id);
   }
 
-  explicit FlowVersion(FlowVersion &&fv)
+  FlowVersion(FlowVersion &&fv) noexcept
       : DeviceInformation("FlowVersion"),
         identifier(std::move(fv.identifier)) {
   }
 
-  std::string getName() const {
+  std::string getName() const override {
     return "FlowVersion";
   }
 
-  virtual std::shared_ptr<state::FlowIdentifier> getFlowIdentifier() const {
+  std::shared_ptr<state::FlowIdentifier> getFlowIdentifier() const override {
     std::lock_guard<std::mutex> lock(guard);
     return identifier;
   }
@@ -96,10 +90,10 @@ class FlowVersion : public DeviceInformation {
 
   void setFlowVersion(const std::string &url, const std::string &bucket_id, const std::string &flow_id) {
     std::lock_guard<std::mutex> lock(guard);
-    identifier = std::make_shared<FlowIdentifier>(url, bucket_id, flow_id);
+    identifier = std::make_shared<FlowIdentifier>(url, bucket_id, flow_id.empty() ? utils::IdGenerator::getIdGenerator()->generate().to_string() : flow_id);
   }
 
-  std::vector<SerializedResponseNode> serialize() {
+  std::vector<SerializedResponseNode> serialize() override {
     std::lock_guard<std::mutex> lock(guard);
     std::vector<SerializedResponseNode> serialized;
     SerializedResponseNode ru;
@@ -120,7 +114,7 @@ class FlowVersion : public DeviceInformation {
     return serialized;
   }
 
-  FlowVersion &operator=(const FlowVersion &&fv) {
+  FlowVersion &operator=(FlowVersion &&fv) noexcept {
     identifier = std::move(fv.identifier);
     return *this;
   }
@@ -131,24 +125,14 @@ class FlowVersion : public DeviceInformation {
   std::shared_ptr<FlowIdentifier> identifier;
 };
 
-class FlowMonitor : public StateMonitorNode {
+class FlowMonitor : public StateMonitorNode, public ConnectionStore {
  public:
-  FlowMonitor(const std::string &name, const utils::Identifier &uuid)
-      : StateMonitorNode(name, uuid) {
+  FlowMonitor(std::string name, const utils::Identifier &uuid)
+      : StateMonitorNode(std::move(name), uuid) {
   }
 
-  FlowMonitor(const std::string &name) // NOLINT
-      : StateMonitorNode(name) {
-  }
-
-  void updateConnection(minifi::Connection* connection) {
-    if (nullptr != connection) {
-      connections_[connection->getUUIDStr()] = connection;
-    }
-  }
-
-  void clearConnections() {
-    connections_.clear();
+  explicit FlowMonitor(std::string name)
+      : StateMonitorNode(std::move(name)) {
   }
 
   void setFlowVersion(std::shared_ptr<state::response::FlowVersion> flow_version) {
@@ -157,7 +141,6 @@ class FlowMonitor : public StateMonitorNode {
 
  protected:
   std::shared_ptr<state::response::FlowVersion> flow_version_;
-  std::map<std::string, minifi::Connection*> connections_;
 };
 
 /**
@@ -165,19 +148,21 @@ class FlowMonitor : public StateMonitorNode {
  */
 class FlowInformation : public FlowMonitor {
  public:
-  FlowInformation(const std::string &name, const utils::Identifier &uuid)
-      : FlowMonitor(name, uuid) {
+  FlowInformation(std::string name, const utils::Identifier &uuid)
+      : FlowMonitor(std::move(name), uuid) {
   }
 
-  FlowInformation(const std::string &name) // NOLINT
-      : FlowMonitor(name) {
+  explicit FlowInformation(std::string name)
+      : FlowMonitor(std::move(name)) {
   }
 
-  std::string getName() const {
+  MINIFIAPI static constexpr const char* Description = "Metric node that defines the flow ID and flow URL deployed to this agent";
+
+  std::string getName() const override {
     return "flowInfo";
   }
 
-  std::vector<SerializedResponseNode> serialize() {
+  std::vector<SerializedResponseNode> serialize() override {
     std::vector<SerializedResponseNode> serialized;
 
     SerializedResponseNode fv;
@@ -262,14 +247,17 @@ class FlowInformation : public FlowMonitor {
     return serialized;
   }
 
- protected:
+  std::vector<PublishedMetric> calculateMetrics() override {
+    std::vector<PublishedMetric> metrics = calculateConnectionMetrics("FlowInformation");
+
+    if (nullptr != monitor_) {
+      monitor_->executeOnAllComponents([&metrics](StateController& component){
+        metrics.push_back({"is_running", (component.isRunning() ? 1.0 : 0.0),
+          {{"component_uuid", component.getComponentUUID().to_string()}, {"component_name", component.getComponentName()}, {"metric_class", "FlowInformation"}}});
+      });
+    }
+    return metrics;
+  }
 };
 
-}  // namespace response
-}  // namespace state
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
-#endif  // LIBMINIFI_INCLUDE_CORE_STATE_NODES_FLOWINFORMATION_H_
+}  // namespace org::apache::nifi::minifi::state::response
