@@ -22,17 +22,12 @@
 #include <string>
 
 #include "core/ProcessGroup.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 
 #include "yaml-cpp/yaml.h"
 #include "utils/gsl.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-namespace yaml {
+namespace org::apache::nifi::minifi::core::yaml {
 
 class YamlConnectionParser {
  public:
@@ -48,6 +43,7 @@ class YamlConnectionParser {
   [[nodiscard]] uint64_t getWorkQueueSizeFromYaml() const;
   [[nodiscard]] uint64_t getWorkQueueDataSizeFromYaml() const;
   [[nodiscard]] utils::Identifier getSourceUUIDFromYaml() const;
+  [[nodiscard]] uint64_t getSwapThresholdFromYaml() const;
   [[nodiscard]] utils::Identifier getDestinationUUIDFromYaml() const;
   [[nodiscard]] std::chrono::milliseconds getFlowFileExpirationFromYaml() const;
   [[nodiscard]] bool getDropEmptyFromYaml() const;
@@ -62,9 +58,4 @@ class YamlConnectionParser {
   const std::shared_ptr<logging::Logger> logger_;
 };
 
-}  // namespace yaml
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::core::yaml
