@@ -23,7 +23,7 @@
 #include <fstream>
 #include <string>
 #include "BaseStream.h"
-#include "core/logging/LoggerConfiguration.h"
+#include "core/logging/LoggerFactory.h"
 
 namespace org {
 namespace apache {
