@@ -114,6 +114,7 @@ class Configuration : public Properties {
   static constexpr const char *nifi_c2_rest_url_ack = "nifi.c2.rest.url.ack";
   static constexpr const char *nifi_c2_rest_ssl_context_service = "nifi.c2.rest.ssl.context.service";
   static constexpr const char *nifi_c2_rest_heartbeat_minimize_updates = "nifi.c2.rest.heartbeat.minimize.updates";
+  static constexpr const char *nifi_c2_rest_request_encoding = "nifi.c2.rest.request.encoding";
   static constexpr const char *nifi_c2_mqtt_connector_service = "nifi.c2.mqtt.connector.service";
   static constexpr const char *nifi_c2_mqtt_heartbeat_topic = "nifi.c2.mqtt.heartbeat.topic";
   static constexpr const char *nifi_c2_mqtt_update_topic = "nifi.c2.mqtt.update.topic";
@@ -153,12 +154,30 @@ class Configuration : public Properties {
   static constexpr const char *nifi_log_compression_cached_log_max_size = "nifi.log.compression.cached.log.max.size";
   static constexpr const char *nifi_log_compression_compressed_log_max_size = "nifi.log.compression.compressed.log.max.size";
 
+  // alert options
+  static constexpr const char *nifi_log_alert_url = "nifi.log.alert.url";
+  static constexpr const char *nifi_log_alert_ssl_context_service = "nifi.log.alert.ssl.context.service";
+  static constexpr const char *nifi_log_alert_batch_size = "nifi.log.alert.batch.size";
+  static constexpr const char *nifi_log_alert_flush_period = "nifi.log.alert.flush.period";
+  static constexpr const char *nifi_log_alert_filter = "nifi.log.alert.filter";
+  static constexpr const char *nifi_log_alert_rate_limit = "nifi.log.alert.rate.limit";
+  static constexpr const char *nifi_log_alert_buffer_limit = "nifi.log.alert.buffer.limit";
+  static constexpr const char *nifi_log_alert_level = "nifi.log.alert.level";
+
+  static constexpr const char *nifi_asset_directory = "nifi.asset.directory";
+
+  // Metrics publisher options
+  static constexpr const char *nifi_metrics_publisher_agent_identifier = "nifi.metrics.publisher.agent.identifier";
+  static constexpr const char *nifi_metrics_publisher_class = "nifi.metrics.publisher.class";
+  static constexpr const char *nifi_metrics_publisher_prometheus_metrics_publisher_port = "nifi.metrics.publisher.PrometheusMetricsPublisher.port";
+  static constexpr const char *nifi_metrics_publisher_metrics = "nifi.metrics.publisher.metrics";
+
   MINIFIAPI static const std::vector<core::ConfigurationProperty> CONFIGURATION_PROPERTIES;
   MINIFIAPI static const std::array<const char*, 2> DEFAULT_SENSITIVE_PROPERTIES;
 
   static std::vector<std::string> mergeProperties(std::vector<std::string> properties,
                                                   const std::vector<std::string>& additional_properties);
-  static std::vector<std::string> getSensitiveProperties(std::function<std::optional<std::string>(const std::string&)> reader);
+  static std::vector<std::string> getSensitiveProperties(const std::function<std::optional<std::string>(const std::string&)>& reader);
   static bool validatePropertyValue(const std::string& property_name, const std::string& property_value);
 };
 
