@@ -37,6 +37,15 @@
 #include "utils/gsl.h"
 #include "utils/meta/detected.h"
 
+// libc++ doesn't define operator<=> on strings, and apparently the operator rewrite rules don't automagically make one
+#if defined(_LIBCPP_VERSION) && _LIBCPP_VERSION < 16000
+#include <compare>
+
+constexpr std::strong_ordering operator<=>(const std::string& lhs, const std::string& rhs) noexcept {
+  return lhs.compare(rhs) <=> 0;
+}
+#endif
+
 namespace org::apache::nifi::minifi {
 namespace utils {
 
@@ -161,7 +170,7 @@ class StringUtils {
    * @param output output float
    * @param cp failure policy
    */
-  static bool StringToFloat(std::string input, float &output, FailurePolicy cp = RETURN);
+  static bool StringToFloat(const std::string& input, float &output, FailurePolicy cp = RETURN);
 
   static std::string replaceEnvironmentVariables(std::string source_string);
 
@@ -431,16 +440,16 @@ class StringUtils {
    * @param padded if true, padding is added to the Base64 encoded string
    * @return the size of Base64 encoded bytes
    */
-  static size_t to_base64(char* base64, gsl::span<const std::byte> data_to_be_transformed, bool url, bool padded);
+  static size_t to_base64(char* base64, gsl::span<const std::byte> raw_data, bool url, bool padded);
 
   /**
    * Creates a Base64 encoded string from data
-   * @param data the bytes to be Base64 encoded
+   * @param raw_data the bytes to be Base64 encoded
    * @param url if true, the URL-safe Base64 encoding will be used
    * @param padded if true, padding is added to the Base64 encoded string
    * @return the Base64 encoded string
    */
-  static std::string to_base64(gsl::span<const std::byte> data_to_be_transformed, bool url = false, bool padded = true);
+  static std::string to_base64(gsl::span<const std::byte> raw_data, bool url = false, bool padded = true);
 
   /**
    * Base64 encodes a string
