@@ -14,8 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIBMINIFI_INCLUDE_UTILS_THREADPOOL_H_
-#define LIBMINIFI_INCLUDE_UTILS_THREADPOOL_H_
+#pragma once
 
 #include <algorithm>
 #include <atomic>
@@ -41,11 +40,7 @@
 #include "controllers/ThreadManagementService.h"
 #include "core/controller/ControllerService.h"
 #include "core/controller/ControllerServiceProvider.h"
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace utils {
+namespace org::apache::nifi::minifi::utils {
 
 using TaskId = std::string;
 
@@ -355,10 +350,4 @@ class ThreadPool {
   void manage_delayed_queue();
 };
 
-}  // namespace utils
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
-
-#endif  // LIBMINIFI_INCLUDE_UTILS_THREADPOOL_H_
+}  // namespace org::apache::nifi::minifi::utils
