@@ -17,7 +17,7 @@
 #include <algorithm>
 
 #include "properties/Configuration.h"
-#include "core/Property.h"
+#include "core/PropertyBuilder.h"
 
 namespace org::apache::nifi::minifi {
 
@@ -92,6 +92,7 @@ const std::vector<core::ConfigurationProperty> Configuration::CONFIGURATION_PROP
   core::ConfigurationProperty{Configuration::nifi_c2_rest_url},
   core::ConfigurationProperty{Configuration::nifi_c2_rest_url_ack},
   core::ConfigurationProperty{Configuration::nifi_c2_rest_ssl_context_service},
+  core::ConfigurationProperty{Configuration::nifi_c2_rest_request_encoding},
   core::ConfigurationProperty{Configuration::nifi_c2_rest_heartbeat_minimize_updates, gsl::make_not_null(core::StandardValidators::get().BOOLEAN_VALIDATOR.get())},
   core::ConfigurationProperty{Configuration::nifi_c2_mqtt_connector_service},
   core::ConfigurationProperty{Configuration::nifi_c2_mqtt_heartbeat_topic},
@@ -122,7 +123,20 @@ const std::vector<core::ConfigurationProperty> Configuration::CONFIGURATION_PROP
   core::ConfigurationProperty{Configuration::nifi_log_appender_syslog},
   core::ConfigurationProperty{Configuration::nifi_log_logger_root},
   core::ConfigurationProperty{Configuration::nifi_log_compression_cached_log_max_size, gsl::make_not_null(core::StandardValidators::get().DATA_SIZE_VALIDATOR.get())},
-  core::ConfigurationProperty{Configuration::nifi_log_compression_compressed_log_max_size, gsl::make_not_null(core::StandardValidators::get().DATA_SIZE_VALIDATOR.get())}
+  core::ConfigurationProperty{Configuration::nifi_log_compression_compressed_log_max_size, gsl::make_not_null(core::StandardValidators::get().DATA_SIZE_VALIDATOR.get())},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_url},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_ssl_context_service},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_batch_size},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_flush_period},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_filter},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_rate_limit},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_buffer_limit},
+  core::ConfigurationProperty{Configuration::nifi_log_alert_level},
+  core::ConfigurationProperty{Configuration::nifi_asset_directory},
+  core::ConfigurationProperty{Configuration::nifi_metrics_publisher_agent_identifier},
+  core::ConfigurationProperty{Configuration::nifi_metrics_publisher_class},
+  core::ConfigurationProperty{Configuration::nifi_metrics_publisher_prometheus_metrics_publisher_port, gsl::make_not_null(core::StandardValidators::get().PORT_VALIDATOR.get())},
+  core::ConfigurationProperty{Configuration::nifi_metrics_publisher_metrics}
 };
 
 const std::array<const char*, 2> Configuration::DEFAULT_SENSITIVE_PROPERTIES = {Configuration::nifi_security_client_pass_phrase,
@@ -143,7 +157,7 @@ std::vector<std::string> Configuration::mergeProperties(std::vector<std::string>
   return properties;
 }
 
-std::vector<std::string> Configuration::getSensitiveProperties(std::function<std::optional<std::string>(const std::string&)> reader) {
+std::vector<std::string> Configuration::getSensitiveProperties(const std::function<std::optional<std::string>(const std::string&)>& reader) {
   std::vector<std::string> sensitive_properties(Configuration::DEFAULT_SENSITIVE_PROPERTIES.begin(), Configuration::DEFAULT_SENSITIVE_PROPERTIES.end());
   if (reader) {
     const auto additional_sensitive_props_list = reader(Configuration::nifi_sensitive_props_additional_keys);
