@@ -28,8 +28,6 @@
 
 #include "FlowController.h"
 #include "core/state/nodes/AgentInformation.h"
-#include "core/state/nodes/FlowInformation.h"
-#include "core/state/nodes/RepositoryMetrics.h"
 #include "core/state/ProcessorController.h"
 #include "c2/C2Agent.h"
 #include "core/ProcessGroup.h"
@@ -41,9 +39,11 @@
 #include "core/Connectable.h"
 #include "utils/file/PathUtils.h"
 #include "utils/file/FileSystem.h"
-#include "utils/HTTPClient.h"
+#include "utils/BaseHTTPClient.h"
 #include "io/NetworkPrioritizer.h"
 #include "io/FileStream.h"
+#include "core/ClassLoader.h"
+#include "core/ThreadedRepository.h"
 
 namespace org::apache::nifi::minifi {
 
@@ -70,6 +70,8 @@ FlowController::FlowController(std::shared_ptr<core::Repository> provenance_repo
   initialized_ = false;
 
   protocol_ = std::make_unique<FlowControlProtocol>(this, configuration_);
+  response_node_loader_.setControllerServiceProvider(this);
+  response_node_loader_.setStateMonitor(this);
 }
 
 FlowController::FlowController(std::shared_ptr<core::Repository> provenance_repo, std::shared_ptr<core::Repository> flow_file_repo,
@@ -98,14 +100,18 @@ FlowController::~FlowController() {
   protocol_ = nullptr;
   flow_file_repo_ = nullptr;
   provenance_repo_ = nullptr;
+  logger_->log_trace("Destroying FlowController");
 }
 
-bool FlowController::applyConfiguration(const std::string &source, const std::string &configurePayload) {
+bool FlowController::applyConfiguration(const std::string &source, const std::string &configurePayload, const std::optional<std::string>& flow_id) {
   std::unique_ptr<core::ProcessGroup> newRoot;
   try {
-    newRoot = flow_configuration_->updateFromPayload(source, configurePayload);
+    newRoot = flow_configuration_->updateFromPayload(source, configurePayload, flow_id);
+  } catch (const std::exception& ex) {
+    logger_->log_error("Invalid configuration payload, type: %s, what: %s", typeid(ex).name(), ex.what());
+    return false;
   } catch (...) {
-    logger_->log_error("Invalid configuration payload");
+    logger_->log_error("Invalid configuration payload, type: %s", getCurrentExceptionTypeName());
     return false;
   }
 
@@ -118,39 +124,52 @@ bool FlowController::applyConfiguration(const std::string &source, const std::st
   logger_->log_info("Starting to reload Flow Controller with flow control name %s, version %d", newRoot->getName(), newRoot->getVersion());
 
   updating_ = true;
-
-  std::lock_guard<std::recursive_mutex> flow_lock(mutex_);
-  stop();
-  unload();
-  controller_map_->clear();
-  auto prevRoot = std::move(this->root_);
-  this->root_ = std::move(newRoot);
-  processor_to_controller_.clear();
-  updateResponseNodeConnections();
-  initialized_ = false;
   bool started = false;
-  try {
-    load(std::move(root_), true);
-    flow_update_ = true;
-    started = start() == 0;
 
-    updating_ = false;
+  {
+    std::lock_guard<std::recursive_mutex> flow_lock(mutex_);
+    stop();
+    unload();
 
-    if (started) {
-      auto flowVersion = flow_configuration_->getFlowVersion();
-      if (flowVersion) {
-        logger_->log_debug("Setting flow id to %s", flowVersion->getFlowId());
-        configuration_->set(Configure::nifi_c2_flow_id, flowVersion->getFlowId());
-        configuration_->set(Configure::nifi_c2_flow_url, flowVersion->getFlowIdentifier()->getRegistryUrl());
-      } else {
-        logger_->log_debug("Invalid flow version, not setting");
-      }
+    // prepare to accept the new controller service provider from flow_configuration_
+    clearControllerServices();
+
+    clearResponseNodes();
+    if (metrics_publisher_) {
+      metrics_publisher_->clearMetricNodes();
+    }
+    auto prevRoot = std::move(this->root_);
+    this->root_ = std::move(newRoot);
+    processor_to_controller_.clear();
+    initialized_ = false;
+    try {
+      load(std::move(root_), true);
+      flow_update_ = true;
+      started = start() == 0;
+    } catch (const std::exception& ex) {
+      logger_->log_error("Caught exception while starting flow, type %s, what: %s", typeid(ex).name(), ex.what());
+    } catch (...) {
+      logger_->log_error("Caught unknown exception while starting flow, type %s", getCurrentExceptionTypeName());
+    }
+    if (!started) {
+      logger_->log_error("Failed to start new flow, restarting previous flow");
+      load(std::move(prevRoot), true);
+      flow_update_ = true;
+      start();
+    }
+  }
+
+  updating_ = false;
+
+  if (started) {
+    auto flowVersion = flow_configuration_->getFlowVersion();
+    if (flowVersion) {
+      logger_->log_debug("Setting flow id to %s", flowVersion->getFlowId());
+      configuration_->set(Configure::nifi_c2_flow_id, flowVersion->getFlowId());
+      configuration_->set(Configure::nifi_c2_flow_url, flowVersion->getFlowIdentifier()->getRegistryUrl());
+    } else {
+      logger_->log_debug("Invalid flow version, not setting");
     }
-  } catch (...) {
-    this->root_ = std::move(prevRoot);
-    load(std::move(this->root_), true);
-    flow_update_ = true;
-    updating_ = false;
   }
 
   return started;
@@ -278,19 +297,21 @@ void FlowController::load(std::unique_ptr<core::ProcessGroup> root, bool reload)
       logger_->log_info("Load Flow Controller from provided root");
       this->root_ = std::move(root);
       processor_to_controller_.clear();
-      updateResponseNodeConnections();
     } else {
       logger_->log_info("Instantiating new flow");
       this->root_ = loadInitialFlow();
     }
 
-    if (root_) {
-      root_->verify();
-    }
-
     logger_->log_info("Loaded root processor Group");
     logger_->log_info("Initializing timers");
     controller_service_provider_impl_ = flow_configuration_->getControllerServiceProvider();
+    response_node_loader_.initializeComponentMetrics(root_.get());
+    initializeResponseNodes(root_.get());
+    if (metrics_publisher_) {
+      metrics_publisher_->loadMetricNodes(root_.get());
+    } else {
+      loadMetricsPublisher();
+    }
 
     if (!thread_pool_.isRunning() || reload) {
       thread_pool_.shutdown();
@@ -365,6 +386,7 @@ int16_t FlowController::start() {
         this->root_->startProcessing(timer_scheduler_, event_scheduler_, cron_scheduler_);
       }
       C2Client::initialize(this, this, this);
+      core::logging::LoggerConfiguration::getConfiguration().initializeAlertSinks(this, configuration_);
       running_ = true;
       this->protocol_->start();
       this->provenance_repo_->start();
@@ -400,8 +422,8 @@ int16_t FlowController::resume() {
   return 0;
 }
 
-int16_t FlowController::applyUpdate(const std::string &source, const std::string &configuration, bool persist) {
-  if (applyConfiguration(source, configuration)) {
+int16_t FlowController::applyUpdate(const std::string &source, const std::string &configuration, bool persist, const std::optional<std::string>& flow_id) {
+  if (applyConfiguration(source, configuration, flow_id)) {
     if (persist) {
       flow_configuration_->persist(configuration);
     }
@@ -425,68 +447,72 @@ int16_t FlowController::clearConnection(const std::string &connection) {
   return -1;
 }
 
-std::shared_ptr<state::response::ResponseNode> FlowController::getAgentManifest() {
-  auto agentInfo = std::make_shared<state::response::AgentInformation>("agentInfo");
-  agentInfo->setUpdatePolicyController(std::static_pointer_cast<controllers::UpdatePolicyControllerService>(getControllerService(c2::C2Agent::UPDATE_NAME)).get());
-  agentInfo->setAgentIdentificationProvider(configuration_);
-  agentInfo->setConfigurationReader([this](const std::string& key){
+state::response::NodeReporter::ReportedNode FlowController::getAgentManifest() {
+  state::response::AgentInformation agentInfo("agentInfo");
+  agentInfo.setUpdatePolicyController(std::static_pointer_cast<controllers::UpdatePolicyControllerService>(getControllerService(c2::C2Agent::UPDATE_NAME)).get());
+  agentInfo.setAgentIdentificationProvider(configuration_);
+  agentInfo.setConfigurationReader([this](const std::string& key){
     return configuration_->getRawValue(key);
   });
-  agentInfo->setStateMonitor(this);
-  agentInfo->includeAgentStatus(false);
-  return agentInfo;
+  agentInfo.setStateMonitor(this);
+  agentInfo.includeAgentStatus(false);
+  state::response::NodeReporter::ReportedNode reported_node;
+  reported_node.name = agentInfo.getName();
+  reported_node.is_array = agentInfo.isArray();
+  reported_node.serialized_nodes = agentInfo.serialize();
+  return reported_node;
 }
 
 void FlowController::executeOnAllComponents(std::function<void(state::StateController&)> func) {
+  if (updating_) {
+    return;
+  }
   std::lock_guard<std::recursive_mutex> lock(mutex_);
   for (auto* component: getAllComponents()) {
     func(*component);
   }
 }
 
-void FlowController::executeOnComponent(const std::string &name, std::function<void(state::StateController&)> func) {
+void FlowController::executeOnComponent(const std::string &id_or_name, std::function<void(state::StateController&)> func) {
+  if (updating_) {
+    return;
+  }
   std::lock_guard<std::recursive_mutex> lock(mutex_);
-  if (auto* component = getComponent(name); component != nullptr) {
+  if (auto* component = getComponent(id_or_name); component != nullptr) {
     func(*component);
   } else {
-    logger_->log_error("Could not get execute requested callback for component \"%s\", because component was not found", name);
+    logger_->log_error("Could not get execute requested callback for component \"%s\", because component was not found", id_or_name);
   }
 }
 
 std::vector<state::StateController*> FlowController::getAllComponents() {
   if (root_) {
-    auto controllerFactory = [this] (core::Processor& p) {
-      return createController(p);
-    };
-    return getAllProcessorControllers(controllerFactory);
+    return getAllProcessorControllers([this](core::Processor& p) { return createController(p); });
   }
 
   return {this};
 }
 
-state::StateController* FlowController::getComponent(const std::string& name) {
-  if (name == "FlowController") {
+state::StateController* FlowController::getComponent(const std::string& id_or_name) {
+  if (id_or_name == getUUIDStr() || id_or_name == "FlowController") {
     return this;
   } else if (root_) {
-    auto controllerFactory = [this] (core::Processor& p) {
-      return createController(p);
-    };
-    return getProcessorController(name, controllerFactory);
+    return getProcessorController(id_or_name, [this](core::Processor& p) { return createController(p); });
   }
 
   return nullptr;
 }
 
-std::unique_ptr<state::ProcessorController> FlowController::createController(core::Processor& processor) {
-  switch (processor.getSchedulingStrategy()) {
-    case core::SchedulingStrategy::TIMER_DRIVEN:
-      return std::make_unique<state::ProcessorController>(&processor, timer_scheduler_);
-    case core::SchedulingStrategy::EVENT_DRIVEN:
-      return std::make_unique<state::ProcessorController>(&processor, event_scheduler_);
-    case core::SchedulingStrategy::CRON_DRIVEN:
-      return std::make_unique<state::ProcessorController>(&processor, cron_scheduler_);
-  }
-  return {};
+gsl::not_null<std::unique_ptr<state::ProcessorController>> FlowController::createController(core::Processor& processor) {
+  const auto scheduler = [this, &processor]() -> std::shared_ptr<SchedulingAgent> {
+    switch (processor.getSchedulingStrategy()) {
+      case core::SchedulingStrategy::TIMER_DRIVEN: return timer_scheduler_;
+      case core::SchedulingStrategy::EVENT_DRIVEN: return event_scheduler_;
+      case core::SchedulingStrategy::CRON_DRIVEN: return cron_scheduler_;
+    }
+    gsl_Assert(false);
+  };
+  return gsl::make_not_null(std::make_unique<state::ProcessorController>(processor, scheduler()));
 }
 
 uint64_t FlowController::getUptime() {
@@ -497,10 +523,14 @@ uint64_t FlowController::getUptime() {
 
 std::vector<BackTrace> FlowController::getTraces() {
   std::vector<BackTrace> traces{thread_pool_.getTraces()};
-  auto prov_repo_trace = provenance_repo_->getTraces();
-  traces.emplace_back(std::move(prov_repo_trace));
-  auto flow_repo_trace = flow_file_repo_->getTraces();
-  traces.emplace_back(std::move(flow_repo_trace));
+  if (auto provenance_repo = std::dynamic_pointer_cast<core::ThreadedRepository>(provenance_repo_)) {
+    auto prov_repo_trace = provenance_repo->getTraces();
+    traces.emplace_back(std::move(prov_repo_trace));
+  }
+  if (auto flow_file_repo = std::dynamic_pointer_cast<core::ThreadedRepository>(flow_file_repo_)) {
+    auto flow_repo_trace = flow_file_repo->getTraces();
+    traces.emplace_back(std::move(flow_repo_trace));
+  }
   auto my_traces = TraceResolver::getResolver().getBackTrace("main");
   traces.emplace_back(std::move(my_traces));
   return traces;
@@ -520,7 +550,7 @@ std::map<std::string, std::unique_ptr<io::InputStream>> FlowController::getDebug
 }
 
 std::vector<state::StateController*> FlowController::getAllProcessorControllers(
-        const std::function<std::unique_ptr<state::ProcessorController>(core::Processor&)>& controllerFactory) {
+        const std::function<gsl::not_null<std::unique_ptr<state::ProcessorController>>(core::Processor&)>& controllerFactory) {
   std::vector<state::StateController*> controllerVec{this};
   std::vector<core::Processor*> processorVec;
   root_->getAllProcessors(processorVec);
@@ -537,19 +567,37 @@ std::vector<state::StateController*> FlowController::getAllProcessorControllers(
   return controllerVec;
 }
 
-state::StateController* FlowController::getProcessorController(const std::string& name, const std::function<std::unique_ptr<state::ProcessorController>(core::Processor&)>& controllerFactory) {
-  auto* processor = root_->findProcessorByName(name);
-  if (processor == nullptr) {
-    logger_->log_error("Could not get processor controller for requested name \"%s\", because processor was not found either", name);
-    return nullptr;
-  }
+state::StateController* FlowController::getProcessorController(const std::string& id_or_name,
+    const std::function<gsl::not_null<std::unique_ptr<state::ProcessorController>>(core::Processor&)>& controllerFactory) {
+  return utils::Identifier::parse(id_or_name)
+      | utils::flatMap([this](utils::Identifier id) { return utils::optional_from_ptr(root_->findProcessorById(id)); })
+      | utils::orElse([this, &id_or_name] { return utils::optional_from_ptr(root_->findProcessorByName(id_or_name)); })
+      | utils::map([this, &controllerFactory](gsl::not_null<core::Processor*> proc) -> gsl::not_null<state::ProcessorController*> {
+        return utils::optional_from_ptr(processor_to_controller_[proc->getUUID()].get())
+            | utils::valueOrElse([this, proc, &controllerFactory] {
+              return gsl::make_not_null((processor_to_controller_[proc->getUUID()] = controllerFactory(*proc)).get());
+            });
+      })
+      | utils::valueOrElse([this, &id_or_name]() -> state::ProcessorController* {
+        logger_->log_error("Could not get processor controller for requested id/name \"%s\", because the processor was not found", id_or_name);
+        return nullptr;
+      });
+}
 
-  // reference to the existing or newly created controller
-  auto& foundController = processor_to_controller_[processor->getUUID()];
-  if (!foundController) {
-    foundController = controllerFactory(*processor);
+void FlowController::loadMetricsPublisher() {
+  if (auto metrics_publisher_class = configuration_->get(minifi::Configure::nifi_metrics_publisher_class)) {
+    auto ptr = core::ClassLoader::getDefaultClassLoader().instantiate(*metrics_publisher_class, *metrics_publisher_class);
+    if (!ptr) {
+      logger_->log_error("Configured metrics publisher class \"%s\" could not be instantiated.", *metrics_publisher_class);
+      return;
+    }
+    metrics_publisher_ = utils::dynamic_unique_cast<state::MetricsPublisher>(std::move(ptr));
+    if (!metrics_publisher_) {
+      logger_->log_error("Configured metrics publisher class \"%s\" is not a metrics publisher.", *metrics_publisher_class);
+      return;
+    }
+    metrics_publisher_->initialize(configuration_, response_node_loader_, root_.get());
   }
-  return foundController.get();
 }
 
 }  // namespace org::apache::nifi::minifi
