@@ -38,7 +38,7 @@
 #include "utils/file/FileUtils.h"
 #include "utils/file/FileManager.h"
 #include "utils/file/FileSystem.h"
-#include "utils/HTTPClient.h"
+#include "utils/BaseHTTPClient.h"
 #include "utils/Environment.h"
 #include "utils/Monitors.h"
 #include "utils/StringUtils.h"
@@ -122,7 +122,7 @@ void C2Agent::checkTriggers() {
       // handle the response the same way. This means that
       // acknowledgements will be sent to the c2 server for every trigger action.
       // this is expected
-      extractPayload(std::move(triggerAction));
+      extractPayload(triggerAction);
       // call reset if the trigger supports this activity
       trigger->reset();
     } else {
@@ -131,7 +131,9 @@ void C2Agent::checkTriggers() {
   }
 }
 void C2Agent::configure(const std::shared_ptr<Configure> &configure, bool reconfigure) {
-  std::string clazz, heartbeat_period, device;
+  std::string clazz;
+  std::string heartbeat_period;
+  std::string device;
 
   if (!reconfigure) {
     if (!configure->get(Configuration::nifi_c2_agent_protocol_class, "c2.agent.protocol.class", clazz)) {
@@ -220,7 +222,7 @@ void C2Agent::performHeartBeat() {
   C2Payload payload(Operation::HEARTBEAT);
   logger_->log_trace("Performing heartbeat");
   auto reporter = dynamic_cast<state::response::NodeReporter*>(update_sink_);
-  std::vector<std::shared_ptr<state::response::ResponseNode>> metrics;
+  std::vector<state::response::NodeReporter::ReportedNode> metrics;
   if (reporter) {
     if (!manifest_sent_) {
       // include agent manifest for the first heartbeat
@@ -233,9 +235,9 @@ void C2Agent::performHeartBeat() {
     payload.reservePayloads(metrics.size());
     for (const auto& metric : metrics) {
       C2Payload child_metric_payload(Operation::HEARTBEAT);
-      child_metric_payload.setLabel(metric->getName());
-      child_metric_payload.setContainer(metric->isArray());
-      serializeMetrics(child_metric_payload, metric->getName(), metric->serialize(), metric->isArray());
+      child_metric_payload.setLabel(metric.name);
+      child_metric_payload.setContainer(metric.is_array);
+      serializeMetrics(child_metric_payload, metric.name, metric.serialized_nodes, metric.is_array);
       payload.addPayload(std::move(child_metric_payload));
     }
   }
@@ -254,7 +256,7 @@ void C2Agent::serializeMetrics(C2Payload &metric_payload, const std::string &nam
   const auto payloads = std::count_if(begin(metrics), end(metrics), [](const state::response::SerializedResponseNode& metric) { return !metric.children.empty() || metric.keep_empty; });
   metric_payload.reservePayloads(metric_payload.getNestedPayloads().size() + payloads);
   for (const auto &metric : metrics) {
-    if (metric.children.size() > 0 || (metric.children.size() == 0 && metric.keep_empty)) {
+    if (metric.keep_empty || !metric.children.empty()) {
       C2Payload child_metric_payload(metric_payload.getOperation());
       if (metric.array) {
         child_metric_payload.setContainer(true);
@@ -344,7 +346,7 @@ void C2Agent::handle_c2_server_response(const C2ContentResponse &resp) {
     case Operation::RESTART: {
       update_sink_->stop();
       C2Payload response(Operation::ACKNOWLEDGE, resp.ident, true);
-      protocol_.load()->consumePayload(std::move(response));
+      protocol_.load()->consumePayload(response);
       restart_needed_ = true;
     }
       break;
@@ -356,7 +358,7 @@ void C2Agent::handle_c2_server_response(const C2ContentResponse &resp) {
 
       // stop all referenced components.
       update_sink_->executeOnComponent(resp.name, [this, &resp] (state::StateController& component) {
-        logger_->log_debug("Stopping component %s", component.getComponentName());
+        logger_->log_debug("Stopping component %s", resp.name);
         if (resp.op == Operation::STOP) {
           component.stop();
         } else {
@@ -407,7 +409,7 @@ C2Payload C2Agent::prepareConfigurationOptions(const C2ContentResponse &resp) co
     auto unsanitized_keys = configuration_->getConfiguredKeys();
     std::vector<std::string> keys;
     std::copy_if(unsanitized_keys.begin(), unsanitized_keys.end(), std::back_inserter(keys),
-            [](std::string key) {return key.find("pass") == std::string::npos;});
+            [](const std::string& key) {return key.find("pass") == std::string::npos;});
 
     C2Payload response(Operation::ACKNOWLEDGE, resp.ident, true);
     C2Payload options(Operation::ACKNOWLEDGE);
@@ -428,7 +430,7 @@ C2Payload C2Agent::prepareConfigurationOptions(const C2ContentResponse &resp) co
 void C2Agent::handle_clear(const C2ContentResponse &resp) {
   ClearOperand operand;
   try {
-    operand = ClearOperand::parse(resp.name.c_str());
+    operand = ClearOperand::parse(resp.name.c_str(), {}, false);
   } catch(const std::runtime_error&) {
     logger_->log_debug("Clearing unknown %s", resp.name);
     return;
@@ -483,7 +485,7 @@ void C2Agent::handle_clear(const C2ContentResponse &resp) {
 void C2Agent::handle_describe(const C2ContentResponse &resp) {
   DescribeOperand operand;
   try {
-    operand = DescribeOperand::parse(resp.name.c_str());
+    operand = DescribeOperand::parse(resp.name.c_str(), {}, false);
   } catch(const std::runtime_error&) {
     C2Payload response(Operation::ACKNOWLEDGE, resp.ident, true);
     enqueue_c2_response(std::move(response));
@@ -504,7 +506,7 @@ void C2Agent::handle_describe(const C2ContentResponse &resp) {
         C2Payload metrics(Operation::ACKNOWLEDGE);
         metricsClass.empty() ? metrics.setLabel("metrics") : metrics.setLabel(metricsClass);
         if (metricsNode) {
-          serializeMetrics(metrics, metricsNode->getName(), metricsNode->serialize(), metricsNode->isArray());
+          serializeMetrics(metrics, metricsNode->name, metricsNode->serialized_nodes, metricsNode->is_array);
         }
         response.addPayload(std::move(metrics));
       }
@@ -523,7 +525,7 @@ void C2Agent::handle_describe(const C2ContentResponse &resp) {
         agentInfo.setLabel("agentInfo");
 
         const auto manifest = reporter->getAgentManifest();
-        serializeMetrics(agentInfo, manifest->getName(), manifest->serialize());
+        serializeMetrics(agentInfo, manifest.name, manifest.serialized_nodes);
         response.addPayload(std::move(agentInfo));
       }
       enqueue_c2_response(std::move(response));
@@ -585,7 +587,7 @@ void C2Agent::handle_describe(const C2ContentResponse &resp) {
 void C2Agent::handle_update(const C2ContentResponse &resp) {
   UpdateOperand operand;
   try {
-    operand = UpdateOperand::parse(resp.name.c_str());
+    operand = UpdateOperand::parse(resp.name.c_str(), {}, false);
   } catch(const std::runtime_error&) {
     C2Payload response(Operation::ACKNOWLEDGE, state::UpdateState::NOT_APPLIED, resp.ident, true);
     enqueue_c2_response(std::move(response));
@@ -601,6 +603,10 @@ void C2Agent::handle_update(const C2ContentResponse &resp) {
       handlePropertyUpdate(resp);
       break;
     }
+    case UpdateOperand::ASSET: {
+      handleAssetUpdate(resp);
+      break;
+    }
   }
 }
 
@@ -619,13 +625,13 @@ void C2Agent::handlePropertyUpdate(const C2ContentResponse &resp) {
     }
   };
 
-  for (auto entry : resp.operation_arguments) {
+  for (const auto& [name, value] : resp.operation_arguments) {
     bool persist = (
-        entry.second.getAnnotation("persist")
+        value.getAnnotation("persist")
         | utils::map(&AnnotatedValue::to_string)
         | utils::flatMap(utils::StringUtils::toBool)).value_or(true);
     PropertyChangeLifetime lifetime = persist ? PropertyChangeLifetime::PERSISTENT : PropertyChangeLifetime::TRANSIENT;
-    changeUpdateState(update_property(entry.first, entry.second.to_string(), lifetime));
+    changeUpdateState(update_property(name, value.to_string(), lifetime));
   }
   // apply changes and persist properties requested to be persisted
   const bool propertyWasUpdated = result == state::UpdateState::FULLY_APPLIED || result == state::UpdateState::PARTIALLY_APPLIED;
@@ -690,7 +696,7 @@ C2Payload C2Agent::bundleDebugInfo(std::map<std::string, std::unique_ptr<io::Inp
 void C2Agent::handle_transfer(const C2ContentResponse &resp) {
   TransferOperand operand;
   try {
-    operand = TransferOperand::parse(resp.name.c_str());
+    operand = TransferOperand::parse(resp.name.c_str(), {}, false);
   } catch(const std::runtime_error&) {
     throw C2TransferError("Unknown operand '" + resp.name + "'");
   }
@@ -733,7 +739,7 @@ utils::TaskRescheduleInfo C2Agent::produce() {
         std::make_move_iterator(payload_batch.end()),
         [&] (C2Payload&& payload) {
           try {
-            C2Payload && response = protocol_.load()->consumePayload(std::move(payload));
+            C2Payload response = protocol_.load()->consumePayload(payload);
             enqueue_c2_server_response(std::move(response));
           }
           catch(const std::exception &e) {
@@ -754,10 +760,10 @@ utils::TaskRescheduleInfo C2Agent::produce() {
       performHeartBeat();
     }
     catch (const std::exception &e) {
-      logger_->log_error("Exception occurred while performing heartbeat. error: %s", e.what());
+      logger_->log_error("Exception occurred while performing heartbeat. type: %s, what: %s", typeid(e).name(), e.what());
     }
     catch (...) {
-      logger_->log_error("Unknown exception occurred while performing heartbeat.");
+      logger_->log_error("Unknown exception occurred while performing heartbeat, type: %s", getCurrentExceptionTypeName());
     }
   }
 
@@ -769,7 +775,7 @@ utils::TaskRescheduleInfo C2Agent::produce() {
 utils::TaskRescheduleInfo C2Agent::consume() {
   if (!responses.empty()) {
     const auto consume_success = responses.consume([this] (C2Payload&& payload) {
-      extractPayload(std::move(payload));
+      extractPayload(payload);
     });
     if (!consume_success) {
       extractPayload(C2Payload{ Operation::HEARTBEAT });
@@ -842,6 +848,11 @@ std::optional<std::string> C2Agent::fetchFlow(const std::string& uri) const {
   return response.getRawDataAsString();
 }
 
+std::optional<std::string> C2Agent::getFlowIdFromConfigUpdate(const C2ContentResponse &resp) {
+  auto flow_id = resp.operation_arguments.find("flowId");
+  return flow_id == resp.operation_arguments.end() ? std::nullopt : std::make_optional(flow_id->second.to_string());
+}
+
 bool C2Agent::handleConfigurationUpdate(const C2ContentResponse &resp) {
   auto url = resp.operation_arguments.find("location");
 
@@ -880,7 +891,7 @@ bool C2Agent::handleConfigurationUpdate(const C2ContentResponse &resp) {
     return utils::StringUtils::equalsIgnoreCase(persist->second.to_string(), "true");
   }();
 
-  int16_t err = {update_sink_->applyUpdate(file_uri, configuration_str, should_persist)};
+  int16_t err = {update_sink_->applyUpdate(file_uri, configuration_str, should_persist, getFlowIdFromConfigUpdate(resp))};
   if (err != 0) {
     logger_->log_error("Flow configuration update failed with error code %" PRIi16, err);
     C2Payload response(Operation::ACKNOWLEDGE, state::UpdateState::SET_ERROR, resp.ident, true);
@@ -900,6 +911,113 @@ bool C2Agent::handleConfigurationUpdate(const C2ContentResponse &resp) {
   return true;
 }
 
+static auto make_path(const std::string& str) {
+  return std::filesystem::path(str);
+}
+
+static std::optional<std::string> validateFilePath(const std::filesystem::path& path) {
+  if (path.empty()) {
+    return "Empty file path";
+  }
+  if (!path.is_relative()) {
+    return "File path must be a relative path '" + path.string() + "'";
+  }
+  if (!path.has_filename()) {
+    return "Filename missing in output path '" + path.string() + "'";
+  }
+  if (path.filename() == "." || path.filename() == "..") {
+    return "Invalid filename '" + path.filename().string() + "'";
+  }
+  for (const auto& segment : path) {
+    if (segment == "..") {
+      return "Accessing parent directory is forbidden in file path '" + path.string() + "'";
+    }
+  }
+  return std::nullopt;
+}
+
+void C2Agent::handleAssetUpdate(const C2ContentResponse& resp) {
+  auto send_error = [&] (std::string_view error) {
+    logger_->log_error("%s", std::string(error));
+    C2Payload response(Operation::ACKNOWLEDGE, state::UpdateState::SET_ERROR, resp.ident, true);
+    response.setRawData(gsl::span<const char>(error).as_span<const std::byte>());
+    enqueue_c2_response(std::move(response));
+  };
+  std::filesystem::path asset_dir = std::filesystem::path(configuration_->getHome()) / "asset";
+  if (auto asset_dir_str = configuration_->get(Configuration::nifi_asset_directory)) {
+    asset_dir = asset_dir_str.value();
+  }
+
+  // output file
+  std::filesystem::path file_path;
+  if (auto file_rel = resp.getArgument("file") | utils::map(make_path)) {
+    if (auto error = validateFilePath(file_rel.value())) {
+      send_error(error.value());
+      return;
+    }
+    file_path = asset_dir / file_rel.value();
+  } else {
+    send_error("Couldn't find 'file' argument");
+    return;
+  }
+
+  // source url
+  std::string url;
+  if (auto url_str = resp.getArgument("url")) {
+    if (auto resolved_url = resolveUrl(*url_str)) {
+      url = resolved_url.value();
+    } else {
+      send_error("Couldn't resolve url");
+      return;
+    }
+  } else {
+    send_error("Couldn't find 'url' argument");
+    return;
+  }
+
+  // forceDownload
+  bool force_download = false;
+  if (auto force_download_str = resp.getArgument("forceDownload")) {
+    if (utils::StringUtils::equalsIgnoreCase(force_download_str.value(), "true")) {
+      force_download = true;
+    } else if (utils::StringUtils::equalsIgnoreCase(force_download_str.value(), "false")) {
+      force_download = false;
+    } else {
+      send_error("Argument 'forceDownload' must be either 'true' or 'false'");
+      return;
+    }
+  }
+
+  if (!force_download && std::filesystem::exists(file_path)) {
+    logger_->log_info("File already exists");
+    C2Payload response(Operation::ACKNOWLEDGE, state::UpdateState::NO_OPERATION, resp.ident, true);
+    enqueue_c2_response(std::move(response));
+    return;
+  }
+
+  C2Payload file_response = protocol_.load()->consumePayload(url, C2Payload(Operation::TRANSFER, true), RECEIVE, false);
+
+  if (file_response.getStatus().getState() != state::UpdateState::READ_COMPLETE) {
+    send_error("Failed to fetch asset from '" + url + "'");
+    return;
+  }
+
+  auto raw_data = std::move(file_response).moveRawData();
+  // ensure directory exists for file
+  if (utils::file::create_dir(file_path.parent_path().string()) != 0) {
+    send_error("Failed to create directory '" + file_path.parent_path().string() + "'");
+    return;
+  }
+
+  {
+    std::ofstream file{file_path, std::ofstream::binary};
+    file.write(reinterpret_cast<const char*>(raw_data.data()), raw_data.size());
+  }
+
+  C2Payload response(Operation::ACKNOWLEDGE, state::UpdateState::FULLY_APPLIED, resp.ident, true);
+  enqueue_c2_response(std::move(response));
+}
+
 void C2Agent::enqueue_c2_server_response(C2Payload &&resp) {
   logger_->log_trace("Server response: %s", [&] {return resp.str();});
 
