@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -30,49 +29,39 @@
 #include <netdb.h>
 #include <unistd.h>
 #endif
-#include <string.h>
-#include <stdlib.h>
+#include <cstring>
+#include <cstdlib>
 
-#include <set>
 #include "utils/StringUtils.h"
 #include "core/TypedValues.h"
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 #if ( defined(__APPLE__) || defined(__MACH__) || defined(BSD))
 #include <net/if_dl.h>
 #include <net/if_types.h>
 #endif
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace controllers {
+namespace org::apache::nifi::minifi::controllers {
 
-core::Property NetworkPrioritizerService::NetworkControllers(
+const core::Property NetworkPrioritizerService::NetworkControllers(
     core::PropertyBuilder::createProperty("Network Controllers")->withDescription("Comma separated list of network controllers in order of priority for this prioritizer")->isRequired(false)->build());
 
-core::Property NetworkPrioritizerService::MaxThroughput(
+const core::Property NetworkPrioritizerService::MaxThroughput(
     core::PropertyBuilder::createProperty("Max Throughput")->withDescription("Max throughput ( per second ) for these network controllers")->isRequired(true)->withDefaultValue<core::DataSizeValue>(
         "1 MB")->build());
 
-core::Property NetworkPrioritizerService::MaxPayload(
+const core::Property NetworkPrioritizerService::MaxPayload(
     core::PropertyBuilder::createProperty("Max Payload")->withDescription("Maximum payload for these network controllers")->isRequired(true)->withDefaultValue<core::DataSizeValue>("1 GB")->build());
 
-core::Property NetworkPrioritizerService::VerifyInterfaces(
+const core::Property NetworkPrioritizerService::VerifyInterfaces(
     core::PropertyBuilder::createProperty("Verify Interfaces")->withDescription("Verify that interfaces are operational")->isRequired(true)->withDefaultValue<bool>(true)->build());
 
-core::Property NetworkPrioritizerService::DefaultPrioritizer(
+const core::Property NetworkPrioritizerService::DefaultPrioritizer(
     core::PropertyBuilder::createProperty("Default Prioritizer")->withDescription("Sets this controller service as the default prioritizer for all comms")->isRequired(false)->withDefaultValue<bool>(
         false)->build());
 
 void NetworkPrioritizerService::initialize() {
-  std::set<core::Property> supportedProperties;
-  supportedProperties.insert(NetworkControllers);
-  supportedProperties.insert(MaxThroughput);
-  supportedProperties.insert(MaxPayload);
-  supportedProperties.insert(VerifyInterfaces);
-  supportedProperties.insert(DefaultPrioritizer);
-  setSupportedProperties(supportedProperties);
+  setSupportedProperties(properties());
 }
 
 void NetworkPrioritizerService::yield() {
@@ -83,7 +72,7 @@ void NetworkPrioritizerService::yield() {
  */
 io::NetworkInterface NetworkPrioritizerService::getInterface(uint32_t size = 0) {
   std::vector<std::string> controllers;
-  std::string ifc = "";
+  std::string ifc;
   if (!network_controllers_.empty()) {
     if (sufficient_tokens(size) && size <= max_payload_) {
       controllers.insert(std::end(controllers), std::begin(network_controllers_), std::end(network_controllers_));
@@ -98,8 +87,8 @@ io::NetworkInterface NetworkPrioritizerService::getInterface(uint32_t size = 0)
       return newifc;
     }
   }
-  for (size_t i = 0; i < linked_services_.size(); i++) {
-    auto np = std::dynamic_pointer_cast<NetworkPrioritizerService>(linked_services_.at(i));
+  for (const auto& service : linked_services_) {
+    auto np = std::dynamic_pointer_cast<NetworkPrioritizerService>(service);
     if (np != nullptr) {
       auto ifcs = np->getInterfaces(size);
       ifc = get_nearest_interface(ifcs);
@@ -164,11 +153,7 @@ bool NetworkPrioritizerService::sufficient_tokens(uint32_t size) {
     tokens_ += gsl::narrow<uint32_t>(diff * tokens_per_ms);
   }
   if (bytes_per_token_ > 0 && size > 0) {
-    if (tokens_ * bytes_per_token_ >= size) {
-      return true;
-    } else {
-      return false;
-    }
+    return tokens_ * bytes_per_token_ >= size;
   }
   return true;
 }
@@ -215,7 +200,7 @@ void NetworkPrioritizerService::onEnable() {
     if (getProperty(DefaultPrioritizer.getName(), is_default)) {
       if (is_default) {
         if (io::NetworkPrioritizerFactory::getInstance()->setPrioritizer(shared_from_this()) < 0) {
-          std::runtime_error("Can only have one prioritizer");
+          throw std::runtime_error("Can only have one prioritizer");
         }
       }
     }
@@ -228,10 +213,6 @@ void NetworkPrioritizerService::onEnable() {
   }
 }
 
-REGISTER_RESOURCE(NetworkPrioritizerService, "Enables selection of networking interfaces on defined parameters to include ouput and payload size");
+REGISTER_RESOURCE(NetworkPrioritizerService, ControllerService);
 
-} /* namespace controllers */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::controllers
