@@ -23,21 +23,17 @@
 #include "core/logging/LoggerConfiguration.h"
 #include "core/Relationship.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
+namespace org::apache::nifi::minifi::core {
 
-Connectable::Connectable(const std::string &name, const utils::Identifier &uuid)
-    : CoreComponent(name, uuid),
+Connectable::Connectable(std::string name, const utils::Identifier &uuid)
+    : CoreComponent(std::move(name), uuid),
       max_concurrent_tasks_(1),
       connectable_version_(nullptr),
       logger_(logging::LoggerFactory<Connectable>::getLogger()) {
 }
 
-Connectable::Connectable(const std::string &name)
-    : CoreComponent(name),
+Connectable::Connectable(std::string name)
+    : CoreComponent(std::move(name)),
       max_concurrent_tasks_(1),
       connectable_version_(nullptr),
       logger_(logging::LoggerFactory<Connectable>::getLogger()) {
@@ -45,20 +41,19 @@ Connectable::Connectable(const std::string &name)
 
 Connectable::~Connectable() = default;
 
-bool Connectable::setSupportedRelationships(const std::set<core::Relationship> &relationships) {
+void Connectable::setSupportedRelationships(gsl::span<const core::Relationship> relationships) {
   if (isRunning()) {
     logger_->log_warn("Can not set processor supported relationship while the process %s is running", name_);
-    return false;
+    return;
   }
 
   std::lock_guard<std::mutex> lock(relationship_mutex_);
 
   relationships_.clear();
-  for (auto item : relationships) {
+  for (const auto& item : relationships) {
     relationships_[item.getName()] = item;
     logger_->log_debug("Processor %s supported relationship name %s", name_, item.getName());
   }
-  return true;
 }
 
 std::vector<Relationship> Connectable::getSupportedRelationships() const {
@@ -69,7 +64,6 @@ std::vector<Relationship> Connectable::getSupportedRelationships() const {
   return relationships;
 }
 
-// Whether the relationship is supported
 bool Connectable::isSupportedRelationship(const core::Relationship &relationship) {
   // if we are running we do not need a lock since the function to change relationships_ ( setSupportedRelationships)
   // cannot be executed while we are running
@@ -77,31 +71,24 @@ bool Connectable::isSupportedRelationship(const core::Relationship &relationship
 
   const auto conditionalLock = isConnectableRunning ? std::unique_lock<std::mutex>() : std::unique_lock<std::mutex>(relationship_mutex_);
 
-  const auto &it = relationships_.find(relationship.getName());
-  if (it != relationships_.end()) {
-    return true;
-  } else {
-    return false;
-  }
+  return relationships_.contains(relationship.getName());
 }
 
-bool Connectable::setAutoTerminatedRelationships(const std::set<Relationship> &relationships) {
+void Connectable::setAutoTerminatedRelationships(gsl::span<const core::Relationship> relationships) {
   if (isRunning()) {
     logger_->log_warn("Can not set processor auto terminated relationship while the process %s is running", name_);
-    return false;
+    return;
   }
 
   std::lock_guard<std::mutex> lock(relationship_mutex_);
 
   auto_terminated_relationships_.clear();
-  for (auto item : relationships) {
+  for (const auto& item : relationships) {
     auto_terminated_relationships_[item.getName()] = item;
     logger_->log_debug("Processor %s auto terminated relationship name %s", name_, item.getName());
   }
-  return true;
 }
 
-// Check whether the relationship is auto terminated
 bool Connectable::isAutoTerminated(const core::Relationship &relationship) {
   // if we are running we do not need a lock since the function to change relationships_ ( setSupportedRelationships)
   // cannot be executed while we are running
@@ -109,20 +96,15 @@ bool Connectable::isAutoTerminated(const core::Relationship &relationship) {
 
   const auto conditionalLock = isConnectableRunning ? std::unique_lock<std::mutex>() : std::unique_lock<std::mutex>(relationship_mutex_);
 
-  const auto &it = auto_terminated_relationships_.find(relationship.getName());
-  if (it != auto_terminated_relationships_.end()) {
-    return true;
-  } else {
-    return false;
-  }
+  return auto_terminated_relationships_.contains(relationship.getName());
 }
 
-void Connectable::waitForWork(uint64_t timeoutMs) {
+void Connectable::waitForWork(std::chrono::milliseconds timeout) {
   has_work_.store(isWorkAvailable());
 
   if (!has_work_.load()) {
     std::unique_lock<std::mutex> lock(work_available_mutex_);
-    work_condition_.wait_for(lock, std::chrono::milliseconds(timeoutMs), [&] {return has_work_.load();});
+    work_condition_.wait_for(lock, timeout, [&] {return has_work_.load();});
   }
 }
 
@@ -175,8 +157,4 @@ Connectable* Connectable::pickIncomingConnection() {
   return getNextIncomingConnection();
 }
 
-} /* namespace core */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::core
