@@ -54,14 +54,10 @@ int getpagesize(void) {
 }
 #endif
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
+namespace org::apache::nifi::minifi::core {
 
 std::string detail::to_string(const detail::ReadBufferResult& read_buffer_result) {
-  return std::string(reinterpret_cast<const char*>(read_buffer_result.buffer.data()), read_buffer_result.buffer.size());
+  return {reinterpret_cast<const char*>(read_buffer_result.buffer.data()), read_buffer_result.buffer.size()};
 }
 
 std::shared_ptr<utils::IdGenerator> ProcessSession::id_generator_ = utils::IdGenerator::getIdGenerator();
@@ -89,10 +85,10 @@ ProcessSession::~ProcessSession() {
 
 void ProcessSession::add(const std::shared_ptr<core::FlowFile> &record) {
   utils::Identifier uuid = record->getUUID();
-  if (_updatedFlowFiles.find(uuid) != _updatedFlowFiles.end()) {
+  if (updated_flowfiles_.find(uuid) != updated_flowfiles_.end()) {
     throw Exception(ExceptionType::PROCESSOR_EXCEPTION, "Mustn't add file that was provided by this session");
   }
-  _addedFlowFiles[uuid] = record;
+  added_flowfiles_[uuid].flow_file = record;
   record->setDeleted(false);
 }
 
@@ -118,7 +114,7 @@ std::shared_ptr<core::FlowFile> ProcessSession::create(const std::shared_ptr<cor
   }
 
   utils::Identifier uuid = record->getUUID();
-  _addedFlowFiles[uuid] = record;
+  added_flowfiles_[uuid].flow_file = record;
   logger_->log_debug("Create FlowFile with UUID %s", record->getUUIDStr());
   std::stringstream details;
   details << process_context_->getProcessorNode()->getName() << " creates flow record " << record->getUUIDStr();
@@ -150,7 +146,7 @@ std::shared_ptr<core::FlowFile> ProcessSession::cloneDuringTransfer(const std::s
   if (flow_version != nullptr) {
     record->setAttribute(SpecialFlowAttribute::FLOW_ID, flow_version->getFlowId());
   }
-  this->_clonedFlowFiles.push_back(record);
+  this->cloned_flowfiles_.push_back(record);
   logger_->log_debug("Clone FlowFile with UUID %s during transfer", record->getUUIDStr());
   // Copy attributes
   for (const auto& attribute : parent->getAttributes()) {
@@ -200,19 +196,19 @@ std::shared_ptr<core::FlowFile> ProcessSession::clone(const std::shared_ptr<core
 
 void ProcessSession::remove(const std::shared_ptr<core::FlowFile> &flow) {
   flow->setDeleted(true);
-  _deletedFlowFiles.push_back(flow);
+  deleted_flowfiles_.push_back(flow);
   std::string reason = process_context_->getProcessorNode()->getName() + " drop flow record " + flow->getUUIDStr();
   provenance_report_->drop(flow, reason);
 }
 
-void ProcessSession::putAttribute(const std::shared_ptr<core::FlowFile> &flow, std::string key, std::string value) {
+void ProcessSession::putAttribute(const std::shared_ptr<core::FlowFile>& flow, const std::string& key, const std::string& value) {
   flow->setAttribute(key, value);
   std::stringstream details;
   details << process_context_->getProcessorNode()->getName() << " modify flow record " << flow->getUUIDStr() << " attribute " << key << ":" << value;
   provenance_report_->modifyAttributes(flow, details.str());
 }
 
-void ProcessSession::removeAttribute(const std::shared_ptr<core::FlowFile> &flow, std::string key) {
+void ProcessSession::removeAttribute(const std::shared_ptr<core::FlowFile>& flow, const std::string& key) {
   flow->removeAttribute(key);
   std::stringstream details;
   details << process_context_->getProcessorNode()->getName() << " remove flow record " << flow->getUUIDStr() << " attribute " + key;
@@ -225,18 +221,21 @@ void ProcessSession::penalize(const std::shared_ptr<core::FlowFile> &flow) {
   flow->penalize(penalization_period);
 }
 
-void ProcessSession::transfer(const std::shared_ptr<core::FlowFile> &flow, Relationship relationship) {
+void ProcessSession::transfer(const std::shared_ptr<core::FlowFile>& flow, const Relationship& relationship) {
   logging::LOG_INFO(logger_) << "Transferring " << flow->getUUIDStr() << " from " << process_context_->getProcessorNode()->getName() << " to relationship " << relationship.getName();
   utils::Identifier uuid = flow->getUUID();
-  _transferRelationship[uuid] = relationship;
+  if (auto it = added_flowfiles_.find(uuid); it != added_flowfiles_.end()) {
+    it->second.rel = &*relationships_.insert(relationship).first;
+  } else {
+    updated_relationships_[uuid] = &*relationships_.insert(relationship).first;
+  }
   flow->setDeleted(false);
 }
 
 void ProcessSession::write(const std::shared_ptr<core::FlowFile> &flow, const io::OutputStreamCallback& callback) {
-  auto flow_file_equality_checker = [&flow](const auto& flow_file) { return flow == flow_file; };
-  gsl_ExpectsAudit(_updatedFlowFiles.contains(flow->getUUID())
-      || _addedFlowFiles.contains(flow->getUUID())
-      || std::any_of(_clonedFlowFiles.begin(), _clonedFlowFiles.end(), flow_file_equality_checker));
+  gsl_ExpectsAudit(updated_flowfiles_.contains(flow->getUUID())
+      || added_flowfiles_.contains(flow->getUUID())
+      || std::any_of(cloned_flowfiles_.begin(), cloned_flowfiles_.end(), [&flow](const auto& flow_file) { return flow == flow_file; }));
 
   std::shared_ptr<ResourceClaim> claim = content_session_->create();
 
@@ -259,11 +258,11 @@ void ProcessSession::write(const std::shared_ptr<core::FlowFile> &flow, const io
     std::string details = process_context_->getProcessorNode()->getName() + " modify flow record content " + flow->getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
     provenance_report_->modifyContent(flow, details, duration);
-  } catch (std::exception &exception) {
-    logger_->log_debug("Caught Exception %s", exception.what());
+  } catch (const std::exception& exception) {
+    logger_->log_debug("Caught Exception during process session write, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
-    logger_->log_debug("Caught Exception during process session write");
+    logger_->log_debug("Caught Exception during process session write, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
@@ -272,17 +271,16 @@ void ProcessSession::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_fil
   writeBuffer(flow_file, buffer.as_span<const std::byte>());
 }
 void ProcessSession::writeBuffer(const std::shared_ptr<core::FlowFile>& flow_file, gsl::span<const std::byte> buffer) {
-  write(flow_file, [buffer](const std::shared_ptr<io::BaseStream>& output_stream) {
+  write(flow_file, [buffer](const std::shared_ptr<io::OutputStream>& output_stream) {
     const auto write_status = output_stream->write(buffer);
     return io::isError(write_status) ? -1 : gsl::narrow<int64_t>(write_status);
   });
 }
 
 void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const io::OutputStreamCallback& callback) {
-  auto flow_file_equality_checker = [&flow](const auto& flow_file) { return flow == flow_file; };
-  gsl_ExpectsAudit(_updatedFlowFiles.contains(flow->getUUID())
-      || _addedFlowFiles.contains(flow->getUUID())
-      || std::any_of(_clonedFlowFiles.begin(), _clonedFlowFiles.end(), flow_file_equality_checker));
+  gsl_ExpectsAudit(updated_flowfiles_.contains(flow->getUUID())
+      || added_flowfiles_.contains(flow->getUUID())
+      || std::any_of(cloned_flowfiles_.begin(), cloned_flowfiles_.end(), [&flow](const auto& flow_file) { return flow == flow_file; }));
 
   std::shared_ptr<ResourceClaim> claim = flow->getResourceClaim();
   if (!claim) {
@@ -292,7 +290,7 @@ void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const i
 
   try {
     auto start_time = std::chrono::steady_clock::now();
-    std::shared_ptr<io::BaseStream> stream = content_session_->write(claim, ContentSession::WriteMode::APPEND);
+    std::shared_ptr<io::BaseStream> stream = content_session_->append(claim);
     if (nullptr == stream) {
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to open flowfile content for append");
     }
@@ -302,7 +300,7 @@ void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const i
     size_t stream_size_before_callback = stream->size();
     // this prevents an issue if we write, above, with zero length.
     if (stream_size_before_callback > 0)
-      stream->seek(stream_size_before_callback + 1);
+      stream->seek(stream_size_before_callback);
     if (callback(stream) < 0) {
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to process flowfile content");
     }
@@ -312,11 +310,11 @@ void ProcessSession::append(const std::shared_ptr<core::FlowFile> &flow, const i
     details << process_context_->getProcessorNode()->getName() << " modify flow record content " << flow->getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
     provenance_report_->modifyContent(flow, details.str(), duration);
-  } catch (std::exception &exception) {
-    logger_->log_debug("Caught Exception %s", exception.what());
+  } catch (const std::exception& exception) {
+    logger_->log_debug("Caught Exception during process session append, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
-    logger_->log_debug("Caught Exception during process session append");
+    logger_->log_debug("Caught Exception during process session append, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
@@ -324,40 +322,43 @@ void ProcessSession::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_fi
   appendBuffer(flow_file, buffer.as_span<const std::byte>());
 }
 void ProcessSession::appendBuffer(const std::shared_ptr<core::FlowFile>& flow_file, gsl::span<const std::byte> buffer) {
-  append(flow_file, [buffer](const std::shared_ptr<io::BaseStream>& output_stream) {
+  append(flow_file, [buffer](const std::shared_ptr<io::OutputStream>& output_stream) {
     const auto write_status = output_stream->write(buffer);
     return io::isError(write_status) ? -1 : gsl::narrow<int64_t>(write_status);
   });
 }
 
+std::shared_ptr<io::InputStream> ProcessSession::getFlowFileContentStream(const std::shared_ptr<core::FlowFile>& flow_file) {
+  if (flow_file->getResourceClaim() == nullptr) {
+    logger_->log_debug("For %s, no resource claim but size is %d", flow_file->getUUIDStr(), flow_file->getSize());
+    if (flow_file->getSize() == 0) {
+      return {};
+    }
+    throw Exception(FILE_OPERATION_EXCEPTION, "No Content Claim existed for read");
+  }
+
+  std::shared_ptr<ResourceClaim> claim = flow_file->getResourceClaim();
+  std::shared_ptr<io::InputStream> stream = content_session_->read(claim);
+  if (nullptr == stream) {
+    throw Exception(FILE_OPERATION_EXCEPTION, "Failed to open flowfile content for read");
+  }
+
+  return std::make_shared<io::StreamSlice>(stream, flow_file->getOffset(), flow_file->getSize());
+}
+
 int64_t ProcessSession::read(const std::shared_ptr<core::FlowFile> &flow, const io::InputStreamCallback& callback) {
   try {
-    std::shared_ptr<ResourceClaim> claim = nullptr;
-
-    if (flow->getResourceClaim() == nullptr) {
-      // No existed claim for read, we throw exception
-      logger_->log_debug("For %s, no resource claim but size is %d", flow->getUUIDStr(), flow->getSize());
-      if (flow->getSize() == 0) {
-        return 0;
-      }
-      throw Exception(FILE_OPERATION_EXCEPTION, "No Content Claim existed for read");
+    auto flow_file_stream = getFlowFileContentStream(flow);
+    if (!flow_file_stream) {
+      return 0;
     }
 
-    claim = flow->getResourceClaim();
-
-    std::shared_ptr<io::BaseStream> stream = content_session_->read(claim);
-
-    if (nullptr == stream) {
-      throw Exception(FILE_OPERATION_EXCEPTION, "Failed to open flowfile content for read");
-    }
-
-    auto flow_file_stream = std::make_shared<io::StreamSlice>(stream, flow->getOffset(), flow->getSize());
     auto ret = callback(flow_file_stream);
     if (ret < 0) {
       throw Exception(FILE_OPERATION_EXCEPTION, "Failed to process flowfile content");
     }
     return ret;
-  } catch (std::exception &exception) {
+  } catch (const std::exception& exception) {
     logger_->log_debug("Caught Exception %s", exception.what());
     throw;
   } catch (...) {
@@ -406,17 +407,17 @@ int64_t ProcessSession::readWrite(const std::shared_ptr<core::FlowFile> &flow, c
 
     return bytes_written;
   } catch (const std::exception& exception) {
-    logger_->log_debug("Caught exception %s during process session readWrite", exception.what());
+    logger_->log_debug("Caught exception during process session readWrite, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
-    logger_->log_debug("Caught unknown exception during process session readWrite");
+    logger_->log_debug("Caught unknown exception during process session readWrite, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
 
 detail::ReadBufferResult ProcessSession::readBuffer(const std::shared_ptr<core::FlowFile>& flow) {
   detail::ReadBufferResult result;
-  result.status = read(flow, [&result, this](const std::shared_ptr<io::BaseStream>& input_stream) {
+  result.status = read(flow, [&result, this](const std::shared_ptr<io::InputStream>& input_stream) {
     result.buffer.resize(input_stream->size());
     const auto read_status = input_stream->read(result.buffer);
     if (read_status != result.buffer.size()) {
@@ -473,11 +474,11 @@ void ProcessSession::importFrom(io::InputStream &stream, const std::shared_ptr<c
     details << process_context_->getProcessorNode()->getName() << " modify flow record content " << flow->getUUIDStr();
     auto duration = std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start_time);
     provenance_report_->modifyContent(flow, details.str(), duration);
-  } catch (std::exception &exception) {
-    logger_->log_debug("Caught Exception %s", exception.what());
+  } catch (const std::exception& exception) {
+    logger_->log_debug("Caught Exception during ProcessSession::importFrom, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
-    logger_->log_debug("Caught Exception during process session write");
+    logger_->log_debug("Caught Exception during ProcessSession::importFrom, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
@@ -545,11 +546,11 @@ void ProcessSession::import(std::string source, const std::shared_ptr<FlowFile>
     } else {
       throw Exception(FILE_OPERATION_EXCEPTION, "File Import Error");
     }
-  } catch (std::exception &exception) {
-    logger_->log_debug("Caught Exception %s", exception.what());
+  } catch (const std::exception& exception) {
+    logger_->log_debug("Caught Exception during ProcessSession::import, type: %s, what: %s", exception.what());
     throw;
   } catch (...) {
-    logger_->log_debug("Caught Exception during process session write");
+    logger_->log_debug("Caught Exception during ProcessSession::import, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
@@ -645,11 +646,11 @@ void ProcessSession::import(const std::string& source, std::vector<std::shared_p
         begin = delimiterPos + 1;
       }
     }
-  } catch (std::exception &exception) {
-    logger_->log_debug("Caught Exception %s", exception.what());
+  } catch (const std::exception& exception) {
+    logger_->log_debug("Caught Exception during ProcessSession::import, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
-    logger_->log_debug("Caught Exception during process session write");
+    logger_->log_debug("Caught Exception during ProcessSession::import, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
@@ -746,16 +747,20 @@ void ProcessSession::restore(const std::string &key, const std::shared_ptr<core:
   flow->clearStashClaim(key);
 }
 
-ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<FlowFile> &record) {
+ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<FlowFile> &record, const std::function<void(const FlowFile&, const Relationship&)>& transfer_callback) {
   if (record->isDeleted()) {
     return RouteResult::Ok_Deleted;
   }
   utils::Identifier uuid = record->getUUID();
-  auto itRelationship = _transferRelationship.find(uuid);
-  if (itRelationship == _transferRelationship.end()) {
+  Relationship relationship;
+  if (auto it = updated_relationships_.find(uuid); it != updated_relationships_.end()) {
+    gsl_Expects(it->second);
+    relationship = *it->second;
+  } else if (auto new_it = added_flowfiles_.find(uuid); new_it != added_flowfiles_.end() && new_it->second.rel) {
+    relationship = *new_it->second.rel;
+  } else {
     return RouteResult::Error_NoRelationship;
   }
-  Relationship relationship = itRelationship->second;
   // Find the relationship, we need to find the connections for that relationship
   const auto connections = process_context_->getProcessorNode()->getOutGoingConnections(relationship.getName());
   if (connections.empty()) {
@@ -767,6 +772,8 @@ ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<
     } else {
       // Autoterminated
       remove(record);
+      transfer_callback(*record, relationship);
+      return RouteResult::Ok_AutoTerminated;
     }
   } else {
     // We connections, clone the flow and assign the connection accordingly
@@ -775,13 +782,16 @@ ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<
       if (itConnection == connections.begin()) {
         // First connection which the flow need be routed to
         record->setConnection(connection);
+        transfer_callback(*record, relationship);
       } else {
         // Clone the flow file and route to the connection
         std::shared_ptr<core::FlowFile> cloneRecord = this->cloneDuringTransfer(record);
-        if (cloneRecord)
+        if (cloneRecord) {
           cloneRecord->setConnection(connection);
-        else
+          transfer_callback(*cloneRecord, relationship);
+        } else {
           throw Exception(PROCESS_SESSION_EXCEPTION, "Can not clone the flow for transfer " + record->getUUIDStr());
+        }
       }
     }
   }
@@ -790,19 +800,24 @@ ProcessSession::RouteResult ProcessSession::routeFlowFile(const std::shared_ptr<
 
 void ProcessSession::commit() {
   try {
+    std::unordered_map<std::string, TransferMetrics> transfers;
+      auto increaseTransferMetrics = [&](const FlowFile& record, const Relationship& relationship) {
+      ++transfers[relationship.getName()].transfer_count;
+      transfers[relationship.getName()].transfer_size += record.getSize();
+    };
     // First we clone the flow record based on the transferred relationship for updated flow record
-    for (auto && it : _updatedFlowFiles) {
+    for (auto && it : updated_flowfiles_) {
       auto record = it.second.modified;
-      if (routeFlowFile(record) == RouteResult::Error_NoRelationship) {
+      if (routeFlowFile(record, increaseTransferMetrics) == RouteResult::Error_NoRelationship) {
         // Can not find relationship for the flow
         throw Exception(PROCESS_SESSION_EXCEPTION, "Can not find the transfer relationship for the updated flow " + record->getUUIDStr());
       }
     }
 
     // Do the same thing for added flow file
-    for (const auto& it : _addedFlowFiles) {
-      auto record = it.second;
-      if (routeFlowFile(record) == RouteResult::Error_NoRelationship) {
+    for (const auto& it : added_flowfiles_) {
+      auto record = it.second.flow_file;
+      if (routeFlowFile(record, increaseTransferMetrics) == RouteResult::Error_NoRelationship) {
         // Can not find relationship for the flow
         throw Exception(PROCESS_SESSION_EXCEPTION, "Can not find the transfer relationship for the added flow " + record->getUUIDStr());
       }
@@ -812,9 +827,9 @@ void ProcessSession::commit() {
 
     Connectable* connection = nullptr;
     // Complete process the added and update flow files for the session, send the flow file to its queue
-    for (const auto &it : _updatedFlowFiles) {
+    for (const auto &it : updated_flowfiles_) {
       auto record = it.second.modified;
-      logger_->log_trace("See %s in %s", record->getUUIDStr(), "_updatedFlowFiles");
+      logger_->log_trace("See %s in %s", record->getUUIDStr(), "updated_flowfiles_");
       if (record->isDeleted()) {
         continue;
       }
@@ -824,9 +839,9 @@ void ProcessSession::commit() {
         connectionQueues[connection].push_back(record);
       }
     }
-    for (const auto &it : _addedFlowFiles) {
-      auto record = it.second;
-      logger_->log_trace("See %s in %s", record->getUUIDStr(), "_addedFlowFiles");
+    for (const auto &it : added_flowfiles_) {
+      auto record = it.second.flow_file;
+      logger_->log_trace("See %s in %s", record->getUUIDStr(), "added_flowfiles_");
       if (record->isDeleted()) {
         continue;
       }
@@ -836,8 +851,8 @@ void ProcessSession::commit() {
       }
     }
     // Process the clone flow files
-    for (const auto &record : _clonedFlowFiles) {
-      logger_->log_trace("See %s in %s", record->getUUIDStr(), "_clonedFlowFiles");
+    for (const auto &record : cloned_flowfiles_) {
+      logger_->log_trace("See %s in %s", record->getUUIDStr(), "cloned_flowfiles_");
       if (record->isDeleted()) {
         continue;
       }
@@ -847,7 +862,7 @@ void ProcessSession::commit() {
       }
     }
 
-    for (const auto& record : _deletedFlowFiles) {
+    for (const auto& record : deleted_flowfiles_) {
       if (!record->isDeleted()) {
         continue;
       }
@@ -865,7 +880,7 @@ void ProcessSession::commit() {
       throw Exception(PROCESS_SESSION_EXCEPTION, "State manager commit failed.");
     }
 
-    persistFlowFilesBeforeTransfer(connectionQueues, _updatedFlowFiles);
+    persistFlowFilesBeforeTransfer(connectionQueues, updated_flowfiles_);
 
     for (auto& cq : connectionQueues) {
       auto connection = dynamic_cast<Connection*>(cq.first);
@@ -878,21 +893,30 @@ void ProcessSession::commit() {
       }
     }
 
-    // All done
-    _updatedFlowFiles.clear();
-    _addedFlowFiles.clear();
-    _clonedFlowFiles.clear();
-    _deletedFlowFiles.clear();
+    if (metrics_) {
+      for (const auto& [relationship_name, transfer_metrics] : transfers) {
+        metrics_->transferred_bytes += transfer_metrics.transfer_size;
+        metrics_->transferred_flow_files += transfer_metrics.transfer_count;
+        metrics_->increaseRelationshipTransferCount(relationship_name, transfer_metrics.transfer_count);
+      }
+    }
 
-    _transferRelationship.clear();
+    // All done
+    updated_flowfiles_.clear();
+    added_flowfiles_.clear();
+    cloned_flowfiles_.clear();
+    deleted_flowfiles_.clear();
+
+    updated_relationships_.clear();
+    relationships_.clear();
     // persistent the provenance report
     this->provenance_report_->commit();
     logger_->log_trace("ProcessSession committed for %s", process_context_->getProcessorNode()->getName());
-  } catch (std::exception &exception) {
-    logger_->log_debug("Caught Exception %s", exception.what());
+  } catch (const std::exception& exception) {
+    logger_->log_debug("Caught Exception during process session commit, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
-    logger_->log_debug("Caught Exception during process session commit");
+    logger_->log_debug("Caught Exception during process session commit, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
@@ -904,7 +928,7 @@ void ProcessSession::rollback() {
 
   try {
     // Requeue the snapshot of the flowfile back
-    for (const auto &it : _updatedFlowFiles) {
+    for (const auto &it : updated_flowfiles_) {
       auto flowFile = it.second.modified;
       // restore flowFile to original state
       *flowFile = *it.second.snapshot;
@@ -916,7 +940,7 @@ void ProcessSession::rollback() {
       connectionQueues[flowFile->getConnection()].push_back(flowFile);
     }
 
-    for (const auto& record : _deletedFlowFiles) {
+    for (const auto& record : deleted_flowfiles_) {
       record->setDeleted(false);
     }
 
@@ -938,16 +962,17 @@ void ProcessSession::rollback() {
       throw Exception(PROCESS_SESSION_EXCEPTION, "State manager rollback failed.");
     }
 
-    _clonedFlowFiles.clear();
-    _addedFlowFiles.clear();
-    _updatedFlowFiles.clear();
-    _deletedFlowFiles.clear();
+    cloned_flowfiles_.clear();
+    added_flowfiles_.clear();
+    updated_flowfiles_.clear();
+    deleted_flowfiles_.clear();
+    relationships_.clear();
     logger_->log_warn("ProcessSession rollback for %s executed", process_context_->getProcessorNode()->getName());
-  } catch (std::exception &exception) {
-    logger_->log_warn("Caught Exception during process session rollback: %s", exception.what());
+  } catch (const std::exception& exception) {
+    logger_->log_warn("Caught Exception during process session rollback, type: %s, what: %s", typeid(exception).name(), exception.what());
     throw;
   } catch (...) {
-    logger_->log_warn("Caught Exception during process session rollback");
+    logger_->log_warn("Caught Exception during process session rollback, type: %s", getCurrentExceptionTypeName());
     throw;
   }
 }
@@ -961,54 +986,72 @@ void ProcessSession::persistFlowFilesBeforeTransfer(
   auto flowFileRepo = process_context_->getFlowFileRepository();
   auto contentRepo = process_context_->getContentRepository();
 
-  for (auto& [target, flows] : transactionMap) {
-    const auto connection = dynamic_cast<Connection*>(target);
-    const bool shouldDropEmptyFiles = connection && connection->getDropEmptyFlowFiles();
-    for (auto &ff : flows) {
-      if (shouldDropEmptyFiles && ff->getSize() == 0) {
-        // the receiver will drop this FF
-        continue;
+  enum class Type {
+    Dropped, Transferred
+  };
+
+  auto forEachFlowFile = [&] (Type type, auto fn) {
+    for (auto& [target, flows] : transactionMap) {
+      const auto connection = dynamic_cast<Connection*>(target);
+      const bool shouldDropEmptyFiles = connection && connection->getDropEmptyFlowFiles();
+      for (auto &ff : flows) {
+        auto snapshotIt = modifiedFlowFiles.find(ff->getUUID());
+        auto original = snapshotIt != modifiedFlowFiles.end() ? snapshotIt->second.snapshot : nullptr;
+        if (shouldDropEmptyFiles && ff->getSize() == 0) {
+          // the receiver will drop this FF
+          if (type == Type::Dropped) {
+            fn(ff, original);
+          }
+        } else {
+          if (type == Type::Transferred) {
+            fn(ff, original);
+          }
+        }
       }
-
-      std::unique_ptr<io::BufferStream> stream(new io::BufferStream());
-      std::static_pointer_cast<FlowFileRecord>(ff)->Serialize(*stream);
-
-      flowData.emplace_back(ff->getUUIDStr(), std::move(stream));
     }
-  }
+  };
+
+  // collect serialized flowfiles
+  forEachFlowFile(Type::Transferred, [&] (auto& ff, auto& /*original*/) {
+    auto stream = std::make_unique<io::BufferStream>();
+    std::static_pointer_cast<FlowFileRecord>(ff)->Serialize(*stream);
+
+    flowData.emplace_back(ff->getUUIDStr(), std::move(stream));
+  });
+
+  // increment on behalf of the to be persisted instance
+  forEachFlowFile(Type::Transferred, [&] (auto& ff, auto& /*original*/) {
+    if (auto claim = ff->getResourceClaim())
+      claim->increaseFlowFileRecordOwnedCount();
+  });
 
   if (!flowFileRepo->MultiPut(flowData)) {
     logger_->log_error("Failed execute multiput on FF repo!");
+    // decrement on behalf of the failed persisted instance
+    forEachFlowFile(Type::Transferred, [&] (auto& ff, auto& /*original*/) {
+      if (auto claim = ff->getResourceClaim())
+        claim->decreaseFlowFileRecordOwnedCount();
+    });
     throw Exception(PROCESS_SESSION_EXCEPTION, "Failed to put flowfiles to repository");
   }
 
-  for (auto& [target, flows] : transactionMap) {
-    const auto connection = dynamic_cast<Connection*>(target);
-    const bool shouldDropEmptyFiles = connection && connection->getDropEmptyFlowFiles();
-    for (auto &ff : flows) {
-      utils::Identifier uuid = ff->getUUID();
-      auto snapshotIt = modifiedFlowFiles.find(uuid);
-      auto original = snapshotIt != modifiedFlowFiles.end() ? snapshotIt->second.snapshot : nullptr;
-      if (shouldDropEmptyFiles && ff->getSize() == 0) {
-        // the receiver promised to drop this FF, no need for it anymore
-        if (ff->isStored() && flowFileRepo->Delete(ff->getUUIDStr())) {
-          // original must be non-null since this flowFile is already stored in the repos ->
-          // must have come from a session->get()
-          assert(original);
-          ff->setStoredToRepository(false);
-        }
-        continue;
-      }
-      auto claim = ff->getResourceClaim();
-      // increment on behalf of the persisted instance
-      if (claim) claim->increaseFlowFileRecordOwnedCount();
-      auto originalClaim = original ? original->getResourceClaim() : nullptr;
-      // decrement on behalf of the overridden instance if any
-      if (originalClaim) originalClaim->decreaseFlowFileRecordOwnedCount();
-
-      ff->setStoredToRepository(true);
+  // decrement on behalf of the overridden instance if any
+  forEachFlowFile(Type::Transferred, [&] (auto& ff, auto& original) {
+    if (auto original_claim = original ? original->getResourceClaim() : nullptr) {
+      original_claim->decreaseFlowFileRecordOwnedCount();
     }
-  }
+    ff->setStoredToRepository(true);
+  });
+
+  forEachFlowFile(Type::Dropped, [&] (auto& ff, auto& original) {
+    // the receiver promised to drop this FF, no need for it anymore
+    if (ff->isStored() && flowFileRepo->Delete(ff->getUUIDStr())) {
+      // original must be non-null since this flowFile is already stored in the repos ->
+      // must have come from a session->get()
+      gsl_Assert(original);
+      ff->setStoredToRepository(false);
+    }
+  });
 }
 
 void ProcessSession::ensureNonNullResourceClaim(
@@ -1064,7 +1107,7 @@ std::shared_ptr<core::FlowFile> ProcessSession::get() {
       *snapshot = *ret;
       logger_->log_debug("Create Snapshot FlowFile with UUID %s", snapshot->getUUIDStr());
       utils::Identifier uuid = ret->getUUID();
-      _updatedFlowFiles[uuid] = {ret, snapshot};
+      updated_flowfiles_[uuid] = {ret, snapshot};
       auto flow_version = process_context_->getProcessorNode()->getFlowIdentifier();
       if (flow_version != nullptr) {
         ret->setAttribute(SpecialFlowAttribute::FLOW_ID, flow_version->getFlowId());
@@ -1094,14 +1137,13 @@ bool ProcessSession::outgoingConnectionsFull(const std::string& relationship) {
 }
 
 bool ProcessSession::existsFlowFileInRelationship(const Relationship &relationship) {
-  return std::any_of(_transferRelationship.begin(), _transferRelationship.end(),
-      [&relationship](const std::map<utils::Identifier, Relationship>::value_type &key_value_pair) {
-        return relationship == key_value_pair.second;
+  return std::any_of(updated_relationships_.begin(), updated_relationships_.end(),
+      [&](const auto& key_value_pair) {
+        return key_value_pair.second && relationship == *key_value_pair.second;
+  }) || std::any_of(added_flowfiles_.begin(), added_flowfiles_.end(),
+      [&](const auto& key_value_pair) {
+        return key_value_pair.second.rel && relationship == *key_value_pair.second.rel;
   });
 }
 
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::core
