@@ -19,7 +19,8 @@
  */
 #include "core/Processor.h"
 
-#include <time.h>
+#include <ctime>
+#include <cctype>
 
 #include <memory>
 #include <set>
@@ -34,19 +35,16 @@
 #include "core/ProcessSessionFactory.h"
 #include "io/StreamFactory.h"
 #include "utils/gsl.h"
+#include "range/v3/algorithm/any_of.hpp"
 
 using namespace std::literals::chrono_literals;
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
+namespace org::apache::nifi::minifi::core {
 
-Processor::Processor(const std::string& name)
-    : Connectable(name),
-      ConfigurableComponent(),
-      logger_(logging::LoggerFactory<Processor>::getLogger()) {
+Processor::Processor(std::string name, std::shared_ptr<ProcessorMetrics> metrics)
+    : Connectable(std::move(name)),
+      logger_(logging::LoggerFactory<Processor>::getLogger()),
+      metrics_(metrics ? std::move(metrics) : std::make_shared<ProcessorMetrics>(*this)) {
   has_work_.store(false);
   // Setup the default values
   state_ = DISABLED;
@@ -62,10 +60,10 @@ Processor::Processor(const std::string& name)
   logger_->log_debug("Processor %s created UUID %s", name_, getUUIDStr());
 }
 
-Processor::Processor(const std::string& name, const utils::Identifier& uuid)
-    : Connectable(name, uuid),
-      ConfigurableComponent(),
-      logger_(logging::LoggerFactory<Processor>::getLogger()) {
+Processor::Processor(std::string name, const utils::Identifier& uuid, std::shared_ptr<ProcessorMetrics> metrics)
+    : Connectable(std::move(name), uuid),
+      logger_(logging::LoggerFactory<Processor>::getLogger()),
+      metrics_(metrics ? std::move(metrics) : std::make_shared<ProcessorMetrics>(*this)) {
   has_work_.store(false);
   // Setup the default values
   state_ = DISABLED;
@@ -81,6 +79,10 @@ Processor::Processor(const std::string& name, const utils::Identifier& uuid)
   logger_->log_debug("Processor %s created with uuid %s", name_, getUUIDStr());
 }
 
+Processor::~Processor() {
+  logger_->log_debug("Destroying processor %s with uuid %s", name_, getUUIDStr());
+}
+
 bool Processor::isRunning() {
   return (state_ == RUNNING && active_tasks_ > 0);
 }
@@ -179,13 +181,17 @@ bool Processor::flowFilesOutGoingFull() const {
 }
 
 void Processor::onTrigger(ProcessContext *context, ProcessSessionFactory *sessionFactory) {
+  ++metrics_->iterations;
   auto session = sessionFactory->createSession();
+  session->setMetrics(metrics_);
 
   try {
     // Call the virtual trigger function
+    const auto start = std::chrono::steady_clock::now();
     onTrigger(context, session.get());
+    metrics_->addLastOnTriggerRuntime(std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start));
     session->commit();
-  } catch (std::exception &exception) {
+  } catch (const std::exception& exception) {
     logger_->log_warn("Caught \"%s\" (%s) during Processor::onTrigger of processor: %s (%s)",
         exception.what(), typeid(exception).name(), getUUIDStr(), getName());
     session->rollback();
@@ -198,11 +204,15 @@ void Processor::onTrigger(ProcessContext *context, ProcessSessionFactory *sessio
 }
 
 void Processor::onTrigger(const std::shared_ptr<ProcessContext> &context, const std::shared_ptr<ProcessSessionFactory> &sessionFactory) {
+  ++metrics_->iterations;
   auto session = sessionFactory->createSession();
+  session->setMetrics(metrics_);
 
   try {
     // Call the virtual trigger function
+    const auto start = std::chrono::steady_clock::now();
     onTrigger(context, session);
+    metrics_->addLastOnTriggerRuntime(std::chrono::duration_cast<std::chrono::milliseconds>(std::chrono::steady_clock::now() - start));
     session->commit();
   } catch (std::exception &exception) {
     logger_->log_warn("Caught \"%s\" (%s) during Processor::onTrigger of processor: %s (%s)",
@@ -233,8 +243,9 @@ bool Processor::isWorkAvailable() {
       }
     }
   } catch (...) {
-    logger_->log_error("Caught an exception while checking if work is available;"
-                       " unless it was positively determined that work is available, assuming NO work is available!");
+    logger_->log_error("Caught an exception (type: %s) while checking if work is available;"
+        " unless it was positively determined that work is available, assuming NO work is available!",
+        getCurrentExceptionTypeName());
   }
 
   return hasWork;
@@ -294,32 +305,16 @@ bool Processor::partOfCycle(Connection* conn) {
 }
 
 bool Processor::isThrottledByBackpressure() const {
-  bool isThrottledByOutgoing = ([&] {
-    for (auto &outIt : outgoing_connections_) {
-      for (auto &out : outIt.second) {
-        auto connection = dynamic_cast<Connection*>(out);
-        if (!connection) {
-          continue;
-        }
-        if (connection->isFull()) {
-          return true;
-        }
-      }
-    }
-    return false;
-  })();
-  bool isForcedByIncomingCycle = ([&] {
-    for (auto &inConn : incoming_connections_) {
-      auto connection = dynamic_cast<Connection*>(inConn);
-      if (!connection) {
-        continue;
-      }
-      if (partOfCycle(connection) && connection->isFull()) {
-        return true;
-      }
-    }
-    return false;
-  })();
+  bool isThrottledByOutgoing = ranges::any_of(outgoing_connections_, [](auto& name_connection_set_pair) {
+    return ranges::any_of(name_connection_set_pair.second, [](auto& connectable) {
+      auto connection = dynamic_cast<Connection*>(connectable);
+      return connection && connection->isFull();
+    });
+  });
+  bool isForcedByIncomingCycle = ranges::any_of(incoming_connections_, [](auto& connectable) {
+    auto connection = dynamic_cast<Connection*>(connectable);
+    return connection && partOfCycle(connection) && connection->isFull();
+  });
   return isThrottledByOutgoing && !isForcedByIncomingCycle;
 }
 
@@ -361,19 +356,6 @@ void Processor::validateAnnotations() const {
   }
 }
 
-std::string Processor::getInputRequirementAsString() const {
-  switch (getInputRequirement()) {
-    case annotation::Input::INPUT_REQUIRED:
-      return "INPUT_REQUIRED";
-    case annotation::Input::INPUT_ALLOWED:
-      return "INPUT_ALLOWED";
-    case annotation::Input::INPUT_FORBIDDEN:
-      return "INPUT_FORBIDDEN";
-  }
-
-  return "ERROR_no_such_input_requirement";
-}
-
 void Processor::setMaxConcurrentTasks(const uint8_t tasks) {
   if (isSingleThreaded() && tasks > 1) {
     logger_->log_warn("Processor %s can not be run in parallel, its \"max concurrent tasks\" value is too high. "
@@ -410,8 +392,4 @@ std::chrono::milliseconds Processor::getYieldTime() const {
     return 0ms;
 }
 
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::core
