@@ -18,15 +18,10 @@
 #include "core/ProcessorNode.h"
 #include <memory>
 #include <utility>
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
+namespace org::apache::nifi::minifi::core {
 
 ProcessorNode::ProcessorNode(Connectable* processor)
-    : ConfigurableComponent(),
-      Connectable(processor->getName()),
+    : Connectable(processor->getName()),
       processor_(processor) {
   setUUID(processor->getUUID());
 }
@@ -41,8 +36,4 @@ bool ProcessorNode::isRunning() {
   return processor_->isRunning();
 }
 
-} /* namespace core */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::core
