@@ -27,16 +27,13 @@
 #include "core/state/Value.h"
 #include "Defaults.h"
 #include "utils/TimeUtil.h"
+#include "Funnel.h"
 
 #ifdef YAML_CONFIGURATION_USE_REGEX
 #include "utils/RegexUtils.h"
 #endif  // YAML_CONFIGURATION_USE_REGEX
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
+namespace org::apache::nifi::minifi::core {
 
 std::shared_ptr<utils::IdGenerator> YamlConfiguration::id_generator_ = utils::IdGenerator::getIdGenerator();
 
@@ -60,7 +57,7 @@ std::unique_ptr<core::ProcessGroup> YamlConfiguration::createProcessGroup(const
   int version = 0;
 
   yaml::checkRequiredField(yamlNode, "name", CONFIG_YAML_REMOTE_PROCESS_GROUP_KEY);
-  std::string flowName = yamlNode["name"].as<std::string>();
+  auto flowName = yamlNode["name"].as<std::string>();
 
   utils::Identifier uuid;
   // assignment throws on invalid uuid
@@ -79,7 +76,7 @@ std::unique_ptr<core::ProcessGroup> YamlConfiguration::createProcessGroup(const
   }
 
   if (yamlNode["onschedule retry interval"]) {
-    std::string onScheduleRetryPeriod = yamlNode["onschedule retry interval"].as<std::string>();
+    auto onScheduleRetryPeriod = yamlNode["onschedule retry interval"].as<std::string>();
     logger_->log_debug("parseRootProcessGroup: onschedule retry period => [%s]", onScheduleRetryPeriod);
 
     auto on_schedule_retry_period_value = utils::timeutils::StringToDuration<std::chrono::milliseconds>(onScheduleRetryPeriod);
@@ -97,6 +94,8 @@ std::unique_ptr<core::ProcessGroup> YamlConfiguration::parseProcessGroupYaml(con
   YAML::Node processorsNode = yamlNode[CONFIG_YAML_PROCESSORS_KEY];
   YAML::Node connectionsNode = yamlNode[yaml::YamlConnectionParser::CONFIG_YAML_CONNECTIONS_KEY];
   YAML::Node funnelsNode = yamlNode[CONFIG_YAML_FUNNELS_KEY];
+  YAML::Node inputPortsNode = yamlNode[CONFIG_YAML_INPUT_PORTS_KEY];
+  YAML::Node outputPortsNode = yamlNode[CONFIG_YAML_OUTPUT_PORTS_KEY];
   YAML::Node remoteProcessingGroupsNode = [&] {
     // assignment is not supported on invalid Yaml nodes
     YAML::Node candidate = yamlNode[CONFIG_YAML_REMOTE_PROCESS_GROUP_KEY];
@@ -110,16 +109,19 @@ std::unique_ptr<core::ProcessGroup> YamlConfiguration::parseProcessGroupYaml(con
   parseProcessorNodeYaml(processorsNode, group.get());
   parseRemoteProcessGroupYaml(remoteProcessingGroupsNode, group.get());
   parseFunnelsYaml(funnelsNode, group.get());
-  // parse connections last to give feedback if the source and/or destination
-  // is not in the same process group
-  parseConnectionYaml(connectionsNode, group.get());
+  parsePorts(inputPortsNode, group.get(), PortType::INPUT);
+  parsePorts(outputPortsNode, group.get(), PortType::OUTPUT);
 
   if (childProcessGroupNodeSeq && childProcessGroupNodeSeq.IsSequence()) {
     for (YAML::const_iterator it = childProcessGroupNodeSeq.begin(); it != childProcessGroupNodeSeq.end(); ++it) {
-      YAML::Node childProcessGroupNode = it->as<YAML::Node>();
+      auto childProcessGroupNode = it->as<YAML::Node>();
       group->addProcessGroup(parseProcessGroupYaml(childProcessGroupNode, childProcessGroupNode));
     }
   }
+
+  // parse connections last to give feedback if the source and/or destination processors
+  // is not in the same process group or input/output port connections are not allowed
+  parseConnectionYaml(connectionsNode, group.get());
   return group;
 }
 
@@ -139,6 +141,8 @@ std::unique_ptr<core::ProcessGroup> YamlConfiguration::getYamlRoot(const YAML::N
     root->addControllerService(controller_service->getUUIDStr(), controller_service);
   }
 
+  root->verify();
+
   return root;
 }
 
@@ -168,7 +172,7 @@ void YamlConfiguration::parseProcessorNodeYaml(const YAML::Node& processorsNode,
     procCfg.name = procNode["name"].as<std::string>();
     procCfg.id = getOrGenerateId(procNode);
 
-    uuid = procCfg.id.c_str();
+    uuid = procCfg.id;
     logger_->log_debug("parseProcessorNode: name => [%s] id => [%s]", procCfg.name, procCfg.id);
     yaml::checkRequiredField(procNode, "class", CONFIG_YAML_PROCESSORS_KEY);
     procCfg.javaClass = procNode["class"].as<std::string>();
@@ -231,7 +235,7 @@ void YamlConfiguration::parseProcessorNodeYaml(const YAML::Node& processorsNode,
       std::vector<std::string> rawAutoTerminatedRelationshipValues;
       if (autoTerminatedSequence.IsSequence() && !autoTerminatedSequence.IsNull() && autoTerminatedSequence.size() > 0) {
         for (YAML::const_iterator relIter = autoTerminatedSequence.begin(); relIter != autoTerminatedSequence.end(); ++relIter) {
-          std::string autoTerminatedRel = relIter->as<std::string>();
+          auto autoTerminatedRel = relIter->as<std::string>();
           rawAutoTerminatedRelationshipValues.push_back(autoTerminatedRel);
         }
       }
@@ -290,11 +294,11 @@ void YamlConfiguration::parseProcessorNodeYaml(const YAML::Node& processorsNode,
       processor->setRunDurationNano(std::chrono::nanoseconds(runDurationNanos));
     }
 
-    std::set<core::Relationship> autoTerminatedRelationships;
+    std::vector<core::Relationship> autoTerminatedRelationships;
     for (auto &&relString : procCfg.autoTerminatedRelationships) {
       core::Relationship relationship(relString, "");
       logger_->log_debug("parseProcessorNode: autoTerminatedRelationship  => [%s]", relString);
-      autoTerminatedRelationships.insert(relationship);
+      autoTerminatedRelationships.push_back(relationship);
     }
 
     processor->setAutoTerminatedRelationships(autoTerminatedRelationships);
@@ -316,7 +320,7 @@ void YamlConfiguration::parseRemoteProcessGroupYaml(const YAML::Node& rpgNode, c
     return;
   }
   for (YAML::const_iterator iter = rpgNode.begin(); iter != rpgNode.end(); ++iter) {
-    YAML::Node currRpgNode = iter->as<YAML::Node>();
+    auto currRpgNode = iter->as<YAML::Node>();
 
     yaml::checkRequiredField(currRpgNode, "name", CONFIG_YAML_REMOTE_PROCESS_GROUP_KEY);
     auto name = currRpgNode["name"].as<std::string>();
@@ -327,7 +331,7 @@ void YamlConfiguration::parseRemoteProcessGroupYaml(const YAML::Node& rpgNode, c
     auto urlNode = getOptionalField(currRpgNode, "url", YAML::Node(""),
     CONFIG_YAML_REMOTE_PROCESS_GROUP_KEY);
 
-    std::string url = urlNode.as<std::string>();
+    auto url = urlNode.as<std::string>();
     logger_->log_debug("parseRemoteProcessGroupYaml: url => [%s]", url);
 
     uuid = id;
@@ -335,7 +339,7 @@ void YamlConfiguration::parseRemoteProcessGroupYaml(const YAML::Node& rpgNode, c
     group->setParent(parentGroup);
 
     if (currRpgNode["yield period"]) {
-      std::string yieldPeriod = currRpgNode["yield period"].as<std::string>();
+      auto yieldPeriod = currRpgNode["yield period"].as<std::string>();
       logger_->log_debug("parseRemoteProcessGroupYaml: yield period => [%s]", yieldPeriod);
 
       auto yield_period_value = utils::timeutils::StringToDuration<std::chrono::milliseconds>(yieldPeriod);
@@ -346,7 +350,7 @@ void YamlConfiguration::parseRemoteProcessGroupYaml(const YAML::Node& rpgNode, c
     }
 
     if (currRpgNode["timeout"]) {
-      std::string timeout = currRpgNode["timeout"].as<std::string>();
+      auto timeout = currRpgNode["timeout"].as<std::string>();
       logger_->log_debug("parseRemoteProcessGroupYaml: timeout => [%s]", timeout);
 
       auto timeout_value = utils::timeutils::StringToDuration<std::chrono::milliseconds>(timeout);
@@ -357,32 +361,32 @@ void YamlConfiguration::parseRemoteProcessGroupYaml(const YAML::Node& rpgNode, c
     }
 
     if (currRpgNode["local network interface"]) {
-      std::string interface = currRpgNode["local network interface"].as<std::string>();
+      auto interface = currRpgNode["local network interface"].as<std::string>();
       logger_->log_debug("parseRemoteProcessGroupYaml: local network interface => [%s]", interface);
       group->setInterface(interface);
     }
 
     if (currRpgNode["transport protocol"]) {
-      std::string transport_protocol = currRpgNode["transport protocol"].as<std::string>();
+      auto transport_protocol = currRpgNode["transport protocol"].as<std::string>();
       logger_->log_debug("parseRemoteProcessGroupYaml: transport protocol => [%s]", transport_protocol);
       if (transport_protocol == "HTTP") {
         group->setTransportProtocol(transport_protocol);
         if (currRpgNode["proxy host"]) {
-          std::string http_proxy_host = currRpgNode["proxy host"].as<std::string>();
+          auto http_proxy_host = currRpgNode["proxy host"].as<std::string>();
           logger_->log_debug("parseRemoteProcessGroupYaml: proxy host => [%s]", http_proxy_host);
           group->setHttpProxyHost(http_proxy_host);
           if (currRpgNode["proxy user"]) {
-            std::string http_proxy_username = currRpgNode["proxy user"].as<std::string>();
+            auto http_proxy_username = currRpgNode["proxy user"].as<std::string>();
             logger_->log_debug("parseRemoteProcessGroupYaml: proxy user => [%s]", http_proxy_username);
             group->setHttpProxyUserName(http_proxy_username);
           }
           if (currRpgNode["proxy password"]) {
-            std::string http_proxy_password = currRpgNode["proxy password"].as<std::string>();
+            auto http_proxy_password = currRpgNode["proxy password"].as<std::string>();
             logger_->log_debug("parseRemoteProcessGroupYaml: proxy password => [%s]", http_proxy_password);
             group->setHttpProxyPassWord(http_proxy_password);
           }
           if (currRpgNode["proxy port"]) {
-            std::string http_proxy_port = currRpgNode["proxy port"].as<std::string>();
+            auto http_proxy_port = currRpgNode["proxy port"].as<std::string>();
             int32_t port;
             if (core::Property::StringToInt(http_proxy_port, port)) {
               logger_->log_debug("parseRemoteProcessGroupYaml: proxy port => [%d]", port);
@@ -403,20 +407,20 @@ void YamlConfiguration::parseRemoteProcessGroupYaml(const YAML::Node& rpgNode, c
     group->setURL(url);
 
     yaml::checkRequiredField(currRpgNode, "Input Ports", CONFIG_YAML_REMOTE_PROCESS_GROUP_KEY);
-    YAML::Node inputPorts = currRpgNode["Input Ports"].as<YAML::Node>();
+    auto inputPorts = currRpgNode["Input Ports"].as<YAML::Node>();
     if (inputPorts && inputPorts.IsSequence()) {
       for (YAML::const_iterator portIter = inputPorts.begin(); portIter != inputPorts.end(); ++portIter) {
-        YAML::Node currPort = portIter->as<YAML::Node>();
+        auto currPort = portIter->as<YAML::Node>();
 
         this->parsePortYaml(currPort, group.get(), sitetosite::SEND);
       }  // for node
     }
-    YAML::Node outputPorts = currRpgNode["Output Ports"].as<YAML::Node>();
+    auto outputPorts = currRpgNode["Output Ports"].as<YAML::Node>();
     if (outputPorts && outputPorts.IsSequence()) {
       for (YAML::const_iterator portIter = outputPorts.begin(); portIter != outputPorts.end(); ++portIter) {
         logger_->log_debug("Got a current port, iterating...");
 
-        YAML::Node currPort = portIter->as<YAML::Node>();
+        auto currPort = portIter->as<YAML::Node>();
 
         this->parsePortYaml(currPort, group.get(), sitetosite::RECEIVE);
       }  // for node
@@ -573,6 +577,7 @@ void YamlConfiguration::parseConnectionYaml(const YAML::Node& connectionsNode, c
     connectionParser.configureConnectionSourceRelationshipsFromYaml(*connection);
     connection->setMaxQueueSize(connectionParser.getWorkQueueSizeFromYaml());
     connection->setMaxQueueDataSize(connectionParser.getWorkQueueDataSizeFromYaml());
+    connection->setSwapThreshold(connectionParser.getSwapThresholdFromYaml());
     connection->setSourceUUID(connectionParser.getSourceUUIDFromYaml());
     connection->setDestinationUUID(connectionParser.getDestinationUUIDFromYaml());
     connection->setFlowExpirationDuration(connectionParser.getFlowFileExpirationFromYaml());
@@ -774,7 +779,7 @@ void YamlConfiguration::parseFunnelsYaml(const YAML::Node& node, core::ProcessGr
       throw Exception(ExceptionType::GENERAL_EXCEPTION, "Incorrect funnel UUID format.");
     });
 
-    auto funnel = std::make_unique<core::Funnel>(name, uuid.value());
+    auto funnel = std::make_unique<Funnel>(name, uuid.value());
     logger_->log_debug("Created funnel with UUID %s and name %s", id, name);
     funnel->setScheduledState(core::RUNNING);
     funnel->setSchedulingStrategy(core::EVENT_DRIVEN);
@@ -782,6 +787,36 @@ void YamlConfiguration::parseFunnelsYaml(const YAML::Node& node, core::ProcessGr
   }
 }
 
+void YamlConfiguration::parsePorts(const YAML::Node& node, core::ProcessGroup* parent, PortType port_type) {
+  if (!parent) {
+    logger_->log_error("parsePorts: no parent group was provided");
+    return;
+  }
+  if (!node || !node.IsSequence()) {
+    return;
+  }
+
+  for (const auto& element : node) {
+    const auto port_node = element.as<YAML::Node>();
+
+    std::string id = getOrGenerateId(port_node);
+
+    // Default name to be same as ID
+    const auto name = port_node["name"].as<std::string>(id);
+
+    const auto uuid = utils::Identifier::parse(id) | utils::orElse([this] {
+      logger_->log_debug("Incorrect port UUID format.");
+      throw Exception(ExceptionType::GENERAL_EXCEPTION, "Incorrect port UUID format.");
+    });
+
+    auto port = std::make_unique<Port>(name, uuid.value(), port_type);
+    logger_->log_debug("Created port UUID %s and name %s", id, name);
+    port->setScheduledState(core::RUNNING);
+    port->setSchedulingStrategy(core::EVENT_DRIVEN);
+    parent->addPort(std::move(port));
+  }
+}
+
 void YamlConfiguration::validateComponentProperties(ConfigurableComponent& component, const std::string &component_name, const std::string &yaml_section) const {
   const auto &component_properties = component.getProperties();
 
@@ -867,7 +902,7 @@ void YamlConfiguration::raiseComponentError(const std::string &component_name, c
 
 std::string YamlConfiguration::getOrGenerateId(const YAML::Node& yamlNode, const std::string& idField) {
   std::string id;
-  YAML::Node node = yamlNode.as<YAML::Node>();
+  auto node = yamlNode.as<YAML::Node>();
 
   if (node[idField]) {
     if (YAML::NodeType::Scalar == node[idField].Type()) {
@@ -921,8 +956,4 @@ void YamlConfiguration::addNewId(const std::string& uuid) {
   }
 }
 
-} /* namespace core */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::core
