@@ -18,21 +18,14 @@
 
 #include "core/yaml/YamlConnectionParser.h"
 #include "core/yaml/CheckRequiredField.h"
+#include "Funnel.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace core {
-namespace yaml {
-
-// This is no longer needed in c++17
-constexpr const char* YamlConnectionParser::CONFIG_YAML_CONNECTIONS_KEY;
+namespace org::apache::nifi::minifi::core::yaml {
 
 void YamlConnectionParser::addNewRelationshipToConnection(const std::string& relationship_name, minifi::Connection& connection) const {
   core::Relationship relationship(relationship_name, "");
   logger_->log_debug("parseConnection: relationship => [%s]", relationship_name);
-  connection.addRelationship(std::move(relationship));
+  connection.addRelationship(relationship);
 }
 
 void YamlConnectionParser::addFunnelRelationshipToConnection(minifi::Connection& connection) const {
@@ -49,8 +42,8 @@ void YamlConnectionParser::addFunnelRelationshipToConnection(minifi::Connection&
   }
 
   auto& processor_ref = *processor;
-  if (typeid(minifi::core::Funnel) == typeid(processor_ref)) {
-    addNewRelationshipToConnection(minifi::core::Funnel::Success.getName(), connection);
+  if (typeid(minifi::Funnel) == typeid(processor_ref)) {
+    addNewRelationshipToConnection(minifi::Funnel::Success.getName(), connection);
   }
 }
 
@@ -83,7 +76,7 @@ uint64_t YamlConnectionParser::getWorkQueueSizeFromYaml() const {
       logger_->log_debug("Setting %" PRIu64 " as the max queue size.", max_work_queue_size);
       return max_work_queue_size;
     }
-    logger_->log_info("Invalid max queue size value: %s.", max_work_queue_str);
+    logger_->log_error("Invalid max queue size value: %s.", max_work_queue_str);
   }
   return 0;
 }
@@ -97,7 +90,21 @@ uint64_t YamlConnectionParser::getWorkQueueDataSizeFromYaml() const {
       logger_->log_debug("Setting %" PRIu64 "as the max as the max queue data size.", max_work_queue_data_size);
       return max_work_queue_data_size;
     }
-    logger_->log_info("Invalid max queue data size value: %s.", max_work_queue_str);
+    logger_->log_error("Invalid max queue data size value: %s.", max_work_queue_str);
+  }
+  return 0;
+}
+
+uint64_t YamlConnectionParser::getSwapThresholdFromYaml() const {
+  const YAML::Node swap_threshold_node = connectionNode_["swap threshold"];
+  if (swap_threshold_node) {
+    auto swap_threshold_str = swap_threshold_node.as<std::string>();
+    uint64_t swap_threshold;
+    if (core::Property::StringToInt(swap_threshold_str, swap_threshold)) {
+      logger_->log_debug("Setting %" PRIu64 " as the swap threshold.", swap_threshold);
+      return swap_threshold;
+    }
+    logger_->log_error("Invalid swap threshold value: %s.", swap_threshold_str);
   }
   return 0;
 }
@@ -148,7 +155,7 @@ utils::Identifier YamlConnectionParser::getDestinationUUIDFromYaml() const {
   // we use the same logic as above for resolving the source processor
   // for looking up the destination processor in absence of a processor id
   checkRequiredField(connectionNode_, "destination name", CONFIG_YAML_CONNECTIONS_KEY);
-  std::string connectionDestProcName = connectionNode_["destination name"].as<std::string>();
+  auto connectionDestProcName = connectionNode_["destination name"].as<std::string>();
   const auto destUUID = utils::Identifier::parse(connectionDestProcName);
   if (destUUID && parent_->findProcessorById(destUUID.value(), ProcessGroup::Traverse::ExcludeChildren)) {
     // the destination name is a remote port id, so use that as the dest id
@@ -197,9 +204,4 @@ bool YamlConnectionParser::getDropEmptyFromYaml() const {
   return false;
 }
 
-}  // namespace yaml
-}  // namespace core
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::core::yaml
