@@ -28,8 +28,8 @@ namespace org::apache::nifi::minifi::utils {
 
 namespace views = ranges::views;
 
-std::optional<bool> StringUtils::toBool(const std::string& str) {
-  std::string trimmed = trim(str);
+std::optional<bool> StringUtils::toBool(const std::string& input) {
+  std::string trimmed = trim(input);
   if (equalsIgnoreCase(trimmed, "true")) {
     return true;
   }
@@ -116,7 +116,7 @@ std::vector<std::string> StringUtils::splitAndTrimRemovingEmpty(const std::strin
   return result;
 }
 
-bool StringUtils::StringToFloat(std::string input, float &output, FailurePolicy cp /*= RETURN*/) {
+bool StringUtils::StringToFloat(const std::string& input, float &output, FailurePolicy cp /*= RETURN*/) {
   try {
     output = std::stof(input);
   } catch (const std::invalid_argument &ie) {
@@ -156,7 +156,7 @@ std::string StringUtils::replaceEnvironmentVariables(std::string source_string)
       beg_seq += 2;
       continue;
     }
-    end_seq = source_string.find("}", beg_seq + 2);
+    end_seq = source_string.find('}', beg_seq + 2);
     if (end_seq == std::string::npos) {
       break;
     }
@@ -215,7 +215,7 @@ std::string StringUtils::replaceMap(std::string source_string, const std::map<st
     }
   }
 
-  std::sort(replacements.begin(), replacements.end(), [](const std::pair<size_t, std::pair<size_t, std::string>> a,
+  std::sort(replacements.begin(), replacements.end(), [](const std::pair<size_t, std::pair<size_t, std::string>> &a,
                                                          const std::pair<size_t, std::pair<size_t, std::string>> &b) {
     return a.first > b.first;
   });
@@ -315,10 +315,7 @@ bool StringUtils::from_hex(std::byte* data, size_t* data_length, std::string_vie
       }
     }
   }
-  if (found_first_nibble) {
-    return false;
-  }
-  return true;
+  return !found_first_nibble;
 }
 
 std::vector<std::byte> StringUtils::from_hex(std::string_view hex) {
@@ -479,9 +476,7 @@ std::string StringUtils::escapeUnprintableBytes(gsl::span<const std::byte> data)
   std::string result;
   for (auto byte : data) {
     char ch = static_cast<char>(byte);
-    if (std::isprint(static_cast<unsigned char>(ch))) {
-      result += ch;
-    } else if (ch == '\n') {
+    if (ch == '\n') {
       result += "\\n";
     } else if (ch == '\t') {
       result += "\\t";
@@ -491,6 +486,8 @@ std::string StringUtils::escapeUnprintableBytes(gsl::span<const std::byte> data)
       result += "\\v";
     } else if (ch == '\f') {
       result += "\\f";
+    } else if (std::isprint(static_cast<unsigned char>(byte))) {
+      result += ch;
     } else {
       result += "\\x";
       result += hex_digits[(std::to_integer<int>(byte) >> 4) & 0xf];
