@@ -25,15 +25,10 @@
 #include "utils/Literals.h"
 #include "utils/Searcher.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace utils {
-namespace file {
+namespace org::apache::nifi::minifi::utils::file {
 
 uint64_t computeChecksum(const std::string &file_name, uint64_t up_to_position) {
-  constexpr uint64_t BUFFER_SIZE = 4096u;
+  constexpr uint64_t BUFFER_SIZE = 4096U;
   std::array<char, std::size_t{BUFFER_SIZE}> buffer;
 
   std::ifstream stream{file_name, std::ios::in | std::ios::binary};
@@ -72,9 +67,7 @@ bool contains(const std::filesystem::path& file_path, std::string_view text_to_s
 }
 
 time_t to_time_t(std::filesystem::file_time_type file_time) {
-#if defined(WIN32)
-  return std::chrono::system_clock::to_time_t(to_sys(file_time));
-#elif defined(_LIBCPP_VERSION) && _LIBCPP_VERSION < 14000
+#if defined(_LIBCPP_VERSION) && _LIBCPP_VERSION < 14000
   return std::chrono::file_clock::to_time_t(file_time);
 #else
   return std::chrono::system_clock::to_time_t(to_sys(file_time));
@@ -82,9 +75,9 @@ time_t to_time_t(std::filesystem::file_time_type file_time) {
 }
 
 std::chrono::time_point<std::chrono::system_clock> to_sys(std::filesystem::file_time_type file_time) {
-#if defined(WIN32)
+#if defined(WIN32) || defined(_LIBCPP_VERSION) && _LIBCPP_VERSION >= 14000
   return std::chrono::time_point_cast<std::chrono::system_clock::duration>(file_time - std::filesystem::file_time_type::clock::now() + std::chrono::system_clock::now());
-#elif defined(_LIBCPP_VERSION) && _LIBCPP_VERSION < 14000
+#elif defined(_LIBCPP_VERSION)
   return std::chrono::system_clock::from_time_t(std::chrono::file_clock::to_time_t(file_time));
 #else
   return std::chrono::file_clock::to_sys(file_time);
@@ -98,9 +91,4 @@ void put_content(const std::filesystem::path& filename, std::string_view new_con
   ofs.write(new_contents.data(), gsl::narrow<std::streamsize>(new_contents.size()));
 }
 
-}  // namespace file
-}  // namespace utils
-}  // namespace minifi
-}  // namespace nifi
-}  // namespace apache
-}  // namespace org
+}  // namespace org::apache::nifi::minifi::utils::file
