@@ -17,4 +17,4 @@
  */
 
 #define CATCH_CONFIG_MAIN
-#include "catch.hpp"
+#include "Catch.h"
