@@ -54,7 +54,7 @@ class ReadCallback {
   ReadCallback& operator=(const ReadCallback&) = delete;
   ReadCallback& operator=(ReadCallback&&) = delete;
 
-  int64_t operator()(const std::shared_ptr<minifi::io::BaseStream>& stream) {
+  int64_t operator()(const std::shared_ptr<minifi::io::InputStream>& stream) {
     int64_t total_read = 0;
     do {
       const auto ret = stream->read(gsl::make_span(buffer_).subspan(read_size_));
@@ -94,7 +94,7 @@ class ReadCallback {
  * decompression test. Each such test controller should either be
  * CompressTestController or a DecompressTestController.
  */
-class CompressDecompressionTestController : public TestController{
+class CompressDecompressionTestController : public TestController {
  protected:
   static std::string tempDir_;
   static std::string raw_content_path_;
@@ -149,7 +149,7 @@ class CompressDecompressionTestController : public TestController{
     helper_session = std::make_shared<core::ProcessSession>(context);
   }
 
-  std::shared_ptr<core::FlowFile> importFlowFile(const std::string& content_path) {
+  [[nodiscard]] std::shared_ptr<core::FlowFile> importFlowFile(const std::string& content_path) const {
     std::shared_ptr<core::FlowFile> flow = std::static_pointer_cast<core::FlowFile>(helper_session->create());
     helper_session->import(content_path, flow, true, 0);
     helper_session->flushContent();
@@ -174,7 +174,7 @@ class CompressDecompressionTestController : public TestController{
     session->commit();
   }
 
-  void read(const std::shared_ptr<core::FlowFile>& file, ReadCallback& reader) {
+  void read(const std::shared_ptr<core::FlowFile>& file, ReadCallback& reader) const {
     helper_session->read(file, std::ref(reader));
   }
 
@@ -192,23 +192,21 @@ class CompressDecompressionTestController : public TestController{
     }
   };
 
-  std::string rawContentPath() const {
+  [[nodiscard]] static std::string rawContentPath() {
     return raw_content_path_;
   }
 
-  std::string compressedPath() const {
+  [[nodiscard]] static std::string compressedPath() {
     return compressed_content_path_;
   }
 
-  RawContent getRawContent() const {
+  [[nodiscard]] static RawContent getRawContent() {
     std::ifstream file;
     file.open(raw_content_path_, std::ios::binary);
     std::string contents{std::istreambuf_iterator<char>(file), std::istreambuf_iterator<char>()};
     return RawContent{std::move(contents)};
   }
 
-
-
   virtual ~CompressDecompressionTestController() = 0;
 
   std::shared_ptr<core::Processor> processor;
@@ -262,7 +260,7 @@ class DecompressTestController : public CompressDecompressionTestController{
   DecompressTestController() {
     setupFlow();
   }
-  ~DecompressTestController() {
+  ~DecompressTestController() override {
     tempDir_ = "";
     raw_content_path_ = "";
     compressed_content_path_ = "";
