@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
+#include <array>
 #include <fstream>
 #include <iostream>
 #include <map>
@@ -70,16 +70,16 @@ class FixedBuffer {
   explicit FixedBuffer(std::size_t capacity) : capacity_(capacity) {
     buf_.reset(new uint8_t[capacity_]);
   }
-  FixedBuffer(FixedBuffer&& other) : buf_(std::move(other.buf_)), size_(other.size_), capacity_(other.capacity_) {
+  FixedBuffer(FixedBuffer&& other) noexcept : buf_(std::move(other.buf_)), size_(other.size_), capacity_(other.capacity_) {
     other.size_ = 0;
     other.capacity_ = 0;
   }
-  std::size_t size() const { return size_; }
-  std::size_t capacity() const { return capacity_; }
-  uint8_t* begin() const { return buf_.get(); }
-  uint8_t* end() const { return buf_.get() + size_; }
+  [[nodiscard]] std::size_t size() const { return size_; }
+  [[nodiscard]] std::size_t capacity() const { return capacity_; }
+  [[nodiscard]] uint8_t* begin() const { return buf_.get(); }
+  [[nodiscard]] uint8_t* end() const { return buf_.get() + size_; }
 
-  std::string to_string() const {
+  [[nodiscard]] std::string to_string() const {
     return {begin(), end()};
   }
 
@@ -97,7 +97,7 @@ class FixedBuffer {
     } while (size_ != capacity_);
     return total_read;
   }
-  int64_t operator()(const std::shared_ptr<minifi::io::BaseStream>& stream) {
+  int64_t operator()(const std::shared_ptr<minifi::io::InputStream>& stream) {
     return write(*stream, capacity_);
   }
 
@@ -177,7 +177,7 @@ class MergeTestController : public TestController {
     input_->setDestinationUUID(processoruuid);
     merge_content_processor_->addConnection(input_.get());
 
-    merge_content_processor_->setAutoTerminatedRelationships({minifi::processors::MergeContent::Original, minifi::processors::MergeContent::Failure});
+    merge_content_processor_->setAutoTerminatedRelationships(std::array{minifi::processors::MergeContent::Original, minifi::processors::MergeContent::Failure});
 
     merge_content_processor_->incrementActiveTasks();
     merge_content_processor_->setScheduledState(core::ScheduledState::RUNNING);
@@ -680,7 +680,7 @@ TEST_CASE_METHOD(MergeTestController, "Test Merge File Attributes Keeping All Un
   REQUIRE(attributes["mime.type"] == "application/tar");
 }
 
-void writeString(const std::string& str, const std::shared_ptr<minifi::io::BaseStream>& out) {
+void writeString(const std::string& str, const std::shared_ptr<minifi::io::OutputStream>& out) {
   out->write(reinterpret_cast<const uint8_t*>(str.data()), str.length());
 }
 
@@ -822,3 +822,69 @@ TEST_CASE_METHOD(MergeTestController, "Batch Size", "[testMergeFileBatchSize]")
     REQUIRE(callback.to_string() == expected[1]);
   }
 }
+
+TEST_CASE_METHOD(MergeTestController, "Maximum Group Size is respected", "[testMergeFileMaximumGroupSize]") {
+  // each flowfile content is 32 bytes
+  for (auto& ff : flowFileContents_) {
+    REQUIRE(ff.length() == 32);
+  }
+  std::string expected[2]{
+      flowFileContents_[0] + flowFileContents_[1],
+      flowFileContents_[2] + flowFileContents_[3]
+  };
+
+  context_->setProperty(minifi::processors::MergeContent::MergeFormat, minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
+  context_->setProperty(minifi::processors::MergeContent::MergeStrategy, minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
+  context_->setProperty(minifi::processors::MergeContent::DelimiterStrategy, minifi::processors::merge_content_options::DELIMITER_STRATEGY_TEXT);
+  context_->setProperty(minifi::processors::BinFiles::BatchSize, "1000");
+
+  // we want a bit more than 2 flowfiles
+  context_->setProperty(minifi::processors::BinFiles::MinSize, "65");
+  context_->setProperty(minifi::processors::BinFiles::MaxSize, "65");
+
+  context_->setProperty(minifi::processors::BinFiles::MinEntries, "3");
+  context_->setProperty(minifi::processors::BinFiles::MaxEntries, "3");
+
+  core::ProcessSession sessionGenFlowFile(context_);
+  // enqueue 6 (six) flowFiles
+  for (const int i : {0, 1, 2, 3, 4, 5}) {
+    const auto flow = sessionGenFlowFile.create();
+    sessionGenFlowFile.writeBuffer(flow, flowFileContents_[i]);
+    sessionGenFlowFile.flushContent();
+    input_->put(flow);
+  }
+
+  REQUIRE(merge_content_processor_->getName() == "mergecontent");
+  auto factory = std::make_shared<core::ProcessSessionFactory>(context_);
+  merge_content_processor_->onSchedule(context_, factory);
+  // a single trigger is enough to process all five flowFiles
+  {
+    auto session = std::make_shared<core::ProcessSession>(context_);
+    merge_content_processor_->onTrigger(context_, session);
+    session->commit();
+  }
+  // validate the merge content
+  std::set<std::shared_ptr<core::FlowFile>> expiredFlowRecords;
+  std::shared_ptr<core::FlowFile> flow1 = output_->poll(expiredFlowRecords);
+  REQUIRE(expiredFlowRecords.empty());
+  REQUIRE(flow1);
+  {
+    FixedBuffer callback(gsl::narrow<size_t>(flow1->getSize()));
+    sessionGenFlowFile.read(flow1, std::ref(callback));
+    REQUIRE(callback.to_string() == expected[0]);
+  }
+
+  std::shared_ptr<core::FlowFile> flow2 = output_->poll(expiredFlowRecords);
+  REQUIRE(expiredFlowRecords.empty());
+  REQUIRE(flow2);
+  {
+    FixedBuffer callback(gsl::narrow<size_t>(flow2->getSize()));
+    sessionGenFlowFile.read(flow2, std::ref(callback));
+    REQUIRE(callback.to_string() == expected[1]);
+  }
+
+  // no more flowfiles
+  std::shared_ptr<core::FlowFile> flow3 = output_->poll(expiredFlowRecords);
+  REQUIRE(expiredFlowRecords.empty());
+  REQUIRE_FALSE(flow3);
+}
