@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <memory>
 
 #include "../TestBase.h"
