@@ -18,22 +18,21 @@
 
 #pragma once
 
-#include <unordered_map>
-#include <string>
 #include <memory>
 #include <random>
+#include <string>
+#include <unordered_map>
+#include <utility>
+
 #include <YamlConfiguration.h>
 #include "core/Processor.h"
 #include "TestBase.h"
 #include "Catch.h"
 #include "processors/GenerateFlowFile.h"
+#include "core/PropertyBuilder.h"
 #include "core/Resource.h"
 
-namespace org {
-namespace apache {
-namespace nifi {
-namespace minifi {
-namespace processors {
+namespace org::apache::nifi::minifi::processors {
 
 static core::Relationship Apple{"apple", ""};
 static core::Relationship Banana{"banana", ""};
@@ -50,11 +49,22 @@ class ProcessorWithStatistics {
 
 class TestProcessor : public core::Processor, public ProcessorWithStatistics {
  public:
-  TestProcessor(const std::string& name, const utils::Identifier& uuid) : Processor(name, uuid) {}
+  TestProcessor(std::string name, const utils::Identifier& uuid) : Processor(std::move(name), uuid) {}
   explicit TestProcessor(const std::string& name) : Processor(name) {}
+
+  static constexpr const char* Description = "Processor used for testing cycles";
+  static auto properties() { return std::array{AppleProbability, BananaProbability}; }
+  static auto relationships() { return std::array{Apple, Banana}; }
+  static constexpr bool SupportsDynamicProperties = false;
+  static constexpr bool SupportsDynamicRelationships = false;
+  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  static constexpr bool IsSingleThreaded = false;
+
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
+
   void initialize() override {
-    setSupportedProperties({AppleProbability, BananaProbability});
-    setSupportedRelationships({Apple, Banana});
+    setSupportedProperties(properties());
+    setSupportedRelationships(relationships());
   }
   void onTrigger(const std::shared_ptr<core::ProcessContext>& /*context*/, const std::shared_ptr<core::ProcessSession> &session) override {
     ++trigger_count;
@@ -93,9 +103,11 @@ class TestProcessor : public core::Processor, public ProcessorWithStatistics {
 
 class TestFlowFileGenerator : public processors::GenerateFlowFile, public ProcessorWithStatistics {
  public:
-  TestFlowFileGenerator(const std::string& name, const utils::Identifier& uuid) : GenerateFlowFile(name, uuid) {}
+  TestFlowFileGenerator(std::string name, const utils::Identifier& uuid) : GenerateFlowFile(std::move(name), uuid) {}
   explicit TestFlowFileGenerator(const std::string& name) : GenerateFlowFile(name) {}
 
+  static constexpr const char* Description = "Processor generating files and notifying us";
+
   using processors::GenerateFlowFile::onTrigger;
   void onTrigger(const std::shared_ptr<core::ProcessContext> &context, const std::shared_ptr<core::ProcessSession> &session) override {
     ++trigger_count;
@@ -106,11 +118,7 @@ class TestFlowFileGenerator : public processors::GenerateFlowFile, public Proces
   }
 };
 
-REGISTER_RESOURCE(TestProcessor, "Processor used for testing cycles");
-REGISTER_RESOURCE(TestFlowFileGenerator, "Processor generating files and notifying us");
+REGISTER_RESOURCE(TestProcessor, Processor);
+REGISTER_RESOURCE(TestFlowFileGenerator, Processor);
 
-} /* namespace processors */
-} /* namespace minifi */
-} /* namespace nifi */
-} /* namespace apache */
-} /* namespace org */
+}  // namespace org::apache::nifi::minifi::processors
