@@ -30,10 +30,22 @@
 #include "core/ProcessSession.h"
 #include "core/ProcessorNode.h"
 #include "core/Processor.h"
+#include "core/RepositoryFactory.h"
 #include "repository/VolatileContentRepository.h"
 
 namespace {
 
+class TestProcessor : public minifi::core::Processor {
+ public:
+  using Processor::Processor;
+
+  static constexpr bool SupportsDynamicProperties = false;
+  static constexpr bool SupportsDynamicRelationships = false;
+  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  static constexpr bool IsSingleThreaded = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
+};
+
 #ifdef WIN32
 const std::string SESSIONTEST_FLOWFILE_CHECKPOINT_DIR = ".\\sessiontest_flowfile_checkpoint";
 #else
@@ -57,7 +69,7 @@ TEST_CASE("Import null data") {
   config->set(minifi::Configure::nifi_dbcontent_repository_directory_default, utils::file::FileUtils::concat_path(dir, "content_repository"));
   config->set(minifi::Configure::nifi_flowfile_repository_directory_default, utils::file::FileUtils::concat_path(dir, "flowfile_repository"));
 
-  auto prov_repo = std::make_shared<core::Repository>();
+  std::shared_ptr<core::Repository> prov_repo = core::createRepository("nooprepository");
   std::shared_ptr<core::Repository> ff_repository = std::make_shared<core::repository::FlowFileRepository>("flowFileRepository", SESSIONTEST_FLOWFILE_CHECKPOINT_DIR);
   std::shared_ptr<core::ContentRepository> content_repo;
   SECTION("VolatileContentRepository") {
@@ -75,7 +87,7 @@ TEST_CASE("Import null data") {
   ff_repository->initialize(config);
   content_repo->initialize(config);
 
-  auto processor = std::make_shared<core::Processor>("dummy");
+  auto processor = std::make_shared<TestProcessor>("dummy");
   utils::Identifier uuid = processor->getUUID();
   auto output = std::make_unique<minifi::Connection>(ff_repository, content_repo, "output");
   output->addRelationship({"out", ""});
