@@ -93,7 +93,7 @@ class EventDriverScheduleErrorHandlingTests: public IntegrationBase {
         auto process_controller = dynamic_cast<org::apache::nifi::minifi::state::ProcessorController*>(&component);
         assert(process_controller != nullptr);
 
-        process_controller->getProcessor()->setSchedulingStrategy(org::apache::nifi::minifi::core::SchedulingStrategy::EVENT_DRIVEN);
+        process_controller->getProcessor().setSchedulingStrategy(org::apache::nifi::minifi::core::SchedulingStrategy::EVENT_DRIVEN);
       }
 
       ++controllerVecIdx;
@@ -114,7 +114,8 @@ class EventDriverScheduleErrorHandlingTests: public IntegrationBase {
 };
 
 int main(int argc, char **argv) {
-  std::string test_file_location, url;
+  std::string test_file_location;
+  std::string url;
   if (argc > 1) {
     test_file_location = argv[1];
   }
