@@ -101,7 +101,7 @@ class PersistableKeyValueStoreServiceTestsFixture {
     content_repo->initialize(configuration);
     stream_factory = minifi::io::StreamFactory::getInstance(configuration);
 
-    yaml_config = std::unique_ptr<core::YamlConfiguration>(new core::YamlConfiguration(test_repo, test_repo, content_repo, stream_factory, configuration, config_yaml));
+    yaml_config = std::make_unique<core::YamlConfiguration>(test_repo, test_repo, content_repo, stream_factory, configuration, config_yaml);
 
     process_group = yaml_config->getRoot();
     persistable_key_value_store_service_node = process_group->findControllerService("testcontroller");
