@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,7 +15,7 @@
  * limitations under the License.
  */
 
-#undef NDEBUG
+#include <array>
 #include <chrono>
 #include <memory>
 #include <string>
@@ -34,14 +33,26 @@
 #include "../../extensions/libarchive/MergeContent.h"
 #include "core/repository/VolatileFlowFileRepository.h"
 #include "../../extensions/rocksdb-repos/DatabaseContentRepository.h"
-#include "utils/gsl.h"
 #include "utils/IntegrationTestUtils.h"
 
 using Connection = minifi::Connection;
 using MergeContent = minifi::processors::MergeContent;
 
+using minifi::utils::verifyEventHappenedInPollTime;
+
 namespace {
 
+class TestProcessor : public minifi::core::Processor {
+ public:
+  using Processor::Processor;
+
+  static constexpr bool SupportsDynamicProperties = false;
+  static constexpr bool SupportsDynamicRelationships = false;
+  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  static constexpr bool IsSingleThreaded = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
+};
+
 #ifdef WIN32
 const std::string PERSISTENCETEST_FLOWFILE_CHECKPOINT_DIR = ".\\persistencetest_flowfile_checkpoint";
 #else
@@ -62,7 +73,7 @@ struct TestFlow{
 
     // setup INPUT processor
     {
-      inputProcessor = std::make_shared<core::Processor>("source", inputProcUUID());
+      inputProcessor = std::make_shared<TestProcessor>("source", inputProcUUID());
       auto node = std::make_shared<core::ProcessorNode>(inputProcessor.get());
       inputContext = std::make_shared<core::ProcessContext>(node, nullptr, prov_repo,
                                                             ff_repository, content_repo);
@@ -103,7 +114,7 @@ struct TestFlow{
     core::ProcessSession sessionGenFlowFile(inputContext);
     std::shared_ptr<core::FlowFile> flow = std::static_pointer_cast<core::FlowFile>(sessionGenFlowFile.create());
     sessionGenFlowFile.importFrom(stream, flow);
-    assert(flow->getResourceClaim()->getFlowFileRecordOwnedCount() == 1);
+    REQUIRE(flow->getResourceClaim()->getFlowFileRecordOwnedCount() == 1);
     sessionGenFlowFile.transfer(flow, {"input", "d"});
     sessionGenFlowFile.commit();
     return flow;
@@ -139,7 +150,7 @@ struct TestFlow{
 std::unique_ptr<MergeContent> setupMergeProcessor(const utils::Identifier& id) {
   auto processor = std::make_unique<MergeContent>("MergeContent", id);
   processor->initialize();
-  processor->setAutoTerminatedRelationships({{"original", "d"}});
+  processor->setAutoTerminatedRelationships(std::array{core::Relationship{"original", "d"}});
 
   processor->setProperty(MergeContent::MergeFormat, org::apache::nifi::minifi::processors::merge_content_options::MERGE_FORMAT_CONCAT_VALUE);
   processor->setProperty(MergeContent::MergeStrategy, org::apache::nifi::minifi::processors::merge_content_options::MERGE_STRATEGY_BIN_PACK);
@@ -167,8 +178,8 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
   config->set(minifi::Configure::nifi_dbcontent_repository_directory_default, utils::file::FileUtils::concat_path(dir, "content_repository"));
   config->set(minifi::Configure::nifi_flowfile_repository_directory_default, utils::file::FileUtils::concat_path(dir, "flowfile_repository"));
 
-  std::shared_ptr<core::Repository> prov_repo = std::make_shared<TestRepository>();
-  std::shared_ptr<core::repository::FlowFileRepository> ff_repository = std::make_shared<core::repository::FlowFileRepository>("flowFileRepository", PERSISTENCETEST_FLOWFILE_CHECKPOINT_DIR);
+  std::shared_ptr<core::Repository> prov_repo = std::make_shared<TestThreadedRepository>();
+  auto ff_repository = std::make_shared<core::repository::FlowFileRepository>("flowFileRepository", PERSISTENCETEST_FLOWFILE_CHECKPOINT_DIR);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::FileSystemRepository>();
   ff_repository->initialize(config);
   content_repo->initialize(config);
@@ -182,6 +193,7 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
 
     flowController->load(std::move(flow.root_));
     ff_repository->start();
+    REQUIRE(verifyEventHappenedInPollTime(std::chrono::seconds(1), [&ff_repository]{ return ff_repository->isRunning(); }));
 
     // write two files into the input
     flow.write("one");
@@ -210,10 +222,8 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
 
     flowController->load(std::move(flow.root_));
     ff_repository->start();
-    // wait for FlowFileRepository to start and notify the owners of
-    // the resurrected FlowFiles
-    using org::apache::nifi::minifi::utils::verifyEventHappenedInPollTime;
-    assert(verifyEventHappenedInPollTime(std::chrono::seconds(1), []{ return LogTestController::getInstance().countOccurrences("Found connection for") == 2; }, std::chrono::milliseconds(100)));
+    REQUIRE(verifyEventHappenedInPollTime(std::chrono::seconds(1), [&ff_repository]{ return ff_repository->isRunning(); }));
+    REQUIRE(verifyEventHappenedInPollTime(std::chrono::seconds(1), []{ return LogTestController::getInstance().countOccurrences("Found connection for") == 2; }));
 
     // write the third file into the input
     flow.write("three");
@@ -227,7 +237,7 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
       file = flow.output_->poll(expired);
       return file != nullptr;
     };
-    assert(verifyEventHappenedInPollTime(std::chrono::seconds(1), flowFileArrivedInOutput, std::chrono::milliseconds(50)));
+    REQUIRE(verifyEventHappenedInPollTime(std::chrono::seconds(1), flowFileArrivedInOutput, std::chrono::milliseconds(50)));
     REQUIRE(expired.empty());
 
     auto content = flow.read(file);
@@ -236,9 +246,16 @@ TEST_CASE("Processors Can Store FlowFiles", "[TestP1]") {
   }
 }
 
-class ContentUpdaterProcessor : public core::Processor{
+class ContentUpdaterProcessor : public core::Processor {
  public:
-  ContentUpdaterProcessor(const std::string& name, const utils::Identifier& id) : Processor(name, id) {}
+  ContentUpdaterProcessor(std::string name, const utils::Identifier& id) : Processor(std::move(name), id) {}
+
+  static constexpr bool SupportsDynamicProperties = false;
+  static constexpr bool SupportsDynamicRelationships = false;
+  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  static constexpr bool IsSingleThreaded = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
+
   void onTrigger(core::ProcessContext* /*context*/, core::ProcessSession *session) override {
     auto ff = session->get();
     std::string data = "<override>";
@@ -269,7 +286,7 @@ TEST_CASE("Persisted flowFiles are updated on modification", "[TestP1]") {
   config->set(minifi::Configure::nifi_dbcontent_repository_directory_default, utils::file::FileUtils::concat_path(dir, "content_repository"));
   config->set(minifi::Configure::nifi_flowfile_repository_directory_default, utils::file::FileUtils::concat_path(dir, "flowfile_repository"));
 
-  std::shared_ptr<core::Repository> prov_repo = std::make_shared<TestRepository>();
+  std::shared_ptr<core::Repository> prov_repo = std::make_shared<TestThreadedRepository>();
   std::shared_ptr<core::Repository> ff_repository = std::make_shared<core::repository::FlowFileRepository>("flowFileRepository", PERSISTENCETEST_FLOWFILE_CHECKPOINT_DIR);
   std::shared_ptr<core::ContentRepository> content_repo;
   SECTION("VolatileContentRepository") {
@@ -296,6 +313,7 @@ TEST_CASE("Persisted flowFiles are updated on modification", "[TestP1]") {
 
     flowController->load(std::move(flow.root_));
     ff_repository->start();
+    REQUIRE(verifyEventHappenedInPollTime(std::chrono::seconds(1), [&ff_repository]{ return ff_repository->isRunning(); }));
 
     std::string removedResource;
     {
@@ -332,17 +350,15 @@ TEST_CASE("Persisted flowFiles are updated on modification", "[TestP1]") {
 
     flowController->load(std::move(flow.root_));
     ff_repository->start();
-    // wait for FlowFileRepository to start and notify the owners of
-    // the resurrected FlowFiles
-    LogTestController::getInstance().contains("Found connection for");
+    REQUIRE(verifyEventHappenedInPollTime(std::chrono::seconds(1), [&ff_repository]{ return ff_repository->isRunning(); }));
+
     std::set<std::shared_ptr<core::FlowFile>> expired;
     std::shared_ptr<org::apache::nifi::minifi::core::FlowFile> file = nullptr;
-    using org::apache::nifi::minifi::utils::verifyEventHappenedInPollTime;
     const auto flowFileArrivedInOutput = [&file, &expired, &flow] {
       file = flow.output_->poll(expired);
       return file != nullptr;
     };
-    assert(verifyEventHappenedInPollTime(std::chrono::seconds(1), flowFileArrivedInOutput, std::chrono::milliseconds(50)));
+    REQUIRE(verifyEventHappenedInPollTime(std::chrono::seconds(1), flowFileArrivedInOutput, std::chrono::milliseconds(50)));
     REQUIRE(expired.empty());
 
     auto content = flow.read(file);
