@@ -45,11 +45,24 @@ const std::string REPOTEST_FLOWFILE_CHECKPOINT_DIR = ".\\repotest_flowfile_check
 const std::string REPOTEST_FLOWFILE_CHECKPOINT_DIR = "./repotest_flowfile_checkpoint";
 #endif
 
+namespace {
+class TestProcessor : public minifi::core::Processor {
+ public:
+  using Processor::Processor;
+
+  static constexpr bool SupportsDynamicProperties = false;
+  static constexpr bool SupportsDynamicRelationships = false;
+  static constexpr core::annotation::Input InputRequirement = core::annotation::Input::INPUT_ALLOWED;
+  static constexpr bool IsSingleThreaded = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
+};
+}  // namespace
+
 TEST_CASE("Test Repo Names", "[TestFFR1]") {
-  auto repoA = minifi::core::createRepository("FlowFileRepository", false, "flowfile");
+  auto repoA = minifi::core::createRepository("FlowFileRepository", "flowfile");
   REQUIRE("flowfile" == repoA->getName());
 
-  auto repoB = minifi::core::createRepository("ProvenanceRepository", false, "provenance");
+  auto repoB = minifi::core::createRepository("ProvenanceRepository", "provenance");
   REQUIRE("provenance" == repoB->getName());
 }
 
@@ -274,8 +287,8 @@ TEST_CASE("Test FlowFile Restore", "[TestFFR6]") {
   config->set(minifi::Configure::nifi_dbcontent_repository_directory_default, utils::file::FileUtils::concat_path(dir, "content_repository"));
   config->set(minifi::Configure::nifi_flowfile_repository_directory_default, utils::file::FileUtils::concat_path(dir, "flowfile_repository"));
 
-  std::shared_ptr<core::Repository> prov_repo = std::make_shared<TestRepository>();
-  std::shared_ptr<core::repository::FlowFileRepository> ff_repository = std::make_shared<core::repository::FlowFileRepository>("flowFileRepository", REPOTEST_FLOWFILE_CHECKPOINT_DIR);
+  std::shared_ptr<core::Repository> prov_repo = std::make_shared<TestThreadedRepository>();
+  auto ff_repository = std::make_shared<core::repository::FlowFileRepository>("flowFileRepository", REPOTEST_FLOWFILE_CHECKPOINT_DIR);
   std::shared_ptr<core::ContentRepository> content_repo = std::make_shared<core::repository::FileSystemRepository>();
   ff_repository->initialize(config);
   content_repo->initialize(config);
@@ -303,7 +316,7 @@ TEST_CASE("Test FlowFile Restore", "[TestFFR6]") {
    * which case the orphan FlowFiles are deleted.)
    */
   {
-    std::shared_ptr<core::Processor> processor = std::make_shared<core::Processor>("dummy");
+    std::shared_ptr<core::Processor> processor = std::make_shared<TestProcessor>("dummy");
     utils::Identifier uuid = processor->getUUID();
     REQUIRE(uuid);
     inputPtr->setSourceUUID(uuid);
@@ -353,7 +366,8 @@ TEST_CASE("Flush deleted flowfiles before shutdown", "[TestFFR7]") {
    public:
     explicit TestFlowFileRepository(const std::string& name)
         : core::SerializableComponent(name),
-          FlowFileRepository(name, REPOTEST_FLOWFILE_CHECKPOINT_DIR, FLOWFILE_REPOSITORY_DIRECTORY, 10min, MAX_FLOWFILE_REPOSITORY_STORAGE_SIZE, 1ms) {}
+          FlowFileRepository(name, REPOTEST_FLOWFILE_CHECKPOINT_DIR, core::repository::FLOWFILE_REPOSITORY_DIRECTORY,
+                             10min, core::repository::MAX_FLOWFILE_REPOSITORY_STORAGE_SIZE, 1ms) {}
     void flush() override {
       FlowFileRepository::flush();
       if (onFlush_) {
