@@ -1,5 +1,4 @@
 /**
- *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -17,33 +16,40 @@
  */
 #pragma once
 
-#include <set>
 #include <memory>
 #include <string>
+#include <utility>
 
 #include "core/controller/ControllerService.h"
 #include "core/Processor.h"
 #include "core/ProcessContext.h"
 #include "core/ProcessSession.h"
 
+namespace minifi = org::apache::nifi::minifi;
+
 std::atomic<bool> disabled;
 std::mutex control_mutex;
 
-class MockControllerService : public org::apache::nifi::minifi::core::controller::ControllerService {
+class MockControllerService : public minifi::core::controller::ControllerService {
  public:
-  explicit MockControllerService(const std::string &name, const org::apache::nifi::minifi::utils::Identifier &uuid)
-      : ControllerService(name, uuid) {
+  explicit MockControllerService(std::string name, const minifi::utils::Identifier &uuid)
+      : ControllerService(std::move(name), uuid) {
   }
 
-  explicit MockControllerService(const std::string &name)
-      : ControllerService(name) {
+  explicit MockControllerService(std::string name)
+      : ControllerService(std::move(name)) {
   }
   MockControllerService() = default;
 
-  ~MockControllerService() = default;
+  ~MockControllerService() override = default;
 
-  virtual void initialize() {
-    org::apache::nifi::minifi::core::controller::ControllerService::initialize();
+  static constexpr const char* Description = "An example service";
+  static auto properties() { return std::array<minifi::core::Property, 0>{}; }
+  static constexpr bool SupportsDynamicProperties = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_CONTROLLER_SERVICES
+
+  void initialize() override {
+    minifi::core::controller::ControllerService::initialize();
     enable();
   }
 
@@ -55,14 +61,14 @@ class MockControllerService : public org::apache::nifi::minifi::core::controller
     str = "pushitrealgood";
   }
 
-  void yield() {
+  void yield() override {
   }
 
-  bool isRunning() {
+  bool isRunning() override {
     return true;
   }
 
-  bool isWorkAvailable() {
+  bool isWorkAvailable() override {
     return true;
   }
 
@@ -70,33 +76,39 @@ class MockControllerService : public org::apache::nifi::minifi::core::controller
   std::string str;
 };
 
-class MockProcessor : public org::apache::nifi::minifi::core::Processor {
+class MockProcessor : public minifi::core::Processor {
  public:
-  explicit MockProcessor(const std::string &name, const org::apache::nifi::minifi::utils::Identifier &uuid)
-      : Processor(name, uuid) {
+  explicit MockProcessor(std::string name, const minifi::utils::Identifier &uuid)
+      : Processor(std::move(name), uuid) {
     setTriggerWhenEmpty(true);
   }
 
-  explicit MockProcessor(const std::string &name)
-      : Processor(name) {
+  explicit MockProcessor(std::string name)
+      : Processor(std::move(name)) {
     setTriggerWhenEmpty(true);
   }
 
-  ~MockProcessor() = default;
+  ~MockProcessor() override = default;
+
+  static constexpr const char* Description = "An example processor";
+  static inline const minifi::core::Property LinkedService{"linkedService", "Linked service"};
+  static auto properties() { return std::array{LinkedService}; }
+  static auto relationships() { return std::array<minifi::core::Relationship, 0>{}; }
+  static constexpr bool SupportsDynamicProperties = false;
+  static constexpr bool SupportsDynamicRelationships = false;
+  static constexpr minifi::core::annotation::Input InputRequirement = minifi::core::annotation::Input::INPUT_ALLOWED;
+  static constexpr bool IsSingleThreaded = false;
+  ADD_COMMON_VIRTUAL_FUNCTIONS_FOR_PROCESSORS
 
   void initialize() override {
-    org::apache::nifi::minifi::core::Property property("linkedService", "Linked service");
-    std::set<org::apache::nifi::minifi::core::Property> properties;
-    properties.insert(property);
-    setSupportedProperties(properties);
+    setSupportedProperties(properties());
   }
 
-  // OnTrigger method, implemented by NiFi Processor Designer
-  void onTrigger(org::apache::nifi::minifi::core::ProcessContext *context, org::apache::nifi::minifi::core::ProcessSession* /*session*/) override {
+  void onTrigger(minifi::core::ProcessContext *context, minifi::core::ProcessSession* /*session*/) override {
     std::string linked_service = "";
     getProperty("linkedService", linked_service);
     if (!IsNullOrEmpty(linked_service)) {
-      std::shared_ptr<org::apache::nifi::minifi::core::controller::ControllerService> service = context->getControllerService(linked_service);
+      std::shared_ptr<minifi::core::controller::ControllerService> service = context->getControllerService(linked_service);
       std::lock_guard<std::mutex> lock(control_mutex);
       if (!disabled.load()) {
         assert(true == context->isControllerServiceEnabled(linked_service));
