@@ -20,6 +20,7 @@
 #include <fstream>
 #include "utils/file/FileUtils.h"
 #include "TestBase.h"
+#include "Catch.h"
 #include "api/nanofi.h"
 
 const std::string test_file_content = "C API raNdOMcaSe test d4t4 th1s is!";
@@ -134,10 +135,8 @@ TEST_CASE("Set valid and invalid properties", "[setProcesssorProperties]") {
 TEST_CASE("get file and put file", "[getAndPutFile]") {
   TestController testController;
 
-  char src_format[] = "/tmp/gt.XXXXXX";
-  char put_format[] = "/tmp/pt.XXXXXX";
-  auto sourcedir = testController.createTempDirectory(src_format);
-  auto putfiledir = testController.createTempDirectory(put_format);
+  auto sourcedir = testController.createTempDirectory();
+  auto putfiledir = testController.createTempDirectory();
   auto instance = create_instance_obj();
   REQUIRE(instance != nullptr);
   flow *test_flow = create_new_flow(instance);
@@ -167,7 +166,7 @@ TEST_CASE("get file and put file", "[getAndPutFile]") {
 
   uint8_t* content = (uint8_t*)malloc(record->size* sizeof(uint8_t));
 
-  REQUIRE(get_content(record, content, record->size) == record->size);
+  REQUIRE(get_content(record, content, static_cast<int>(record->size)) == static_cast<int>(record->size));
 
   REQUIRE(test_file_content == std::string(reinterpret_cast<char*>(content), record->size));
 
@@ -183,8 +182,7 @@ TEST_CASE("get file and put file", "[getAndPutFile]") {
 TEST_CASE("Test manipulation of attributes", "[testAttributes]") {
   TestController testController;
 
-  char src_format[] = "/tmp/gt.XXXXXX";
-  auto sourcedir = testController.createTempDirectory(src_format);
+  auto sourcedir = testController.createTempDirectory();
 
   create_testfile_for_getfile(sourcedir.c_str());
 
@@ -234,7 +232,7 @@ TEST_CASE("Test manipulation of attributes", "[testAttributes]") {
   attr_set.size = attr_size;
   attr_set.attributes = (attribute*) malloc(attr_set.size * sizeof(attribute));  // NOLINT
 
-  REQUIRE(get_all_attributes(record, &attr_set) == attr_set.size);
+  REQUIRE(get_all_attributes(record, &attr_set) == static_cast<int>(attr_set.size));
 
   bool test_attr_found = false;
   bool updated_attr_found = false;
@@ -259,8 +257,7 @@ TEST_CASE("Test manipulation of attributes", "[testAttributes]") {
 
 TEST_CASE("Test error handling callback", "[errorHandling]") {
   TestController testController;
-  char src_format[] = "/tmp/gt.XXXXXX";
-  auto sourcedir = testController.createTempDirectory(src_format);
+  auto sourcedir = testController.createTempDirectory();
 
   auto instance = create_instance_obj();
   REQUIRE(instance != nullptr);
@@ -305,8 +302,7 @@ TEST_CASE("Test error handling callback", "[errorHandling]") {
 TEST_CASE("Test standalone processors", "[testStandalone]") {
   TestController testController;
 
-  char src_format[] = "/tmp/gt.XXXXXX";
-  auto sourcedir = testController.createTempDirectory(src_format);
+  auto sourcedir = testController.createTempDirectory();
 
   create_testfile_for_getfile(sourcedir.c_str());
 
@@ -353,10 +349,8 @@ TEST_CASE("Test standalone processors", "[testStandalone]") {
 TEST_CASE("Test interaction of flow and standlone processors", "[testStandaloneWithFlow]") {
   TestController testController;
 
-  char src_format[] = "/tmp/gt.XXXXXX";
-  char put_format[] = "/tmp/pt.XXXXXX";
-  auto sourcedir = testController.createTempDirectory(src_format);
-  auto putfiledir = testController.createTempDirectory(put_format);
+  auto sourcedir = testController.createTempDirectory();
+  auto putfiledir = testController.createTempDirectory();
 
   create_testfile_for_getfile(sourcedir.c_str());
 
@@ -398,8 +392,7 @@ TEST_CASE("Test standalone processors with file input", "[testStandaloneWithFile
   TestController testController;
 
   enable_logging();
-  char src_format[] = "/tmp/gt.XXXXXX";
-  auto sourcedir = testController.createTempDirectory(src_format);
+  auto sourcedir = testController.createTempDirectory();
   std::string path = create_testfile_for_getfile(sourcedir.c_str());
 
   standalone_processor* extract_test = create_processor("ExtractText", NULL);
@@ -424,8 +417,7 @@ TEST_CASE("Test standalone processors with file input", "[testStandaloneWithFile
 TEST_CASE("Test custom processor", "[TestCutomProcessor]") {
   TestController testController;
 
-  char src_format[] = "/tmp/gt.XXXXXX";
-  auto sourcedir = testController.createTempDirectory(src_format);
+  auto sourcedir = testController.createTempDirectory();
 
   create_testfile_for_getfile(sourcedir.c_str());
 
